@@ -5,15 +5,18 @@ import datetime
 from datetime import timedelta
 import hashlib
 
-from sqlalchemy import desc, select, update, func, text
+from sqlalchemy import desc, select, update, func, text, and_, delete
 from sqlalchemy.sql import exists
 
 from .models import FileAudit, FileUpdate, PermAudit, \
-        Activity, UserActivity, FileHistory
+        Activity, UserActivity, FileHistory, FileTrash
 
 
 logger = logging.getLogger('seafevents')
 
+USER_ACTIVITIES_GENERATE_LIMIT = 50
+
+
 class UserEventDetail(object):
     """Regular objects which can be used by seahub without worrying about ORM"""
     def __init__(self, org_id, user_name, event):
@@ -58,28 +61,76 @@ def _get_user_activities(session, username, start, limit):
     if limit <= 0:
         logger.error('limit must be positive')
         raise RuntimeError('limit must be positive')
+    
+    sub_query = (
+        select(UserActivity.activity_id)
+        .where(UserActivity.username == username)
+    )
 
-    stmt = select(Activity).where(
-        UserActivity.username == username,
-        UserActivity.activity_id == Activity.id).\
-        order_by(desc(UserActivity.timestamp)).\
-        slice(start, start + limit)
+    stmt = (
+        select(Activity)
+        .where(Activity.id.in_(sub_query))
+        .order_by(desc(Activity.timestamp))
+        .slice(start, start + limit)
+    )
     events = session.scalars(stmt).all()
 
     return [ UserActivityDetail(ev, username=username) for ev in events ]
 
+def _get_user_activities_by_op_user(session, username, op_user, start, limit):
+    if start < 0:
+        logger.error('start must be non-negative')
+        raise RuntimeError('start must be non-negative')
+
+    if limit <= 0:
+        logger.error('limit must be positive')
+        raise RuntimeError('limit must be positive')
+    
+    sub_query = (
+        select(UserActivity.activity_id)
+        .where(UserActivity.username == username)
+    )
+
+    stmt = (
+        select(Activity)
+        .where(Activity.id.in_(sub_query) & (Activity.op_user == op_user))
+        .order_by(desc(Activity.timestamp))
+        .slice(start, start + limit)
+    )
+    events = session.scalars(stmt).all()
+
+    return [ UserActivityDetail(ev, username=username) for ev in events ]
+
+
 def get_user_activities(session, username, start, limit):
     return _get_user_activities(session, username, start, limit)
 
+def get_user_activities_by_op_user(session, username, op_user, start, limit):
+    return _get_user_activities_by_op_user(session, username, op_user, start, limit)
+
 def _get_user_activities_by_timestamp(session, username, start, end):
     events = []
     try:
-        stmt = select(Activity).where(
-            UserActivity.username == username,
-            UserActivity.timestamp.between(start, end),
-            UserActivity.activity_id == Activity.id).\
-            order_by(UserActivity.timestamp)
-        events = session.scalars(stmt).all()
+        sub_query = (
+            select(UserActivity.activity_id)
+                .where(
+                    and_(
+                        UserActivity.username == username,
+                        UserActivity.timestamp.between(start, end)
+                    )
+                )
+        )
+
+        activity_ids = session.scalars(sub_query).all()
+
+        events = []
+        if activity_ids:
+            stmt = (
+                select(Activity)
+                    .where(Activity.id.in_(activity_ids))
+                    .order_by(Activity.timestamp)
+            )
+            events = session.scalars(stmt).all()
     except Exception as e:
         logging.warning('Failed to get activities of %s: %s.', username, e)
     finally:
@@ -214,11 +265,45 @@ def save_user_activity(session, record):
     activity = Activity(record)
     session.add(activity)
     session.commit()
-    for username in record['related_users']:
+    for username in record['related_users'][:USER_ACTIVITIES_GENERATE_LIMIT]:
         user_activity = UserActivity(username, activity.id, record['timestamp'])
         session.add(user_activity)
     session.commit()
 
+def save_repo_trash(session, record):
+    repo_trash = FileTrash(record)
+    session.add(repo_trash)
+    session.commit()
+
+def restore_repo_trash(session, record):
+    stmt = delete(FileTrash).where(FileTrash.repo_id == record['repo_id'], FileTrash.obj_name == record['obj_name'],
+                                    FileTrash.path == record['path'])
+    session.execute(stmt)
+    session.commit()
+
+def clean_up_repo_trash(session, repo_id, keep_days):
+    if keep_days == 0:
+        stmt = delete(FileTrash).where(FileTrash.repo_id == repo_id)
+        session.execute(stmt)
+        session.commit()
+    else:
+        _timestamp = datetime.datetime.now() - timedelta(days=keep_days)
+        stmt = delete(FileTrash).where(FileTrash.repo_id == repo_id, FileTrash.delete_time < _timestamp)
+        session.execute(stmt)
+        session.commit()
+        
+def clean_up_all_repo_trash(session, keep_days):
+    if keep_days == 0:
+        stmt = delete(FileTrash)
+        session.execute(stmt)
+        session.commit()
+    else:
+        _timestamp = datetime.datetime.now() - timedelta(days=keep_days)
+        stmt = delete(FileTrash).where(FileTrash.delete_time < _timestamp)
+        session.execute(stmt)
+        session.commit()
+
+
 def update_user_activity_timestamp(session, activity_id, record):
     activity_stmt = update(Activity).where(Activity.id == activity_id).\
         values(timestamp=record["timestamp"])
