@@ -11,33 +11,45 @@ from datetime import timedelta
 from os.path import splitext
 
 from django.core.cache import cache
-from sqlalchemy import select, text
+from sqlalchemy import select, text, desc, func
 import pymysql
 
 from seaserv import get_org_id_by_repo_id, seafile_api, get_commit
 from seafobj import CommitDiffer, commit_mgr, fs_mgr
 from seafobj.commit_differ import DiffEntry
 from seafevents.events.db import save_file_audit_event, save_file_update_event, \
-        save_perm_audit_event, save_user_activity, save_filehistory, update_user_activity_timestamp
+        save_perm_audit_event, save_user_activity, save_filehistory, update_user_activity_timestamp, \
+        save_repo_trash, restore_repo_trash
 from seafevents.app.config import TIME_ZONE
 from seafevents.utils import get_opt_from_conf_or_env
 from .change_file_path import ChangeFilePathHandler
-from .change_extended_props import ChangeExtendedPropsHandler
-from .models import Activity
+from .models import Activity, FileTrash
 from seafevents.batch_delete_files_notice.utils import get_deleted_files_count, save_deleted_files_msg
 from seafevents.batch_delete_files_notice.db import get_deleted_files_total_count, save_deleted_files_count
 
 recent_added_events = {'recent_added_events': []}
+EXCLUDED_PATHS = ['/_Internal', '/images/sdoc', '/images/auto-upload']
+
+def _check_ignored_path(path):
+    for p in EXCLUDED_PATHS:
+        if path.startswith(p):
+            return True
+    return False
 
 
 def RepoUpdateEventHandler(config, session, msg):
-    elements = msg['content'].split('\t')
-    if len(elements) != 3:
-        logging.warning("got bad message: %s", elements)
+    try:
+        elements = json.loads(msg['content'])
+    except:
+        logging.warning("got bad message: %s", msg)
         return
 
-    repo_id = elements[1]
-    commit_id = elements[2]
+    repo_id = elements.get('repo_id')
+    commit_id = elements.get('commit_id')
+
+    if not repo_id or not commit_id:
+        logging.warning("repo_id: %s, or commit_id: %s invalid.", repo_id, commit_id)
+        return
 
     commit = commit_mgr.load_commit(repo_id, 1, commit_id)
     if commit is None:
@@ -49,30 +61,24 @@ def RepoUpdateEventHandler(config, session, msg):
         parent = commit_mgr.load_commit(repo_id, commit.version, commit.parent_id)
 
         if parent is not None:
-            differ = CommitDiffer(repo_id, commit.version, parent.root_id, commit.root_id,
-                                  True, True)
-            added_files, deleted_files, added_dirs, deleted_dirs, modified_files,\
-                renamed_files, moved_files, renamed_dirs, moved_dirs = differ.diff()
+            description = commit.description
+            if description.startswith('Deleted') and 'more' in description:
+                differ = CommitDiffer(repo_id, commit.version, parent.root_id, commit.root_id, False, False)
+            else:
+                differ = CommitDiffer(repo_id, commit.version, parent.root_id, commit.root_id, True, True)
+            added_files, deleted_files, added_dirs, deleted_dirs, modified_files, \
+            renamed_files, moved_files, renamed_dirs, moved_dirs = differ.diff()
 
-            if renamed_files or renamed_dirs or moved_files or moved_dirs or deleted_files or deleted_dirs:
+            if renamed_files or renamed_dirs or moved_files or moved_dirs:
                 changer = ChangeFilePathHandler(session)
-                ex_props_changer = ChangeExtendedPropsHandler()
                 for r_file in renamed_files:
                     changer.update_db_records(repo_id, r_file.path, r_file.new_path, 0)
-                    ex_props_changer.change_file_ex_props(repo_id, r_file.path, r_file.new_path)
                 for r_dir in renamed_dirs:
                     changer.update_db_records(repo_id, r_dir.path, r_dir.new_path, 1)
-                    ex_props_changer.change_dir_ex_props(repo_id, r_dir.path, r_dir.new_path)
                 for m_file in moved_files:
                     changer.update_db_records(repo_id, m_file.path, m_file.new_path, 0)
-                    ex_props_changer.change_file_ex_props(repo_id, m_file.path, m_file.new_path)
                 for m_dir in moved_dirs:
                     changer.update_db_records(repo_id, m_dir.path, m_dir.new_path, 1)
-                    ex_props_changer.change_dir_ex_props(repo_id, m_dir.path, m_dir.new_path)
-                for d_file in deleted_files:
-                    ex_props_changer.delete_file_ex_props(repo_id, d_file.path)
-                for d_dir in deleted_dirs:
-                    ex_props_changer.delete_dir_ex_props(repo_id, d_dir.path)
 
             users = []
             org_id = get_org_id_by_repo_id(repo_id)
@@ -102,13 +108,13 @@ def RepoUpdateEventHandler(config, session, msg):
                                     parent, time)
                     save_file_histories(config, session, records)
 
-                records = generate_activity_records(added_files, deleted_files,
+                records, trash_records = generate_activity_records(added_files, deleted_files,
                         added_dirs, deleted_dirs, modified_files, renamed_files,
                         moved_files, renamed_dirs, moved_dirs, commit, repo_id,
                         parent, users, time)
 
                 save_user_activities(session, records)
-
+                save_repo_trashs(session, trash_records)
                 # save repo monitor recodes
                 records = generate_repo_monitor_records(repo_id, commit,
                                                         added_files, deleted_files,
@@ -118,6 +124,7 @@ def RepoUpdateEventHandler(config, session, msg):
                                                         modified_files)
                 save_message_to_user_notification(session, records)
 
+
             enable_collab_server = False
             if config.has_option('COLLAB_SERVER', 'enabled'):
                 enable_collab_server = config.getboolean('COLLAB_SERVER', 'enabled')
@@ -223,6 +230,8 @@ def generate_repo_monitor_records(repo_id, commit,
     #            'version': 1}}
 
     repo = seafile_api.get_repo(repo_id)
+    if repo.repo_type == 'wiki':
+        return []
     base_record = {
         'op_user': getattr(commit, 'creator_name', ''),
         'repo_id': repo_id,
@@ -244,7 +253,8 @@ def generate_repo_monitor_records(repo_id, commit,
         #  'path': '/3',
         #  'size': 0}
         for de in added_files:
-
+            if _check_ignored_path(de.path):
+                continue
             if commit.description.startswith('Reverted'):
                 op_type = OP_RECOVER
             else:
@@ -262,12 +272,12 @@ def generate_repo_monitor_records(repo_id, commit,
         records.append(added_files_record)
 
     if deleted_files:
-
         deleted_files_record = copy.copy(base_record)
         deleted_files_record["commit_diff"] = []
 
         for de in deleted_files:
-
+            if _check_ignored_path(de.path):
+                continue
             commit_diff = dict()
             commit_diff['op_type'] = OP_DELETE
             commit_diff['obj_type'] = OBJ_FILE
@@ -285,7 +295,8 @@ def generate_repo_monitor_records(repo_id, commit,
         added_dirs_record["commit_diff"] = []
 
         for de in added_dirs:
-
+            if _check_ignored_path(de.path):
+                continue
             if commit.description.startswith('Recovered'):
                 op_type = OP_RECOVER
             else:
@@ -307,7 +318,8 @@ def generate_repo_monitor_records(repo_id, commit,
         deleted_dirs_record["commit_diff"] = []
 
         for de in deleted_dirs:
-
+            if _check_ignored_path(de.path):
+                continue
             commit_diff = dict()
             commit_diff['op_type'] = OP_DELETE
             commit_diff['obj_type'] = OBJ_DIR
@@ -324,7 +336,8 @@ def generate_repo_monitor_records(repo_id, commit,
         renamed_files_record["commit_diff"] = []
 
         for de in renamed_files:
-
+            if _check_ignored_path(de.path):
+                continue
             commit_diff = dict()
             commit_diff['op_type'] = OP_RENAME
             commit_diff['obj_type'] = OBJ_FILE
@@ -343,7 +356,8 @@ def generate_repo_monitor_records(repo_id, commit,
         renamed_dirs_record["commit_diff"] = []
 
         for de in renamed_dirs:
-
+            if _check_ignored_path(de.path):
+                continue
             commit_diff = dict()
             commit_diff['op_type'] = OP_RENAME
             commit_diff['obj_type'] = OBJ_DIR
@@ -362,7 +376,8 @@ def generate_repo_monitor_records(repo_id, commit,
         moved_files_record["commit_diff"] = []
 
         for de in moved_files:
-
+            if _check_ignored_path(de.path):
+                continue
             commit_diff = dict()
             commit_diff['op_type'] = OP_MOVE
             commit_diff['obj_type'] = OBJ_FILE
@@ -381,7 +396,8 @@ def generate_repo_monitor_records(repo_id, commit,
         moved_dirs_record["commit_diff"] = []
 
         for de in moved_dirs:
-
+            if _check_ignored_path(de.path):
+                continue
             commit_diff = dict()
             commit_diff['op_type'] = OP_MOVE
             commit_diff['obj_type'] = OBJ_DIR
@@ -400,12 +416,12 @@ def generate_repo_monitor_records(repo_id, commit,
         modified_files_record["commit_diff"] = []
 
         for de in modified_files:
-
             if commit.description.startswith('Reverted'):
                 op_type = OP_RECOVER
             else:
                 op_type = OP_EDIT
-
+            if _check_ignored_path(de.path):
+                continue
             commit_diff = dict()
             commit_diff['op_type'] = op_type
             commit_diff['obj_type'] = OBJ_FILE
@@ -417,11 +433,19 @@ def generate_repo_monitor_records(repo_id, commit,
 
         records.append(modified_files_record)
 
-    return records
+    filtered_records = []
+    for record in records:
+        if len(record['commit_diff']) == 0:
+            continue
+        filtered_records.append(record)
+    return filtered_records
 
 
 def save_message_to_user_notification(session, records):
 
+    if not records:
+        return
+
     repo_id_monitor_users = {}
 
     for record in records:
@@ -540,6 +564,8 @@ def save_message_to_user_notification(session, records):
 
 
 def save_user_activities(session, records):
+    if not records:
+        return
     # If a file was edited many times by same user in 30 minutes, just update timestamp.
     if len(records) == 1 and records[0]['op_type'] == 'edit':
         record = records[0]
@@ -559,6 +585,36 @@ def save_user_activities(session, records):
         for record in records:
             save_user_activity(session, record)
 
+
+def save_repo_trashs(session, records):
+    for record in records:
+        if record['op_type'] == 'delete':
+            save_repo_trash(session, record)
+        if record['op_type'] == 'recover':
+            restore_repo_trash(session, record)
+
+
+def get_delete_records(session, repo_id, show_day, start, limit):
+    if show_day == 0:
+        return [], 0
+    elif show_day == -1:
+        stmt = select(FileTrash).where(FileTrash.repo_id == repo_id)
+        count_stmt = select(func.count(FileTrash.id)).where(FileTrash.repo_id == repo_id)
+
+    else:
+        _timestamp = datetime.datetime.now() - timedelta(days=show_day)
+        stmt = select(FileTrash).where(FileTrash.repo_id == repo_id,
+                                         FileTrash.delete_time > _timestamp,)
+        count_stmt = select(func.count(FileTrash.id)).where(FileTrash.repo_id == repo_id,
+                                                            FileTrash.delete_time > _timestamp,)
+
+    stmt = stmt.order_by(desc(FileTrash.delete_time))
+    total_count = session.scalar(count_stmt)
+    stmt = stmt.slice(start, start + limit)
+    res = session.scalars(stmt).all()
+
+    return res, total_count
+
 def generate_activity_records(added_files, deleted_files, added_dirs,
         deleted_dirs, modified_files, renamed_files, moved_files, renamed_dirs,
         moved_dirs, commit, repo_id, parent, related_users, time):
@@ -574,6 +630,9 @@ def generate_activity_records(added_files, deleted_files, added_dirs,
     OBJ_DIR = 'dir'
 
     repo = seafile_api.get_repo(repo_id)
+    if repo.repo_type == 'wiki':
+        return [], []
+
     base_record = {
         'commit_id': commit.commit_id,
         'timestamp': time,
@@ -582,13 +641,27 @@ def generate_activity_records(added_files, deleted_files, added_dirs,
         'op_user': getattr(commit, 'creator_name', ''),
         'repo_name': repo.repo_name
     }
+    base_trash_record = {
+        'commit_id': commit.parent_id,
+        'op_user': getattr(commit, 'creator_name', ''),
+        'timestamp': time,
+        'repo_id': repo_id,
+    }
     records = []
+    trash_records = []
 
     for de in added_files:
         record = copy.copy(base_record)
+        trash_record = copy.copy(base_trash_record)
         op_type = ''
         if commit.description.startswith('Reverted'):
             op_type = OP_RECOVER
+            trash_record['op_type'] = OP_RECOVER
+            trash_record['obj_id'] = de.obj_id
+            trash_record['obj_name'] = os.path.basename(de.path)
+            trash_record['path'] = '/' if os.path.dirname(de.path) == '/' else os.path.dirname(de.path) + '/'
+            trash_record['size'] = de.size
+            trash_records.append(trash_record)
         else:
             op_type = OP_CREATE
         record['op_type'] = op_type
@@ -607,11 +680,26 @@ def generate_activity_records(added_files, deleted_files, added_dirs,
         record['path'] = de.path
         records.append(record)
 
+        trash_record = copy.copy(base_trash_record)
+        trash_record['obj_type'] = 'file'
+        trash_record['op_type'] = OP_DELETE
+        trash_record['obj_id'] = de.obj_id
+        trash_record['obj_name'] = os.path.basename(de.path)
+        trash_record['path'] = '/' if os.path.dirname(de.path) == '/' else os.path.dirname(de.path) + '/'
+        trash_record['size'] = de.size
+        trash_records.append(trash_record)
     for de in added_dirs:
         record = copy.copy(base_record)
+        trash_record = copy.copy(base_trash_record)
         op_type = ''
         if commit.description.startswith('Recovered'):
             op_type = OP_RECOVER
+            trash_record['op_type'] = OP_RECOVER
+            trash_record['obj_id'] = de.obj_id
+            trash_record['obj_name'] = os.path.basename(de.path)
+            trash_record['path'] = '/' if os.path.dirname(de.path) == '/' else os.path.dirname(de.path) + '/'
+            trash_record['size'] = de.size
+            trash_records.append(trash_record)
         else:
             op_type = OP_CREATE
         record['op_type'] = op_type
@@ -628,6 +716,14 @@ def generate_activity_records(added_files, deleted_files, added_dirs,
         record['path'] = de.path
         records.append(record)
 
+        trash_record = copy.copy(base_trash_record)
+        trash_record['obj_type'] = 'dir'
+        trash_record['op_type'] = OP_DELETE
+        trash_record['obj_id'] = de.obj_id
+        trash_record['obj_name'] = os.path.basename(de.path)
+        trash_record['path'] = '/' if os.path.dirname(de.path) == '/' else os.path.dirname(de.path) + '/'
+        trash_record['size'] = de.size
+        trash_records.append(trash_record)
     for de in modified_files:
         record = copy.copy(base_record)
         op_type = ''
@@ -682,18 +778,19 @@ def generate_activity_records(added_files, deleted_files, added_dirs,
         record['old_path'] = de.path
         records.append(record)
 
+    filtered_records = []
     for record in records:
         if os.path.dirname(record['path']).startswith('/images/auto-upload'):
-            records.remove(record)
+            continue
         if os.path.dirname(record['path']).startswith('/images/sdoc'):
-            records.remove(record)
+            continue
         if os.path.dirname(record['path']).startswith('/_Internal'):
-            records.remove(record)
+            continue
         if 'old_path' in record:
             record['old_path'] = record['old_path'].rstrip('/')
         record['path'] = record['path'].rstrip('/') if record['path'] != '/' else '/'
-
-    return records
+        filtered_records.append(record)
+    return filtered_records, trash_records
 
 def list_file_in_dir(repo_id, dirents, op_type):
     _dirents = copy.copy(dirents)
@@ -830,13 +927,17 @@ def should_record(config, record):
 
 
 def FileUpdateEventHandler(config, session, msg):
-    elements = msg['content'].split('\t')
-    if len(elements) != 3:
-        logging.warning("got bad message: %s", elements)
+    try:
+        elements = json.loads(msg['content'])
+    except:
+        logging.warning("got bad message: %s", msg)
         return
 
-    repo_id = elements[1]
-    commit_id = elements[2]
+    repo_id = elements.get('repo_id')
+    commit_id = elements.get('commit_id')
+    if not repo_id or not commit_id:
+        logging.debug("repo_id: %s, or commit_id: %s invalid.", repo_id, commit_id)
+        return
 
     org_id = get_org_id_by_repo_id(repo_id)
 
@@ -850,23 +951,23 @@ def FileUpdateEventHandler(config, session, msg):
     creator_name = getattr(commit, 'creator_name', '')
     if creator_name is None:
         creator_name = ''
-
     save_file_update_event(session, time, creator_name, org_id,
                            repo_id, commit_id, commit.desc)
 
 def FileAuditEventHandler(config, session, msg):
-    elements = msg['content'].split('\t')
-    if len(elements) != 6:
-        logging.warning("got bad message: %s", elements)
+    try:
+        elements = json.loads(msg['content'])
+    except:
+        logging.warning("got bad message: %s", msg)
         return
 
     timestamp = datetime.datetime.utcfromtimestamp(msg['ctime'])
-    msg_type = elements[0]
-    user_name = elements[1]
-    ip = elements[2]
-    user_agent = elements[3]
-    repo_id = elements[4]
-    file_path = elements[5]
+    msg_type = elements.get('msg_type')
+    user_name = elements.get('user_name')
+    ip = elements.get('ip')
+    user_agent = elements.get('user_agent')
+    repo_id = elements.get('repo_id')
+    file_path = elements.get('file_path')
     if not file_path.startswith('/'):
         file_path = '/' + file_path
 
@@ -876,18 +977,19 @@ def FileAuditEventHandler(config, session, msg):
                           user_agent, org_id, repo_id, file_path)
 
 def PermAuditEventHandler(config, session, msg):
-    elements = msg['content'].split('\t')
-    if len(elements) != 7:
-        logging.warning("got bad message: %s", elements)
+    try:
+        elements = json.loads(msg['content'])
+    except:
+        logging.warning("got bad message: %s", msg)
         return
 
     timestamp = datetime.datetime.utcfromtimestamp(msg['ctime'])
-    etype = elements[1]
-    from_user = elements[2]
-    to = elements[3]
-    repo_id = elements[4]
-    file_path = elements[5]
-    perm = elements[6]
+    etype = elements.get('etype')
+    from_user = elements.get('from_user')
+    to = elements.get('to')
+    repo_id = elements.get('repo_id')
+    file_path = elements.get('file_path')
+    perm = elements.get('perm')
 
     org_id = get_org_id_by_repo_id(repo_id)
 
@@ -895,43 +997,6 @@ def PermAuditEventHandler(config, session, msg):
                           org_id, repo_id, file_path, perm)
 
 
-def DraftPublishEventHandler(config, session, msg):
-
-    elements = msg['content'].split('\t')
-    if len(elements) != 6:
-        logging.warning("got bad message: %s", elements)
-        return
-
-    record = dict()
-    record["timestamp"] = datetime.datetime.utcfromtimestamp(msg['ctime'])
-    record["op_type"] = elements[0]
-    record["obj_type"] = elements[1]
-    record["repo_id"] = elements[2]
-    repo = seafile_api.get_repo(elements[2])
-    record["repo_name"] = repo.name if repo else ''
-    record["op_user"] = elements[3]
-    record["path"] = elements[4]
-    record["old_path"] = elements[5]
-
-    users = []
-    org_id = get_org_id_by_repo_id(elements[2])
-    if org_id > 0:
-        users.extend(seafile_api.org_get_shared_users_by_repo(org_id, elements[2]))
-        owner = seafile_api.get_org_repo_owner(elements[2])
-    else:
-        users.extend(seafile_api.get_shared_users_by_repo(elements[2]))
-        owner = seafile_api.get_repo_owner(elements[2])
-
-    if owner not in users:
-        users = users + [owner]
-    if not users:
-        return
-
-    record["related_users"] = users
-
-    save_user_activity(session, record)
-
-
 def register_handlers(handlers, enable_audit):
     handlers.add_handler('seaf_server.event:repo-update', RepoUpdateEventHandler)
     if enable_audit:
@@ -944,4 +1009,3 @@ def register_handlers(handlers, enable_audit):
         handlers.add_handler('seahub.audit:file-download-api', FileAuditEventHandler)
         handlers.add_handler('seahub.audit:file-download-share-link', FileAuditEventHandler)
         handlers.add_handler('seahub.audit:perm-change', PermAuditEventHandler)
-        handlers.add_handler('seahub.draft:publish', DraftPublishEventHandler)
