@@ -1,9 +1,11 @@
 from .db import init_db_session_class
 from .statistics.db import *
 from .events.db import *
+from .events.handlers import get_delete_records
 from .content_scanner.db import *
 from .virus_scanner.db_oper import *
-from .app.config import is_repo_auto_del_enabled, is_search_enabled, is_audit_enabled
+from .app.config import is_repo_auto_del_enabled, is_search_enabled, is_audit_enabled, \
+    is_seasearch_enabled
 
 
 def is_pro():
