@@ -11,7 +11,7 @@ class VirusScanner(object):
         self.settings = Settings(config, seafile_config)
 
     def is_enabled(self):
-        return False
+        return self.settings.is_enabled()
 
     def start(self):
         if not self.is_enabled():
