@@ -13,15 +13,15 @@ from seafevents.app.config import get_config
 
 if __name__ == "__main__":
     kw = {
-        'format': '[%(asctime)s] [%(levelname)s] %(message)s',
-        'datefmt': '%m/%d/%Y %H:%M:%S',
-        'level': logging.DEBUG,
+        'format': '[seafevents] [%(asctime)s] [%(levelname)s] %(name)s:%(lineno)s %(funcName)s %(message)s',
+        'datefmt': '%Y-%m-%d %H:%M:%S',
+        'level': logging.INFO,
         'stream': sys.stdout
     }
     logging.basicConfig(**kw)
 
     from seafevents.virus_scanner.scan_settings import logger
-    logger.setLevel(logging.DEBUG)
+    logger.setLevel(logging.INFO)
 
     parser = argparse.ArgumentParser()
     parser.add_argument('-c', '--config-file',
