@@ -6,13 +6,13 @@ class SeafServerThreadedRpcClient(NamedPipeClient):
         NamedPipeClient.__init__(self, pipe_path, "seafserv-threaded-rpcserver")
 
     # repo manipulation
-    @searpc_func("string", ["string", "string", "string", "string", "int"])
-    def seafile_create_repo(name, desc, owner_email, passwd, enc_version):
+    @searpc_func("string", ["string", "string", "string", "string", "int", "string", "string"])
+    def seafile_create_repo(name, desc, owner_email, passwd, enc_version, pwd_hash_algo, pwd_hash_params):
         pass
     create_repo = seafile_create_repo
 
-    @searpc_func("string", ["string", "string", "string", "string", "string", "string", "string", "int"])
-    def seafile_create_enc_repo(repo_id, name, desc, owner_email, magic, random_key, salt, enc_version):
+    @searpc_func("string", ["string", "string", "string", "string", "string", "string", "string", "int", "string", "string", "string"])
+    def seafile_create_enc_repo(repo_id, name, desc, owner_email, magic, random_key, salt, enc_version, pwd_hash, pwd_hash_algo, pwd_hash_params):
         pass
     create_enc_repo = seafile_create_enc_repo
 
@@ -126,6 +126,11 @@ class SeafServerThreadedRpcClient(NamedPipeClient):
         pass
     del_file = seafile_del_file
 
+    @searpc_func("int", ["string", "string", "string"])
+    def seafile_batch_del_files(repo_id, filepaths, user):
+        pass
+    batch_del_files = seafile_batch_del_files
+
     @searpc_func("object", ["string", "string", "string", "string", "string", "string", "string", "int", "int"])
     def seafile_copy_file(src_repo, src_dir, src_filename, dst_repo, dst_dir, dst_filename, user, need_progress, synchronous):
         pass
@@ -607,6 +612,10 @@ class SeafServerThreadedRpcClient(NamedPipeClient):
     def get_repo_history_limit(repo_id):
         pass
 
+    @searpc_func("int", ["string", "int64"])
+    def set_repo_valid_since(repo_id, timestamp):
+        pass
+
     # virtual repo
     @searpc_func("string", ["string", "string", "string", "string", "string", "string"])
     def create_virtual_repo(origin_repo_id, path, repo_name, repo_desc, owner, passwd=''):
