@@ -86,11 +86,11 @@ class SeafileAPI(object):
 
     # repo manipulation
 
-    def create_repo(self, name, desc, username, passwd=None, enc_version=2, storage_id=None):
-        return seafserv_threaded_rpc.create_repo(name, desc, username, passwd, enc_version)
+    def create_repo(self, name, desc, username, passwd=None, enc_version=2, storage_id=None, pwd_hash_algo=None, pwd_hash_params=None):
+        return seafserv_threaded_rpc.create_repo(name, desc, username, passwd, enc_version, pwd_hash_algo, pwd_hash_params)
 
-    def create_enc_repo(self, repo_id, name, desc, username, magic, random_key, salt, enc_version):
-        return seafserv_threaded_rpc.create_enc_repo(repo_id, name, desc, username, magic, random_key, salt, enc_version)
+    def create_enc_repo(self, repo_id, name, desc, username, magic, random_key, salt, enc_version, pwd_hash=None, pwd_hash_algo=None, pwd_hash_params=None):
+        return seafserv_threaded_rpc.create_enc_repo(repo_id, name, desc, username, magic, random_key, salt, enc_version, pwd_hash, pwd_hash_algo, pwd_hash_params)
 
     def get_repos_by_id_prefix(self, id_prefix, start=-1, limit=-1):
         """
@@ -295,15 +295,17 @@ class SeafileAPI(object):
                                               filename, username, head_id)
 
     '''
-    If you want to delete multiple files in a batch, @filename should be in
-    the following format: 'filename1\tfilename2\tfilename3'
+    If you want to delete multiple files in a batch, @filename should be json array
     '''
     def del_file(self, repo_id, parent_dir, filename, username):
         return seafserv_threaded_rpc.del_file(repo_id, parent_dir, filename, username)
 
+    def batch_del_files(self, repo_id, filepaths, username):
+        return seafserv_threaded_rpc.batch_del_files(repo_id, filepaths, username)
+
     '''
     If you want to move or copy multiple files in a batch, @src_filename and @dst_filename
-    should be in the following format: 'filename1\tfilename2\tfilename3',make sure the number of files
+    should be json array, make sure the number of files
     in @src_filename and @dst_filename parameters match
     '''
     def copy_file(self, src_repo, src_dir, src_filename, dst_repo,
@@ -397,6 +399,9 @@ class SeafileAPI(object):
         """
         return seafserv_threaded_rpc.set_repo_history_limit(repo_id, days)
 
+    def set_repo_valid_since(self, repo_id, timestamp):
+        return seafserv_threaded_rpc.set_repo_valid_since(repo_id, timestamp)
+
     def check_repo_blocks_missing(self, repo_id, blklist):
         return seafserv_threaded_rpc.check_repo_blocks_missing(repo_id, blklist)
 
@@ -859,7 +864,7 @@ class SeafileAPI(object):
 
     def search_files_by_path (self, repo_id, path, search_str):
         return seafserv_threaded_rpc.search_files_by_path(repo_id, path, search_str)
-    
+
 seafile_api = SeafileAPI()
 
 class CcnetAPI(object):
