@@ -90,6 +90,24 @@ const hasJsxRuntime = (() => {
   }
 })();
 
+// Load third-party packages on demand
+const excludedChunkNames = [
+  'sharedFileViewAudio',
+  'sharedFileViewVideo',
+  'fileView',
+  'viewFileSdoc',
+  'sharedFileViewSdoc',
+  'sdocPublishedRevision',
+  'sdocFileHistory',
+  'wiki2',
+  'sharedFileViewText',
+  'viewFileText',
+  'sharedFileViewMarkdown',
+  'markdownEditor',
+  'plainMarkdownEditor',
+  'tldrawEditor',
+];
+
 // This is the production and development configuration.
 // It is focused on developer experience, fast rebuilds, and a minimal bundle.
 module.exports = function (webpackEnv) {
@@ -298,7 +316,9 @@ module.exports = function (webpackEnv) {
       // https://twitter.com/wSokra/status/969633336732905474
       // https://medium.com/webpack/webpack-4-code-splitting-chunk-graph-and-the-splitchunks-optimization-be739a861366
       splitChunks: {
-        chunks: 'all',
+        chunks(chunk) {
+          return !excludedChunkNames.includes(chunk.name);
+        },
         automaticNameDelimiter: '-',
         cacheGroups: {
           default: false,
@@ -309,7 +329,7 @@ module.exports = function (webpackEnv) {
             priority: 30000,
             reuseExistingChunk: true,
           },
-        }
+        },
       },
       // Keep the runtime chunk separated to enable long term caching
       // https://twitter.com/wSokra/status/969679223278505985
@@ -317,6 +337,7 @@ module.exports = function (webpackEnv) {
       runtimeChunk: {
         name: 'runtime',
       },
+      // concatenateModules: false,
     },
     resolve: {
       // This allows you to set a fallback for where webpack should look for modules.
@@ -336,6 +357,7 @@ module.exports = function (webpackEnv) {
         .map(ext => `.${ext}`)
         .filter(ext => useTypeScript || !ext.includes('ts')),
       alias: {
+        '@': path.resolve(process.cwd(), 'src'),
         // Support React Native Web
         // https://www.smashingmagazine.com/2016/08/a-glimpse-into-the-future-with-react-native-for-web/
         'react-native': 'react-native-web',
@@ -577,7 +599,7 @@ module.exports = function (webpackEnv) {
                   loader: 'svg-sprite-loader', options: {}
                 },
                 { loader: 'svgo-loader', options: {
-                  plugins:[
+                  plugins: [
                     'removeTitle',
                     'removeStyleElement',
                     'cleanupIDs',
@@ -598,7 +620,7 @@ module.exports = function (webpackEnv) {
               // its runtime that would otherwise be processed through "file" loader.
               // Also exclude `html` and `json` extensions so they get processed
               // by webpacks internal loaders.
-              exclude: [/^$/, /\.(js|mjs|jsx|ts|tsx)$/, /\.html$/, /\.json$/],
+              exclude: [/^$/, /\.(js|cjs|mjs|jsx|ts|tsx)$/, /\.html$/, /\.json$/, /axios/],
               type: 'asset/resource',
             },
             // ** STOP ** Are you adding a new loader?
@@ -711,10 +733,10 @@ module.exports = function (webpackEnv) {
       // solution that requires the user to opt into importing specific locales.
       // https://github.com/jmblog/how-to-optimize-momentjs-with-webpack
       // You can remove this if you don't use Moment.js:
-      new webpack.IgnorePlugin({
-        resourceRegExp: /^\.\/locale$/,
-        contextRegExp: /moment$/,
-      }),
+      // new webpack.IgnorePlugin({
+      //   resourceRegExp: /^\.\/locale$/,
+      //   contextRegExp: /moment$/,
+      // }),
       new webpack.ContextReplacementPlugin(/moment[\/\\]locale$/, /zh-cn|zh-tw|en|cs|nl_NL|fi|fr|de|hu|it|ko|lv|pl|ru|es|es_MX|sv/),
       // Generate a service worker script that will precache, and keep up to date,
       // the HTML & assets that are part of the webpack build.
