@@ -1,6 +1,7 @@
 import React from 'react';
 import PropTypes from 'prop-types';
-import moment from 'moment';
+import dayjs from 'dayjs';
+import relativeTime from 'dayjs/plugin/relativeTime';
 import { gettext, siteRoot } from '../../utils/constants';
 import { Utils } from '../../utils/utils';
 
@@ -15,14 +16,20 @@ const MSG_TYPE_REPO_SHARE = 'repo_share';
 const MSG_TYPE_REPO_SHARE_TO_GROUP = 'repo_share_to_group';
 const MSG_TYPE_REPO_TRANSFER = 'repo_transfer';
 const MSG_TYPE_FILE_UPLOADED = 'file_uploaded';
-const MSG_TYPE_DRAFT_REVIEWER = 'draft_reviewer';
+const MSG_TYPE_FOLDER_UPLOADED = 'folder_uploaded';
 // const MSG_TYPE_GUEST_INVITATION_ACCEPTED = 'guest_invitation_accepted';
 const MSG_TYPE_REPO_MONITOR = 'repo_monitor';
 const MSG_TYPE_DELETED_FILES = 'deleted_files';
+const MSG_TYPE_SAML_SSO_FAILED = 'saml_sso_failed';
+const MSG_TYPE_REPO_SHARE_PERM_CHANGE = 'repo_share_perm_change';
+const MSG_TYPE_REPO_SHARE_PERM_DELETE = 'repo_share_perm_delete';
+const MSG_TYPE_FACE_CLUSTER = 'face_cluster';
+
+dayjs.extend(relativeTime);
 
 class NoticeItem extends React.Component {
 
-  generatorNoticeInfo () {
+  generatorNoticeInfo() {
     let noticeItem = this.props.noticeItem;
     let noticeType = noticeItem.type;
     let detail = noticeItem.detail;
@@ -34,18 +41,17 @@ class NoticeItem extends React.Component {
       let groupStaff = detail.group_staff_name;
 
       // group name does not support special characters
-      let userHref = siteRoot + 'profile/' + detail.group_staff_email + '/';
+      let userHref = siteRoot + 'profile/' + encodeURIComponent(detail.group_staff_email) + '/';
       let groupHref = siteRoot + 'group/' + detail.group_id + '/';
       let groupName = detail.group_name;
 
       let notice = gettext('User {user_link} has added you to {group_link}');
-      let userLink = '<a href=' + userHref + '>' + groupStaff + '</a>';
-      let groupLink = '<a href=' + groupHref + '>' + groupName + '</a>';
-
+      let userLink = '<a href=' + userHref + '>' + Utils.HTMLescape(groupStaff) + '</a>';
+      let groupLink = '<a href=' + groupHref + '>' + Utils.HTMLescape(groupName) + '</a>';
       notice = notice.replace('{user_link}', userLink);
       notice = notice.replace('{group_link}', groupLink);
 
-      return {avatar_url, notice};
+      return { avatar_url, notice };
     }
 
     if (noticeType === MSG_TYPE_REPO_SHARE) {
@@ -55,7 +61,7 @@ class NoticeItem extends React.Component {
       let shareFrom = detail.share_from_user_name;
 
       let repoName = detail.repo_name;
-      let repoUrl = siteRoot + 'library/' + detail.repo_id + '/' +  repoName + '/';
+      let repoUrl = siteRoot + 'library/' + detail.repo_id + '/' + repoName + '/';
 
       let path = detail.path;
       let notice = '';
@@ -75,7 +81,57 @@ class NoticeItem extends React.Component {
       notice = notice.replace('{tagA}', `<a href='${Utils.encodePath(repoUrl)}'>`);
       notice = notice.replace('{/tagA}', '</a>');
 
-      return {avatar_url, notice};
+      return { avatar_url, notice };
+    }
+
+    if (noticeType === MSG_TYPE_REPO_SHARE_PERM_CHANGE) {
+
+      let avatar_url = detail.share_from_user_avatar_url;
+      let shareFrom = detail.share_from_user_name;
+      let permission = detail.permission;
+      let repoName = detail.repo_name;
+      let repoUrl = siteRoot + 'library/' + detail.repo_id + '/' + repoName + '/';
+      let path = detail.path;
+      let notice = '';
+      // 1. handle translate
+      if (path === '/') { // share repo
+        notice = gettext('{share_from} has changed the permission of library {repo_link} to {permission}.');
+      } else { // share folder
+        notice = gettext('{share_from} has changed the permission of folder {repo_link} to {permission}.');
+      }
+
+      // 2. handle xss(cross-site scripting)
+      notice = notice.replace('{share_from}', shareFrom);
+      notice = notice.replace('{repo_link}', `{tagA}${repoName}{/tagA}`);
+      notice = notice.replace('{permission}', permission);
+      notice = Utils.HTMLescape(notice);
+
+      // 3. add jump link
+      notice = notice.replace('{tagA}', `<a href='${Utils.encodePath(repoUrl)}'>`);
+      notice = notice.replace('{/tagA}', '</a>');
+
+      return { avatar_url, notice };
+    }
+
+    if (noticeType === MSG_TYPE_REPO_SHARE_PERM_DELETE) {
+
+      let avatar_url = detail.share_from_user_avatar_url;
+      let shareFrom = detail.share_from_user_name;
+      let repoName = detail.repo_name;
+      let path = detail.path;
+      let notice = '';
+      // 1. handle translate
+      if (path === '/') { // share repo
+        notice = gettext('{share_from} has cancelled the sharing of library {repo_name}.');
+      } else { // share folder
+        notice = gettext('{share_from} has cancelled the sharing of folder {repo_name}.');
+      }
+
+      // 2. handle xss(cross-site scripting)
+      notice = notice.replace('{share_from}', shareFrom);
+      notice = notice.replace('{repo_name}', repoName);
+      notice = Utils.HTMLescape(notice);
+      return { avatar_url, notice };
     }
 
     if (noticeType === MSG_TYPE_REPO_SHARE_TO_GROUP) {
@@ -94,9 +150,9 @@ class NoticeItem extends React.Component {
       let notice = '';
       // 1. handle translate
       if (path === '/') {
-        notice =  gettext('{share_from} has shared a library named {repo_link} to group {group_link}.');
+        notice = gettext('{share_from} has shared a library named {repo_link} to group {group_link}.');
       } else {
-        notice =  gettext('{share_from} has shared a folder named {repo_link} to group {group_link}.');
+        notice = gettext('{share_from} has shared a folder named {repo_link} to group {group_link}.');
       }
 
       // 2. handle xss(cross-site scripting)
@@ -110,7 +166,7 @@ class NoticeItem extends React.Component {
       notice = notice.replace('{/tagA}', '</a>');
       notice = notice.replace('{tagB}', `<a href='${Utils.encodePath(groupUrl)}'>`);
       notice = notice.replace('{/tagB}', '</a>');
-      return {avatar_url, notice};
+      return { avatar_url, notice };
     }
 
     if (noticeType === MSG_TYPE_REPO_TRANSFER) {
@@ -132,7 +188,7 @@ class NoticeItem extends React.Component {
       // 3. add jump link
       notice = notice.replace('{tagA}', `<a href=${Utils.encodePath(repoUrl)}>`);
       notice = notice.replace('{/tagA}', '</a>');
-      return {avatar_url, notice};
+      return { avatar_url, notice };
     }
 
     if (noticeType === MSG_TYPE_FILE_UPLOADED) {
@@ -159,30 +215,46 @@ class NoticeItem extends React.Component {
         notice = notice.replace('{/tagB}', '</a>');
       } else {
         // 1. handle translate
-        notice = gettext('A file named {upload_file_link} is uploaded to {uploaded_link}.');
+        notice = gettext('A file named {upload_file_link} is uploaded.');
 
         // 2. handle xss(cross-site scripting)
         notice = notice.replace('{upload_file_link}', `${fileName}`);
         notice = Utils.HTMLescape(notice);
-        notice = notice.replace('{uploaded_link}', '<strong>Deleted Library</strong>');
       }
-      return {avatar_url, notice};
+      return { avatar_url, notice };
     }
 
-    if (noticeType === MSG_TYPE_DRAFT_REVIEWER) {
+    if (noticeType === MSG_TYPE_FOLDER_UPLOADED) {
+      let avatar_url = detail.uploaded_user_avatar_url;
+      let folderName = detail.folder_name;
+      let folderLink = siteRoot + 'library/' + detail.repo_id + '/' + detail.repo_name + detail.folder_path;
 
-      let avatar_url = detail.request_user_avatat_url;
+      let parentDirName = detail.parent_dir_name;
+      let parentDirLink = siteRoot + 'library/' + detail.repo_id + '/' + detail.repo_name + detail.parent_dir_path;
+      let notice = '';
+      if (detail.repo_id) { // todo is repo exist ?
+        // 1. handle translate
+        notice = gettext('A folder named {upload_folder_link} is uploaded to {uploaded_link}.');
 
-      let fromUser = detail.request_user_name;
+        // 2. handle xss(cross-site scripting)
+        notice = notice.replace('{upload_folder_link}', `{tagA}${folderName}{/tagA}`);
+        notice = notice.replace('{uploaded_link}', `{tagB}${parentDirName}{/tagB}`);
+        notice = Utils.HTMLescape(notice);
 
-      let draftId = detail.draft_id;
-      let draftUrl = siteRoot + 'drafts/' + draftId + '/';
+        // 3. add jump link
+        notice = notice.replace('{tagA}', `<a href=${Utils.encodePath(folderLink)}>`);
+        notice = notice.replace('{/tagA}', '</a>');
+        notice = notice.replace('{tagB}', `<a href=${Utils.encodePath(parentDirLink)}>`);
+        notice = notice.replace('{/tagB}', '</a>');
+      } else {
+        // 1. handle translate
+        notice = gettext('A folder named {upload_folder_link} is uploaded.');
 
-      let notice = gettext('{from_user} has sent you a request for {draft_link}.');
-      let draftLink = '<a href=' + draftUrl + '>' + gettext('Draft') + '#' + draftId + '</a>';
-      notice = notice.replace('{from_user}', fromUser);
-      notice = notice.replace('{draft_link}', draftLink);
-      return {avatar_url, notice};
+        // 2. handle xss(cross-site scripting)
+        notice = notice.replace('{upload_folder_link}', `${folderName}`);
+        notice = Utils.HTMLescape(notice);
+      }
+      return { avatar_url, notice };
     }
 
     if (noticeType === MSG_TYPE_REPO_MONITOR) {
@@ -279,14 +351,34 @@ class NoticeItem extends React.Component {
       let notice = gettext('Your library {libraryName} has recently deleted a large number of files.');
       notice = notice.replace('{libraryName}', repoLink);
 
-      return { avatar_url : null, notice };
+      return { avatar_url: null, notice };
+    }
+
+    if (noticeType === MSG_TYPE_FACE_CLUSTER) {
+      let repo_id = detail.repo_id;
+      let repo_name = detail.repo_name;
+
+      const repoURL = `${siteRoot}library/${repo_id}/${encodeURIComponent(repo_name)}/`;
+      const repoLink = `<a href=${repoURL} target="_blank">${Utils.HTMLescape(repo_name)}</a>`;
+
+      let notice = gettext('Face recognition is done for library {libraryName}.');
+      notice = notice.replace('{libraryName}', repoLink);
+
+      return { avatar_url: null, notice };
+    }
+
+    if (noticeType === MSG_TYPE_SAML_SSO_FAILED) {
+      const { error_msg } = detail;
+      let notice = gettext(error_msg);
+
+      return { avatar_url: null, notice };
     }
 
     // if (noticeType === MSG_TYPE_GUEST_INVITATION_ACCEPTED) {
 
     // }
 
-    return {avatar_url : null, notice : null};
+    return { avatar_url: null, notice: null };
   }
 
   onNoticeItemClick = () => {
@@ -311,10 +403,10 @@ class NoticeItem extends React.Component {
           <img src={avatar_url} width="32" height="32" className="avatar" alt="" />
         </td>
         <td className="pr-1 pr-md-8">
-          <p className="m-0" dangerouslySetInnerHTML={{__html: notice}}></p>
+          <p className="m-0" dangerouslySetInnerHTML={{ __html: notice }}></p>
         </td>
         <td>
-          {moment(noticeItem.time).fromNow()}
+          {dayjs(noticeItem.time).fromNow()}
         </td>
       </tr>
     ) : (
@@ -322,9 +414,9 @@ class NoticeItem extends React.Component {
         <div className="notice-item">
           <div className="main-info">
             <img src={avatar_url} width="32" height="32" className="avatar" alt=""/>
-            <p className="brief" dangerouslySetInnerHTML={{__html: notice}}></p>
+            <p className="brief" dangerouslySetInnerHTML={{ __html: notice }}></p>
           </div>
-          <p className="time">{moment(noticeItem.time).fromNow()}</p>
+          <p className="time">{dayjs(noticeItem.time).fromNow()}</p>
         </div>
       </li>
     );
