@@ -1,5 +1,6 @@
 import React from 'react';
 import PropTypes from 'prop-types';
+import { Dropdown, DropdownMenu, DropdownToggle, DropdownItem } from 'reactstrap';
 import listener from './globalEventListener';
 import { hideMenu } from './actions';
 import { callIfExists } from './helpers';
@@ -7,13 +8,14 @@ import { Utils } from '../../utils/utils';
 
 const propTypes = {
   id: PropTypes.string.isRequired,
-  rtl: PropTypes.bool,
   onMenuItemClick: PropTypes.func.isRequired,
   onShowMenu: PropTypes.func,
   onHideMenu: PropTypes.func,
-  hideOnLeave: PropTypes.bool,
+  getMenuContainerSize: PropTypes.func,
 };
 
+const MENU_BORDER_INDENT = 10;
+
 class ContextMenu extends React.Component {
 
   constructor(props) {
@@ -25,6 +27,8 @@ class ContextMenu extends React.Component {
       isVisible: false,
       currentObject: null,
       menuList: [],
+      isSubMenuShown: false,
+      currentItem: ''
     };
   }
 
@@ -32,13 +36,13 @@ class ContextMenu extends React.Component {
     this.listenId = listener.register(this.handleShow, this.handleHide);
   }
 
-  componentDidUpdate () {
+  componentDidUpdate() {
     if (this.state.isVisible) {
       const wrapper = window.requestAnimationFrame || setTimeout;
 
       wrapper(() => {
         const { x, y } = this.state;
-        const { top, left } = this.props.rtl ? this.getRTLMenuPosition(x, y) : this.getMenuPosition(x, y);
+        const { top, left } = this.getMenuPosition(x, y);
 
         wrapper(() => {
           if (!this.menu) return;
@@ -83,11 +87,21 @@ class ContextMenu extends React.Component {
 
   handleShow = (e) => {
     if (e.detail.id !== this.props.id) return;
-
     const { x, y } = e.detail.position;
-    const { currentObject, menuList} = e.detail;
+    if (this.props.getMenuContainerSize) {
+      const containerSize = this.props.getMenuContainerSize();
+      const relativeX = x - (window.innerWidth - parseFloat(containerSize.width));
+      const relativeY = y - (window.innerHeight - parseFloat(containerSize.height));
+      this.setState({
+        x: relativeX,
+        y: relativeY,
+      });
+    } else {
+      this.setState({ x, y });
+    }
 
-    this.setState({ isVisible: true, x, y, currentObject, menuList });
+    const { currentObject, menuList } = e.detail;
+    this.setState({ isVisible: true, currentObject, menuList });
     this.registerHandlers();
     callIfExists(this.props.onShowMenu, e);
   };
@@ -95,7 +109,7 @@ class ContextMenu extends React.Component {
   handleHide = (e) => {
     if (this.state.isVisible && (!e.detail || !e.detail.id || e.detail.id === this.props.id)) {
       this.unregisterHandlers();
-      this.setState({ isVisible: false});
+      this.setState({ isVisible: false });
       callIfExists(this.props.onHideMenu, e);
     }
   };
@@ -106,8 +120,6 @@ class ContextMenu extends React.Component {
 
   handleMouseLeave = (event) => {
     event.preventDefault();
-
-    if (this.props.hideOnLeave) hideMenu();
   };
 
   handleContextMenu = (e) => {
@@ -136,58 +148,31 @@ class ContextMenu extends React.Component {
 
     if (!this.menu) return menuStyles;
 
-    const { innerWidth, innerHeight } = window;
+    let { innerWidth, innerHeight } = window;
     const rect = this.menu.getBoundingClientRect();
 
-    if (y + rect.height > innerHeight) {
-      menuStyles.top -= rect.height;
+    if (this.props.getMenuContainerSize) {
+      let containerSize = this.props.getMenuContainerSize();
+      innerWidth = parseFloat(containerSize.width);
+      innerHeight = parseFloat(containerSize.height);
     }
 
-    if (x + rect.width > innerWidth) {
-      menuStyles.left -= rect.width;
+    if (y + rect.height > innerHeight - MENU_BORDER_INDENT) {
+      menuStyles.top = innerHeight - rect.height - MENU_BORDER_INDENT;
     }
 
-    if (menuStyles.top < 0) {
-      menuStyles.top = rect.height < innerHeight ? (innerHeight - rect.height) / 2 : 0;
+    if (x + rect.width > innerWidth - MENU_BORDER_INDENT) {
+      menuStyles.left = innerWidth - rect.width - MENU_BORDER_INDENT;
     }
 
     if (menuStyles.left < 0) {
       menuStyles.left = rect.width < innerWidth ? (innerWidth - rect.width) / 2 : 0;
     }
 
-    return menuStyles;
-  };
-
-  getRTLMenuPosition = (x = 0, y = 0) => {
-    let menuStyles = {
-      top: y,
-      left: x
-    };
-
-    if (!this.menu) return menuStyles;
-
-    const { innerWidth, innerHeight } = window;
-    const rect = this.menu.getBoundingClientRect();
-
-    // Try to position the menu on the left side of the cursor
-    menuStyles.left = x - rect.width;
-
-    if (y + rect.height > innerHeight) {
-      menuStyles.top -= rect.height;
-    }
-
-    if (menuStyles.left < 0) {
-      menuStyles.left += rect.width;
-    }
-
     if (menuStyles.top < 0) {
       menuStyles.top = rect.height < innerHeight ? (innerHeight - rect.height) / 2 : 0;
     }
 
-    if (menuStyles.left + rect.width > innerWidth) {
-      menuStyles.left = rect.width < innerWidth ? (innerWidth - rect.width) / 2 : 0;
-    }
-
     return menuStyles;
   };
 
@@ -203,6 +188,28 @@ class ContextMenu extends React.Component {
     event.stopPropagation();
   };
 
+  onDropDownMouseMove = (e) => {
+    if (this.state.isSubMenuShown) {
+      this.setState({
+        isSubMenuShown: false
+      });
+    }
+  };
+
+  toggleSubMenu = (e) => {
+    e.stopPropagation();
+    this.setState({
+      isSubMenuShown: !this.state.isSubMenuShown
+    });
+  };
+
+  toggleSubMenuShown = (item) => {
+    this.setState({
+      isSubMenuShown: true,
+      currentItem: item.key
+    });
+  };
+
   render() {
     const inlineStyle = { position: 'fixed', opacity: 0, pointerEvents: 'none', display: 'block' };
     return (
@@ -210,6 +217,37 @@ class ContextMenu extends React.Component {
         {this.state.menuList.map((menuItem, index) => {
           if (menuItem === 'Divider') {
             return <div key={index} className="seafile-divider dropdown-divider"></div>;
+          } else if (menuItem.subOpList) {
+            return (
+              <Dropdown
+                key={index}
+                direction="right"
+                className="w-100"
+                isOpen={this.state.isSubMenuShown && this.state.currentItem == menuItem.key}
+                toggle={this.toggleSubMenu}
+                onMouseMove={(e) => {e.stopPropagation();}}
+              >
+                <DropdownToggle
+                  tag='div'
+                  className="dropdown-item font-weight-normal rounded-0 d-flex align-items-center"
+                  onMouseEnter={this.toggleSubMenuShown.bind(this, menuItem)}
+                >
+                  <span className="mr-auto">{menuItem.value}</span>
+                  <i className="sf3-font-down sf3-font rotate-270"></i>
+                </DropdownToggle>
+                <DropdownMenu>
+                  {menuItem.subOpList.map((item, index) => {
+                    if (item == 'Divider') {
+                      return <DropdownItem key={index} divider />;
+                    } else {
+                      return (
+                        <DropdownItem key={index} data-operation={item.key} onClick={this.onMenuItemClick} onContextMenu={this.onContextMenu}>{item.value}</DropdownItem>
+                      );
+                    }
+                  })}
+                </DropdownMenu>
+              </Dropdown>
+            );
           } else {
             return (
               <button
@@ -218,6 +256,7 @@ class ContextMenu extends React.Component {
                 data-operation={menuItem.key}
                 onClick={this.onMenuItemClick}
                 onContextMenu={this.onContextMenu}
+                onMouseMove={this.onDropDownMouseMove}
               >
                 {menuItem.value}
               </button>
