@@ -1,11 +1,10 @@
-import React, { Fragment } from 'react';
+import React from 'react';
 import PropTypes from 'prop-types';
-import { Utils } from '../../utils/utils';
 import SortOptionsDialog from '../../components/dialog/sort-options';
 import DirPath from './dir-path';
-import DirTool from './dir-tool';
 
 const propTypes = {
+  currentRepoInfo: PropTypes.object.isRequired,
   repoID: PropTypes.string.isRequired,
   repoName: PropTypes.string.isRequired,
   userPerm: PropTypes.string,
@@ -13,14 +12,26 @@ const propTypes = {
   onPathClick: PropTypes.func.isRequired,
   onTabNavClick: PropTypes.func,
   pathPrefix: PropTypes.array,
-  isViewFile: PropTypes.bool,
-  updateUsedRepoTags: PropTypes.func.isRequired,
   fileTags: PropTypes.array.isRequired,
-  onDeleteRepoTag: PropTypes.func.isRequired,
+  toggleTreePanel: PropTypes.func.isRequired,
   direntList: PropTypes.array,
   sortBy: PropTypes.string,
   sortOrder: PropTypes.string,
   sortItems: PropTypes.func,
+  repoEncrypted: PropTypes.bool.isRequired,
+  isGroupOwnedRepo: PropTypes.bool.isRequired,
+  enableDirPrivateShare: PropTypes.bool.isRequired,
+  showShareBtn: PropTypes.bool.isRequired,
+  onAddFile: PropTypes.func.isRequired,
+  onAddFolder: PropTypes.func.isRequired,
+  onUploadFile: PropTypes.func.isRequired,
+  onUploadFolder: PropTypes.func.isRequired,
+  fullDirentList: PropTypes.array.isRequired,
+  filePermission: PropTypes.string,
+  repoTags: PropTypes.array.isRequired,
+  onFileTagChanged: PropTypes.func.isRequired,
+  onItemMove: PropTypes.func.isRequired,
+  loadDirentList: PropTypes.func.isRequired,
 };
 
 class CurDirPath extends React.Component {
@@ -39,29 +50,35 @@ class CurDirPath extends React.Component {
   };
 
   render() {
-    const isDesktop = Utils.isDesktop();
     return (
-      <Fragment>
+      <div className="cur-dir-path d-flex justify-content-between align-items-center">
         <DirPath
+          currentRepoInfo={this.props.currentRepoInfo}
+          repoID={this.props.repoID}
           repoName={this.props.repoName}
+          repoEncrypted={this.props.repoEncrypted}
+          isGroupOwnedRepo={this.props.isGroupOwnedRepo}
           pathPrefix={this.props.pathPrefix}
           currentPath={this.props.currentPath}
+          userPerm={this.props.userPerm}
           onPathClick={this.props.onPathClick}
           onTabNavClick={this.props.onTabNavClick}
-          repoID={this.props.repoID}
-          isViewFile={this.props.isViewFile}
           fileTags={this.props.fileTags}
+          toggleTreePanel={this.props.toggleTreePanel}
+          enableDirPrivateShare={this.props.enableDirPrivateShare}
+          showShareBtn={this.props.showShareBtn}
+          onAddFolder={this.props.onAddFolder}
+          onAddFile={this.props.onAddFile}
+          onUploadFile={this.props.onUploadFile}
+          onUploadFolder={this.props.onUploadFolder}
+          direntList={this.props.fullDirentList}
+          filePermission={this.props.filePermission}
+          onFileTagChanged={this.props.onFileTagChanged}
+          repoTags={this.props.repoTags}
+          onItemMove={this.props.onItemMove}
+          loadDirentList={this.props.loadDirentList}
         />
-        {isDesktop &&
-        <DirTool
-          repoID={this.props.repoID}
-          repoName={this.props.repoName}
-          userPerm={this.props.userPerm}
-          currentPath={this.props.currentPath}
-          updateUsedRepoTags={this.props.updateUsedRepoTags}
-          onDeleteRepoTag={this.props.onDeleteRepoTag}
-        />}
-        {!isDesktop && this.props.direntList.length > 0 &&
+        {!this.props.isDesktop && this.props.direntList.length > 0 &&
         <span className="sf3-font sf3-font-sort action-icon" onClick={this.toggleSortOptionsDialog}></span>}
         {this.state.isSortOptionsDialogOpen &&
         <SortOptionsDialog
@@ -71,7 +88,7 @@ class CurDirPath extends React.Component {
           sortItems={this.props.sortItems}
         />
         }
-      </Fragment>
+      </div>
     );
   }
 }
