@@ -1,10 +1,11 @@
 import React from 'react';
 import PropTypes from 'prop-types';
-import { Modal, ModalHeader, ModalBody, ModalFooter, Alert } from 'reactstrap';
+import { Modal, ModalBody, ModalFooter, Alert } from 'reactstrap';
 import { gettext, repoPasswordMinLength } from '../../utils/constants';
 import { Utils } from '../../utils/utils';
 import { seafileAPI } from '../../utils/seafile-api';
 import toaster from '../toast';
+import SeahubModalHeader from '@/components/common/seahub-modal-header';
 
 const propTypes = {
   repoID: PropTypes.string.isRequired,
@@ -95,21 +96,43 @@ class ChangeRepoPasswordDialog extends React.Component {
   render() {
     const { repoName, toggleDialog } = this.props;
 
+    let title = gettext('Change Password of Library {placeholder}');
+    title = title.replace('{placeholder}', '<span class="op-target text-truncate mx-1">' + Utils.HTMLescape(repoName) + '</span>');
+
     return (
-      <Modal isOpen={true} style={{height: 'auto'}} toggle={toggleDialog}>
-        <ModalHeader toggle={toggleDialog}>
-          <span>
-            {Utils.generateDialogTitle(gettext('Change Password of Library {placeholder}'), repoName)}
-          </span>
-        </ModalHeader>
+      <Modal isOpen={true} style={{ height: 'auto' }} toggle={toggleDialog}>
+        <SeahubModalHeader toggle={toggleDialog}>
+          <span dangerouslySetInnerHTML={{ __html: title }} className="d-flex mw-100"></span>
+        </SeahubModalHeader>
         <ModalBody>
           <form id="repo-change-passwd-form" action="" method="post">
-            <label htmlFor="passwd">{gettext('Old Password')}</label><br />
-            <input type="password" name="old_passwd" className="form-control" id="passwd" value={this.state.oldPassword} onChange={this.handleOldPasswordInputChange} /><br />
-            <label htmlFor="new-passwd">{gettext('New Password')}</label><span className="tip">{gettext('(at least {placeholder} characters)').replace('{placeholder}', repoPasswordMinLength)}</span><br />
-            <input type="password" name="new_passwd" className="form-control" id="new-passwd" value={this.state.newPassword} onChange={this.handleNewPasswordInputChange} /><br />
-            <label htmlFor="new-passwd-again">{gettext('New Password Again')}</label><br />
-            <input type="password" name="new_passwd_again" className="form-control" id="new-passwd-again" value={this.state.newPasswordAgain} onChange={this.handleNewPasswordAgainInputChange} /><br />
+            <label htmlFor="passwd">{gettext('Old Password')}</label>
+            <br />
+            <input
+              type="password"
+              name="old_passwd"
+              className="form-control"
+              id="passwd"
+              value={this.state.oldPassword}
+              onChange={this.handleOldPasswordInputChange}
+            />
+            <br />
+            <label htmlFor="new-passwd">{gettext('New Password')}</label>
+            <span className="tip">{gettext('(at least {placeholder} characters)').replace('{placeholder}', repoPasswordMinLength)}</span>
+            <br />
+            <input
+              type="password"
+              name="new_passwd"
+              className="form-control"
+              id="new-passwd"
+              value={this.state.newPassword}
+              onChange={this.handleNewPasswordInputChange}
+            />
+            <br />
+            <label htmlFor="new-passwd-again">{gettext('New Password Again')}</label>
+            <br />
+            <input type="password" name="new_passwd_again" className="form-control" id="new-passwd-again" value={this.state.newPasswordAgain} onChange={this.handleNewPasswordAgainInputChange} />
+            <br />
             {this.state.errorMsg && <Alert color="danger">{this.state.errorMsg}</Alert>}
           </form>
         </ModalBody>
