@@ -1,7 +1,8 @@
 import React, { Component } from 'react';
 import PropTypes from 'prop-types';
-import { Modal, ModalHeader, ModalBody, ModalFooter, Button } from 'reactstrap';
+import { Modal, ModalBody, ModalFooter, Button } from 'reactstrap';
 import { gettext } from '../../utils/constants';
+import SeahubModalHeader from '@/components/common/seahub-modal-header';
 
 const propTypes = {
   formActionURL: PropTypes.string.isRequired,
@@ -21,10 +22,10 @@ class ConfirmDisconnectDingtalk extends Component {
   };
 
   render() {
-    const {formActionURL, csrfToken, toggle} = this.props;
+    const { formActionURL, csrfToken, toggle } = this.props;
     return (
       <Modal centered={true} isOpen={true} toggle={toggle}>
-        <ModalHeader toggle={toggle}>{gettext('Disconnect')}</ModalHeader>
+        <SeahubModalHeader toggle={toggle}>{gettext('Disconnect')}</SeahubModalHeader>
         <ModalBody>
           <p>{gettext('Are you sure you want to disconnect?')}</p>
           <form ref={this.form} className="d-none" method="post" action={formActionURL}>
