@@ -1,8 +1,9 @@
 import React from 'react';
 import PropTypes from 'prop-types';
-import { Button, Modal, ModalHeader, Input, ModalBody, ModalFooter, Form, FormGroup, Label, Alert } from 'reactstrap';
+import { Button, Modal, Input, ModalBody, ModalFooter, Form, FormGroup, Label, Alert } from 'reactstrap';
 import { gettext } from '../../utils/constants';
-import { Utils } from '../../utils/utils';
+import { Utils, validateName } from '../../utils/utils';
+import SeahubModalHeader from '@/components/common/seahub-modal-header';
 
 const propTypes = {
   fileType: PropTypes.string,
@@ -25,39 +26,41 @@ class CreateForder extends React.Component {
 
   componentDidMount() {
     let parentPath = this.props.parentPath;
-    if (parentPath[parentPath.length - 1] === '/') {  // mainPanel
-      this.setState({parentPath: parentPath});
+    if (parentPath[parentPath.length - 1] === '/') { // mainPanel
+      this.setState({ parentPath: parentPath });
     } else {
-      this.setState({parentPath: parentPath + '/'}); // sidePanel
+      this.setState({ parentPath: parentPath + '/' }); // sidePanel
     }
   }
 
   handleChange = (e) => {
     if (!e.target.value.trim()) {
-      this.setState({isSubmitBtnActive: false});
+      this.setState({ isSubmitBtnActive: false });
     } else {
-      this.setState({isSubmitBtnActive: true});
+      this.setState({ isSubmitBtnActive: true });
     }
 
-    this.setState({childName: e.target.value});
+    this.setState({ childName: e.target.value });
   };
 
   handleSubmit = () => {
     if (!this.state.isSubmitBtnActive) {
       return;
     }
-
-    let newName = this.state.childName;
-    let isDuplicated = this.checkDuplicatedName();
-
+    let newName = this.state.childName.trim();
+    let { isValid, errMessage } = validateName(newName);
+    if (!isValid) {
+      this.setState({ errMessage });
+      return;
+    }
+    let isDuplicated = this.props.checkDuplicatedName(newName);
     if (isDuplicated) {
       let errMessage = gettext('The name "{name}" is already taken. Please choose a different name.');
       errMessage = errMessage.replace('{name}', Utils.HTMLescape(newName));
-      this.setState({errMessage: errMessage});
-    } else {
-      let path = this.state.parentPath + newName;
-      this.props.onAddFolder(path);
+      this.setState({ errMessage });
+      return;
     }
+    this.props.onAddFolder(this.state.parentPath + newName);
   };
 
   handleKeyDown = (e) => {
@@ -71,21 +74,17 @@ class CreateForder extends React.Component {
     this.props.addFolderCancel();
   };
 
-  checkDuplicatedName = () => {
-    let isDuplicated = this.props.checkDuplicatedName(this.state.childName);
-    return isDuplicated;
-  };
-
   render() {
     return (
       <Modal isOpen={true} toggle={this.toggle} autoFocus={false}>
-        <ModalHeader toggle={this.toggle}>{gettext('New Folder')}</ModalHeader>
+        <SeahubModalHeader toggle={this.toggle}>{gettext('New Folder')}</SeahubModalHeader>
         <ModalBody>
           <Form>
             <FormGroup>
               <Label for="folderName">{gettext('Name')}</Label>
               <Input
                 id="folderName"
+                name="folder-name"
                 value={this.state.childName}
                 onKeyDown={this.handleKeyDown}
                 onChange={this.handleChange}
