@@ -1,12 +1,13 @@
 import React, { Fragment } from 'react';
 import PropTypes from 'prop-types';
-import { Button, Modal, ModalHeader, ModalBody, ModalFooter } from 'reactstrap';
+import { Button, Modal, ModalBody, ModalFooter } from 'reactstrap';
 import { gettext } from '../../utils/constants';
 import { seafileAPI } from '../../utils/seafile-api';
 import { Utils } from '../../utils/utils';
-import RepoTag from '../../models/repo-tag';
 import CreateTagDialog from './create-tag-dialog';
 import toaster from '../toast';
+import SeahubModalHeader from '@/components/common/seahub-modal-header';
+
 require('../../css/repo-tag.css');
 
 const TagItemPropTypes = {
@@ -60,7 +61,7 @@ class TagItem extends React.Component {
     } else {
       let fileTag = null;
       let fileTagList = this.props.fileTagList;
-      for(let i = 0; i < fileTagList.length; i++) {
+      for (let i = 0; i < fileTagList.length; i++) {
         if (fileTagList[i].repo_tag_id === repoTag.id) {
           fileTag = fileTagList[i];
           break;
@@ -89,10 +90,10 @@ class TagItem extends React.Component {
         onMouseLeave={this.onMouseLeave}
       >
         <div className="d-flex align-items-center">
-          <span className="tag-color w-4 h-4 rounded-circle" style={{backgroundColor: repoTag.color}}></span>
+          <span className="tag-color w-4 h-4 rounded-circle" style={{ backgroundColor: repoTag.color }}></span>
           <span className="tag-name mx-2">{repoTag.name}</span>
         </div>
-        {isTagSelected && <i className="fas fa-check tag-selected-icon"></i>}
+        {isTagSelected && <i className="sf2-icon-tick tag-selected-icon"></i>}
       </li>
     );
   }
@@ -103,6 +104,7 @@ TagItem.propTypes = TagItemPropTypes;
 
 const TagListPropTypes = {
   repoID: PropTypes.string.isRequired,
+  repoTags: PropTypes.array.isRequired,
   filePath: PropTypes.string.isRequired,
   fileTagList: PropTypes.array.isRequired,
   onFileTagChanged: PropTypes.func.isRequired,
@@ -111,39 +113,15 @@ const TagListPropTypes = {
 };
 
 class TagList extends React.Component {
-  constructor(props) {
-    super(props);
-    this.state = {
-      repotagList: [],
-    };
-  }
-
-  componentDidMount() {
-    this.getRepoTagList();
-  }
-
-  getRepoTagList = () => {
-    let repoID = this.props.repoID;
-    seafileAPI.listRepoTags(repoID).then(res => {
-      let repotagList = [];
-      res.data.repo_tags.forEach(item => {
-        let repoTag = new RepoTag(item);
-        repotagList.push(repoTag);
-      });
-      this.setState({repotagList: repotagList});
-    }).catch(error => {
-      let errMessage = Utils.getErrorMsg(error);
-      toaster.danger(errMessage);
-    });
-  };
 
   render() {
+    const { repoTags } = this.props;
     return (
       <Fragment>
-        <ModalHeader toggle={this.props.toggleCancel}>{gettext('Select Tags')}</ModalHeader>
+        <SeahubModalHeader toggle={this.props.toggleCancel}>{gettext('Select Tags')}</SeahubModalHeader>
         <ModalBody className="px-0">
           <ul className="tag-list tag-list-container">
-            {this.state.repotagList.map((repoTag) => {
+            {repoTags.map((repoTag) => {
               return (
                 <TagItem
                   key={repoTag.id}
@@ -177,6 +155,7 @@ TagList.propTypes = TagListPropTypes;
 
 const propTypes = {
   repoID: PropTypes.string.isRequired,
+  repoTags: PropTypes.array.isRequired,
   filePath: PropTypes.string.isRequired,
   fileTagList: PropTypes.array.isRequired,
   toggleCancel: PropTypes.func.isRequired,
@@ -200,7 +179,7 @@ class EditFileTagDialog extends React.Component {
   };
 
   onRepoTagCreated = (repoTagID) => {
-    let {repoID, filePath} = this.props;
+    let { repoID, filePath } = this.props;
     seafileAPI.addFileTag(repoID, filePath, repoTagID).then(() => {
       this.props.onFileTagChanged();
     }).catch(error => {
@@ -215,6 +194,7 @@ class EditFileTagDialog extends React.Component {
         {this.state.isListRepoTagShow &&
           <TagList
             repoID={this.props.repoID}
+            repoTags={this.props.repoTags}
             filePath={this.props.filePath}
             fileTagList={this.props.fileTagList}
             onFileTagChanged={this.props.onFileTagChanged}
