@@ -1,15 +1,17 @@
 import React, { Fragment } from 'react';
-import { Button, Modal, ModalHeader, ModalBody, ModalFooter } from 'reactstrap';
+import { Button, Modal, ModalBody, ModalFooter } from 'reactstrap';
 import PropTypes from 'prop-types';
 import toaster from '../toast';
 import copy from '../copy-to-clipboard';
 import { gettext } from '../../utils/constants';
 import { seafileAPI } from '../../utils/seafile-api';
 import { Utils } from '../../utils/utils';
+import SeahubModalHeader from '@/components/common/seahub-modal-header';
 
 const propTypes = {
   path: PropTypes.string.isRequired,
   repoID: PropTypes.string.isRequired,
+  internalLink: PropTypes.string,
   onInternalLinkDialogToggle: PropTypes.func.isRequired,
 };
 
@@ -24,6 +26,10 @@ class InternalLinkDialog extends React.Component {
   }
 
   componentDidMount() {
+    if (this.props.internalLink) {
+      this.setState({ smartLink: this.props.internalLink });
+      return;
+    }
     this.getInternalLink();
   }
 
@@ -39,19 +45,19 @@ class InternalLinkDialog extends React.Component {
     }).catch(error => {
       let errMessage = Utils.getErrorMsg(error);
       toaster.danger(errMessage);
-      this.setState({isLoading: false});
+      this.setState({ isLoading: false });
     });
   };
 
   copyToClipBoard = () => {
     copy(this.state.smartLink);
     const message = gettext('Internal link has been copied to clipboard');
-    toaster.success(message, {duration: 2});
+    toaster.success(message, { duration: 2 });
     this.toggle();
   };
 
   toggle = () => {
-    this.props.onInternalLinkDialogToggle();
+    this.props.onInternalLinkDialogToggle({ internalLink: '' });
   };
 
   render() {
@@ -59,7 +65,7 @@ class InternalLinkDialog extends React.Component {
     return (
       <Fragment>
         <Modal isOpen={true} toggle={this.toggle}>
-          <ModalHeader toggle={this.toggle}>{gettext('Internal Link')}</ModalHeader>
+          <SeahubModalHeader toggle={this.toggle}>{gettext('Internal Link')}</SeahubModalHeader>
           <ModalBody>
             <p className="tip mb-1">{tipMessage}</p>
             <p>
