@@ -6,7 +6,8 @@ import { seafileAPI } from '../../utils/seafile-api';
 import { Utils } from '../../utils/utils';
 import UserSelect from '../user-select';
 import SharePermissionEditor from '../select-editor/share-permission-editor';
-import FileChooser from '../file-chooser/file-chooser';
+import FileChooser from '../file-chooser';
+import toaster from '../../components/toast';
 
 class UserItem extends React.Component {
 
@@ -18,11 +19,11 @@ class UserItem extends React.Component {
   }
 
   onMouseEnter = () => {
-    this.setState({isOperationShow: true});
+    this.setState({ isOperationShow: true });
   };
 
   onMouseLeave = () => {
-    this.setState({isOperationShow: false});
+    this.setState({ isOperationShow: false });
   };
 
   deleteUserFolderPermission = () => {
@@ -81,16 +82,15 @@ UserItem.propTypes = {
   deleteUserFolderPermission: PropTypes.func.isRequired,
   onChangeUserFolderPerm: PropTypes.func.isRequired,
   showPath: PropTypes.bool.isRequired,
-  repoName: PropTypes.string.isRequired,
-  handleChange: PropTypes.func.isRequired,
+  repoName: PropTypes.string,
 };
 
 
 const propTypes = {
   repoID: PropTypes.string.isRequired,
   isDepartmentRepo: PropTypes.bool,
-  folderPath: PropTypes.string.isRequired,
-  repoName: PropTypes.string.isRequired,
+  folderPath: PropTypes.string,
+  repoName: PropTypes.string,
 };
 
 
@@ -114,23 +114,26 @@ class LibSubFolderSetUserPermissionDialog extends React.Component {
   }
 
   handleUserSelectChange = (option) => {
-    this.setState({selectedUsers: option});
+    this.setState({ selectedUsers: option });
   };
 
   componentDidMount() {
-    const {repoID, folderPath, isDepartmentRepo} = this.props;
+    const { repoID, folderPath, isDepartmentRepo } = this.props;
     const request = isDepartmentRepo ?
       seafileAPI.listDepartmentRepoUserFolderPerm(repoID, folderPath) :
       seafileAPI.listUserFolderPerm(repoID, folderPath);
     request.then((res) => {
       if (res.data.length !== 0) {
-        this.setState({userFolderPermItems: res.data});
+        this.setState({ userFolderPermItems: res.data });
       }
+    }).catch(error => {
+      let errMessage = Utils.getErrorMsg(error);
+      toaster.danger(errMessage);
     });
   }
 
   setPermission = (permission) => {
-    this.setState({permission: permission});
+    this.setState({ permission: permission });
   };
 
   addUserFolderPerm = () => {
@@ -160,20 +163,9 @@ class LibSubFolderSetUserPermissionDialog extends React.Component {
         folderPath: '',
       });
       this.refs.userSelect.clearSelect();
-    }).catch((error) => {
-      let errorMsg = '';
-      if (error.response) {
-        if (error.response.data && error.response.data['error_msg']) {
-          errorMsg = error.response.data['error_msg'];
-        } else {
-          errorMsg = gettext('Error');
-        }
-      } else {
-        errorMsg = gettext('Please check the network.');
-      }
-      this.setState({
-        errorMsg: [errorMsg]
-      });
+    }).catch(error => {
+      let errMessage = Utils.getErrorMsg(error);
+      toaster.danger(errMessage);
     });
   };
 
@@ -187,6 +179,9 @@ class LibSubFolderSetUserPermissionDialog extends React.Component {
           return deletedItem != item;
         })
       });
+    }).catch(error => {
+      let errMessage = Utils.getErrorMsg(error);
+      toaster.danger(errMessage);
     });
   };
 
@@ -201,7 +196,10 @@ class LibSubFolderSetUserPermissionDialog extends React.Component {
         }
         return item;
       });
-      this.setState({userFolderPermItems: userFolderPermItems});
+      this.setState({ userFolderPermItems: userFolderPermItems });
+    }).catch(error => {
+      let errMessage = Utils.getErrorMsg(error);
+      toaster.danger(errMessage);
     });
   };
 
@@ -226,6 +224,7 @@ class LibSubFolderSetUserPermissionDialog extends React.Component {
 
   handleFileChooserSubmit = () => {
     this.setState({
+      folderPath: this.state.folderPath || '/',
       showFileChooser: !this.state.showFileChooser
     });
   };
@@ -260,17 +259,18 @@ class LibSubFolderSetUserPermissionDialog extends React.Component {
     const thead = (
       <thead>
         <tr>
-          <th width={showPath ? '32%': '55%'}>{gettext('User')}</th>
+          <th width={showPath ? '32%' : '55%'}>{gettext('User')}</th>
           {showPath &&
           <th width="32%">{gettext('Folder')}</th>
           }
-          <th width={showPath ? '24%': '30%'}>{gettext('Permission')}</th>
+          <th width={showPath ? '24%' : '30%'}>{gettext('Permission')}</th>
           <th width={showPath ? '12%' : '15%'}></th>
         </tr>
       </thead>
     );
     return (
       <Fragment>
+        <p className="text-gray small">{gettext('Folder permission is only effective after the library is shared to users or groups. It is used to fine tune sub-folder permissions.')}</p>
         <table className="w-xs-250">
           {thead}
           <tbody>
@@ -279,7 +279,6 @@ class LibSubFolderSetUserPermissionDialog extends React.Component {
                 <UserSelect
                   ref="userSelect"
                   isMulti={true}
-                  className="reviewer-select"
                   placeholder={gettext('Search users')}
                   onSelectChange={this.handleUserSelectChange}
                   value={this.state.selectedUsers}
@@ -303,7 +302,7 @@ class LibSubFolderSetUserPermissionDialog extends React.Component {
                 />
               </td>
               <td>
-                <Button onClick={this.addUserFolderPerm}>{gettext('Submit')}</Button>
+                <Button color="primary" onClick={this.addUserFolderPerm}>{gettext('Submit')}</Button>
               </td>
             </tr>
             {this.state.errorMsg.length > 0 &&
