@@ -1,12 +1,13 @@
 import React from 'react';
 import PropTypes from 'prop-types';
-import { Button, Modal, ModalHeader, ModalBody, ModalFooter, Alert } from 'reactstrap';
+import { Button, Modal, ModalBody, ModalFooter, Alert } from 'reactstrap';
 import { gettext, orgID } from '../../utils/constants';
 import { Utils } from '../../utils/utils';
 import toaster from '../toast';
 import UserSelect from '../user-select';
-import { seafileAPI } from '../../utils/seafile-api';
+import { orgAdminAPI } from '../../utils/org-admin-api';
 import OrgUserInfo from '../../models/org-user';
+import SeahubModalHeader from '@/components/common/seahub-modal-header';
 
 const propTypes = {
   toggle: PropTypes.func.isRequired,
@@ -33,8 +34,8 @@ class AddOrgAdminDialog extends React.Component {
 
   addOrgAdmin = () => {
     if (!this.state.selectedOption) return;
-    const userEmail = this.state.selectedOption.email;
-    seafileAPI.orgAdminSetOrgAdmin(orgID, userEmail, true).then(res => {
+    const userEmail = this.state.selectedOption[0].email;
+    orgAdminAPI.orgAdminSetOrgAdmin(orgID, userEmail, true).then(res => {
       let userInfo = new OrgUserInfo(res.data);
       this.props.onAddedOrgAdmin(userInfo);
     }).catch(error => {
@@ -50,12 +51,11 @@ class AddOrgAdminDialog extends React.Component {
   render() {
     return (
       <Modal isOpen={true} toggle={this.toggle}>
-        <ModalHeader toggle={this.toggle}>{gettext('Add Admins')}</ModalHeader>
+        <SeahubModalHeader toggle={this.toggle}>{gettext('Add Admins')}</SeahubModalHeader>
         <ModalBody>
           <UserSelect
             ref="userSelect"
             isMulti={false}
-            className="reviewer-select"
             placeholder={gettext('Select a user as admin')}
             onSelectChange={this.handleSelectChange}
           />
