@@ -1,15 +1,16 @@
 import React from 'react';
 import PropTypes from 'prop-types';
-import { Button, Modal, ModalHeader, ModalBody, ModalFooter, Input, InputGroupAddon, InputGroup } from 'reactstrap';
+import { Button, Modal, ModalBody, ModalFooter, Input, InputGroupAddon, InputGroup } from 'reactstrap';
 import { gettext, orgID } from '../../utils/constants';
-import { seafileAPI } from '../../utils/seafile-api';
+import SeahubModalHeader from '@/components/common/seahub-modal-header';
+import { orgAdminAPI } from '../../utils/org-admin-api';
 import { Utils } from '../../utils/utils';
 import toaster from '../toast';
 
 const propTypes = {
   toggle: PropTypes.func.isRequired,
-  groupID: PropTypes.number.isRequired,
-  onDepartChanged: PropTypes.func.isRequired,
+  group: PropTypes.object.isRequired,
+  onSetQuota: PropTypes.func.isRequired,
 };
 
 class SetGroupQuotaDialog extends React.Component {
@@ -28,9 +29,9 @@ class SetGroupQuotaDialog extends React.Component {
     if ((quota.length && myReg.test(quota)) || quota == -2) {
       this.setState({ errMessage: '' });
       let newQuota = this.state.quota == -2 ? this.state.quota : this.state.quota * 1000000;
-      seafileAPI.orgAdminSetGroupQuota(orgID, this.props.groupID, newQuota).then((res) => {
+      orgAdminAPI.orgAdminSetGroupQuota(orgID, this.props.group.id, newQuota).then((res) => {
         this.props.toggle();
-        this.props.onDepartChanged();
+        this.props.onSetQuota(res.data);
       }).catch(error => {
         let errMessage = Utils.getErrorMsg(error);
         toaster.danger(errMessage);
@@ -54,10 +55,15 @@ class SetGroupQuotaDialog extends React.Component {
   };
 
   render() {
+    const group = this.props.group;
+    const oldQuota = Utils.bytesToSize(group.quota);
+    const message = gettext('The current quota for {group_name} is {quota}').replace('{group_name}', group.name).replace('{quota}', oldQuota);
     return (
       <Modal isOpen={true} toggle={this.props.toggle} autoFocus={false}>
-        <ModalHeader toggle={this.props.toggle}>{gettext('Set Quota')}</ModalHeader>
+        <SeahubModalHeader toggle={this.props.toggle}>{gettext('Set Quota')}</SeahubModalHeader>
         <ModalBody>
+          <p>{message}</p>
+          <p>{gettext('Please enter a new quota')}</p>
           <InputGroup>
             <Input
               onKeyDown={this.handleKeyDown}
@@ -74,6 +80,7 @@ class SetGroupQuotaDialog extends React.Component {
           { this.state.errMessage && <p className="error">{this.state.errMessage}</p> }
         </ModalBody>
         <ModalFooter>
+          <Button color="secondary" onClick={this.props.toggle}>{gettext('Cancel')}</Button>
           <Button color="primary" onClick={this.setGroupQuota}>{gettext('Submit')}</Button>
         </ModalFooter>
       </Modal>
