@@ -1,8 +1,9 @@
 import React from 'react';
 import PropTypes from 'prop-types';
 import { gettext } from '../../utils/constants';
-import { Utils } from '../../utils/utils';
-import { Button, Modal, ModalHeader, Input, ModalBody, ModalFooter, Alert } from 'reactstrap';
+import { Utils, validateName } from '../../utils/utils';
+import { Button, Modal, Input, ModalBody, ModalFooter, Alert } from 'reactstrap';
+import SeahubModalHeader from '@/components/common/seahub-modal-header';
 
 const propTypes = {
   currentNode: PropTypes.object,
@@ -24,7 +25,7 @@ class Rename extends React.Component {
   }
 
   UNSAFE_componentWillMount() {
-    this.setState({newName: this.props.currentNode.object.name});
+    this.setState({ newName: this.props.currentNode.object.name });
   }
 
   componentDidMount() {
@@ -38,28 +39,29 @@ class Rename extends React.Component {
 
   handleChange = (e) => {
     if (!e.target.value.trim()) {
-      this.setState({isSubmitBtnActive: false});
+      this.setState({ isSubmitBtnActive: false });
     } else {
-      this.setState({isSubmitBtnActive: true});
+      this.setState({ isSubmitBtnActive: true });
     }
 
-    this.setState({newName: e.target.value});
+    this.setState({ newName: e.target.value });
   };
 
   handleSubmit = () => {
-    let { isValid, errMessage } = this.validateInput();
+    let newName = this.state.newName.trim();
+    let { isValid, errMessage } = validateName(newName);
     if (!isValid) {
-      this.setState({errMessage : errMessage});
-    } else {
-      let isDuplicated = this.checkDuplicatedName();
-      if (isDuplicated) {
-        let errMessage = gettext('The name "{name}" is already taken. Please choose a different name.');
-        errMessage = errMessage.replace('{name}', Utils.HTMLescape(this.state.newName));
-        this.setState({errMessage: errMessage});
-      } else {
-        this.props.onRename(this.state.newName);
-      }
+      this.setState({ errMessage });
+      return;
     }
+    let isDuplicated = this.props.checkDuplicatedName(newName);
+    if (isDuplicated) {
+      let errMessage = gettext('The name "{name}" is already taken. Please choose a different name.');
+      errMessage = errMessage.replace('{name}', Utils.HTMLescape(newName));
+      this.setState({ errMessage });
+      return;
+    }
+    this.props.onRename(newName);
   };
 
   handleKeyDown = (e) => {
@@ -74,31 +76,7 @@ class Rename extends React.Component {
 
   changeState = (currentNode) => {
     let name = currentNode.object.name;
-    this.setState({newName: name});
-  };
-
-  validateInput = () => {
-    let newName = this.state.newName.trim();
-    let isValid = true;
-    let errMessage = '';
-    if (!newName) {
-      isValid = false;
-      errMessage = gettext('Name is required.');
-      return { isValid, errMessage };
-    }
-
-    if (newName.indexOf('/') > -1) {
-      isValid = false;
-      errMessage = gettext('Name should not include ' + '\'/\'' + '.');
-      return { isValid, errMessage };
-    }
-
-    return { isValid, errMessage };
-  };
-
-  checkDuplicatedName = () => {
-    let isDuplicated = this.props.checkDuplicatedName(this.state.newName);
-    return isDuplicated;
+    this.setState({ newName: name });
   };
 
   onAfterModelOpened = () => {
@@ -118,10 +96,17 @@ class Rename extends React.Component {
     let type = this.props.currentNode.object.type;
     return (
       <Modal isOpen={true} toggle={this.toggle} onOpened={this.onAfterModelOpened}>
-        <ModalHeader toggle={this.toggle}>{type === 'file' ? gettext('Rename File') : gettext('Rename Folder') }</ModalHeader>
+        <SeahubModalHeader toggle={this.toggle}>{type === 'file' ? gettext('Rename File') : gettext('Rename Folder') }</SeahubModalHeader>
         <ModalBody>
-          <p>{type === 'file' ? gettext('New file name'): gettext('New folder name')}</p>
-          <Input onKeyDown={this.handleKeyDown} innerRef={this.newInput} placeholder="newName" value={this.state.newName} onChange={this.handleChange} />
+          <p>{type === 'file' ? gettext('New file name') : gettext('New folder name')}</p>
+          <Input
+            onKeyDown={this.handleKeyDown}
+            innerRef={this.newInput}
+            placeholder="newName"
+            value={this.state.newName}
+            onChange={this.handleChange}
+            name={type === 'file' ? 'new-file-name' : 'new-folder-name'}
+          />
           {this.state.errMessage && <Alert color="danger" className="mt-2">{this.state.errMessage}</Alert>}
         </ModalBody>
         <ModalFooter>
