@@ -1,9 +1,10 @@
 import React from 'react';
 import PropTypes from 'prop-types';
-import { Modal, ModalHeader, ModalBody, ModalFooter, InputGroup, InputGroupAddon, InputGroupText } from 'reactstrap';
+import { Modal, ModalBody, ModalFooter, InputGroup, InputGroupAddon, InputGroupText } from 'reactstrap';
 import { gettext } from '../../utils/constants';
-import { seafileAPI } from '../../utils/seafile-api';
+import { orgAdminAPI } from '../../utils/org-admin-api';
 import { Utils } from '../../utils/utils';
+import SeahubModalHeader from '@/components/common/seahub-modal-header';
 
 const propTypes = {
   orgID: PropTypes.string,
@@ -46,7 +47,7 @@ class SetOrgUserQuota extends React.Component {
       submitBtnDisabled: true
     });
 
-    seafileAPI.orgAdminSetOrgUserQuota(orgID, email, quota).then((res) => {
+    orgAdminAPI.orgAdminSetOrgUserQuota(orgID, email, quota).then((res) => {
       this.props.updateQuota(res.data.quota_total);
       this.props.toggleDialog();
     }).catch((error) => {
@@ -62,7 +63,7 @@ class SetOrgUserQuota extends React.Component {
     const { inputValue, formErrorMsg, submitBtnDisabled } = this.state;
     return (
       <Modal isOpen={true} centered={true} toggle={this.props.toggleDialog}>
-        <ModalHeader toggle={this.props.toggleDialog}>{gettext('Set user quota')}</ModalHeader>
+        <SeahubModalHeader toggle={this.props.toggleDialog}>{gettext('Set user quota')}</SeahubModalHeader>
         <ModalBody>
           <React.Fragment>
             <InputGroup>
