@@ -6,7 +6,9 @@ import { seafileAPI } from '../../utils/seafile-api';
 import { Utils } from '../../utils/utils';
 import toaster from '../toast';
 import SharePermissionEditor from '../select-editor/share-permission-editor';
-import { SeahubSelect, NoGroupMessage } from '../common/select';
+import EventBus from '../common/event-bus';
+import { EVENT_BUS_TYPE } from '../common/event-bus-type';
+import GroupSelect from '../common/group-select';
 
 class GroupItem extends React.Component {
 
@@ -18,11 +20,11 @@ class GroupItem extends React.Component {
   }
 
   onMouseEnter = () => {
-    this.setState({isOperationShow: true});
+    this.setState({ isOperationShow: true });
   };
 
   onMouseLeave = () => {
-    this.setState({isOperationShow: false});
+    this.setState({ isOperationShow: false });
   };
 
   deleteShareItem = () => {
@@ -113,7 +115,9 @@ const propTypes = {
   itemPath: PropTypes.string.isRequired,
   itemType: PropTypes.string.isRequired,
   repoID: PropTypes.string.isRequired,
+  repoType: PropTypes.string,
   isRepoOwner: PropTypes.bool.isRequired,
+  repo: PropTypes.object,
   onAddCustomPermissionToggle: PropTypes.func,
 };
 
@@ -123,10 +127,11 @@ class ShareToGroup extends React.Component {
     super(props);
     this.state = {
       options: [],
-      selectedOption: null,
+      selectedOptions: [],
       errorMsg: [],
       permission: 'rw',
-      sharedItems: []
+      sharedItems: [],
+      isWiki: this.props.repoType === 'wiki'
     };
     this.permissions = [];
     let { itemType, isRepoOwner } = props;
@@ -141,10 +146,29 @@ class ShareToGroup extends React.Component {
     if (this.props.isGroupOwnedRepo) {
       this.permissions = ['rw', 'r', 'cloud-edit', 'preview'];
     }
+    if (this.state.isWiki) {
+      this.permissions = ['rw', 'r'];
+    }
   }
 
-  handleSelectChange = (option) => {
-    this.setState({selectedOption: option});
+  onSelectOption = (option) => {
+    const selectedOptions = this.state.selectedOptions.slice(0);
+    const index = selectedOptions.findIndex(item => item.id === option.id);
+    if (index > -1) {
+      selectedOptions.splice(index, 1);
+    } else {
+      selectedOptions.push(option);
+    }
+    this.setState({ selectedOptions: selectedOptions });
+  };
+
+  onDeleteOption = (option) => {
+    const selectedOptions = this.state.selectedOptions.slice(0);
+    const index = selectedOptions.findIndex(item => item.id === option.id);
+    if (index > -1) {
+      selectedOptions.splice(index, 1);
+    }
+    this.setState({ selectedOptions: selectedOptions });
   };
 
   componentDidMount() {
@@ -166,9 +190,10 @@ class ShareToGroup extends React.Component {
         obj.value = res.data[i].name;
         obj.id = res.data[i].id;
         obj.label = res.data[i].name;
+        obj.name = res.data[i].name;
         options.push(obj);
       }
-      this.setState({options: options});
+      this.setState({ options: options });
     }).catch(error => {
       let errMessage = Utils.getErrorMsg(error);
       toaster.danger(errMessage);
@@ -179,7 +204,7 @@ class ShareToGroup extends React.Component {
     let path = this.props.itemPath;
     let repoID = this.props.repoID;
     seafileAPI.listSharedItems(repoID, path, 'group').then((res) => {
-      if(res.data.length !== 0) {
+      if (res.data.length !== 0) {
         this.setState({
           sharedItems: res.data
         });
@@ -191,17 +216,16 @@ class ShareToGroup extends React.Component {
   };
 
   setPermission = (permission) => {
-    this.setState({permission: permission});
+    this.setState({ permission: permission });
   };
 
   shareToGroup = () => {
-
-    let path = this.props.itemPath;
-    let repoID = this.props.repoID;
-    let isGroupOwnedRepo = this.props.isGroupOwnedRepo;
-
+    const eventBus = EventBus.getInstance();
+    const { isGroupOwnedRepo, itemPath: path, repoID } = this.props;
+    const { permission, selectedOptions } = this.state;
+    const targetGroupIds = selectedOptions.map(item => item.id);
     if (isGroupOwnedRepo) {
-      seafileAPI.shareGroupOwnedRepoToGroup(repoID, this.state.permission, this.state.selectedOption['id'], path).then(res => {
+      seafileAPI.shareGroupOwnedRepoToGroup(repoID, permission, targetGroupIds, path).then(res => {
         let errorMsg = [];
         if (res.data.failed.length > 0) {
           for (let i = 0 ; i < res.data.failed.length ; i++) {
@@ -212,17 +236,24 @@ class ShareToGroup extends React.Component {
         // todo modify api
         let items = res.data.success.map(item => {
           let sharedItem = {
-            'group_info': { 'id': item.group_id, 'name': item.group_name},
+            'group_info': { 'id': item.group_id, 'name': item.group_name },
             'permission': item.permission,
             'share_type': 'group',
           };
           return sharedItem;
         });
 
+        if (this.props.repo && res.data.success.length > 0) {
+          const sharedRepo = { ...this.props.repo, permission: res.data.success[0].permission };
+          targetGroupIds.forEach(targetGroupId => {
+            eventBus.dispatch(EVENT_BUS_TYPE.ADD_SHARED_REPO_INTO_GROUP, { repo: sharedRepo, group_id: targetGroupId });
+          });
+        }
+
         this.setState({
           errorMsg: errorMsg,
           sharedItems: this.state.sharedItems.concat(items),
-          selectedOption: null,
+          selectedOptions: [],
           permission: 'rw',
         });
       }).catch(error => {
@@ -230,7 +261,7 @@ class ShareToGroup extends React.Component {
         toaster.danger(errMessage);
       });
     } else {
-      seafileAPI.shareFolder(repoID, path, 'group', this.state.permission, [this.state.selectedOption['id']]).then(res => {
+      seafileAPI.shareFolder(repoID, path, 'group', permission, targetGroupIds).then(res => {
         let errorMsg = [];
         if (res.data.failed.length > 0) {
           for (let i = 0 ; i < res.data.failed.length ; i++) {
@@ -238,10 +269,17 @@ class ShareToGroup extends React.Component {
           }
         }
 
+        if (this.props.repo && res.data.success.length > 0) {
+          const sharedRepo = { ...this.props.repo, permission: res.data.success[0].permission };
+          targetGroupIds.forEach(targetGroupId => {
+            eventBus.dispatch(EVENT_BUS_TYPE.ADD_SHARED_REPO_INTO_GROUP, { repo: sharedRepo, group_id: targetGroupId });
+          });
+        }
+
         this.setState({
           errorMsg: errorMsg,
           sharedItems: this.state.sharedItems.concat(res.data.success),
-          selectedOption: null,
+          selectedOptions: [],
           permission: 'rw'
         });
       }).catch(error => {
@@ -252,10 +290,12 @@ class ShareToGroup extends React.Component {
   };
 
   deleteShareItem = (groupID) => {
-    let path = this.props.itemPath;
-    let repoID = this.props.repoID;
-    if (this.props.isGroupOwnedRepo) {
+    const eventBus = EventBus.getInstance();
+    const { isGroupOwnedRepo, itemPath: path, repoID } = this.props;
+    if (isGroupOwnedRepo) {
       seafileAPI.deleteGroupOwnedRepoSharedGroupItem(repoID, groupID, path).then(() => {
+        eventBus.dispatch(EVENT_BUS_TYPE.UNSHARE_REPO_TO_GROUP, { repo_id: repoID, group_id: groupID });
+
         this.setState({
           sharedItems: this.state.sharedItems.filter(item => { return item.group_info.id !== groupID; })
         });
@@ -265,6 +305,8 @@ class ShareToGroup extends React.Component {
       });
     } else {
       seafileAPI.deleteShareToGroupItem(repoID, path, 'group', groupID).then(() => {
+        eventBus.dispatch(EVENT_BUS_TYPE.UNSHARE_REPO_TO_GROUP, { repo_id: repoID, group_id: groupID });
+
         this.setState({
           sharedItems: this.state.sharedItems.filter(item => { return item.group_info.id !== groupID; })
         });
@@ -306,7 +348,7 @@ class ShareToGroup extends React.Component {
       }
       return sharedItem;
     });
-    this.setState({sharedItems: sharedItems});
+    this.setState({ sharedItems: sharedItems });
   };
 
   render() {
@@ -326,13 +368,14 @@ class ShareToGroup extends React.Component {
           <tbody>
             <tr>
               <td>
-                <SeahubSelect
-                  onChange={this.handleSelectChange}
+                <GroupSelect
+                  selectedOptions={this.state.selectedOptions}
                   options={this.state.options}
-                  placeholder={gettext('Select groups')}
-                  maxMenuHeight={200}
-                  value={this.state.selectedOption}
-                  components={{ NoOptionsMessage: NoGroupMessage }}
+                  onSelectOption={this.onSelectOption}
+                  onDeleteOption={this.onDeleteOption}
+                  searchPlaceholder={gettext('Search groups')}
+                  noOptionsPlaceholder={gettext('No results')}
+                  isInModal={true}
                 />
               </td>
               <td>
@@ -344,11 +387,12 @@ class ShareToGroup extends React.Component {
                   permissions={this.permissions}
                   onPermissionChanged={this.setPermission}
                   enableAddCustomPermission={isPro}
+                  isWiki={this.state.isWiki}
                   onAddCustomPermissionToggle={this.props.onAddCustomPermissionToggle}
                 />
               </td>
               <td>
-                <Button onClick={this.shareToGroup}>{gettext('Submit')}</Button>
+                <Button color="primary" onClick={this.shareToGroup}>{gettext('Submit')}</Button>
               </td>
             </tr>
             {this.state.errorMsg.length > 0 &&
