@@ -1,15 +1,16 @@
 import React from 'react';
 import PropTypes from 'prop-types';
-import { Button, Modal, ModalHeader, ModalBody, ModalFooter } from 'reactstrap';
+import { Button, Modal, ModalBody, ModalFooter } from 'reactstrap';
 import { gettext } from '../../../utils/constants';
-import { seafileAPI } from '../../../utils/seafile-api';
+import { systemAdminAPI } from '../../../utils/system-admin-api';
 import { Utils } from '../../../utils/utils';
 import toaster from '../../toast';
 import UserSelect from '../../user-select';
+import SeahubModalHeader from '@/components/common/seahub-modal-header';
 
 const propTypes = {
   toggle: PropTypes.func.isRequired,
-  groupID:  PropTypes.string.isRequired,
+  groupID: PropTypes.string.isRequired,
   onAddNewMembers: PropTypes.func.isRequired
 };
 
@@ -32,7 +33,7 @@ class AddMemberDialog extends React.Component {
     const emails = this.state.selectedOption.map(item => item.email);
     this.refs.orgSelect.clearSelect();
     this.setState({ errMessage: [] });
-    seafileAPI.sysAdminAddGroupMember(this.props.groupID, emails).then((res) => {
+    systemAdminAPI.sysAdminAddGroupMember(this.props.groupID, emails).then((res) => {
       this.setState({ selectedOption: null });
       if (res.data.failed.length > 0) {
         this.setState({ errMessage: res.data.failed[0].error_msg });
@@ -50,7 +51,7 @@ class AddMemberDialog extends React.Component {
   render() {
     return (
       <Modal isOpen={true} toggle={this.props.toggle}>
-        <ModalHeader toggle={this.props.toggle}>{gettext('Add Member')}</ModalHeader>
+        <SeahubModalHeader toggle={this.props.toggle}>{gettext('Add Member')}</SeahubModalHeader>
         <ModalBody>
           <UserSelect
             placeholder={gettext('Search users')}
