@@ -1,9 +1,9 @@
 import React from 'react';
 import PropTypes from 'prop-types';
-import { Button, Modal, ModalHeader, Input, ModalBody, ModalFooter, Form, FormGroup, Label, Alert } from 'reactstrap';
+import { Button, Modal, Input, ModalBody, ModalFooter, Form, FormGroup, Label, Alert } from 'reactstrap';
 import { gettext } from '../../../utils/constants';
 import UserSelect from '../../user-select';
-
+import SeahubModalHeader from '@/components/common/seahub-modal-header';
 
 const propTypes = {
   createGroup: PropTypes.func.isRequired,
@@ -24,12 +24,12 @@ class SysAdminCreateGroupDialog extends React.Component {
 
   handleRepoNameChange = (e) => {
     if (!e.target.value.trim()) {
-      this.setState({isSubmitBtnActive: false});
+      this.setState({ isSubmitBtnActive: false });
     } else {
-      this.setState({isSubmitBtnActive: true});
+      this.setState({ isSubmitBtnActive: true });
     }
 
-    this.setState({groupName: e.target.value});
+    this.setState({ groupName: e.target.value });
   };
 
   handleSubmit = () => {
@@ -38,9 +38,9 @@ class SysAdminCreateGroupDialog extends React.Component {
   };
 
   handleSelectChange = (option) => {
-    // option can be null
+    // option can be `null`, `[{...}]`, or `[]`
     this.setState({
-      ownerEmail: option ? option.email : ''
+      ownerEmail: option && option.length ? option[0].email : ''
     });
   };
 
@@ -58,7 +58,7 @@ class SysAdminCreateGroupDialog extends React.Component {
   render() {
     return (
       <Modal isOpen={true} toggle={this.toggle} autoFocus={false}>
-        <ModalHeader toggle={this.toggle}>{gettext('New Group')}</ModalHeader>
+        <SeahubModalHeader toggle={this.toggle}>{gettext('New Group')}</SeahubModalHeader>
         <ModalBody>
           <Form>
             <FormGroup>
@@ -76,7 +76,6 @@ class SysAdminCreateGroupDialog extends React.Component {
               </Label>
               <UserSelect
                 isMulti={false}
-                className="reviewer-select"
                 placeholder={gettext('Select a user')}
                 onSelectChange={this.handleSelectChange}
               />
