@@ -1,8 +1,9 @@
 import React from 'react';
 import PropTypes from 'prop-types';
-import { Button, Modal, ModalHeader, ModalBody, ModalFooter } from 'reactstrap';
+import { Button, Modal, ModalBody, ModalFooter } from 'reactstrap';
 import { gettext } from '../../../utils/constants';
 import UserSelect from '../../user-select';
+import SeahubModalHeader from '@/components/common/seahub-modal-header';
 
 const propTypes = {
   repoName: PropTypes.string.isRequired,
@@ -20,7 +21,7 @@ class SysAdminRepoTransferDialog extends React.Component {
   }
 
   handleSelectChange = (option) => {
-    this.setState({selectedOption: option});
+    this.setState({ selectedOption: option });
   };
 
   submit = () => {
@@ -30,19 +31,18 @@ class SysAdminRepoTransferDialog extends React.Component {
 
   render() {
     const repoName = this.props.repoName;
-    const innerSpan = '<span class="op-target" title=' + repoName + '>' + repoName +'</span>';
+    const innerSpan = '<span class="op-target" title=' + repoName + '>' + repoName + '</span>';
     let msg = gettext('Transfer Library {library_name}');
     let message = msg.replace('{library_name}', innerSpan);
     return (
       <Modal isOpen={true} toggle={this.props.toggle}>
-        <ModalHeader toggle={this.props.toggle}>
-          <div dangerouslySetInnerHTML={{__html:message}} />
-        </ModalHeader>
+        <SeahubModalHeader toggle={this.props.toggle}>
+          <div dangerouslySetInnerHTML={{ __html: message }} />
+        </SeahubModalHeader>
         <ModalBody>
           <UserSelect
             ref="userSelect"
             isMulti={false}
-            className="reviewer-select"
             placeholder={gettext('Search users')}
             onSelectChange={this.handleSelectChange}
           />
