@@ -3,10 +3,11 @@ import PropTypes from 'prop-types';
 import { Button } from 'reactstrap';
 import { isPro, gettext } from '../../../utils/constants';
 import { seafileAPI } from '../../../utils/seafile-api';
+import { systemAdminAPI } from '../../../utils/system-admin-api';
 import { Utils } from '../../../utils/utils';
 import toaster from '../../toast';
 import SharePermissionEditor from '../../select-editor/share-permission-editor';
-import { SeahubSelect, NoGroupMessage } from '../../common/select';
+import GroupSelect from '../../common/group-select';
 
 class GroupItem extends React.Component {
 
@@ -18,11 +19,11 @@ class GroupItem extends React.Component {
   }
 
   onMouseEnter = () => {
-    this.setState({isOperationShow: true});
+    this.setState({ isOperationShow: true });
   };
 
   onMouseLeave = () => {
-    this.setState({isOperationShow: false});
+    this.setState({ isOperationShow: false });
   };
 
   deleteShareItem = () => {
@@ -50,6 +51,7 @@ class GroupItem extends React.Component {
             currentPermission={currentPermission}
             permissions={this.props.permissions}
             onPermissionChanged={this.onChangeUserPermission}
+            isSysAdmin={true}
           />
         </td>
         <td>
@@ -114,7 +116,7 @@ class SysAdminShareToGroup extends React.Component {
   constructor(props) {
     super(props);
     this.state = {
-      selectedOption: null,
+      selectedOptions: [],
       errorMsg: [],
       permission: 'rw',
       sharedItems: []
@@ -126,10 +128,6 @@ class SysAdminShareToGroup extends React.Component {
     }
   }
 
-  handleSelectChange = (option) => {
-    this.setState({selectedOption: option});
-  };
-
   componentDidMount() {
     this.loadOptions();
     this.listSharedGroups();
@@ -140,6 +138,7 @@ class SysAdminShareToGroup extends React.Component {
       this.options = [];
       for (let i = 0 ; i < res.data.length; i++) {
         let obj = {};
+        obj.name = res.data[i].name;
         obj.value = res.data[i].name;
         obj.id = res.data[i].id;
         obj.label = res.data[i].name;
@@ -151,10 +150,30 @@ class SysAdminShareToGroup extends React.Component {
     });
   };
 
+  onSelectOption = (option) => {
+    const selectedOptions = this.state.selectedOptions.slice(0);
+    const index = selectedOptions.findIndex(item => item.id === option.id);
+    if (index > -1) {
+      selectedOptions.splice(index, 1);
+    } else {
+      selectedOptions.push(option);
+    }
+    this.setState({ selectedOptions: selectedOptions });
+  };
+
+  onDeleteOption = (option) => {
+    const selectedOptions = this.state.selectedOptions.slice(0);
+    const index = selectedOptions.findIndex(item => item.id === option.id);
+    if (index > -1) {
+      selectedOptions.splice(index, 1);
+    }
+    this.setState({ selectedOptions: selectedOptions });
+  };
+
   listSharedGroups = () => {
     let repoID = this.props.repoID;
-    seafileAPI.sysAdminListRepoSharedItems(repoID, 'group').then((res) => {
-      if(res.data.length !== 0) {
+    systemAdminAPI.sysAdminListRepoSharedItems(repoID, 'group').then((res) => {
+      if (res.data.length !== 0) {
         this.setState({
           sharedItems: res.data
         });
@@ -166,18 +185,15 @@ class SysAdminShareToGroup extends React.Component {
   };
 
   setPermission = (permission) => {
-    this.setState({permission: permission});
+    this.setState({ permission: permission });
   };
 
   shareToGroup = () => {
-    let groups = [];
     let repoID = this.props.repoID;
-    if (this.state.selectedOption && this.state.selectedOption.length > 0 ) {
-      for (let i = 0; i < this.state.selectedOption.length; i ++) {
-        groups[i] = this.state.selectedOption[i].id;
-      }
-    }
-    seafileAPI.sysAdminAddRepoSharedItem(repoID, 'group', groups, this.state.permission).then(res => {
+    let { selectedOptions } = this.state;
+    if (selectedOptions.length === 0) return;
+    let targetGroupIDs = selectedOptions.map(item => { return item.id; });
+    systemAdminAPI.sysAdminAddRepoSharedItem(repoID, 'group', targetGroupIDs, this.state.permission).then(res => {
       let errorMsg = [];
       if (res.data.failed.length > 0) {
         for (let i = 0 ; i < res.data.failed.length ; i++) {
@@ -188,7 +204,7 @@ class SysAdminShareToGroup extends React.Component {
       this.setState({
         errorMsg: errorMsg,
         sharedItems: this.state.sharedItems.concat(items),
-        selectedOption: null,
+        selectedOptions: [],
         permission: 'rw',
       });
     }).catch(error => {
@@ -199,7 +215,7 @@ class SysAdminShareToGroup extends React.Component {
 
   deleteShareItem = (groupID) => {
     let repoID = this.props.repoID;
-    seafileAPI.sysAdminDeleteRepoSharedItem(repoID, 'group', groupID).then(() => {
+    systemAdminAPI.sysAdminDeleteRepoSharedItem(repoID, 'group', groupID).then(() => {
       this.setState({
         sharedItems: this.state.sharedItems.filter(item => { return item.group_id !== groupID; })
       });
@@ -212,7 +228,7 @@ class SysAdminShareToGroup extends React.Component {
   onChangeUserPermission = (item, permission) => {
     let repoID = this.props.repoID;
     let groupID = item.group_id;
-    seafileAPI.sysAdminUpdateRepoSharedItemPermission(repoID, 'group', groupID, permission).then(() => {
+    systemAdminAPI.sysAdminUpdateRepoSharedItemPermission(repoID, 'group', groupID, permission).then(() => {
       this.updateSharedItems(item, permission);
     }).catch(error => {
       let errMessage = Utils.getErrorMsg(error);
@@ -230,7 +246,7 @@ class SysAdminShareToGroup extends React.Component {
       }
       return sharedItem;
     });
-    this.setState({sharedItems: sharedItems});
+    this.setState({ sharedItems: sharedItems });
   };
 
   render() {
@@ -247,13 +263,14 @@ class SysAdminShareToGroup extends React.Component {
           <tbody>
             <tr>
               <td>
-                <SeahubSelect
-                  onChange={this.handleSelectChange}
+                <GroupSelect
+                  selectedOptions={this.state.selectedOptions}
                   options={this.options}
-                  placeholder={gettext('Select groups')}
-                  maxMenuHeight={200}
-                  value={this.state.selectedOption}
-                  components={{ NoOptionsMessage: NoGroupMessage }}
+                  onSelectOption={this.onSelectOption}
+                  onDeleteOption={this.onDeleteOption}
+                  searchPlaceholder={gettext('Search groups')}
+                  noOptionsPlaceholder={gettext('No results')}
+                  isInModal={true}
                 />
               </td>
               <td>
@@ -264,10 +281,11 @@ class SysAdminShareToGroup extends React.Component {
                   currentPermission={this.state.permission}
                   permissions={this.permissions}
                   onPermissionChanged={this.setPermission}
+                  isSysAdmin={true}
                 />
               </td>
               <td>
-                <Button onClick={this.shareToGroup}>{gettext('Submit')}</Button>
+                <Button color="primary" onClick={this.shareToGroup}>{gettext('Submit')}</Button>
               </td>
             </tr>
             {this.state.errorMsg.length > 0 &&
