@@ -2,7 +2,7 @@ import React, { Fragment } from 'react';
 import PropTypes from 'prop-types';
 import { isPro, gettext } from '../../../utils/constants';
 import { Button } from 'reactstrap';
-import { seafileAPI } from '../../../utils/seafile-api';
+import { systemAdminAPI } from '../../../utils/system-admin-api';
 import { Utils } from '../../../utils/utils';
 import toaster from '../../toast';
 import UserSelect from '../../user-select';
@@ -18,11 +18,11 @@ class UserItem extends React.Component {
   }
 
   onMouseEnter = () => {
-    this.setState({isOperationShow: true});
+    this.setState({ isOperationShow: true });
   };
 
   onMouseLeave = () => {
-    this.setState({isOperationShow: false});
+    this.setState({ isOperationShow: false });
   };
 
   deleteShareItem = () => {
@@ -50,6 +50,7 @@ class UserItem extends React.Component {
             currentPermission={currentPermission}
             permissions={this.props.permissions}
             onPermissionChanged={this.onChangeUserPermission}
+            isSysAdmin={true}
           />
         </td>
         <td>
@@ -126,15 +127,15 @@ class SysAdminShareToUser extends React.Component {
   }
 
   handleSelectChange = (option) => {
-    this.setState({selectedOption: option});
+    this.setState({ selectedOption: option });
     this.options = [];
   };
 
   componentDidMount() {
     let repoID = this.props.repoID;
-    seafileAPI.sysAdminListRepoSharedItems(repoID, 'user').then((res) => {
-      if(res.data.length !== 0) {
-        this.setState({sharedItems: res.data});
+    systemAdminAPI.sysAdminListRepoSharedItems(repoID, 'user').then((res) => {
+      if (res.data.length !== 0) {
+        this.setState({ sharedItems: res.data });
       }
     }).catch(error => {
       let errMessage = Utils.getErrorMsg(error);
@@ -143,18 +144,18 @@ class SysAdminShareToUser extends React.Component {
   }
 
   setPermission = (permission) => {
-    this.setState({permission: permission});
+    this.setState({ permission: permission });
   };
 
   shareToUser = () => {
     let users = [];
     let repoID = this.props.repoID;
-    if (this.state.selectedOption && this.state.selectedOption.length > 0 ) {
+    if (this.state.selectedOption && this.state.selectedOption.length > 0) {
       for (let i = 0; i < this.state.selectedOption.length; i ++) {
         users[i] = this.state.selectedOption[i].email;
       }
     }
-    seafileAPI.sysAdminAddRepoSharedItem(repoID, 'user' , users, this.state.permission).then(res => {
+    systemAdminAPI.sysAdminAddRepoSharedItem(repoID, 'user', users, this.state.permission).then(res => {
       let errorMsg = [];
       if (res.data.failed.length > 0) {
         for (let i = 0 ; i < res.data.failed.length ; i++) {
@@ -184,9 +185,9 @@ class SysAdminShareToUser extends React.Component {
 
   deleteShareItem = (useremail) => {
     let repoID = this.props.repoID;
-    seafileAPI.sysAdminDeleteRepoSharedItem(repoID, 'user', useremail).then(res => {
+    systemAdminAPI.sysAdminDeleteRepoSharedItem(repoID, 'user', useremail).then(res => {
       this.setState({
-        sharedItems: this.state.sharedItems.filter( item => { return item.user_email !== useremail; })
+        sharedItems: this.state.sharedItems.filter(item => { return item.user_email !== useremail; })
       });
     }).catch(error => {
       let errMessage = Utils.getErrorMsg(error);
@@ -197,7 +198,7 @@ class SysAdminShareToUser extends React.Component {
   onChangeUserPermission = (item, permission) => {
     let repoID = this.props.repoID;
     let userEmail = item.user_email;
-    seafileAPI.sysAdminUpdateRepoSharedItemPermission(repoID, 'user', userEmail, permission).then(() => {
+    systemAdminAPI.sysAdminUpdateRepoSharedItemPermission(repoID, 'user', userEmail, permission).then(() => {
       this.updateSharedItems(item, permission);
     }).catch(error => {
       let errMessage = Utils.getErrorMsg(error);
@@ -215,7 +216,7 @@ class SysAdminShareToUser extends React.Component {
       }
       return sharedItem;
     });
-    this.setState({sharedItems: sharedItems});
+    this.setState({ sharedItems: sharedItems });
   };
 
   render() {
@@ -236,7 +237,6 @@ class SysAdminShareToUser extends React.Component {
                 <UserSelect
                   ref="userSelect"
                   isMulti={true}
-                  className="reviewer-select"
                   placeholder={gettext('Search users')}
                   onSelectChange={this.handleSelectChange}
                 />
@@ -249,10 +249,11 @@ class SysAdminShareToUser extends React.Component {
                   currentPermission={this.state.permission}
                   permissions={this.permissions}
                   onPermissionChanged={this.setPermission}
+                  isSysAdmin={true}
                 />
               </td>
               <td>
-                <Button onClick={this.shareToUser}>{gettext('Submit')}</Button>
+                <Button color="primary" onClick={this.shareToUser}>{gettext('Submit')}</Button>
               </td>
             </tr>
             {this.state.errorMsg.length > 0 &&
