@@ -1,8 +1,9 @@
 import React from 'react';
 import PropTypes from 'prop-types';
-import { Modal, ModalHeader, ModalBody } from 'reactstrap';
+import { Modal, ModalBody } from 'reactstrap';
 import { SimpleEditor } from '@seafile/seafile-editor';
 import { gettext } from '../../utils/constants';
+import SeahubModalHeader from '@/components/common/seahub-modal-header';
 
 const propTypes = {
   title: PropTypes.string,
@@ -39,7 +40,7 @@ class TermsEditorDialog extends React.Component {
   };
 
   onContentChanged = () => {
-    return this.setState({isValueChanged: true});
+    return this.setState({ isValueChanged: true });
   };
 
   getCurrentContent = () => {
@@ -61,9 +62,9 @@ class TermsEditorDialog extends React.Component {
         className={'conditions-editor-dialog'}
         contentClassName={'conditions-editor-dialog-content'}
         size={'lg'}
-        style={{width: 770}}
+        style={{ width: 770 }}
       >
-        <ModalHeader className="conditions-editor-dialog-title" toggle={this.toggle}>{title}</ModalHeader>
+        <SeahubModalHeader className="conditions-editor-dialog-title" toggle={this.toggle}>{title}</SeahubModalHeader>
         <ModalBody className={'conditions-editor-dialog-main'}>
           <SimpleEditor
             ref={this.editorRef}
