@@ -1,10 +1,11 @@
 import React from 'react';
 import PropTypes from 'prop-types';
-import { Modal, ModalHeader, ModalBody } from 'reactstrap';
+import { Modal, ModalBody } from 'reactstrap';
 import { mediaUrl, gettext, fileServerRoot } from '../../utils/constants';
 import { seafileAPI } from '../../utils/seafile-api';
 import { Utils } from '../../utils/utils';
 import Loading from '../loading';
+import SeahubModalHeader from '@/components/common/seahub-modal-header';
 
 const propTypes = {
   data: PropTypes.object,
@@ -81,7 +82,7 @@ class ZipDownloadDialog extends React.Component {
         });
       } else {
         this.setState({
-          zipProgress: data.total == 0 ? '100%' : (data.zipped/data.total*100).toFixed(2) + '%'
+          zipProgress: data.total == 0 ? '100%' : (data.zipped / data.total * 100).toFixed(2) + '%'
         });
         if (data['total'] == data['zipped']) {
           clearInterval(interval);
@@ -120,7 +121,7 @@ class ZipDownloadDialog extends React.Component {
   render() {
     return (
       <Modal isOpen={true} toggle={this.toggleDialog}>
-        <ModalHeader toggle={this.toggleDialog}>{gettext('Download')}</ModalHeader>
+        <SeahubModalHeader toggle={this.toggleDialog}>{gettext('Download')}</SeahubModalHeader>
         <ModalBody>
           <Content data={this.state} />
         </ModalBody>
@@ -132,7 +133,7 @@ class ZipDownloadDialog extends React.Component {
 class Content extends React.Component {
 
   render() {
-    const {isLoading, errorMsg, zipProgress} = this.props.data;
+    const { isLoading, errorMsg, zipProgress } = this.props.data;
 
     if (isLoading) {
       return <Loading />;
