@@ -8,10 +8,11 @@ const propTypes = {
   path: PropTypes.string.isRequired,
   repoID: PropTypes.string.isRequired,
   currentRepoInfo: PropTypes.object.isRequired,
-  draftCounts: PropTypes.number,
   usedRepoTags: PropTypes.array.isRequired,
   updateUsedRepoTags: PropTypes.func.isRequired,
   direntList: PropTypes.array.isRequired,
+  selectedDirentList: PropTypes.array.isRequired,
+  onSelectedDirentListUpdate: PropTypes.func.isRequired,
   onItemClick: PropTypes.func.isRequired,
   onGridItemClick: PropTypes.func,
   onAddFile: PropTypes.func.isRequired,
@@ -19,19 +20,24 @@ const propTypes = {
   onItemMove: PropTypes.func.isRequired,
   onItemCopy: PropTypes.func.isRequired,
   onItemConvert: PropTypes.func.isRequired,
+  onItemsMove: PropTypes.func.isRequired,
+  onItemsCopy: PropTypes.func.isRequired,
+  onItemsDelete: PropTypes.func.isRequired,
   onRenameNode: PropTypes.func.isRequired,
   isGroupOwnedRepo: PropTypes.bool.isRequired,
   userPerm: PropTypes.string,
   isRepoInfoBarShow: PropTypes.bool.isRequired,
   isDirentListLoading: PropTypes.bool.isRequired,
-  isDirentDetailShow: PropTypes.bool.isRequired,
   enableDirPrivateShare: PropTypes.bool.isRequired,
   updateDirent: PropTypes.func.isRequired,
   showDirentDetail: PropTypes.func.isRequired,
   onAddFolder: PropTypes.func.isRequired,
+  repoTags: PropTypes.array.isRequired,
   onFileTagChanged: PropTypes.func,
   onItemRename: PropTypes.func.isRequired,
   fullDirentList: PropTypes.array,
+  getMenuContainerSize: PropTypes.func,
+  eventBus: PropTypes.object,
 };
 
 class DirGridView extends React.Component {
@@ -43,6 +49,10 @@ class DirGridView extends React.Component {
           path={this.props.path}
           isDirentListLoading={this.props.isDirentListLoading}
           onAddFile={this.props.onAddFile}
+          currentRepoInfo={this.props.currentRepoInfo}
+          userPerm={this.props.userPerm}
+          onAddFolder={this.props.onAddFolder}
+          getMenuContainerSize={this.props.getMenuContainerSize}
         />
       );
     }
@@ -52,7 +62,6 @@ class DirGridView extends React.Component {
           <RepoInfoBar
             repoID={this.props.repoID}
             currentPath={this.props.path}
-            draftCounts={this.props.draftCounts}
             usedRepoTags={this.props.usedRepoTags}
             updateUsedRepoTags={this.props.updateUsedRepoTags}
             onFileTagChanged={this.props.onFileTagChanged}
@@ -67,21 +76,28 @@ class DirGridView extends React.Component {
           enableDirPrivateShare={this.props.enableDirPrivateShare}
           direntList={this.props.direntList}
           fullDirentList={this.props.fullDirentList}
+          selectedDirentList={this.props.selectedDirentList}
+          onSelectedDirentListUpdate={this.props.onSelectedDirentListUpdate}
           onAddFile={this.props.onAddFile}
           onItemClick={this.props.onItemClick}
           onItemDelete={this.props.onItemDelete}
           onItemMove={this.props.onItemMove}
           onItemCopy={this.props.onItemCopy}
           onItemConvert={this.props.onItemConvert}
+          onItemsMove={this.props.onItemsMove}
+          onItemsCopy={this.props.onItemsCopy}
+          onItemsDelete={this.props.onItemsDelete}
           isDirentListLoading={this.props.isDirentListLoading}
           updateDirent={this.props.updateDirent}
           onRenameNode={this.props.onRenameNode}
           showDirentDetail={this.props.showDirentDetail}
           onGridItemClick={this.props.onGridItemClick}
-          isDirentDetailShow={this.props.isDirentDetailShow}
           onItemRename={this.props.onItemRename}
           onAddFolder={this.props.onAddFolder}
+          repoTags={this.props.repoTags}
           onFileTagChanged={this.props.onFileTagChanged}
+          getMenuContainerSize={this.props.getMenuContainerSize}
+          eventBus={this.props.eventBus}
         />
       </Fragment>
     );
