@@ -3,6 +3,7 @@ import PropTypes from 'prop-types';
 import DirentNoneView from '../../components/dirent-list-view/dirent-none-view';
 import RepoInfoBar from '../../components/repo-info-bar';
 import DirentListView from '../../components/dirent-list-view/dirent-list-view';
+import Loading from '../loading';
 
 const propTypes = {
   path: PropTypes.string.isRequired,
@@ -12,8 +13,8 @@ const propTypes = {
   userPerm: PropTypes.string,
   enableDirPrivateShare: PropTypes.bool.isRequired,
   isRepoInfoBarShow: PropTypes.bool.isRequired,
+  repoTags: PropTypes.array.isRequired,
   usedRepoTags: PropTypes.array.isRequired,
-  draftCounts: PropTypes.number,
   updateUsedRepoTags: PropTypes.func.isRequired,
   isDirentListLoading: PropTypes.bool.isRequired,
   direntList: PropTypes.array.isRequired,
@@ -41,6 +42,8 @@ const propTypes = {
   showDirentDetail: PropTypes.func.isRequired,
   loadDirentList: PropTypes.func,
   fullDirentList: PropTypes.array,
+  getMenuContainerSize: PropTypes.func,
+  eventBus: PropTypes.object,
 };
 
 class DirListView extends React.Component {
@@ -53,6 +56,10 @@ class DirListView extends React.Component {
           path={this.props.path}
           isDirentListLoading={this.props.isDirentListLoading}
           onAddFile={this.props.onAddFile}
+          currentRepoInfo={this.props.currentRepoInfo}
+          userPerm={this.props.userPerm}
+          onAddFolder={this.props.onAddFolder}
+          getMenuContainerSize={this.props.getMenuContainerSize}
         />
       );
     }
@@ -63,46 +70,51 @@ class DirListView extends React.Component {
           <RepoInfoBar
             repoID={this.props.repoID}
             currentPath={this.props.path}
-            draftCounts={this.props.draftCounts}
             usedRepoTags={this.props.usedRepoTags}
             updateUsedRepoTags={this.props.updateUsedRepoTags}
             onFileTagChanged={this.props.onFileTagChanged}
           />
         )}
-        <DirentListView
-          path={this.props.path}
-          currentRepoInfo={this.props.currentRepoInfo}
-          repoID={this.props.repoID}
-          isGroupOwnedRepo={this.props.isGroupOwnedRepo}
-          userPerm={this.props.userPerm}
-          enableDirPrivateShare={this.props.enableDirPrivateShare}
-          direntList={this.props.direntList}
-          fullDirentList={this.props.fullDirentList}
-          sortBy={this.props.sortBy}
-          sortOrder={this.props.sortOrder}
-          sortItems={this.props.sortItems}
-          onItemClick={this.props.onItemClick}
-          onItemSelected={this.props.onItemSelected}
-          onItemDelete={this.props.onItemDelete}
-          onItemRename={this.props.onItemRename}
-          onItemMove={this.props.onItemMove}
-          onItemCopy={this.props.onItemCopy}
-          onDirentClick={this.props.onDirentClick}
-          isDirentListLoading={this.props.isDirentListLoading}
-          updateDirent={this.props.updateDirent}
-          isAllItemSelected={this.props.isAllItemSelected}
-          onAllItemSelected={this.props.onAllItemSelected}
-          selectedDirentList={this.props.selectedDirentList}
-          onItemsMove={this.props.onItemsMove}
-          onItemsCopy={this.props.onItemsCopy}
-          onItemConvert={this.props.onItemConvert}
-          onItemsDelete={this.props.onItemsDelete}
-          onAddFile={this.props.onAddFile}
-          onAddFolder={this.props.onAddFolder}
-          onFileTagChanged={this.props.onFileTagChanged}
-          showDirentDetail={this.props.showDirentDetail}
-          loadDirentList={this.props.loadDirentList}
-        />
+        {this.props.isDirentListLoading ? (
+          <Loading />
+        ) : (
+          <DirentListView
+            path={this.props.path}
+            currentRepoInfo={this.props.currentRepoInfo}
+            repoID={this.props.repoID}
+            isGroupOwnedRepo={this.props.isGroupOwnedRepo}
+            userPerm={this.props.userPerm}
+            enableDirPrivateShare={this.props.enableDirPrivateShare}
+            direntList={this.props.direntList}
+            fullDirentList={this.props.fullDirentList}
+            sortBy={this.props.sortBy}
+            sortOrder={this.props.sortOrder}
+            sortItems={this.props.sortItems}
+            onItemClick={this.props.onItemClick}
+            onItemSelected={this.props.onItemSelected}
+            onItemDelete={this.props.onItemDelete}
+            onItemRename={this.props.onItemRename}
+            onItemMove={this.props.onItemMove}
+            onItemCopy={this.props.onItemCopy}
+            onDirentClick={this.props.onDirentClick}
+            updateDirent={this.props.updateDirent}
+            isAllItemSelected={this.props.isAllItemSelected}
+            onAllItemSelected={this.props.onAllItemSelected}
+            selectedDirentList={this.props.selectedDirentList}
+            onItemsMove={this.props.onItemsMove}
+            onItemsCopy={this.props.onItemsCopy}
+            onItemConvert={this.props.onItemConvert}
+            onItemsDelete={this.props.onItemsDelete}
+            onAddFile={this.props.onAddFile}
+            onAddFolder={this.props.onAddFolder}
+            repoTags={this.props.repoTags}
+            onFileTagChanged={this.props.onFileTagChanged}
+            showDirentDetail={this.props.showDirentDetail}
+            loadDirentList={this.props.loadDirentList}
+            getMenuContainerSize={this.props.getMenuContainerSize}
+            eventBus={this.props.eventBus}
+          />
+        )}
       </Fragment>
     );
   }
