@@ -1,18 +1,19 @@
 import React, { Fragment } from 'react';
 import PropTypes from 'prop-types';
-import moment from 'moment';
+import dayjs from 'dayjs';
+import relativeTime from 'dayjs/plugin/relativeTime';
 import { v4 as uuidv4 } from 'uuid';
 import Icon from '../icon';
-import { gettext, canSetExProps } from '../../utils/constants';
+import { gettext, enableFileTags } from '../../utils/constants';
 import { Utils } from '../../utils/utils';
 import EditFileTagPopover from '../popover/edit-filetag-popover';
-import ExtraAttributesDialog from '../dialog/extra-attributes-dialog';
 import FileTagList from '../file-tag-list';
-import ConfirmApplyFolderPropertiesDialog from '../dialog/confirm-apply-folder-properties-dialog';
+import ExtraMetadataAttributesDialog from '../dialog/extra-metadata-attributes-dialog';
 
 const propTypes = {
   repoInfo: PropTypes.object.isRequired,
   repoID: PropTypes.string.isRequired,
+  repoTags: PropTypes.array.isRequired,
   dirent: PropTypes.object.isRequired,
   direntType: PropTypes.string.isRequired,
   direntDetail: PropTypes.object.isRequired,
@@ -21,19 +22,20 @@ const propTypes = {
   onFileTagChanged: PropTypes.func.isRequired,
 };
 
+dayjs.extend(relativeTime);
+
 class DetailListView extends React.Component {
 
   constructor(props) {
     super(props);
     this.state = {
       isEditFileTagShow: false,
-      isShowExtraProperties: false,
-      isShowApplyProperties: false
+      isShowMetadataExtraProperties: false,
     };
     this.tagListTitleID = `detail-list-view-tags-${uuidv4()}`;
   }
 
-  getDirentPosition = () => {
+  getFileParent = () => {
     let { repoInfo } = this.props;
     let direntPath = this.getDirentPath();
     let position = repoInfo.repo_name;
@@ -45,6 +47,14 @@ class DetailListView extends React.Component {
     return position;
   };
 
+  getDirentPath = () => {
+    if (Utils.isMarkdownFile(this.props.path)) {
+      return this.props.path; // column mode: view file
+    }
+    let { dirent, path } = this.props;
+    return Utils.joinPath(path, dirent.name);
+  };
+
   onEditFileTagToggle = () => {
     this.setState({
       isEditFileTagShow: !this.state.isEditFileTagShow
@@ -56,25 +66,13 @@ class DetailListView extends React.Component {
     this.props.onFileTagChanged(this.props.dirent, direntPath);
   };
 
-  getDirentPath = () => {
-    if (Utils.isMarkdownFile(this.props.path)) {
-      return this.props.path; // column mode: view file
-    }
-    let { dirent, path } = this.props;
-    return Utils.joinPath(path, dirent.name);
-  };
-
-  toggleExtraPropertiesDialog = () => {
-    this.setState({ isShowExtraProperties: !this.state.isShowExtraProperties });
-  };
-
-  toggleApplyPropertiesDialog = () => {
-    this.setState({ isShowApplyProperties: !this.state.isShowApplyProperties });
+  toggleExtraMetadataPropertiesDialog = () => {
+    this.setState({ isShowMetadataExtraProperties: !this.state.isShowMetadataExtraProperties });
   };
 
   renderTags = () => {
     const { direntType, direntDetail } = this.props;
-    const position = this.getDirentPosition();
+    const position = this.getFileParent();
     if (direntType === 'dir') {
       return (
         <table className="table-thead-hidden">
@@ -83,24 +81,13 @@ class DetailListView extends React.Component {
           </thead>
           <tbody>
             <tr><th>{gettext('Location')}</th><td>{position}</td></tr>
-            <tr><th>{gettext('Last Update')}</th><td>{moment(direntDetail.mtime).format('YYYY-MM-DD')}</td></tr>
-            {direntDetail.permission === 'rw' && canSetExProps && (
+            <tr><th>{gettext('Last Update')}</th><td>{dayjs(direntDetail.mtime).format('YYYY-MM-DD')}</td></tr>
+            {direntDetail.permission === 'rw' && window.app.pageOptions.enableMetadataManagement && (
               <Fragment>
                 <tr className="file-extra-attributes">
                   <th colSpan={2}>
-                    <div className="edit-file-extra-attributes-btn" onClick={this.toggleExtraPropertiesDialog}>
-                      {gettext('Edit extra properties')}
-                    </div>
-                  </th>
-                </tr>
-                <tr className="file-extra-attributes">
-                  <th colSpan={2}>
-                    <div
-                      className="edit-file-extra-attributes-btn text-truncate"
-                      onClick={this.toggleApplyPropertiesDialog}
-                      title={gettext('Apply properties to files inside the folder')}
-                    >
-                      {gettext('Apply properties to files inside the folder')}
+                    <div className="edit-file-extra-attributes-btn" onClick={this.toggleExtraMetadataPropertiesDialog}>
+                      {gettext('Edit metadata properties')}
                     </div>
                   </th>
                 </tr>
@@ -118,19 +105,21 @@ class DetailListView extends React.Component {
         <tbody>
           <tr><th>{gettext('Size')}</th><td>{Utils.bytesToSize(direntDetail.size)}</td></tr>
           <tr><th>{gettext('Location')}</th><td>{position}</td></tr>
-          <tr><th>{gettext('Last Update')}</th><td>{moment(direntDetail.last_modified).fromNow()}</td></tr>
+          <tr><th>{gettext('Last Update')}</th><td>{dayjs(direntDetail.last_modified).fromNow()}</td></tr>
           <tr className="file-tag-container">
             <th>{gettext('Tags')}</th>
             <td>
               <FileTagList fileTagList={this.props.fileTagList} />
-              <span onClick={this.onEditFileTagToggle} id={this.tagListTitleID}><Icon symbol='tag' /></span>
+              {enableFileTags &&
+                <span onClick={this.onEditFileTagToggle} id={this.tagListTitleID}><Icon symbol='tag' /></span>
+              }
             </td>
           </tr>
-          {direntDetail.permission === 'rw' && canSetExProps && (
+          {direntDetail.permission === 'rw' && window.app.pageOptions.enableMetadataManagement && (
             <tr className="file-extra-attributes">
               <th colSpan={2}>
-                <div className="edit-file-extra-attributes-btn" onClick={this.toggleExtraPropertiesDialog}>
-                  {gettext('Edit extra properties')}
+                <div className="edit-file-extra-attributes-btn" onClick={this.toggleExtraMetadataPropertiesDialog}>
+                  {gettext('Edit metadata properties')}
                 </div>
               </th>
             </tr>
@@ -150,6 +139,7 @@ class DetailListView extends React.Component {
         {this.state.isEditFileTagShow &&
           <EditFileTagPopover
             repoID={this.props.repoID}
+            repoTags={this.props.repoTags}
             filePath={direntPath}
             fileTagList={fileTagList}
             toggleCancel={this.onEditFileTagToggle}
@@ -158,20 +148,13 @@ class DetailListView extends React.Component {
             isEditFileTagShow={this.state.isEditFileTagShow}
           />
         }
-        {this.state.isShowExtraProperties && (
-          <ExtraAttributesDialog
+        {this.state.isShowMetadataExtraProperties && (
+          <ExtraMetadataAttributesDialog
             repoID={this.props.repoID}
             filePath={direntPath}
             direntType={direntType}
             direntDetail={direntDetail}
-            onToggle={this.toggleExtraPropertiesDialog}
-          />
-        )}
-        {this.state.isShowApplyProperties && (
-          <ConfirmApplyFolderPropertiesDialog
-            toggle={this.toggleApplyPropertiesDialog}
-            repoID={this.props.repoID}
-            path={direntPath}
+            onToggle={this.toggleExtraMetadataPropertiesDialog}
           />
         )}
       </Fragment>
