@@ -1,10 +1,10 @@
 import React, { Fragment } from 'react';
 import PropTypes from 'prop-types';
-import { siteRoot, gettext, username, enableSeadoc } from '../../utils/constants';
+import classnames from 'classnames';
+import { siteRoot, gettext, username, enableSeadoc, thumbnailSizeForOriginal, thumbnailDefaultSize, fileServerRoot, enableWhiteboard, useGoFileserver } from '../../utils/constants';
 import { Utils } from '../../utils/utils';
 import TextTranslation from '../../utils/text-translation';
 import URLDecorator from '../../utils/url-decorator';
-import Loading from '../loading';
 import toaster from '../toast';
 import ModalPortal from '../modal-portal';
 import CreateFile from '../dialog/create-file-dialog';
@@ -17,13 +17,17 @@ import DirentListItem from './dirent-list-item';
 import ContextMenu from '../context-menu/context-menu';
 import { hideMenu, showMenu } from '../context-menu/actions';
 import DirentsDraggedPreview from '../draggable/dirents-dragged-preview';
+import { EVENT_BUS_TYPE } from '../common/event-bus-type';
+import EmptyTip from '../empty-tip';
+import imageAPI from '../../utils/image-api';
+import { seafileAPI } from '../../utils/seafile-api';
+import FixedWidthTable from '../common/fixed-width-table';
 
 const propTypes = {
   path: PropTypes.string.isRequired,
   repoID: PropTypes.string.isRequired,
   currentRepoInfo: PropTypes.object,
   isAllItemSelected: PropTypes.bool.isRequired,
-  isDirentListLoading: PropTypes.bool.isRequired,
   direntList: PropTypes.array.isRequired,
   sortBy: PropTypes.string.isRequired,
   sortOrder: PropTypes.string.isRequired,
@@ -44,6 +48,7 @@ const propTypes = {
   onItemsCopy: PropTypes.func.isRequired,
   onItemConvert: PropTypes.func.isRequired,
   onItemsDelete: PropTypes.func.isRequired,
+  repoTags: PropTypes.array.isRequired,
   onFileTagChanged: PropTypes.func,
   enableDirPrivateShare: PropTypes.bool.isRequired,
   isGroupOwnedRepo: PropTypes.bool.isRequired,
@@ -53,6 +58,8 @@ const propTypes = {
   fullDirentList: PropTypes.array,
   posX: PropTypes.string,
   posY: PropTypes.string,
+  getMenuContainerSize: PropTypes.func,
+  eventBus: PropTypes.object,
 };
 
 class DirentListView extends React.Component {
@@ -71,7 +78,7 @@ class DirentListView extends React.Component {
       isCopyDialogShow: false,
       isProgressDialogShow: false,
       downloadItems: [],
-      isMutipleOperation: true,
+      isMultipleOperation: true,
       activeDirent: null,
       isListDropTipShow: false,
       isShowDirentsDraggablePreview: false,
@@ -97,12 +104,32 @@ class DirentListView extends React.Component {
     }
   }
 
+  componentDidMount() {
+    this.unsubscribeEvent = this.props.eventBus.subscribe(EVENT_BUS_TYPE.RESTORE_IMAGE, this.recalculateImageItems);
+  }
+
+  recalculateImageItems = () => {
+    if (!this.state.isImagePopupOpen) return;
+    let imageItems = this.props.direntList
+      .filter((item) => Utils.imageCheck(item.name))
+      .map((item) => this.prepareImageItem(item));
+
+    this.setState({
+      imageItems: imageItems,
+      imageIndex: this.state.imageIndex % imageItems.length,
+    });
+  };
+
+  componentWillUnmount() {
+    this.unsubscribeEvent();
+  }
+
   freezeItem = () => {
-    this.setState({isItemFreezed: true});
+    this.setState({ isItemFreezed: true });
   };
 
   unfreezeItem = () => {
-    this.setState({isItemFreezed: false});
+    this.setState({ isItemFreezed: false });
   };
 
   onItemRename = (dirent, newName) => {
@@ -122,18 +149,14 @@ class DirentListView extends React.Component {
     this.freezeItem();
   };
 
-  onItemSelected = (dirent) => {
-    this.setState({activeDirent: null});
-    this.props.onItemSelected(dirent);
+  onItemSelected = (dirent, event) => {
+    this.setState({ activeDirent: null });
+    this.props.onItemSelected(dirent, event);
   };
 
-  onDirentClick = (dirent) => {
+  onDirentClick = (dirent, event) => {
     hideMenu();
-    if (this.props.selectedDirentList.length > 0 && !this.state.activeDirent ) {
-      return;
-    }
-    this.setState({activeDirent: dirent});
-    this.props.onDirentClick(dirent);
+    this.props.onDirentClick(dirent, event);
   };
 
   sortByName = (e) => {
@@ -159,15 +182,35 @@ class DirentListView extends React.Component {
 
   // for image popup
   prepareImageItem = (item) => {
+    const { path: parentDir, repoID, currentRepoInfo } = this.props;
     const name = item.name;
-    const repoID = this.props.repoID;
-    const path = Utils.encodePath(Utils.joinPath(this.props.path, name));
-    const src = `${siteRoot}repo/${repoID}/raw${path}`;
+    const repoEncrypted = currentRepoInfo.encrypted;
+    const path = Utils.encodePath(Utils.joinPath(parentDir, name));
+    const fileExt = name.substr(name.lastIndexOf('.') + 1).toLowerCase();
+
+    let thumbnail = '';
+    const isGIF = fileExt === 'gif';
+    if (repoEncrypted || isGIF) {
+      thumbnail = `${siteRoot}repo/${repoID}/raw${path}`;
+    } else {
+      thumbnail = `${siteRoot}thumbnail/${repoID}/${thumbnailSizeForOriginal}${path}`;
+    }
+
+    let src = '';
+    const isTIFF = fileExt == 'tiff';
+    if (isTIFF) {
+      src = `${siteRoot}thumbnail/${repoID}/${thumbnailSizeForOriginal}${path}`;
+    } else {
+      src = `${siteRoot}repo/${repoID}/raw${path}`;
+    }
 
     return {
-      'name': name,
+      name,
+      thumbnail,
+      src,
+      parentDir,
       'url': `${siteRoot}lib/${repoID}/file${path}`,
-      'src': src
+      'downloadURL': `${fileServerRoot}repos/${repoID}/files${path}/?op=download`
     };
   };
 
@@ -183,7 +226,7 @@ class DirentListView extends React.Component {
     this.setState({
       isImagePopupOpen: true,
       imageItems: imageItems,
-      imageIndex: items.indexOf(curItem)
+      imageIndex: items.findIndex((item) => item.id === curItem.id),
     });
   };
 
@@ -201,8 +244,54 @@ class DirentListView extends React.Component {
     }));
   };
 
+  deleteImage = (name) => {
+    const item = this.props.fullDirentList.find((item) => item.name === name);
+    this.props.onItemDelete(item);
+
+    const newImageItems = this.props.fullDirentList
+      .filter((item) => item.name !== name && Utils.imageCheck(item.name))
+      .map((item) => this.prepareImageItem(item));
+
+    this.setState((prevState) => ({
+      isImagePopupOpen: newImageItems.length > 0,
+      imageItems: newImageItems,
+      imageIndex: prevState.imageIndex % newImageItems.length,
+    }));
+  };
+
+  handleError = (error) => {
+    toaster.danger(Utils.getErrorMsg(error));
+  };
+
+  rotateImage = (imageIndex, angle) => {
+    if (imageIndex >= 0 && angle !== 0) {
+      let { repoID } = this.props;
+      let imageName = this.state.imageItems[imageIndex].name;
+      let path = Utils.joinPath(this.props.path, imageName);
+      imageAPI.rotateImage(repoID, path, 360 - angle).then((res) => {
+        seafileAPI.createThumbnail(repoID, path, thumbnailDefaultSize).then((res) => {
+          // Generate a unique query parameter to bust the cache
+          const cacheBuster = new Date().getTime();
+          const newThumbnailSrc = `${res.data.encoded_thumbnail_src}?t=${cacheBuster}`;
+          this.setState((prevState) => {
+            const updatedImageItems = [...prevState.imageItems];
+            updatedImageItems[imageIndex].src = newThumbnailSrc;
+            return { imageItems: updatedImageItems };
+          });
+          // Update the thumbnail URL with the cache-busting query parameter
+          const item = this.props.direntList.find((item) => item.name === imageName);
+          this.props.updateDirent(item, 'encoded_thumbnail_src', newThumbnailSrc);
+        }).catch(error => {
+          this.handleError(error);
+        });
+      }).catch(error => {
+        this.handleError(error);
+      });
+    }
+  };
+
   closeImagePopup = () => {
-    this.setState({isImagePopupOpen: false});
+    this.setState({ isImagePopupOpen: false });
   };
 
   onCreateFileToggle = (fileType) => {
@@ -213,11 +302,11 @@ class DirentListView extends React.Component {
   };
 
   onCreateFolderToggle = () => {
-    this.setState({isCreateFolderDialogShow: !this.state.isCreateFolderDialogShow});
+    this.setState({ isCreateFolderDialogShow: !this.state.isCreateFolderDialogShow });
   };
 
   onAddFolder = (dirPath) => {
-    this.setState({isCreateFolderDialogShow: false});
+    this.setState({ isCreateFolderDialogShow: false });
     this.props.onAddFolder(dirPath);
   };
 
@@ -230,11 +319,11 @@ class DirentListView extends React.Component {
   };
 
   onMoveToggle = () => {
-    this.setState({isMoveDialogShow: !this.state.isMoveDialogShow});
+    this.setState({ isMoveDialogShow: !this.state.isMoveDialogShow });
   };
 
   onCopyToggle = () => {
-    this.setState({isCopyDialogShow: !this.state.isCopyDialogShow});
+    this.setState({ isCopyDialogShow: !this.state.isCopyDialogShow });
   };
 
   onItemsDownload = () => {
@@ -242,8 +331,8 @@ class DirentListView extends React.Component {
     if (selectedDirentList.length) {
       if (selectedDirentList.length === 1 && !selectedDirentList[0].isDir()) {
         let direntPath = Utils.joinPath(path, selectedDirentList[0].name);
-        let url = URLDecorator.getUrl({type: 'download_file_url', repoID: repoID, filePath: direntPath});
-        location.href= url;
+        let url = URLDecorator.getUrl({ type: 'download_file_url', repoID: repoID, filePath: direntPath });
+        location.href = url;
         return;
       }
 
@@ -251,21 +340,31 @@ class DirentListView extends React.Component {
         return dirent.name;
       });
 
-      this.setState({
-        isProgressDialogShow: true,
-        downloadItems: selectedDirentNames
-      });
+      if (useGoFileserver) {
+        seafileAPI.zipDownload(repoID, path, selectedDirentNames).then((res) => {
+          const zipToken = res.data['zip_token'];
+          location.href = `${fileServerRoot}zip/${zipToken}`;
+        }).catch((error) => {
+          let errorMsg = Utils.getErrorMsg(error);
+          toaster.danger(errorMsg);
+        });
+      } else {
+        this.setState({
+          isProgressDialogShow: true,
+          downloadItems: selectedDirentNames
+        });
+      }
     }
   };
 
   onCloseZipDownloadDialog = () => {
-    this.setState({isProgressDialogShow: false});
+    this.setState({ isProgressDialogShow: false });
   };
 
   // common contextmenu handle
   onMouseDown = (event) => {
-    event.stopPropagation();
     if (event.button === 2) {
+      event.stopPropagation();
       return;
     }
   };
@@ -304,7 +403,7 @@ class DirentListView extends React.Component {
   // table-container contextmenu handle
   onContainerClick = () => {
     hideMenu();
-    if (this.state.activeDirent) {
+    if (this.props.selectedDirentList.length > 0) {
       this.onDirentClick(null);
     }
   };
@@ -329,18 +428,26 @@ class DirentListView extends React.Component {
       NEW_EXCEL_FILE,
       NEW_POWERPOINT_FILE,
       NEW_WORD_FILE,
-      NEW_SEADOC_FILE
+      NEW_SEADOC_FILE,
+      NEW_TLDRAW_FILE
     } = TextTranslation;
 
     const direntsContainerMenuList = [
       NEW_FOLDER, NEW_FILE, 'Divider',
+    ];
+    const { currentRepoInfo } = this.props;
+    if (enableSeadoc && !currentRepoInfo.encrypted) {
+      direntsContainerMenuList.push(NEW_SEADOC_FILE);
+    }
+    direntsContainerMenuList.push(
       NEW_MARKDOWN_FILE,
       NEW_EXCEL_FILE,
       NEW_POWERPOINT_FILE,
-      NEW_WORD_FILE
-    ];
-    if (enableSeadoc) {
-      direntsContainerMenuList.push(NEW_SEADOC_FILE);
+      NEW_WORD_FILE,
+    );
+
+    if (enableWhiteboard) {
+      direntsContainerMenuList.push(NEW_TLDRAW_FILE);
     }
 
     if (this.props.selectedDirentList.length === 0) {
@@ -398,7 +505,7 @@ class DirentListView extends React.Component {
   };
 
   onContainerMenuItemClick = (operation) => {
-    switch(operation) {
+    switch (operation) {
       case 'New Folder':
         this.onCreateFolderToggle();
         break;
@@ -417,6 +524,9 @@ class DirentListView extends React.Component {
       case 'New Word File':
         this.onCreateFileToggle('.docx');
         break;
+      case 'New Whiteboard File':
+        this.onCreateFileToggle('.draw');
+        break;
       case 'New SeaDoc File':
         this.onCreateFileToggle('.sdoc');
         break;
@@ -428,7 +538,7 @@ class DirentListView extends React.Component {
   };
 
   onDirentsMenuItemClick = (operation) => {
-    switch(operation) {
+    switch (operation) {
       case 'Move':
         this.onMoveToggle();
         break;
@@ -512,7 +622,7 @@ class DirentListView extends React.Component {
   };
 
   onTableDragEnter = (e) => {
-    if (Utils.isIEBrower() || !this.canDrop) {
+    if (Utils.isIEBrowser() || !this.canDrop) {
       return false;
     }
     this.enteredCounter++;
@@ -520,12 +630,12 @@ class DirentListView extends React.Component {
       if (this.state.isListDropTipShow) {
         return ;
       }
-      this.setState({isListDropTipShow: true});
+      this.setState({ isListDropTipShow: true });
     }
   };
 
   onTableDragOver = (e) => {
-    if (Utils.isIEBrower() || !this.canDrop) {
+    if (Utils.isIEBrowser() || !this.canDrop) {
       return false;
     }
     if (e.dataTransfer.dropEffect === 'copy') {
@@ -536,31 +646,31 @@ class DirentListView extends React.Component {
   };
 
   onTableDragLeave = (e) => {
-    if (Utils.isIEBrower() || !this.canDrop) {
+    if (Utils.isIEBrowser() || !this.canDrop) {
       return false;
     }
     this.enteredCounter--;
     if (this.enteredCounter === 0) {
-      this.setState({isListDropTipShow: false});
+      this.setState({ isListDropTipShow: false });
     }
   };
 
   tableDrop = (e) => {
-    if (Utils.isIEBrower() || !this.canDrop) {
+    if (Utils.isIEBrowser() || !this.canDrop) {
       return false;
     }
     e.persist();
     this.enteredCounter = 0;
-    this.setState({isListDropTipShow: false});
+    this.setState({ isListDropTipShow: false });
     if (e.dataTransfer.files.length) { // uploaded files
       return;
     }
-    let dragStartItemData = e.dataTransfer.getData('applicaiton/drag-item-info');
+    let dragStartItemData = e.dataTransfer.getData('application/drag-item-info');
     dragStartItemData = JSON.parse(dragStartItemData);
 
-    let {nodeDirent, nodeParentPath, nodeRootPath} = dragStartItemData;
+    let { nodeDirent, nodeParentPath, nodeRootPath } = dragStartItemData;
 
-    if (Array.isArray(dragStartItemData)) { //selected items
+    if (Array.isArray(dragStartItemData)) { // selected items
       return;
     }
 
@@ -587,21 +697,83 @@ class DirentListView extends React.Component {
     });
   };
 
-  render() {
+  getHeaders = (isDesktop) => {
     const { direntList, sortBy, sortOrder } = this.props;
-
-    if (this.props.isDirentListLoading) {
-      return (<Loading />);
+    if (!isDesktop) {
+      return [
+        { isFixed: false, width: 0.12 },
+        { isFixed: false, width: 0.8 },
+        { isFixed: false, width: 0.08 },
+      ];
     }
 
-    // sort
-    const sortByName = sortBy == 'name';
-    const sortByTime = sortBy == 'time';
-    const sortBySize = sortBy == 'size';
-    const sortIcon = sortOrder == 'asc' ? <span className="fas fa-caret-up"></span> : <span className="fas fa-caret-down"></span>;
+    const sortIcon = <span className={`sf3-font sf3-font-down ${sortOrder == 'asc' ? 'rotate-180 d-inline-block' : ''}`}></span>;
+    return [
+      { isFixed: true,
+        width: 31,
+        className: 'pl10 pr-2 cursor-pointer',
+        title: this.props.isAllItemSelected ? gettext('Unselect all items') : gettext('Select all items'),
+        ariaLabel: this.props.isAllItemSelected ? gettext('Unselect all items') : gettext('Select all items'),
+        children: (
+          <input
+            type="checkbox"
+            className="vam cursor-pointer"
+            checked={this.props.isAllItemSelected}
+            disabled={direntList.length === 0}
+            readOnly
+          />
+        ),
+        onClick: (e) => {
+          e.stopPropagation();
+          this.props.onAllItemSelected();
+        }
+      },
+      {
+        isFixed: true, width: 32, className: 'pl-2 pr-2', // star
+      },
+      {
+        isFixed: true, width: 40, className: 'pl-2 pr-2', // icon
+      },
+      {
+        isFixed: false,
+        width: 0.5,
+        children: (<a className="d-block table-sort-op" href="#" onClick={this.sortByName}>{gettext('Name')} {sortBy == 'name' && sortIcon}</a>),
+      },
+      {
+        isFixed: false, width: 0.06, // tag
+      },
+      {
+        isFixed: false, width: 0.18, // operation
+      },
+      {
+        isFixed: false,
+        width: 0.11,
+        children: (<a className="d-block table-sort-op" href="#" onClick={this.sortBySize}>{gettext('Size')} {sortBy == 'size' && sortIcon}</a>)
+      },
+      {
+        isFixed: false,
+        width: 0.15,
+        children: (<a className="d-block table-sort-op" href="#" onClick={this.sortByTime}>{gettext('Last Update')} {sortBy == 'time' && sortIcon}</a>)
+      }
+    ];
+  };
 
+  render() {
+    const { direntList, currentRepoInfo, userPerm } = this.props;
+    const { encrypted: repoEncrypted } = currentRepoInfo;
     const isDesktop = Utils.isDesktop();
 
+    let canModifyFile = false;
+    if (['rw', 'cloud-edit'].indexOf(userPerm) != -1) {
+      canModifyFile = true;
+    } else {
+      const { isCustomPermission, customPermission } = Utils.getUserPermission(userPerm);
+      if (isCustomPermission) {
+        const { modify } = customPermission.permission;
+        canModifyFile = modify;
+      }
+    }
+
     return (
       <div
         className={`table-container ${(this.state.isListDropTipShow && this.canDrop) ? 'table-drop-active' : ''}`}
@@ -613,37 +785,17 @@ class DirentListView extends React.Component {
         onDragLeave={this.onTableDragLeave}
         onDrop={this.tableDrop}
       >
-        <table className={`table-hover ${isDesktop ? '': 'table-thead-hidden'}`}>
-          {isDesktop ? (
-            <thead onMouseDown={this.onThreadMouseDown} onContextMenu={this.onThreadContextMenu}>
-              <tr>
-                <th width="3%" className="pl10">
-                  <input type="checkbox" className="vam" onChange={this.props.onAllItemSelected} checked={this.props.isAllItemSelected} />
-                </th>
-                <th width="3%" className="pl10">{/*icon */}</th>
-                <th width="5%" className="pl10">{/*star */}</th>
-                <th width="39%"><a className="d-block table-sort-op" href="#" onClick={this.sortByName}>{gettext('Name')} {sortByName && sortIcon}</a></th>
-                <th width="6%">{/*tag */}</th>
-                <th width="18%">{/*operation */}</th>
-                <th width="11%"><a className="d-block table-sort-op" href="#" onClick={this.sortBySize}>{gettext('Size')} {sortBySize && sortIcon}</a></th>
-                <th width="15%"><a className="d-block table-sort-op" href="#" onClick={this.sortByTime}>{gettext('Last Update')} {sortByTime && sortIcon}</a></th>
-              </tr>
-            </thead>
-          ) : (
-            <thead>
-              <tr>
-                <th width="12%"></th>
-                <th width="80%"></th>
-                <th width="8%"></th>
-              </tr>
-            </thead>
-          )}
-          <tbody>
+        {direntList.length > 0 && (
+          <FixedWidthTable
+            className={classnames('table-hover', { 'table-thead-hidden': !isDesktop })}
+            headers={this.getHeaders(isDesktop)}
+            theadOptions={isDesktop ? { onMouseDown: this.onThreadMouseDown, onContextMenu: this.onThreadContextMenu } : {}}
+          >
             {direntList.map((dirent, index) => {
               return (
                 <DirentListItem
                   ref={this.setDirentItemRef(index)}
-                  key={index}
+                  key={dirent.name} // dirent.id is not unique, so use dirent.name as key
                   dirent={dirent}
                   path={this.props.path}
                   repoID={this.props.repoID}
@@ -671,31 +823,39 @@ class DirentListView extends React.Component {
                   onItemContextMenu={this.onItemContextMenu}
                   selectedDirentList={this.props.selectedDirentList}
                   activeDirent={this.state.activeDirent}
+                  repoTags={this.props.repoTags}
                   onFileTagChanged={this.props.onFileTagChanged}
                   getDirentItemMenuList={this.getDirentItemMenuList}
                   showDirentDetail={this.props.showDirentDetail}
                   onItemsMove={this.props.onItemsMove}
                   onShowDirentsDraggablePreview={this.onShowDirentsDraggablePreview}
                   loadDirentList={this.props.loadDirentList}
+                  onAddFolder={this.props.onAddFolder}
                 />
               );
             })}
-          </tbody>
-        </table>
+          </FixedWidthTable>
+        )}
+        {direntList.length === 0 &&
+          <EmptyTip text={gettext('No file')}/>
+        }
         <Fragment>
           <ContextMenu
             id={'dirent-container-menu'}
             onMenuItemClick={this.onContainerMenuItemClick}
+            getMenuContainerSize={this.props.getMenuContainerSize}
           />
           <ContextMenu
             id={'dirent-item-menu'}
             onMenuItemClick={this.onMenuItemClick}
             onShowMenu={this.onShowMenu}
             onHideMenu={this.onHideMenu}
+            getMenuContainerSize={this.props.getMenuContainerSize}
           />
           <ContextMenu
             id={'dirents-menu'}
             onMenuItemClick={this.onDirentsMenuItemClick}
+            getMenuContainerSize={this.props.getMenuContainerSize}
           />
           {this.state.isShowDirentsDraggablePreview &&
             <ModalPortal>
@@ -714,6 +874,9 @@ class DirentListView extends React.Component {
                 closeImagePopup={this.closeImagePopup}
                 moveToPrevImage={this.moveToPrevImage}
                 moveToNextImage={this.moveToNextImage}
+                onDeleteImage={this.deleteImage}
+                onRotateImage={this.rotateImage}
+                enableRotate={canModifyFile}
               />
             </ModalPortal>
           )}
@@ -742,22 +905,24 @@ class DirentListView extends React.Component {
             <MoveDirentDialog
               path={this.props.path}
               repoID={this.props.repoID}
-              repoEncrypted={this.props.currentRepoInfo.encrypted}
-              isMutipleOperation={this.state.isMutipleOperation}
+              repoEncrypted={repoEncrypted}
+              isMultipleOperation={this.state.isMultipleOperation}
               selectedDirentList={this.props.selectedDirentList}
               onItemsMove={this.props.onItemsMove}
               onCancelMove={this.onMoveToggle}
+              onAddFolder={this.props.onAddFolder}
             />
           }
           {this.state.isCopyDialogShow &&
             <CopyDirentDialog
               path={this.props.path}
               repoID={this.props.repoID}
-              repoEncrypted={this.props.currentRepoInfo.encrypted}
+              repoEncrypted={repoEncrypted}
               selectedDirentList={this.props.selectedDirentList}
-              isMutipleOperation={this.state.isMutipleOperation}
+              isMultipleOperation={this.state.isMultipleOperation}
               onItemsCopy={this.props.onItemsCopy}
               onCancelCopy={this.onCopyToggle}
+              onAddFolder={this.props.onAddFolder}
             />
           }
           {this.state.isProgressDialogShow &&
