@@ -11,13 +11,23 @@ const propTypes = {
   onNodeExpanded: PropTypes.func.isRequired,
   filePath: PropTypes.string,
   fileSuffixes: PropTypes.array,
+  level: PropTypes.number,
+  isBrowsing: PropTypes.bool,
 };
 
 class TreeViewItem extends React.Component {
 
   constructor(props) {
     super(props);
-    let filePath = this.props.filePath ?  this.props.filePath +  '/' + this.props.node.object.name : this.props.node.path;
+    let filePath;
+
+    if (this.props.filePath === '/') {
+      filePath = '/' + this.props.node.object.name;
+    } else if (this.props.filePath) {
+      filePath = this.props.filePath + '/' + this.props.node.object.name;
+    } else {
+      filePath = this.props.node.path;
+    }
 
     this.state = {
       filePath: filePath,
@@ -35,7 +45,7 @@ class TreeViewItem extends React.Component {
   };
 
   onItemClick = (e) => {
-    e.stopPropagation();  // need prevent event popup
+    e.stopPropagation(); // need prevent event popup
     let isCurrentRepo = false;
     if (this.props.selectedRepo) {
       isCurrentRepo = this.props.selectedRepo.repo_id === this.props.repo.repo_id;
@@ -59,7 +69,7 @@ class TreeViewItem extends React.Component {
     if (!node.hasChildren()) {
       return '';
     }
-    return(
+    return (
       <div className="list-view-content">
         {node.children.map(item => {
           return (
@@ -73,6 +83,8 @@ class TreeViewItem extends React.Component {
               selectedRepo={this.props.selectedRepo}
               selectedPath={this.props.selectedPath}
               fileSuffixes={this.props.fileSuffixes}
+              filePath={this.state.filePath}
+              level={(this.props.level || 0) + 1}
             />);
         })}
       </div>
@@ -85,11 +97,11 @@ class TreeViewItem extends React.Component {
     if (this.props.selectedRepo) {
       isCurrentRepo = this.props.selectedRepo.repo_id === this.props.repo.repo_id;
     }
-    let isCurrentPath = this.props.selectedPath === this.state.filePath;
+    let isCurrentPath = this.props.selectedPath === this.state.filePath || this.props.selectedPath === node.path;
 
     const fileName = node.object.name;
     if (this.props.fileSuffixes && fileName && node.object.type === 'file') {
-      if ( fileName.indexOf('.') !== -1) {
+      if (fileName.indexOf('.') !== -1) {
         const suffix = fileName.slice(fileName.lastIndexOf('.') + 1).toLowerCase();
         if (!this.props.fileSuffixes.includes(suffix)) return null;
       } else {
@@ -97,22 +109,27 @@ class TreeViewItem extends React.Component {
       }
     }
 
+    const paddingLeft = `${this.props.level * 20}px`;
     return (
       <div className="file-chooser-item">
-        <div className={`${node.path === '/'? 'hide': ''}`}>
-          <div className={`${(isCurrentRepo && isCurrentPath) ? 'item-active' : ''} item-info`} onClick={this.onItemClick}>
-            <div className="item-text">
-              <span className="name user-select-none ellipsis" title={node.object && node.object.name}>{node.object && node.object.name}</span>
-            </div>
+        <div className={`${node.path === '/' ? 'hide' : ''}`}>
+          <div
+            className={`${(isCurrentRepo && isCurrentPath) ? 'item-active' : ''} item-info`}
+            onClick={this.onItemClick}
+            style={{ paddingLeft }}
+          >
             <div className="item-left-icon">
               {
                 node.object.type !== 'file' &&
-                <span className={`icon item-toggle fa ${node.isExpanded ? 'fa-caret-down' : 'fa-caret-right'}`} onClick={this.onToggleClick}></span>
+                <span className={`icon item-toggle sf3-font ${node.isExpanded ? 'sf3-font-down' : 'sf3-font-down rotate-270 d-inline-block'}`} onClick={this.onToggleClick}></span>
               }
               <i className="tree-node-icon">
-                <span className={`icon far ${node.object.type === 'dir' ? 'fa-folder' : 'fa-file'}`}></span>
+                <span className={`icon sf3-font ${node.object.type === 'dir' ? 'sf3-font-folder' : 'sf3-font-file'}`}></span>
               </i>
             </div>
+            <div className="item-text">
+              <span className="name user-select-none ellipsis" title={node.object && node.object.name}>{node.object && node.object.name}</span>
+            </div>
           </div>
         </div>
         {node.isExpanded && this.renderChildren()}
