@@ -2,10 +2,9 @@ import React, { Fragment } from 'react';
 import PropTypes from 'prop-types';
 import Resumablejs from '@seafile/resumablejs';
 import MD5 from 'MD5';
-import { resumableUploadFileBlockSize, maxUploadFileSize, maxNumberOfFilesForFileupload } from '../../utils/constants';
+import { gettext, resumableUploadFileBlockSize, maxUploadFileSize, maxNumberOfFilesForFileupload } from '../../utils/constants';
 import { seafileAPI } from '../../utils/seafile-api';
 import { Utils } from '../../utils/utils';
-import { gettext } from '../../utils/constants';
 import UploadProgressDialog from './upload-progress-dialog';
 import UploadRemindDialog from '../dialog/upload-remind-dialog';
 import toaster from '../toast';
@@ -46,7 +45,6 @@ class FileUploader extends React.Component {
       isUploadRemindDialogShow: false,
       currentResumableFile: null,
       uploadBitrate: 0,
-      allFilesUploaded: false,
     };
 
     this.uploadInput = React.createRef();
@@ -82,7 +80,7 @@ class FileUploader extends React.Component {
 
     this.resumable.assignBrowse(this.uploadInput.current, true);
 
-    //Enable or Disable DragAnd Drop
+    // Enable or Disable DragAnd Drop
     if (this.props.dragAndDrop === true) {
       this.resumable.enableDropOnDocument();
     }
@@ -154,31 +152,26 @@ class FileUploader extends React.Component {
   maxFileSizeErrorCallback = (file) => {
     let { forbidUploadFileList } = this.state;
     forbidUploadFileList.push(file);
-    this.setState({forbidUploadFileList: forbidUploadFileList});
+    this.setState({ forbidUploadFileList: forbidUploadFileList });
   };
 
   onChunkingComplete = (resumableFile) => {
 
-    let allFilesUploaded = this.state.allFilesUploaded;
-    if (allFilesUploaded === true) {
-      this.setState({allFilesUploaded: false});
-    }
-
-    //get parent_dir relative_path
+    // get parent_dir relative_path
     let path = this.props.path === '/' ? '/' : this.props.path + '/';
     let fileName = resumableFile.fileName;
     let relativePath = resumableFile.relativePath;
     let isFile = fileName === relativePath;
 
-    //update formdata
+    // update formdata
     resumableFile.formData = {};
     if (isFile) { // upload file
-      resumableFile.formData  = {
+      resumableFile.formData = {
         parent_dir: path,
       };
     } else { // upload folder
       let relative_path = relativePath.slice(0, relativePath.lastIndexOf('/') + 1);
-      resumableFile.formData  = {
+      resumableFile.formData = {
         parent_dir: path,
         relative_path: relative_path
       };
@@ -316,13 +309,13 @@ class FileUploader extends React.Component {
 
   onProgress = () => {
     let progress = Math.round(this.resumable.progress() * 100);
-    this.setState({totalProgress: progress});
+    this.setState({ totalProgress: progress });
     Utils.registerGlobalVariable('uploader', 'totalProgress', progress);
   };
 
   onFileUploadSuccess = (resumableFile, message) => {
     let formData = resumableFile.formData;
-    let currentTime = new Date().getTime()/1000;
+    let currentTime = new Date().getTime() / 1000;
     message = formData.replace ? message : JSON.parse(message)[0];
     if (formData.relative_path) { // upload folder
       let relative_path = formData.relative_path;
@@ -349,7 +342,7 @@ class FileUploader extends React.Component {
         }
         return item;
       });
-      this.setState({uploadFileList: uploadFileList});
+      this.setState({ uploadFileList: uploadFileList });
 
       return;
     }
@@ -371,7 +364,7 @@ class FileUploader extends React.Component {
         }
         return item;
       });
-      this.setState({uploadFileList: uploadFileList});
+      this.setState({ uploadFileList: uploadFileList });
 
       return;
     }
@@ -393,17 +386,17 @@ class FileUploader extends React.Component {
       }
       return item;
     });
-    this.setState({uploadFileList: uploadFileList});
+    this.setState({ uploadFileList: uploadFileList });
   };
 
   getFileServerErrorMessage = (key) => {
     const errorMessage = {
-      'File locked by others.': gettext('File is locked by others.'),       // 403
-      'Invalid filename.': gettext('Invalid filename.'),                    // 440
-      'File already exists.': gettext('File already exists.'),              // 441
-      'File size is too large.': gettext('File size is too large.'),        // 442
-      'Out of quota.': gettext('Out of quota.'),                            // 443
-      'Internal error.': gettext('Internal Server Error'),                  // 500
+      'File locked by others.': gettext('File is locked by others.'), // 403
+      'Invalid filename.': gettext('Invalid filename.'), // 440
+      'File already exists.': gettext('File already exists.'), // 441
+      'File size is too large.': gettext('File size is too large.'), // 442
+      'Out of quota.': gettext('Out of quota.'), // 443
+      'Internal error.': gettext('Internal Server Error'), // 500
     };
     return errorMessage[key] || key;
   };
@@ -415,7 +408,7 @@ class FileUploader extends React.Component {
     } else {
       // eg: '{"error": "Internal error" \n }'
       let errorMessage = message.replace(/\n/g, '');
-      errorMessage  = JSON.parse(errorMessage);
+      errorMessage = JSON.parse(errorMessage);
       error = this.getFileServerErrorMessage(errorMessage.error);
     }
 
@@ -427,7 +420,7 @@ class FileUploader extends React.Component {
       return item;
     });
 
-    this.loaded = 0;  // reset loaded data;
+    this.loaded = 0; // reset loaded data;
     this.setState({
       retryFileList: this.state.retryFileList,
       uploadFileList: uploadFileList
@@ -439,11 +432,9 @@ class FileUploader extends React.Component {
     this.notifiedFolders = [];
     // reset upload link loaded
     this.isUploadLinkLoaded = false;
-    this.setState({allFilesUploaded: true});
   };
 
   onPause = () => {
-
   };
 
   onError = (message) => {
@@ -491,7 +482,7 @@ class FileUploader extends React.Component {
   };
 
   generateUniqueIdentifier = (file) => {
-    let relativePath = file.webkitRelativePath||file.relativePath||file.fileName||file.name;
+    let relativePath = file.webkitRelativePath || file.relativePath || file.fileName || file.name;
     return MD5(relativePath + new Date()) + relativePath;
   };
 
@@ -520,7 +511,7 @@ class FileUploader extends React.Component {
     this.resumable.files = [];
     // reset upload link loaded
     this.isUploadLinkLoaded = false;
-    this.setState({isUploadProgressDialogShow: false, uploadFileList: [], forbidUploadFileList: []});
+    this.setState({ isUploadProgressDialogShow: false, uploadFileList: [], forbidUploadFileList: [] });
     Utils.registerGlobalVariable('uploader', 'isUploadProgressDialogShow', false);
   };
 
@@ -536,13 +527,12 @@ class FileUploader extends React.Component {
 
     if (!this.resumable.isUploading()) {
       this.setState({
-        totalProgress: '100',
-        allFilesUploaded: true,
+        totalProgress: 100,
       });
       this.loaded = 0;
     }
 
-    this.setState({uploadFileList: uploadFileList});
+    this.setState({ uploadFileList: uploadFileList });
   };
 
   onCancelAllUploading = () => {
@@ -557,8 +547,7 @@ class FileUploader extends React.Component {
     this.loaded = 0;
 
     this.setState({
-      allFilesUploaded: true,
-      totalProgress: '100',
+      totalProgress: 100,
       uploadFileList: uploadFileList
     });
     // reset upload link loaded
@@ -625,7 +614,7 @@ class FileUploader extends React.Component {
     resumableFile.bootstrap();
     var firedRetry = false;
     resumableFile.resumableObj.on('chunkingComplete', () => {
-      if(!firedRetry) {
+      if (!firedRetry) {
         seafileAPI.getFileUploadedBytes(repoID, path, fileName).then(res => {
           let uploadedBytes = res.data.uploadedBytes;
           let blockSize = parseInt(resumableUploadFileBlockSize) * 1024 * 1024 || 1024 * 1024;
@@ -652,7 +641,7 @@ class FileUploader extends React.Component {
       let resumableFile = this.resumable.files[this.resumable.files.length - 1];
       resumableFile.formData['replace'] = 1;
       resumableFile.formData['target_file'] = resumableFile.formData.parent_dir + resumableFile.fileName;
-      this.setState({isUploadRemindDialogShow: false});
+      this.setState({ isUploadRemindDialogShow: false });
       this.setUploadFileList(this.resumable.files);
       this.resumable.upload();
     }).catch(error => {
@@ -664,7 +653,7 @@ class FileUploader extends React.Component {
   uploadFile = () => {
     let resumableFile = this.resumable.files[this.resumable.files.length - 1];
     let { repoID, path } = this.props;
-    seafileAPI.getFileServerUploadLink(repoID, path).then((res) => {  // get upload link
+    seafileAPI.getFileServerUploadLink(repoID, path).then((res) => { // get upload link
       this.resumable.opts.target = res.data + '?ret-json=1';
       this.setState({
         isUploadRemindDialogShow: false,
@@ -682,8 +671,8 @@ class FileUploader extends React.Component {
   };
 
   cancelFileUpload = () => {
-    this.resumable.files.pop(); //delete latest file；
-    this.setState({isUploadRemindDialogShow: false});
+    this.resumable.files.pop(); // delete latest file；
+    this.setState({ isUploadRemindDialogShow: false });
   };
 
   render() {
@@ -691,7 +680,7 @@ class FileUploader extends React.Component {
       <Fragment>
         <div className="file-uploader-container">
           <div className="file-uploader">
-            <input className="upload-input" type="file" ref={this.uploadInput} onClick={this.onClick}/>
+            <input className="upload-input" type="file" ref={this.uploadInput} onClick={this.onClick} aria-label={gettext('Upload')} />
           </div>
         </div>
         {this.state.isUploadRemindDialogShow &&
@@ -709,12 +698,12 @@ class FileUploader extends React.Component {
             forbidUploadFileList={this.state.forbidUploadFileList}
             totalProgress={this.state.totalProgress}
             uploadBitrate={this.state.uploadBitrate}
-            allFilesUploaded={this.state.allFilesUploaded}
             onCloseUploadDialog={this.onCloseUploadDialog}
             onCancelAllUploading={this.onCancelAllUploading}
             onUploadCancel={this.onUploadCancel}
             onUploadRetry={this.onUploadRetry}
             onUploadRetryAll={this.onUploadRetryAll}
+            isUploading={this.resumable.isUploading()}
           />
         }
       </Fragment>
