@@ -1,6 +1,6 @@
 import React, { Fragment } from 'react';
 import PropTypes from 'prop-types';
-import { ButtonGroup, ButtonDropdown, Dropdown, DropdownToggle, DropdownMenu, DropdownItem } from 'reactstrap';
+import { ButtonGroup, Dropdown, DropdownToggle, DropdownMenu, DropdownItem } from 'reactstrap';
 import IconButton from '../icon-button';
 import { gettext, siteRoot } from '../../utils/constants';
 import { Utils } from '../../utils/utils';
@@ -8,6 +8,8 @@ import ModalPortal from '../modal-portal';
 import ShareDialog from '../dialog/share-dialog';
 import { seafileAPI } from '../../utils/seafile-api';
 import toaster from '../toast';
+import Icon from '../../components/icon';
+import ImageZoomer from './image-zoomer';
 
 const propTypes = {
   isLocked: PropTypes.bool.isRequired,
@@ -16,17 +18,20 @@ const propTypes = {
   isSaving: PropTypes.bool,
   needSave: PropTypes.bool,
   toggleLockFile: PropTypes.func.isRequired,
-  toggleDetailsPanel: PropTypes.func.isRequired
+  toggleDetailsPanel: PropTypes.func.isRequired,
+  setImageScale: PropTypes.func,
+  rotateImage: PropTypes.func
 };
 
 const {
   canLockUnlockFile,
   repoID, repoName, repoEncrypted, parentDir, filePerm, filePath,
-  fileType,
+  fileType, fileExt,
   fileName,
   canEditFile, err,
   // fileEnc, // for 'edit', not undefined only for some kinds of files (e.g. text file)
   canDownloadFile,
+  fileDownloadURL,
 } = window.app.pageOptions;
 
 class FileToolbar extends React.Component {
@@ -50,19 +55,19 @@ class FileToolbar extends React.Component {
         this.customPermission = permissionRes.data.permission;
         // share dialog need a global custom_permission
         window.custom_permission = this.customPermission;
-        this.setState({isLoading: false});
-      } catch(error) {
+        this.setState({ isLoading: false });
+      } catch (error) {
         let errorMsg = Utils.getErrorMsg(error);
         toaster.danger(errorMsg);
-        this.setState({isLoading: false});
+        this.setState({ isLoading: false });
       }
     } else {
-      this.setState({isLoading: false});
+      this.setState({ isLoading: false });
     }
   }
 
   toggleShareDialog = () => {
-    this.setState({isShareDialogOpen: !this.state.isShareDialogOpen});
+    this.setState({ isShareDialogOpen: !this.state.isShareDialogOpen });
   };
 
   toggleMoreOpMenu = () => {
@@ -82,19 +87,20 @@ class FileToolbar extends React.Component {
       return null;
     }
 
-    const { isLocked, lockedByMe } = this.props;
     const { moreDropdownOpen } = this.state;
+
+    const { isLocked, lockedByMe } = this.props;
     let showLockUnlockBtn = false;
-    let lockUnlockText, lockUnlockIcon;
+    let lockUnlockText; let lockUnlockIcon;
     if (canLockUnlockFile) {
       if (!isLocked) {
         showLockUnlockBtn = true;
         lockUnlockText = gettext('Lock');
-        lockUnlockIcon = 'fa fa-lock';
+        lockUnlockIcon = 'lock';
       } else if (lockedByMe) {
         showLockUnlockBtn = true;
         lockUnlockText = gettext('Unlock');
-        lockUnlockIcon = 'fa fa-unlock';
+        lockUnlockIcon = 'unlock';
       }
     }
 
@@ -111,23 +117,38 @@ class FileToolbar extends React.Component {
       showShareBtn = download_external_link;
     }
 
+    const shortcutMain = Utils.isMac() ? '⌘ + ' : 'Ctrl + ';
+
     return (
       <Fragment>
-        <ButtonGroup className="d-none d-md-block">
+        <div className="d-none d-md-flex justify-content-between align-items-center flex-shrink-0 ml-4">
+          {(fileType == 'Image' && !err) && (
+            <>
+              <ImageZoomer setImageScale={this.props.setImageScale} />
+              {['psd', 'heic'].indexOf(fileExt) == -1 && (
+                <IconButton
+                  id="rotate-image"
+                  icon="rotate"
+                  text={gettext('Rotate')}
+                  onClick={this.props.rotateImage}
+                />
+              )}
+            </>
+          )}
           {fileType == 'PDF' && (
+            <IconButton
+              id="seafile-pdf-find"
+              icon="search"
+              text={`${gettext('Find')}(${shortcutMain}F)`}
+            />
+          )}
+          {(fileType == 'PDF' && canDownloadFile) && (
             <IconButton
               id="seafile-pdf-print"
-              icon="fa fa-print"
+              icon="print"
               text={gettext('Print')}
             />
           )}
-          <IconButton
-            id="open-parent-folder"
-            icon="fa fa-folder-open"
-            text={gettext('Open parent folder')}
-            tag="a"
-            href={`${siteRoot}library/${repoID}/${Utils.encodePath(repoName + parentDir)}`}
-          />
           {showLockUnlockBtn && (
             <IconButton
               id="lock-unlock-file"
@@ -139,58 +160,60 @@ class FileToolbar extends React.Component {
           {showShareBtn && (
             <IconButton
               id="share-file"
-              icon='fa fa-share-alt'
+              icon='share'
               text={gettext('Share')}
               onClick={this.toggleShareDialog}
             />
           )}
 
           {(canEditFile && fileType != 'SDoc' && !err) &&
-            ( this.props.isSaving ?
-              <button type={'button'} aria-label={gettext('Saving...')} className={'btn btn-icon btn-secondary btn-active'}>
-                <i className={'fa fa-spin fa-spinner'}/></button> :
-              (
-                this.props.needSave ?
-                  <IconButton
-                    text={gettext('Save')}
-                    id={'saveButton'}
-                    icon={'fa fa-save'}
-                    // button imported in this file does not have functionalities of
-                    // isActive as button imported in markdowneditor has
-                    //isActive={!isContentChanged}
-                    onClick={this.props.onSave}
-                  /> :
-                  <button type={'button'} className={'btn btn-icon btn-secondary btn-active'} disabled>
-                    <i className={'fa fa-save'}/></button>
-              )
-            )}
+            (this.props.isSaving ?
+              <div type='button' aria-label={gettext('Saving...')} className={'file-toolbar-btn'}>
+                <Icon symbol="spinner" />
+              </div>
+              :
+              (this.props.needSave ?
+                <IconButton
+                  text={gettext('Save')}
+                  id='save-file'
+                  icon='save'
+                  onClick={this.props.onSave}
+                />
+                :
+                <div type='button' className='file-toolbar-btn disabled'>
+                  <Icon symbol="save" />
+                </div>
+              ))}
           {canDownloadFile && (
             <IconButton
               id="download-file"
-              icon="fa fa-download"
+              icon="download"
               text={gettext('Download')}
-              tag="a"
-              href="?dl=1"
+              href={fileDownloadURL}
             />
           )}
           <IconButton
             id="file-details"
-            icon='fas fa-info'
+            icon='info'
             text={gettext('Details')}
             onClick={this.props.toggleDetailsPanel}
           />
           {filePerm == 'rw' && (
             <IconButton
               id="open-via-client"
-              icon="sf3-font sf3-font-desktop"
+              icon="client"
               text={gettext('Open via Client')}
-              tag="a"
               href={`seafile://openfile?repo_id=${encodeURIComponent(repoID)}&path=${encodeURIComponent(filePath)}`}
             />
           )}
-          <ButtonDropdown isOpen={moreDropdownOpen} toggle={this.toggleMoreOpMenu}>
-            <DropdownToggle aria-label={gettext('More Operations')}>
-              <span className="fas fa-ellipsis-v"></span>
+          <Dropdown isOpen={moreDropdownOpen} toggle={this.toggleMoreOpMenu}>
+            <DropdownToggle
+              className="file-toolbar-btn"
+              aria-label={gettext('More operations')}
+              title={gettext('More operations')}
+              tag="div"
+            >
+              <Icon symbol="more-vertical" />
             </DropdownToggle>
             <DropdownMenu right={true}>
               {filePerm == 'rw' && (
@@ -198,34 +221,38 @@ class FileToolbar extends React.Component {
                   {gettext('History')}
                 </a>
               )}
+              <a href={`${siteRoot}library/${repoID}/${Utils.encodePath(repoName + parentDir)}`} className="dropdown-item">
+                {gettext('Open parent folder')}
+              </a>
             </DropdownMenu>
-          </ButtonDropdown>
-        </ButtonGroup>
+          </Dropdown>
+        </div>
 
-        <Dropdown isOpen={this.state.dropdownOpen} toggle={this.toggle} className="d-block d-md-none">
+        <Dropdown isOpen={this.state.dropdownOpen} toggle={this.toggle} className="d-block d-md-none flex-shrink-0 ml-4">
           <ButtonGroup >
             {(canEditFile && fileType != 'SDoc' && !err) &&
                 (this.props.isSaving ?
-                  <button type={'button'} aria-label={gettext('Saving...')} className={'btn btn-icon btn-secondary btn-active'}>
-                    <i className={'fa fa-spin fa-spinner'}/></button> :
-                  (
-                    this.props.needSave ?
-                      <IconButton
-                        text={gettext('Save')}
-                        id={'saveButton'}
-                        icon={'fa fa-save'}
-                        // button imported in this file does not have functionalities of
-                        // isActive as button imported in markdowneditor has
-                        //isActive={!isContentChanged}
-                        onClick={this.props.onSave}
-                      /> :
-                      <button type={'button'} className={'btn btn-icon btn-secondary btn-active'} disabled>
-                        <i className={'fa fa-save'}/></button>
-                  )
-                )}
+                  <button type='button' aria-label={gettext('Saving...')} className={'btn btn-icon btn-secondary'}>
+                    <Icon symbol="spinner" />
+                  </button>
+                  :
+                  (this.props.needSave ?
+                    <IconButton
+                      text={gettext('Save')}
+                      id="save-file"
+                      icon='save'
+                      onClick={this.props.onSave}
+                    />
+                    :
+                    <button type='button' className={'btn btn-icon btn-secondary'} disabled>
+                      <Icon symbol="save" />
+                    </button>
+                  ))}
           </ButtonGroup>
 
-          <DropdownToggle className="sf2-icon-more mx-1" aria-label={gettext('More Operations')}></DropdownToggle>
+          <DropdownToggle className="mx-1" aria-label={gettext('More operations')}>
+            <Icon symbol="more-vertical" />
+          </DropdownToggle>
           <DropdownMenu right={true}>
             <DropdownItem>
               <a href={`${siteRoot}library/${repoID}/${Utils.encodePath(repoName + parentDir)}`} className="text-inherit">
@@ -242,13 +269,6 @@ class FileToolbar extends React.Component {
                 {gettext('Share')}
               </DropdownItem>
             )}
-            {filePerm == 'rw' && (
-              <DropdownItem>
-                <a href={`${siteRoot}repo/file_revisions/${repoID}/?p=${encodeURIComponent(filePath)}&referer=${encodeURIComponent(location.href)}`} className="text-inherit">
-                  {gettext('History')}
-                </a>
-              </DropdownItem>
-            )}
             {canDownloadFile && (
               <DropdownItem>
                 <a href="?dl=1" className="text-inherit">
