@@ -1,13 +1,13 @@
 import React from 'react';
 import PropTypes from 'prop-types';
-import moment from 'moment';
-import { Dropdown, DropdownToggle, DropdownMenu, DropdownItem} from 'reactstrap';
+import dayjs from 'dayjs';
+import { Dropdown, DropdownToggle, DropdownMenu, DropdownItem } from 'reactstrap';
 import { gettext, filePath } from '../../utils/constants';
 import URLDecorator from '../../utils/url-decorator';
 
 import '../../css/history-record-item.css';
 
-moment.locale(window.app.config.lang);
+dayjs.locale(window.app.config.lang);
 
 const propTypes = {
   index: PropTypes.number.isRequired,
@@ -31,23 +31,23 @@ class HistoryListItem extends React.Component {
 
   onMouseEnter = () => {
     if (!this.props.isItemFreezed) {
-      this.setState({isShowOperationIcon: true});
+      this.setState({ isShowOperationIcon: true });
     }
   };
 
   onMouseLeave = () => {
     if (!this.props.isItemFreezed) {
-      this.setState({isShowOperationIcon: false});
+      this.setState({ isShowOperationIcon: false });
     }
   };
 
   onToggleClick = (e) => {
-    this.setState({isMenuShow: !this.state.isMenuShow});
+    this.setState({ isMenuShow: !this.state.isMenuShow });
     this.props.onFreezedItemToggle();
   };
 
   onItemClick = () => {
-    this.setState({isShowOperationIcon: false});  //restore to default state
+    this.setState({ isShowOperationIcon: false }); // restore to default state
     if (this.props.item.commit_id === this.props.currentItem.commit_id) {
       return;
     }
@@ -68,13 +68,13 @@ class HistoryListItem extends React.Component {
       return '';
     }
     let item = this.props.item;
-    let time = moment(item.ctime).format('YYYY-MM-DD HH:mm');
+    let time = dayjs(item.ctime).format('YYYY-MM-DD HH:mm');
     let isHigtlightItem = false;
     if (this.props.item && this.props.currentItem) {
       isHigtlightItem = this.props.item.commit_id === this.props.currentItem.commit_id;
     }
     let objID = this.props.currentItem.rev_file_id;
-    let url = URLDecorator.getUrl({type: 'download_historic_file', filePath: filePath, objID: objID});
+    let url = URLDecorator.getUrl({ type: 'download_historic_file', filePath: filePath, objID: objID });
     return (
       <li
         className={`history-list-item ${isHigtlightItem ? 'item-active' : ''}`}
@@ -93,10 +93,11 @@ class HistoryListItem extends React.Component {
           <Dropdown isOpen={this.state.isMenuShow} toggle={this.onToggleClick}>
             <DropdownToggle
               tag='a'
-              className={`fas fa-ellipsis-v ${(this.state.isShowOperationIcon || isHigtlightItem) ? '' : 'invisible'}`}
+              className={`sf3-font sf3-font-more-vertical ${(this.state.isShowOperationIcon || isHigtlightItem) ? '' : 'invisible'}`}
               data-toggle="dropdown"
               aria-expanded={this.state.isMenuShow}
-              alt={gettext('More Operations')}
+              title={gettext('More operations')}
+              aria-label={gettext('More operations')}
             />
             <DropdownMenu>
               {(this.props.index !== 0) && <DropdownItem onClick={this.onItemRestore}>{gettext('Restore')}</DropdownItem>}
