@@ -1,13 +1,13 @@
 import React from 'react';
 import PropTypes from 'prop-types';
-import { Button, Tooltip } from 'reactstrap';
+import { Tooltip } from 'reactstrap';
+import Icon from './icon';
 
 const propTypes = {
   id: PropTypes.string.isRequired,
   icon: PropTypes.string.isRequired,
   text: PropTypes.string.isRequired,
   onClick: PropTypes.func,
-  tag: PropTypes.string,
   href: PropTypes.string
 };
 
@@ -25,43 +25,42 @@ class IconButton extends React.Component {
       tooltipOpen: !this.state.tooltipOpen
     });
   };
+
   render() {
-    const className = 'btn-icon';
     const btnContent = (
-      <React.Fragment>
-        <i className={this.props.icon}></i>
+      <>
+        <Icon symbol={this.props.icon} />
         <Tooltip
           toggle={this.toggle}
-          delay={{show: 0, hide: 0}}
+          delay={{ show: 0, hide: 0 }}
           target={this.props.id}
           placement='bottom'
           isOpen={this.state.tooltipOpen}>
           {this.props.text}
         </Tooltip>
-      </React.Fragment>
+      </>
     );
-    if (this.props.tag && this.props.tag == 'a') {
+    if (this.props.href) {
       return (
-        <Button
+        <div
           id={this.props.id}
-          className={className}
-          tag="a"
-          href={this.props.href}
+          className='file-toolbar-btn'
           aria-label={this.props.text}
+          onClick={() => window.open(this.props.href, '_parent')}
         >
           {btnContent}
-        </Button>
+        </div>
       );
     } else {
       return (
-        <Button
+        <div
           id={this.props.id}
-          className={className}
+          className='file-toolbar-btn'
           onClick={this.props.onClick}
           aria-label={this.props.text}
         >
           {btnContent}
-        </Button>
+        </div>
       );
     }
   }
