@@ -1,6 +1,6 @@
 import React from 'react';
 import PropTypes from 'prop-types';
-import { siteRoot, mediaUrl, logoPath, logoWidth, logoHeight, siteTitle } from '../utils/constants';
+import { siteRoot, mediaUrl, logoPath, logoWidth, logoHeight, siteTitle, gettext } from '../utils/constants';
 
 const propTypes = {
   onCloseSidePanel: PropTypes.func,
@@ -15,7 +15,7 @@ class Logo extends React.Component {
 
   render() {
     return (
-      <div className="top-logo">
+      <div className='top-logo'>
         <a href={siteRoot} id="logo">
           <img src={logoPath.indexOf('image-view') != -1 ? logoPath : mediaUrl + logoPath} height={logoHeight} width={logoWidth} title={siteTitle} alt="logo" />
         </a>
@@ -23,8 +23,8 @@ class Logo extends React.Component {
           <a
             className="sf2-icon-x1 sf-popover-close side-panel-close action-icon d-md-none"
             onClick={this.closeSide}
-            title="Close"
-            aria-label="Close"
+            title={gettext('Close')}
+            aria-label={gettext('Close')}
           >
           </a>
         }
