@@ -1,22 +1,20 @@
 import React, { Fragment } from 'react';
 import PropTypes from 'prop-types';
 import { UncontrolledTooltip } from 'reactstrap';
-import Icon from '../components/icon';
 import { gettext } from '../utils/constants';
 
 const propTypes = {
-  repoID: PropTypes.string.isRequired
+  repoID: PropTypes.string.isRequired,
+  className: PropTypes.string
 };
 
 class RepoMonitoredIcon extends React.Component {
 
   render() {
-    const { repoID } = this.props;
+    const { repoID, className } = this.props;
     return (
       <Fragment>
-        <span id={`watching-${repoID}`} className="ml-1">
-          <Icon symbol='monitor' />
-        </span>
+        <i id={`watching-${repoID}`} className={`sf3-font-monitor sf3-font ${className ? className : ''}`}></i>
         <UncontrolledTooltip
           placement="bottom"
           target={`#watching-${repoID}`}
