@@ -8,6 +8,7 @@ import More from '../more';
 import { Utils } from '../../utils/utils';
 import toaster from '../toast';
 import { getValueLength } from './constant';
+import { SEARCH_MASK, SEARCH_CONTAINER } from '../../constants/zIndexes';
 
 const propTypes = {
   repoID: PropTypes.string,
@@ -28,7 +29,7 @@ class Search extends Component {
       total: 0,
       isMaskShow: false,
       isResultShow: false,
-      isResultGetted: false,
+      isResultGotten: false,
       isCloseShow: false,
       isSearchInputShow: false, // for mobile
     };
@@ -55,7 +56,7 @@ class Search extends Component {
 
   onChangeHandler = (event) => {
     let _this = this;
-    this.setState({value: event.target.value});
+    this.setState({ value: event.target.value });
     let newValue = event.target.value;
     if (this.inputValue === newValue.trim()) {
       return false;
@@ -65,7 +66,7 @@ class Search extends Component {
     if (this.inputValue === '' || getValueLength(this.inputValue) < 3) {
       this.setState({
         isResultShow: false,
-        isResultGetted: false
+        isResultGotten: false
       });
       return false;
     }
@@ -85,12 +86,12 @@ class Search extends Component {
 
   getSearchResult(queryData) {
 
-    if(this.source){
+    if (this.source) {
       this.cancelRequest();
     }
     this.setState({
       isResultShow: true,
-      isResultGetted: false
+      isResultGotten: false
     });
 
     this.source = seafileAPI.getSource();
@@ -103,7 +104,7 @@ class Search extends Component {
       if (!res.data.total) {
         _this.setState({
           resultItems: [],
-          isResultGetted: true
+          isResultGotten: true
         });
         _this.source = null;
         return;
@@ -113,7 +114,7 @@ class Search extends Component {
       _this.setState({
         total: res.data.total,
         resultItems: page == 1 ? items : this.state.resultItems.concat(items),
-        isResultGetted: true
+        isResultGotten: true
       });
       _this.source = null;
     }).catch(error => {
@@ -124,7 +125,7 @@ class Search extends Component {
 
   sendRequest(queryData) {
     // 'page=1' for this first request
-    this.setState({page: 1}, () => {
+    this.setState({ page: 1 }, () => {
       const { search_repo, q } = queryData;
       const { page, perPage } = this.state;
       this.searchWiki(search_repo, q, page, perPage);
@@ -160,7 +161,7 @@ class Search extends Component {
       isMaskShow: false,
       isCloseShow: false,
       isResultShow: false,
-      isResultGetted: false,
+      isResultGotten: false,
       resultItems: [],
       isSearchInputShow: false,
     });
@@ -183,14 +184,14 @@ class Search extends Component {
     if (!this.state.isResultShow) {
       return;
     }
-    if (!this.state.isResultGetted || getValueLength(this.inputValue) < 3) {
+    if (!this.state.isResultGotten || getValueLength(this.inputValue) < 3) {
       return (
         <span className="loading-icon loading-tip"></span>
       );
     }
     if (!this.state.resultItems.length) {
       return (
-        <div className="search-result-none">{gettext('No results matching.')}</div>
+        <div className="search-result-none">{gettext('No results matching')}</div>
       );
     }
     const { resultItems, total } = this.state;
@@ -220,15 +221,15 @@ class Search extends Component {
 
   render() {
     let width = this.state.width !== 'default' ? this.state.width : '';
-    let style = {'width': width};
+    let style = { 'width': width };
     return (
       <Fragment>
         <MediaQuery query="(min-width: 768px)">
           <div className="search">
-            <div className={`search-mask ${this.state.isMaskShow ? '' : 'hide'}`} onClick={this.onCloseHandler}></div>
-            <div className="search-container">
+            <div className={`search-mask ${this.state.isMaskShow ? '' : 'hide'}`} onClick={this.onCloseHandler} style={{ zIndex: SEARCH_MASK }}></div>
+            <div className="search-container" style={{ zIndex: SEARCH_CONTAINER }}>
               <div className="input-icon">
-                <i className="search-icon-left input-icon-addon fas fa-search"></i>
+                <i className="search-icon-left input-icon-addon sf3-font sf3-font-search"></i>
                 <input
                   type="text"
                   className="form-control search-input"
@@ -240,7 +241,7 @@ class Search extends Component {
                   onChange={this.onChangeHandler}
                   autoComplete="off"
                 />
-                {this.state.isCloseShow && <i className='search-icon-right input-icon-addon fas fa-times' onClick={this.onCloseHandler}></i>}
+                {this.state.isCloseShow && <i className='search-icon-right input-icon-addon sf3-font sf3-font-x-01' onClick={this.onCloseHandler}></i>}
               </div>
               <div className="search-result-container dropdown-search-result-container">
                 {this.renderSearchResult()}
@@ -250,14 +251,14 @@ class Search extends Component {
         </MediaQuery>
         <MediaQuery query="(max-width: 767.8px)">
           <div className="search-icon-container">
-            <i className="search-icon fas fa-search" onClick={this.onSearchToggle}></i>
+            <i className="search-icon sf3-font sf3-font-search" onClick={this.onSearchToggle}></i>
           </div>
           {this.state.isSearchInputShow &&
             <div className="search">
-              <div className={`search-mask ${this.state.isMaskShow ? '' : 'hide'}`} onClick={this.onCloseHandler}></div>
-              <div className="search-container">
+              <div className={`search-mask ${this.state.isMaskShow ? '' : 'hide'}`} onClick={this.onCloseHandler} style={{ zIndex: SEARCH_MASK }}></div>
+              <div className="search-container" style={{ zIndex: SEARCH_CONTAINER }}>
                 <div className="input-icon">
-                  <i className="search-icon-left input-icon-addon fas fa-search"></i>
+                  <i className="search-icon-left input-icon-addon sf3-font sf3-font-search"></i>
                   <input
                     type="text"
                     className="form-control search-input"
@@ -269,7 +270,7 @@ class Search extends Component {
                     onChange={this.onChangeHandler}
                     autoComplete="off"
                   />
-                  {this.state.isCloseShow && <i className='search-icon-right input-icon-addon fas fa-times' onClick={this.onCloseHandler}></i>}
+                  {this.state.isCloseShow && <i className='search-icon-right input-icon-addon sf3-font sf3-font-x-01' onClick={this.onCloseHandler}></i>}
                 </div>
                 <div className="search-result-container dropdown-search-result-container">
                   {this.renderSearchResult()}
