@@ -9,6 +9,7 @@ const propTypes = {
   isTextMode: PropTypes.bool.isRequired, // there will be two mode. first: text and select. second: just select
   isEditing: PropTypes.bool,
   isEditIconShow: PropTypes.bool.isRequired,
+  isWiki: PropTypes.bool,
   autoFocus: PropTypes.bool,
   options: PropTypes.array.isRequired,
   currentOption: PropTypes.string.isRequired,
@@ -42,27 +43,33 @@ class SelectEditor extends React.Component {
   }
 
   setOptions = () => {
+    const { enableAddCustomPermission, options } = this.props;
     this.options = [];
-    const options = this.props.options;
     for (let i = 0, length = options.length; i < length; i++) {
       let option = {};
       option.value = options[i];
       if (!options[i].length) { // it's ''. for example, intitution option in 'system admin - users' page can be ''.
-        option.label = <div style={{minHeight: '1em'}}></div>;
+        option.label = <div style={{ minHeight: '1em' }}></div>;
       } else {
-        option.label = <div>{this.props.translateOption(options[i])}{ this.props.translateExplanation && <div className="permission-editor-explanation">{this.props.translateExplanation(options[i])}</div>}</div>;
+        option.label = (
+          <div>
+            {this.props.translateOption(options[i])}
+            {this.props.translateExplanation &&
+              <div className="permission-editor-explanation">{this.props.translateExplanation(options[i])}</div>
+            }
+          </div>
+        );
       }
       this.options.push(option);
     }
 
-    const { enableAddCustomPermission } = this.props;
-    if (enableAddCustomPermission) {
+    if (enableAddCustomPermission && !this.props.isWiki) {
       const option = {
         value: gettext('Add custom permission'),
         isDisabled: true,
         label: (
           <div className="permission-editor-btn-add-custom-permission" onClick={this.props.onAddCustomPermissionToggle}>
-            <i className="fa fa-plus"></i>
+            <i className="sf3-font sf3-font-enlarge"></i>
             <span>{gettext('Add custom permission')}</span>
           </div>
         )
@@ -82,7 +89,7 @@ class SelectEditor extends React.Component {
   onEditPermission = (e) => {
     e.preventDefault();
     e.nativeEvent.stopImmediatePropagation();
-    this.setState({isEditing: true});
+    this.setState({ isEditing: true });
     this.props.toggleItemFreezed && this.props.toggleItemFreezed(true);
   };
 
@@ -91,7 +98,7 @@ class SelectEditor extends React.Component {
     if (permission !== this.props.currentOption) {
       this.props.onOptionChanged(permission);
     }
-    this.setState({isEditing: false});
+    this.setState({ isEditing: false });
     this.props.toggleItemFreezed && this.props.toggleItemFreezed(false);
   };
 
@@ -100,14 +107,12 @@ class SelectEditor extends React.Component {
   };
 
   onMenuClose = () => {
-    this.setState({isEditing: false});
+    this.setState({ isEditing: false });
     this.props.toggleItemFreezed && this.props.toggleItemFreezed(false);
   };
 
   render() {
     let { currentOption, isTextMode } = this.props;
-    // scence1: isTextMode (text)editor-icon --> select
-    // scence2: !isTextMode select
     return (
       <div className="permission-editor" onClick={this.onSelectHandler}>
         {(!isTextMode || this.state.isEditing) &&
@@ -115,8 +120,7 @@ class SelectEditor extends React.Component {
             options={this.state.options}
             className="permission-editor-select"
             classNamePrefix="permission-editor"
-            placeholder={this.props.translateOption(currentOption)}
-            value={currentOption}
+            value={this.state.options.filter(item => item.value == currentOption)[0]}
             onChange={this.onOptionChanged}
             captureMenuScroll={false}
             menuPlacement="auto"
@@ -136,7 +140,7 @@ class SelectEditor extends React.Component {
                 role="button"
                 aria-label={gettext('Edit')}
                 title={gettext('Edit')}
-                className="fa fa-pencil-alt attr-action-icon"
+                className="sf3-font sf3-font-rename attr-action-icon"
                 onClick={this.onEditPermission}>
               </a>
             )}
