@@ -1,26 +1,31 @@
 import React, { Fragment } from 'react';
 import PropTypes from 'prop-types';
-import moment from 'moment';
+import dayjs from 'dayjs';
+import relativeTime from 'dayjs/plugin/relativeTime';
 import { Dropdown, DropdownMenu, DropdownToggle, DropdownItem } from 'reactstrap';
 import { Link, navigate } from '@gatsbyjs/reach-router';
 import { Utils } from '../../utils/utils';
-import { gettext, siteRoot, isPro, username, folderPermEnabled, isSystemStaff, enableResetEncryptedRepoPassword, isEmailConfigured, enableRepoAutoDel } from '../../utils/constants';
+import { gettext, siteRoot, isPro, username, folderPermEnabled, isSystemStaff, enableResetEncryptedRepoPassword, isEmailConfigured } from '../../utils/constants';
 import ModalPortal from '../../components/modal-portal';
 import ShareDialog from '../../components/dialog/share-dialog';
 import LibSubFolderPermissionDialog from '../../components/dialog/lib-sub-folder-permission-dialog';
 import DeleteRepoDialog from '../../components/dialog/delete-repo-dialog';
 import ChangeRepoPasswordDialog from '../../components/dialog/change-repo-password-dialog';
 import ResetEncryptedRepoPasswordDialog from '../../components/dialog/reset-encrypted-repo-password-dialog';
-import LibOldFilesAutoDelDialog from '../../components/dialog/lib-old-files-auto-del-dialog';
 import Rename from '../rename';
 import { seafileAPI } from '../../utils/seafile-api';
-import LibHistorySettingDialog from '../dialog/lib-history-setting-dialog';
+import { userAPI } from '../../utils/user-api';
 import toaster from '../toast';
 import RepoAPITokenDialog from '../dialog/repo-api-token-dialog';
 import RepoShareAdminDialog from '../dialog/repo-share-admin-dialog';
 import RepoMonitoredIcon from '../../components/repo-monitored-icon';
+import { LIST_MODE } from '../dir-view-mode/constants';
+import TransferDialog from '../dialog/transfer-dialog';
+
+dayjs.extend(relativeTime);
 
 const propTypes = {
+  currentViewMode: PropTypes.string,
   currentGroup: PropTypes.object,
   libraryType: PropTypes.string,
   repo: PropTypes.object.isRequired,
@@ -28,10 +33,11 @@ const propTypes = {
   onFreezedItem: PropTypes.func.isRequired,
   onUnfreezedItem: PropTypes.func.isRequired,
   onItemUnshare: PropTypes.func.isRequired,
-  onItemDetails: PropTypes.func,
   onItemRename: PropTypes.func,
   onItemDelete: PropTypes.func,
-  onMonitorRepo: PropTypes.func
+  onMonitorRepo: PropTypes.func,
+  onContextMenu: PropTypes.func.isRequired,
+  onTransferRepo: PropTypes.func
 };
 
 class SharedRepoListItem extends React.Component {
@@ -47,16 +53,15 @@ class SharedRepoListItem extends React.Component {
       isRenaming: false,
       isStarred: this.props.repo.starred,
       isFolderPermissionDialogOpen: false,
-      isHistorySettingDialogShow: false,
       isDeleteDialogShow: false,
       isAPITokenDialogShow: false,
+      isTransferDialogShow: false,
       isRepoShareAdminDialogOpen: false,
       isRepoDeleted: false,
       isChangePasswordDialogShow: false,
       isResetPasswordDialogShow: false,
-      isOldFilesAutoDelDialogOpen: false,
     };
-    this.isDeparementOnwerGroupMember = false;
+    this.isDepartmentOwnerGroupMember = false;
   }
 
   onMouseEnter = () => {
@@ -99,12 +104,12 @@ class SharedRepoListItem extends React.Component {
   toggleOperationMenu = (e) => {
     let dataset = e.target ? e.target.dataset : null;
     if (dataset && dataset.toggle && dataset.toggle === 'Rename') {
-      this.setState({isItemMenuShow: !this.state.isItemMenuShow});
+      this.setState({ isItemMenuShow: !this.state.isItemMenuShow });
       return;
     }
 
     this.setState(
-      {isItemMenuShow: !this.state.isItemMenuShow},
+      { isItemMenuShow: !this.state.isItemMenuShow },
       () => {
         if (this.state.isItemMenuShow) {
           this.props.onFreezedItem();
@@ -139,9 +144,8 @@ class SharedRepoListItem extends React.Component {
   };
 
   getRepoComputeParams = () => {
-    let repo = this.props.repo;
-
-    let iconUrl = Utils.getLibIconUrl(repo);
+    const { repo } = this.props;
+    const iconUrl = Utils.getLibIconUrl(repo);
     let iconTitle = Utils.getLibIconTitle(repo);
     let libPath = `${siteRoot}library/${repo.repo_id}/${Utils.encodePath(repo.repo_name)}/`;
 
@@ -155,26 +159,23 @@ class SharedRepoListItem extends React.Component {
   };
 
   onMenuItemClick = (e) => {
-    let operation = e.target.dataset.toggle;
-    switch(operation) {
+    let operation = e.target.dataset.toggle || e.target.dataset.operation;
+    switch (operation) {
       case 'Rename':
         this.onItemRenameToggle();
         break;
+      case 'Transfer':
+        this.onTransferToggle();
+        break;
       case 'Folder Permission':
         this.onItemFolderPermissionToggle();
         break;
-      case 'Details':
-        this.onItemDetails();
-        break;
       case 'Share':
         this.onItemShare();
         break;
       case 'Unshare':
         this.onItemUnshare();
         break;
-      case 'History Setting':
-        this.onHistorySettingToggle();
-        break;
       case 'API Token':
         this.onAPITokenToggle();
         break;
@@ -193,9 +194,6 @@ class SharedRepoListItem extends React.Component {
       case 'Unwatch File Changes':
         this.unwatchFileChanges();
         break;
-      case 'Old Files Auto Delete':
-        this.toggleOldFilesAutoDelDialog();
-        break;
       // no default
     }
   };
@@ -228,6 +226,27 @@ class SharedRepoListItem extends React.Component {
     });
   };
 
+  onTransferToggle = () => {
+    this.setState({ isTransferDialogShow: !this.state.isTransferDialogShow });
+  };
+
+  onTransferRepo = (email, reshare) => {
+    let repoID = this.props.repo.repo_id;
+    let groupID = this.props.currentGroup.id;
+    userAPI.depAdminTransferRepo(repoID, groupID, email, reshare).then(res => {
+      this.props.onTransferRepo(repoID, groupID, email);
+      let message = gettext('Successfully transferred the library.');
+      toaster.success(message);
+    }).catch(error => {
+      if (error.response) {
+        toaster.danger(error.response.data.error_msg || gettext('Error'), { duration: 3 });
+      } else {
+        toaster.danger(gettext('Failed. Please check the network.'), { duration: 3 });
+      }
+    });
+    this.onTransferToggle();
+  };
+
   onRenameConfirm = (name) => {
     this.props.onItemRename(this.props.repo, name);
     this.onRenameCancel();
@@ -235,39 +254,28 @@ class SharedRepoListItem extends React.Component {
 
   onRenameCancel = () => {
     this.props.onUnfreezedItem();
-    this.setState({isRenaming: !this.state.isRenaming});
+    this.setState({ isRenaming: !this.state.isRenaming });
   };
 
   onItemFolderPermissionToggle = () => {
-    this.setState({isFolderPermissionDialogOpen: !this.state.isFolderPermissionDialogOpen});
+    this.setState({ isFolderPermissionDialogOpen: !this.state.isFolderPermissionDialogOpen });
   };
 
-  onHistorySettingToggle = () => {
-    this.setState({isHistorySettingDialogShow: !this.state.isHistorySettingDialogShow});
+  onItemShare = () => {
+    this.setState({ isShowSharedDialog: true });
   };
 
-  onItemDetails = () => {
-    this.props.onItemDetails(this.props.repo);
-  };
-
-  onItemShare = (e) => {
-    e.preventDefault();
-    this.setState({isShowSharedDialog: true});
-  };
-
-  onItemUnshare = (e) => {
-    e.preventDefault();
+  onItemUnshare = () => {
     this.props.onItemUnshare(this.props.repo);
   };
 
-  onItemDeleteToggle = (e) => {
-    e.preventDefault();
-    this.setState({isDeleteDialogShow: !this.state.isDeleteDialogShow});
+  onItemDeleteToggle = () => {
+    this.setState({ isDeleteDialogShow: !this.state.isDeleteDialogShow });
   };
 
   onItemDelete = () => {
     const { currentGroup, repo } = this.props;
-    if (!currentGroup) {  // repo can not be deleted in share all module
+    if (!currentGroup) { // repo can not be deleted in share all module
       return;
     }
 
@@ -292,55 +300,48 @@ class SharedRepoListItem extends React.Component {
       }
       toaster.danger(errMessage);
 
-      this.setState({isRepoDeleted: false});
+      this.setState({ isRepoDeleted: false });
     });
   };
 
   toggleShareDialog = () => {
-    this.setState({isShowSharedDialog: false});
+    this.setState({ isShowSharedDialog: false });
   };
 
   toggleRepoShareAdminDialog = () => {
-    this.setState({isRepoShareAdminDialogOpen: !this.state.isRepoShareAdminDialogOpen});
-  };
-
-  toggleOldFilesAutoDelDialog = () => {
-    this.setState({isOldFilesAutoDelDialogOpen: !this.state.isOldFilesAutoDelDialogOpen});
+    this.setState({ isRepoShareAdminDialogOpen: !this.state.isRepoShareAdminDialogOpen });
   };
 
   onAPITokenToggle = () => {
-    this.setState({isAPITokenDialogShow: !this.state.isAPITokenDialogShow});
+    this.setState({ isAPITokenDialogShow: !this.state.isAPITokenDialogShow });
   };
 
   onChangePasswordToggle = () => {
-    this.setState({isChangePasswordDialogShow: !this.state.isChangePasswordDialogShow});
+    this.setState({ isChangePasswordDialogShow: !this.state.isChangePasswordDialogShow });
   };
 
   onResetPasswordToggle = () => {
-    this.setState({isResetPasswordDialogShow: !this.state.isResetPasswordDialogShow});
+    this.setState({ isResetPasswordDialogShow: !this.state.isResetPasswordDialogShow });
   };
 
   translateMenuItem = (menuItem) => {
     let translateResult = '';
-    switch(menuItem) {
+    switch (menuItem) {
       case 'Rename':
         translateResult = gettext('Rename');
         break;
+      case 'Transfer':
+        translateResult = gettext('Transfer');
+        break;
       case 'Folder Permission':
         translateResult = gettext('Folder Permission');
         break;
-      case 'Details':
-        translateResult = gettext('Details');
-        break;
       case 'Unshare':
         translateResult = gettext('Unshare');
         break;
       case 'Share':
         translateResult = gettext('Share');
         break;
-      case 'History Setting':
-        translateResult = gettext('History Setting');
-        break;
       case 'Share Admin':
         translateResult = gettext('Share Admin');
         break;
@@ -356,15 +357,15 @@ class SharedRepoListItem extends React.Component {
       case 'Unwatch File Changes':
         translateResult = gettext('Unwatch File Changes');
         break;
-      case 'Old Files Auto Delete':
-        translateResult = gettext('Auto Deletion Setting');
-        break;
       case 'API Token':
         translateResult = 'API Token'; // translation is not needed here
         break;
       case 'Advanced':
         translateResult = gettext('Advanced');
         break;
+      case 'SeaTable integration':
+        translateResult = gettext('SeaTable integration');
+        break;
       default:
         break;
     }
@@ -374,25 +375,23 @@ class SharedRepoListItem extends React.Component {
   getAdvancedOperations = () => {
     const operations = [];
     operations.push('API Token');
-    if (enableRepoAutoDel) {
-      operations.push('Old Files Auto Delete');
-    }
     return operations;
   };
 
   generatorOperations = () => {
     let { repo, currentGroup } = this.props;
-    //todo this have a bug; use current api is not return admins param;
-    let isStaff = currentGroup && currentGroup.admins && currentGroup.admins.indexOf(username) > -1; //for group repolist;
+    // todo this have a bug; use current api is not return admins param;
+    let isStaff = currentGroup && currentGroup.admins && currentGroup.admins.indexOf(username) > -1; // for group repo list;
     let isRepoOwner = repo.owner_email === username;
     let isAdmin = repo.is_admin;
     let operations = [];
     if (isPro) {
       if (repo.owner_email.indexOf('@seafile_group') != -1) {
+        // is group admin
         if (isStaff) {
           if (repo.owner_email == currentGroup.id + '@seafile_group') {
-            this.isDeparementOnwerGroupMember = true;
-            operations = ['Rename'];
+            this.isDepartmentOwnerGroupMember = true;
+            operations = ['Rename', 'Transfer'];
             if (folderPermEnabled) {
               operations.push('Folder Permission');
             }
@@ -407,9 +406,8 @@ class SharedRepoListItem extends React.Component {
               const monitorOp = repo.monitored ? 'Unwatch File Changes' : 'Watch File Changes';
               operations.push(monitorOp);
             }
-            operations.push('Divider', 'History Setting', 'Details');
             if (Utils.isDesktop()) {
-              operations.push('Advanced');
+              operations.push('Divider', 'Advanced');
             }
             return operations;
           } else {
@@ -447,8 +445,8 @@ class SharedRepoListItem extends React.Component {
         operations.push('Unshare');
       }
     } else {
-      operations = this.generatorOperations();
-      if (this.isDeparementOnwerGroupMember) {
+      operations = this.generatorOperations().filter(item => item != 'Divider');
+      if (this.isDepartmentOwnerGroupMember) {
         operations.unshift('Unshare');
         operations.unshift('Share');
       }
@@ -461,13 +459,14 @@ class SharedRepoListItem extends React.Component {
       <Dropdown isOpen={this.state.isItemMenuShow} toggle={this.toggleOperationMenu}>
         <DropdownToggle
           tag="i"
-          className="sf-dropdown-toggle fa fa-ellipsis-v ml-0"
-          title={gettext('More Operations')}
+          className="sf-dropdown-toggle sf3-font sf3-font-more-vertical ml-0"
+          title={gettext('More operations')}
+          aria-label={gettext('More operations')}
           data-toggle="dropdown"
           aria-expanded={this.state.isItemMenuShow}
           onClick={this.clickOperationMenuToggle}
         />
-        <div className={`${this.state.isItemMenuShow?'':'d-none'}`} onClick={this.toggleOperationMenu}>
+        <div className={`${this.state.isItemMenuShow ? '' : 'd-none'}`} onClick={this.toggleOperationMenu}>
           <div className="mobile-operation-menu-bg-layer"></div>
           <div className="mobile-operation-menu">
             {operations.map((item, index) => {
@@ -491,11 +490,11 @@ class SharedRepoListItem extends React.Component {
     } else {
       operations = this.generatorOperations();
     }
-    const shareOperation   = <a href="#" className="op-icon sf2-icon-share" title={gettext('Share')} role="button" aria-label={gettext('Share')} onClick={this.onItemShare}></a>;
-    const unshareOperation = <a href="#" className="op-icon sf2-icon-x3" title={gettext('Unshare')} role="button" aria-label={gettext('Unshare')} onClick={this.onItemUnshare}></a>;
-    const deleteOperation  = <a href="#" className="op-icon sf2-icon-delete" title={gettext('Delete')} role="button" aria-label={gettext('Delete')} onClick={this.onItemDeleteToggle}></a>;
+    const shareOperation = <i className="op-icon sf3-font-share sf3-font" title={gettext('Share')} role="button" aria-label={gettext('Share')} onClick={this.onItemShare}></i>;
+    const unshareOperation = <i className="op-icon sf2-icon-x3" title={gettext('Unshare')} role="button" aria-label={gettext('Unshare')} onClick={this.onItemUnshare}></i>;
+    const deleteOperation = <i className="op-icon sf3-font-delete1 sf3-font" title={gettext('Delete')} role="button" aria-label={gettext('Delete')} onClick={this.onItemDeleteToggle}></i>;
 
-    if (this.isDeparementOnwerGroupMember) {
+    if (this.isDepartmentOwnerGroupMember) {
       const advancedOperations = this.getAdvancedOperations();
       return (
         <Fragment>
@@ -503,17 +502,21 @@ class SharedRepoListItem extends React.Component {
           {deleteOperation}
           <Dropdown isOpen={this.state.isItemMenuShow} toggle={this.toggleOperationMenu}>
             <DropdownToggle
-              className="sf-dropdown-toggle sf2-icon-caret-down border-0 p-0"
-              title={gettext('More Operations')}
+              tag="i"
+              role="button"
+              tabIndex="0"
+              className="sf-dropdown-toggle sf3-font-more sf3-font"
+              title={gettext('More operations')}
+              aria-label={gettext('More operations')}
               data-toggle="dropdown"
               aria-expanded={this.state.isItemMenuShow}
               aria-haspopup={true}
-              style={{'minWidth': '0'}}
+              style={{ 'minWidth': '0' }}
               onClick={this.clickOperationMenuToggle}
               onKeyDown={this.onDropdownToggleKeyDown}
             />
             <DropdownMenu onMouseMove={this.onDropDownMouseMove}>
-              {operations.map((item, index)=> {
+              {operations.map((item, index) => {
                 if (item == 'Divider') {
                   return <DropdownItem key={index} divider />;
                 } else if (item == 'Advanced') {
@@ -527,14 +530,14 @@ class SharedRepoListItem extends React.Component {
                       onMouseMove={(e) => {e.stopPropagation();}}
                     >
                       <DropdownToggle
-                        caret
                         className="dropdown-item font-weight-normal rounded-0 d-flex justify-content-between align-items-center pr-2"
                         onMouseEnter={this.toggleAdvancedMenuShown}
                       >
                         {this.translateMenuItem(item)}
+                        <i className="sf3-font-down sf3-font rotate-270"></i>
                       </DropdownToggle>
                       <DropdownMenu>
-                        {advancedOperations.map((item, index)=> {
+                        {advancedOperations.map((item, index) => {
                           return (<DropdownItem key={index} data-toggle={item} onClick={this.onMenuItemClick} onKeyDown={this.onMenuItemKeyDown}>{this.translateMenuItem(item)}</DropdownItem>);
                         })}
                       </DropdownMenu>
@@ -562,12 +565,16 @@ class SharedRepoListItem extends React.Component {
                 return (
                   <Dropdown isOpen={this.state.isItemMenuShow} toggle={this.toggleOperationMenu} key={item}>
                     <DropdownToggle
-                      className="sf-dropdown-toggle sf2-icon-caret-down border-0 p-0"
-                      title={gettext('More Operations')}
+                      tag="i"
+                      role="button"
+                      tabIndex="0"
+                      className="sf-dropdown-toggle sf3-font-more sf3-font"
+                      title={gettext('More operations')}
+                      aria-label={gettext('More operations')}
                       data-toggle="dropdown"
                       aria-expanded={this.state.isItemMenuShow}
                       aria-haspopup={true}
-                      style={{'minWidth': '0'}}
+                      style={{ 'minWidth': '0' }}
                       onClick={this.clickOperationMenuToggle}
                       onKeyDown={this.onDropdownToggleKeyDown}
                     />
@@ -593,7 +600,7 @@ class SharedRepoListItem extends React.Component {
     const { repo_name: repoName } = this.props.repo;
     if (this.state.isStarred) {
       seafileAPI.unstarItem(this.props.repo.repo_id, '/').then(() => {
-        this.setState({isStarred: !this.state.isStarred});
+        this.setState({ isStarred: !this.state.isStarred });
         const msg = gettext('Successfully unstarred {library_name_placeholder}.')
           .replace('{library_name_placeholder}', repoName);
         toaster.success(msg);
@@ -603,7 +610,7 @@ class SharedRepoListItem extends React.Component {
       });
     } else {
       seafileAPI.starItem(this.props.repo.repo_id, '/').then(() => {
-        this.setState({isStarred: !this.state.isStarred});
+        this.setState({ isStarred: !this.state.isStarred });
         const msg = gettext('Successfully starred {library_name_placeholder}.')
           .replace('{library_name_placeholder}', repoName);
         toaster.success(msg);
@@ -614,33 +621,80 @@ class SharedRepoListItem extends React.Component {
     }
   };
 
+  handleContextMenu = (e) => {
+    this.props.onContextMenu(e, this.props.repo);
+  };
+
   renderPCUI = () => {
+    const { isStarred } = this.state;
     let { iconUrl, iconTitle, libPath } = this.getRepoComputeParams();
-    let { repo } = this.props;
-    return (
-      <Fragment>
-        <tr className={this.state.highlight ? 'tr-highlight' : ''} onMouseEnter={this.onMouseEnter} onMouseOver={this.onMouseOver} onMouseLeave={this.onMouseLeave} onFocus={this.onMouseEnter}>
-          <td className="text-center">
-            <a href="#" role="button" aria-label={this.state.isStarred ? gettext('Unstar') : gettext('Star')} onClick={this.onToggleStarRepo}>
-              <i className={`fa-star ${this.state.isStarred ? 'fas' : 'far star-empty'}`}></i>
-            </a>
-          </td>
-          <td><img src={iconUrl} title={iconTitle} alt={iconTitle} width="24" /></td>
-          <td>
-            {this.state.isRenaming ?
-              <Rename name={repo.repo_name} onRenameConfirm={this.onRenameConfirm} onRenameCancel={this.onRenameCancel}/> :
-              <Fragment>
-                <Link to={libPath}>{repo.repo_name}</Link>
-                {repo.monitored && <RepoMonitoredIcon repoID={repo.repo_id} />}
-              </Fragment>
-            }
-          </td>
-          <td>{this.state.isOperationShow && this.generatorPCMenu()}</td>
-          <td>{repo.size}</td>
-          <td title={moment(repo.last_modified).format('llll')}>{moment(repo.last_modified).fromNow()}</td>
-          <td title={repo.owner_contact_email}>{repo.owner_name}</td>
-        </tr>
-      </Fragment>
+    const { repo, currentViewMode } = this.props;
+    return currentViewMode == LIST_MODE ? (
+      <tr
+        className={this.state.highlight ? 'tr-highlight' : ''}
+        onMouseEnter={this.onMouseEnter}
+        onMouseOver={this.onMouseOver}
+        onMouseLeave={this.onMouseLeave}
+        onFocus={this.onMouseEnter}
+        onContextMenu={this.handleContextMenu}
+      >
+        <td className="text-center">
+          <i
+            role="button"
+            title={this.state.isStarred ? gettext('Unstar') : gettext('Star')}
+            aria-label={this.state.isStarred ? gettext('Unstar') : gettext('Star')}
+            onClick={this.onToggleStarRepo}
+            className={`op-icon m-0 ${this.state.isStarred ? 'sf3-font-star' : 'sf3-font-star-empty'} sf3-font`}
+          >
+          </i>
+        </td>
+        <td><img src={iconUrl} title={iconTitle} alt={iconTitle} width="24" /></td>
+        <td>
+          {this.state.isRenaming ?
+            <Rename name={repo.repo_name} onRenameConfirm={this.onRenameConfirm} onRenameCancel={this.onRenameCancel}/> :
+            <Fragment>
+              <Link to={libPath}>{repo.repo_name}</Link>
+              {repo.monitored && <RepoMonitoredIcon repoID={repo.repo_id} className="ml-1 op-icon" />}
+            </Fragment>
+          }
+        </td>
+        <td>{this.state.isOperationShow && this.generatorPCMenu()}</td>
+        <td>{repo.size}</td>
+        <td title={dayjs(repo.last_modified).format('dddd, MMMM D, YYYY h:mm:ss A')}>{dayjs(repo.last_modified).fromNow()}</td>
+        <td title={repo.owner_contact_email}>{repo.owner_name}</td>
+      </tr>
+    ) : (
+      <div
+        className="library-grid-item px-3 d-flex justify-content-between align-items-center"
+        onMouseEnter={this.onMouseEnter}
+        onMouseLeave={this.onMouseLeave}
+        onFocus={this.onMouseEnter}
+        onContextMenu={this.handleContextMenu}
+      >
+        <div className="d-flex align-items-center text-truncate">
+          <img src={iconUrl} title={iconTitle} alt={iconTitle} width="36" className="mr-2" />
+          {this.state.isRenaming ?
+            <Rename name={repo.repo_name} onRenameConfirm={this.onRenameConfirm} onRenameCancel={this.onRenameCancel} /> :
+            <Fragment>
+              <Link to={libPath} className="library-name text-truncate" title={repo.repo_name}>{repo.repo_name}</Link>
+              {isStarred &&
+                <i
+                  role="button"
+                  title={gettext('Unstar')}
+                  aria-label={gettext('Unstar')}
+                  onClick={this.onToggleStarRepo}
+                  className='op-icon library-grid-item-icon sf3-font-star sf3-font'
+                >
+                </i>
+              }
+              {repo.monitored && <RepoMonitoredIcon repoID={repo.repo_id} className="op-icon library-grid-item-icon" />}
+            </Fragment>
+          }
+        </div>
+        <div className="flex-shrink-0">
+          {this.state.isOperationShow && this.generatorPCMenu()}
+        </div>
+      </div>
     );
   };
 
@@ -656,20 +710,20 @@ class SharedRepoListItem extends React.Component {
     this.repoURL = libPath;
     return (
       <Fragment>
-        <tr className={this.state.highlight ? 'tr-highlight' : ''}  onMouseEnter={this.onMouseEnter} onMouseOver={this.onMouseOver} onMouseLeave={this.onMouseLeave}>
+        <tr className={this.state.highlight ? 'tr-highlight' : ''} onMouseEnter={this.onMouseEnter} onMouseOver={this.onMouseOver} onMouseLeave={this.onMouseLeave}>
           <td onClick={this.visitRepo}><img src={iconUrl} title={iconTitle} width="24" alt={iconTitle}/></td>
           <td onClick={this.visitRepo}>
             {this.state.isRenaming ?
               <Rename name={repo.repo_name} onRenameConfirm={this.onRenameConfirm} onRenameCancel={this.onRenameCancel} /> :
               <Fragment>
                 <Link to={libPath}>{repo.repo_name}</Link>
-                {repo.monitored && <RepoMonitoredIcon repoID={repo.repo_id} />}
+                {repo.monitored && <RepoMonitoredIcon repoID={repo.repo_id} className="ml-1 op-icon" />}
               </Fragment>
             }
             <br />
             <span className="item-meta-info" title={repo.owner_contact_email}>{repo.owner_name}</span>
             <span className="item-meta-info">{repo.size}</span>
-            <span className="item-meta-info" title={moment(repo.last_modified).format('llll')}>{moment(repo.last_modified).fromNow()}</span>
+            <span className="item-meta-info" title={dayjs(repo.last_modified).format('dddd, MMMM D, YYYY h:mm:ss A')}>{dayjs(repo.last_modified).fromNow()}</span>
           </td>
           <td>{this.generatorMobileMenu()}</td>
         </tr>
@@ -690,6 +744,7 @@ class SharedRepoListItem extends React.Component {
               itemName={repo.repo_name}
               itemPath={'/'}
               repoID={repo.repo_id}
+              repo={repo}
               repoEncrypted={repo.encrypted}
               enableDirPrivateShare={true}
               userPerm={repo.permission}
@@ -716,18 +771,10 @@ class SharedRepoListItem extends React.Component {
               isRepoDeleted={this.state.isRepoDeleted}
               onDeleteRepo={this.onItemDelete}
               toggle={this.onItemDeleteToggle}
+              isGetShare={true}
             />
           </ModalPortal>
         }
-        {this.state.isHistorySettingDialogShow && (
-          <ModalPortal>
-            <LibHistorySettingDialog
-              repoID={repo.repo_id}
-              itemName={repo.repo_name}
-              toggleDialog={this.onHistorySettingToggle}
-            />
-          </ModalPortal>
-        )}
         {this.state.isAPITokenDialogShow && (
           <ModalPortal>
             <RepoAPITokenDialog
@@ -761,15 +808,17 @@ class SharedRepoListItem extends React.Component {
             />
           </ModalPortal>
         )}
-        {this.state.isOldFilesAutoDelDialogOpen && (
+        {this.state.isTransferDialogShow && (
           <ModalPortal>
-            <LibOldFilesAutoDelDialog
-              repoID={repo.repo_id}
-              toggleDialog={this.toggleOldFilesAutoDelDialog}
+            <TransferDialog
+              itemName={repo.repo_name}
+              onTransferRepo={this.onTransferRepo}
+              canTransferToDept={true}
+              toggleDialog={this.onTransferToggle}
+              isDepAdminTransfer={true}
             />
           </ModalPortal>
         )}
-
       </Fragment>
     );
   }
