@@ -2,10 +2,10 @@ import React from 'react';
 import PropTypes from 'prop-types';
 import AsyncSelect from 'react-select/async';
 import { seafileAPI } from '../utils/seafile-api';
-import { gettext, enableShowContactEmailWhenSearchUser } from '../utils/constants';
+import { gettext, enableShowContactEmailWhenSearchUser, enableShowLoginIDWhenSearchUser } from '../utils/constants';
 import { Utils } from '../utils/utils';
 import toaster from './toast';
-import { UserSelectStyle } from './common/select';
+import { UserSelectStyle, NoOptionsStyle } from './common/select';
 
 import '../css/user-select.css';
 
@@ -26,9 +26,14 @@ class UserSelect extends React.Component {
     this.state = {
       searchValue: ''
     };
+    this.userSelect = React.createRef();
   }
 
   onInputChange = (searchValue) => {
+    if (!this.props.isMulti && searchValue.trim()) {
+      this.handleSelectChange(null);
+      this.clearSelect();
+    }
     this.setState({ searchValue });
   };
 
@@ -49,12 +54,13 @@ class UserSelect extends React.Component {
             let obj = {};
             obj.value = item.name;
             obj.email = item.email;
-            obj.label = enableShowContactEmailWhenSearchUser ? (
+            obj.label = (enableShowContactEmailWhenSearchUser || enableShowLoginIDWhenSearchUser) ? (
               <div className="d-flex">
                 <img src={item.avatar_url} className="avatar" width="24" alt="" />
                 <div className="ml-2">
                   <span className="user-option-name">{item.name}</span><br />
-                  <span className="user-option-email">{item.contact_email}</span>
+                  {enableShowContactEmailWhenSearchUser && <span className="user-option-email">{item.contact_email}</span>}
+                  {enableShowLoginIDWhenSearchUser && <span className="user-option-email">{item.login_id}</span>}
                 </div>
               </div>
             ) : (
@@ -75,12 +81,11 @@ class UserSelect extends React.Component {
   };
 
   clearSelect = () => {
-    this.refs.userSelect.onChange([], { action: 'clear' });
+    this.userSelect.current.onChange([], { action: 'clear' });
   };
 
   render() {
     const searchValue = this.state.searchValue;
-    const style = { margin: '6px 10px', textAlign: 'center', color: 'hsl(0,0%,50%)' };
     return (
       <AsyncSelect
         isClearable
@@ -88,18 +93,20 @@ class UserSelect extends React.Component {
         components={{
           NoOptionsMessage: (props) => {
             return (
-              <div {...props.innerProps} style={style}>{searchValue ? gettext('User not found') : gettext('Enter characters to start searching')}</div>
+              <div {...props.innerProps} style={NoOptionsStyle}>
+                {searchValue ? gettext('User not found') : gettext('Enter characters to start searching')}
+              </div>
             );
           }
         }}
-        isMulti={this.props.isMulti}
+        isMulti={true}
         loadOptions={this.loadOptions}
         onChange={this.handleSelectChange}
         onInputChange={this.onInputChange}
         placeholder={this.props.placeholder}
         className={`user-select ${this.props.className}`}
         value={this.props.value}
-        ref="userSelect"
+        ref={this.userSelect}
         styles={UserSelectStyle}
       />
     );
@@ -108,4 +115,8 @@ class UserSelect extends React.Component {
 
 UserSelect.propTypes = propTypes;
 
+UserSelect.defaultProps = {
+  className: ''
+};
+
 export default UserSelect;
