@@ -5,7 +5,7 @@ import './css/draft.css';
 
 export default function Draft() {
   return (
-    <div style={{display: 'flex', flex: 1, flexDirection: 'column', justifyContent: 'center', alignItems: 'center'}}>
+    <div id="draft">
       <h1>Draft module</h1>
       <div>The current module is no longer supported</div>
     </div>
