@@ -20,7 +20,7 @@ class FileHistory extends React.Component {
     };
   }
 
-  setDiffContent = (newMarkdownContent, oldMarkdownContent)=> {
+  setDiffContent = (newMarkdownContent, oldMarkdownContent) => {
     this.setState({
       renderingContent: false,
       newMarkdownContent: newMarkdownContent,
@@ -29,8 +29,8 @@ class FileHistory extends React.Component {
   };
 
 
-  onHistoryItemClick = (item, preItem)=> {
-    this.setState({renderingContent: true});
+  onHistoryItemClick = (item, preItem) => {
+    this.setState({ renderingContent: true });
     seafileAPI.getFileRevision(historyRepoID, item.commit_id, item.path).then((res) => {
       axios.all([
         seafileAPI.getFileContent(res.data),
@@ -48,13 +48,13 @@ class FileHistory extends React.Component {
   render() {
     return (
       <div className="history-content flex-fill d-flex h-100">
-        <div className="flex-fill d-flex flex-column">
+        <div className="flex-fill d-flex flex-column text-truncate">
           <div className="history-header file-history-header flex-shrink-0">
-            <div className="title">
+            <div className="title d-flex mw-100">
               <a href="#" className="go-back" title="Back" onClick={this.onBackClick}>
-                <span className="fas fa-chevron-left"></span>
+                <span className="sf3-font sf3-font-down rotate-90 d-inline-block"></span>
               </a>
-              <span className="name">{fileName}</span>
+              <span className="name text-truncate" title={fileName}>{fileName}</span>
             </div>
           </div>
           <MainPanel
