@@ -10,6 +10,8 @@ class RepoInfo {
     this.owner_name = object.owner_name;
     this.owner_email = object.owner_email;
     this.owner_contact_email = object.owner_contact_email;
+    this.owner_avatar = object.owner_avatar || '';
+
     // is repo shared admin;
     // is repo shared admin && is one of current ordinary group's admins;
     // is one of current group owned group's admins;
@@ -19,8 +21,9 @@ class RepoInfo {
     this.has_been_shared_out = object.has_been_shared_out;
     this.encrypted = object.encrypted;
     this.lib_need_decrypt = object.lib_need_decrypt;
-    this.last_modified= object.last_modified;
+    this.last_modified = object.last_modified;
     this.status = object.status;
+    this.enable_onlyoffice = object.enable_onlyoffice;
   }
 }
 
