@@ -1,6 +1,6 @@
 import React, { Component, Fragment } from 'react';
 import PropTypes from 'prop-types';
-import moment from 'moment';
+import dayjs from 'dayjs';
 import { Link } from '@gatsbyjs/reach-router';
 import { seafileAPI } from '../../utils/seafile-api';
 import { gettext, siteRoot, username } from '../../utils/constants';
@@ -12,7 +12,7 @@ import UserSelector from './user-selector';
 
 import '../../css/files-activities.css';
 
-moment.locale(window.app.config.lang);
+dayjs.locale(window.app.config.lang);
 
 const propTypes = {
   onlyMine: PropTypes.bool
@@ -25,7 +25,7 @@ class FilesActivities extends Component {
     this.state = {
       errorMsg: '',
       isFirstLoading: true,
-      isLoadingMore: false,
+      isLoadingMore: false, // only for 'scroll down to the bottom'
       currentPage: 1,
       hasMore: true,
       allItems: [],
@@ -33,7 +33,6 @@ class FilesActivities extends Component {
       availableUsers: [],
       targetUsers: []
     };
-    this.avatarSize = 72;
     this.curPathList = [];
     this.oldPathList = [];
     this.availableUserEmails = new Set();
@@ -41,7 +40,7 @@ class FilesActivities extends Component {
 
   componentDidMount() {
     let { currentPage, availableUsers } = this.state;
-    seafileAPI.listActivities(currentPage, this.avatarSize).then(res => {
+    seafileAPI.listActivities(currentPage, this.props.onlyMine ? username : '').then(res => {
       // {"events":[...]}
       let events = this.mergePublishEvents(res.data.events);
       events = this.mergeFileCreateEvents(events);
@@ -51,17 +50,20 @@ class FilesActivities extends Component {
           availableUsers.push({
             email: item.author_email,
             name: item.author_name,
+            contact_email: item.author_contact_email,
             avatar_url: item.avatar_url,
             isSelected: false
           });
         }
       });
+
+      const curItems = this.filterEvents(events);
       this.setState({
         allItems: events,
-        items: this.filterEvents(events),
+        items: curItems,
         availableUsers: availableUsers,
         currentPage: currentPage + 1,
-        isFirstLoading: false,
+        isFirstLoading: curItems.length == 0,
         hasMore: true,
       });
       if (this.state.items.length < 25) {
@@ -137,7 +139,7 @@ class FilesActivities extends Component {
 
   getMore() {
     const { currentPage, availableUsers, targetUsers } = this.state;
-    seafileAPI.listActivities(currentPage, this.avatarSize).then(res => {
+    seafileAPI.listActivities(currentPage, this.props.onlyMine ? username : '').then(res => {
       // {"events":[...]}
       let events = this.mergePublishEvents(res.data.events);
       events = this.mergeFileCreateEvents(events);
@@ -147,17 +149,20 @@ class FilesActivities extends Component {
           availableUsers.push({
             email: item.author_email,
             name: item.author_name,
+            contact_email: item.author_contact_email,
             avatar_url: item.avatar_url,
             isSelected: false
           });
         }
       });
       const filteredEvents = this.filterEvents(events);
+      const curItems = [...this.state.items, ...filteredEvents];
       this.setState({
         allItems: [...this.state.allItems, ...events],
-        items: [...this.state.items, ...filteredEvents],
+        items: curItems,
         availableUsers: availableUsers,
         currentPage: currentPage + 1,
+        isFirstLoading: curItems.length == 0,
         isLoadingMore: false,
         hasMore: res.data.events.length === 0 ? false : true
       });
@@ -168,6 +173,7 @@ class FilesActivities extends Component {
       }
     }).catch(error => {
       this.setState({
+        isFirstLoading: false,
         isLoadingMore: false,
         errorMsg: Utils.getErrorMsg(error, true) // true: show login tip if 403
       });
@@ -178,13 +184,10 @@ class FilesActivities extends Component {
     const { onlyMine } = this.props;
     const { targetUsers } = this.state;
 
-    if (onlyMine) {
-      return events.filter(item => item.author_email == username);
-    } else if (targetUsers.length) {
+    if (!onlyMine && targetUsers.length) {
       return events.filter(item => targetUsers.map(item => item.email).indexOf(item.author_email) != -1);
-    } else {
-      return events;
     }
+    return events;
   };
 
   setTargetUsers = (selectedUsers) => {
@@ -218,10 +221,10 @@ class FilesActivities extends Component {
     if (!this.state.isLoadingMore && this.state.hasMore) {
       const clientHeight = event.target.clientHeight;
       const scrollHeight = event.target.scrollHeight;
-      const scrollTop    = event.target.scrollTop;
+      const scrollTop = event.target.scrollTop;
       const isBottom = (clientHeight + scrollTop + 1 >= scrollHeight);
       if (isBottom) { // scroll to the bottom
-        this.setState({isLoadingMore: true}, () => {
+        this.setState({ isLoadingMore: true }, () => {
           this.getMore();
         });
       }
@@ -240,7 +243,7 @@ class FilesActivities extends Component {
                 <Link to={`${siteRoot}dashboard/`} className={`nav-link${onlyMine ? '' : ' active'}`}>{gettext('All Activities')}</Link>
               </li>
               <li className="nav-item">
-                <Link to={`${siteRoot}my-activities/`} className={`nav-link${onlyMine ? ' active': ''}`}>{gettext('My Activities')}</Link>
+                <Link to={`${siteRoot}my-activities/`} className={`nav-link${onlyMine ? ' active' : ''}`}>{gettext('My Activities')}</Link>
               </li>
             </ul>
           </div>
