@@ -1,11 +1,11 @@
 import React, { Component, Fragment } from 'react';
 import { Dropdown, DropdownToggle, DropdownItem } from 'reactstrap';
 import PropTypes from 'prop-types';
-import moment from 'moment';
+import dayjs from 'dayjs';
 import { gettext } from '../../utils/constants';
 import { Utils } from '../../utils/utils';
 import { seafileAPI } from '../../utils/seafile-api';
-import InvitationsToolbar from '../../components/toolbar/invitations-toolbar';
+import SingleDropdownToolbar from '../../components/toolbar/single-dropdown-toolbar';
 import InvitePeopleDialog from '../../components/dialog/invite-people-dialog';
 import InvitationRevokeDialog from '../../components/dialog/invitation-revoke-dialog';
 import Loading from '../../components/loading';
@@ -43,15 +43,14 @@ class Item extends React.Component {
     });
   };
 
-  deleteItem = (e) => {
-    e.preventDefault();
+  deleteItem = () => {
     // make the icon avoid being clicked repeatedly
     this.setState({
       isOpIconShown: false
     });
     const token = this.props.invitation.token;
     seafileAPI.deleteInvitation(token).then((res) => {
-      this.setState({deleted: true});
+      this.props.deleteItem(token);
       toaster.success(gettext('Successfully deleted 1 item.'));
     }).catch((error) => {
       const errorMsg = Utils.getErrorMsg(error);
@@ -63,87 +62,82 @@ class Item extends React.Component {
   };
 
   revokeItem = () => {
-    this.setState({deleted: true});
+    const token = this.props.invitation.token;
+    this.props.deleteItem(token);
   };
 
-  toggleRevokeDialog = (e) => {
-    e.preventDefault();
+  toggleRevokeDialog = () => {
     this.setState({
       isRevokeDialogOpen: !this.state.isRevokeDialogOpen
     });
   };
 
   render() {
-    const { isOpIconShown, deleted, isRevokeDialogOpen } = this.state;
-
-    if (deleted) {
-      return null;
-    }
+    const { isOpIconShown, isRevokeDialogOpen } = this.state;
 
     const item = this.props.invitation;
 
-    const desktopItem = (
-      <tr onMouseEnter={this.onMouseEnter} onMouseLeave={this.onMouseLeave} onFocus={this.onMouseEnter} tabIndex="0">
-        <td>{item.accepter}</td>
-        <td>{moment(item.invite_time).format('YYYY-MM-DD')}</td>
-        <td>{moment(item.expire_time).format('YYYY-MM-DD')}</td>
-        <td>{item.accept_time && <i className="sf2-icon-tick invite-accept-icon"></i>}</td>
-        <td>
-          {isOpIconShown && (
-            item.accept_time ?
-              <a href="#"
-                role="button"
-                className="action-icon sf3-font sf3-font-cancel-invitation"
-                title={gettext('Revoke Access')}
-                aria-label={gettext('Revoke Access')}
-                onClick={this.toggleRevokeDialog}>
-              </a> :
-              <a href="#"
-                role="button"
-                className="action-icon sf2-icon-x3"
-                title={gettext('Delete')}
-                aria-label={gettext('Delete')}
-                onClick={this.deleteItem}>
-              </a>
-          )}
-        </td>
-      </tr>
-    );
-
-    const mobileItem = (
-      <tr>
-        <td>
-          {item.accepter}<br />
-          <span className="item-meta-info">{moment(item.invite_time).format('YYYY-MM-DD')}<span className="small">({gettext('Invite Time')})</span></span>
-          <span className="item-meta-info">{moment(item.expire_time).format('YYYY-MM-DD')}<span className="small">({gettext('Expiration')})</span></span>
-          <span className="item-meta-info">{item.accept_time && gettext('Accepted')}</span>
-        </td>
-        <td>
-          <Dropdown isOpen={this.state.isOpMenuOpen} toggle={this.toggleOpMenu}>
-            <DropdownToggle
-              tag="i"
-              className="sf-dropdown-toggle fa fa-ellipsis-v ml-0"
-              title={gettext('More Operations')}
-              data-toggle="dropdown"
-              aria-expanded={this.state.isOpMenuOpen}
-            />
-            <div className={this.state.isOpMenuOpen ? '' : 'd-none'} onClick={this.toggleOpMenu}>
-              <div className="mobile-operation-menu-bg-layer"></div>
-              <div className="mobile-operation-menu">
-                {item.accept_time ?
-                  <DropdownItem className="mobile-menu-item" onClick={this.toggleRevokeDialog}>{gettext('Revoke Access')}</DropdownItem> :
-                  <DropdownItem className="mobile-menu-item" onClick={this.deleteItem}>{gettext('Delete')}</DropdownItem>
-                }
-              </div>
-            </div>
-          </Dropdown>
-        </td>
-      </tr>
-    );
-
     return (
       <Fragment>
-        {this.props.isDesktop ? desktopItem : mobileItem}
+        {this.props.isDesktop ?
+          <tr onMouseEnter={this.onMouseEnter} onMouseLeave={this.onMouseLeave} onFocus={this.onMouseEnter} tabIndex="0">
+            <td>{item.accepter}</td>
+            <td>{dayjs(item.invite_time).format('YYYY-MM-DD')}</td>
+            <td>{dayjs(item.expire_time).format('YYYY-MM-DD')}</td>
+            <td>{item.accept_time && <i className="sf2-icon-tick invite-accept-icon"></i>}</td>
+            <td>
+              {isOpIconShown && (
+                item.accept_time ?
+                  <i
+                    role="button"
+                    className="action-icon sf3-font sf3-font-cancel-invitation"
+                    title={gettext('Revoke Access')}
+                    aria-label={gettext('Revoke Access')}
+                    onClick={this.toggleRevokeDialog}
+                  >
+                  </i> :
+                  <i
+                    role="button"
+                    className="action-icon sf2-icon-x3"
+                    title={gettext('Delete')}
+                    aria-label={gettext('Delete')}
+                    onClick={this.deleteItem}
+                  >
+                  </i>
+              )}
+            </td>
+          </tr>
+          :
+          <tr>
+            <td>
+              {item.accepter}<br />
+              <span className="item-meta-info">{dayjs(item.invite_time).format('YYYY-MM-DD')}<span className="small">({gettext('Invite Time')})</span></span>
+              <span className="item-meta-info">{dayjs(item.expire_time).format('YYYY-MM-DD')}<span className="small">({gettext('Expiration')})</span></span>
+              <span className="item-meta-info">{item.accept_time && gettext('Accepted')}</span>
+            </td>
+            <td>
+              <Dropdown isOpen={this.state.isOpMenuOpen} toggle={this.toggleOpMenu}>
+                <DropdownToggle
+                  tag="i"
+                  className="sf-dropdown-toggle sf3-font sf3-font-more-vertical ml-0"
+                  title={gettext('More operations')}
+                  aria-label={gettext('More operations')}
+                  data-toggle="dropdown"
+                  aria-expanded={this.state.isOpMenuOpen}
+                />
+                <div className={this.state.isOpMenuOpen ? '' : 'd-none'} onClick={this.toggleOpMenu}>
+                  <div className="mobile-operation-menu-bg-layer"></div>
+                  <div className="mobile-operation-menu">
+                    {item.accept_time ?
+                      <DropdownItem className="mobile-menu-item" onClick={this.toggleRevokeDialog}>{gettext('Revoke Access')}</DropdownItem> :
+                      <DropdownItem className="mobile-menu-item" onClick={this.deleteItem}>{gettext('Delete')}</DropdownItem>
+                    }
+                  </div>
+                </div>
+              </Dropdown>
+            </td>
+          </tr>
+        }
         {isRevokeDialogOpen &&
         <InvitationRevokeDialog
           accepter={item.accepter}
@@ -158,9 +152,9 @@ class Item extends React.Component {
 }
 
 const ItemPropTypes = {
-  data: PropTypes.object.isRequired,
   invitation: PropTypes.object.isRequired,
   isDesktop: PropTypes.bool.isRequired,
+  deleteItem: PropTypes.func.isRequired
 };
 
 Item.propTypes = ItemPropTypes;
@@ -186,16 +180,16 @@ class Content extends Component {
 
     if (!invitationsList.length) {
       return (
-        <EmptyTip>
-          <h2>{gettext('No guest invitations')}</h2>
-          <p>{gettext('You have not invited any guests yet. A guest can access shared libraries through the web interface allowing more efficient ways to collaborate than through links. You can invite a guest by clicking the "Invite Guest" button in the menu bar.')}</p>
-        </EmptyTip>
+        <EmptyTip
+          title={gettext('No guest invitations')}
+          text={gettext('You have not invited any guests yet. A guest can access shared libraries through the web interface allowing more efficient ways to collaborate than through links. You can invite a guest by clicking the "Invite Guest" item in the dropdown menu.')}
+        />
       );
     }
 
     const isDesktop = Utils.isDesktop();
     return (
-      <table className={`table-hover${isDesktop ? '': ' table-thead-hidden'}`}>
+      <table className={`table-hover${isDesktop ? '' : ' table-thead-hidden'}`}>
         <thead>
           {isDesktop ?
             <tr>
@@ -219,6 +213,7 @@ class Content extends Component {
                 key={index}
                 isDesktop={isDesktop}
                 invitation={invitation}
+                deleteItem={this.props.deleteItem}
               />
             );
           })}
@@ -261,6 +256,12 @@ class InvitationsView extends React.Component {
     });
   };
 
+  deleteItem = (token) => {
+    this.setState({
+      invitationsList: this.state.invitationsList.filter(item => item.token != token)
+    });
+  };
+
   toggleInvitePeopleDialog = () => {
     this.setState({
       isInvitePeopleDialogOpen: !this.state.isInvitePeopleDialogOpen
@@ -270,18 +271,22 @@ class InvitationsView extends React.Component {
   render() {
     return (
       <Fragment>
-        <InvitationsToolbar
-          onShowSidePanel={this.props.onShowSidePanel}
-          onSearchedClick={this.props.onSearchedClick}
-          toggleInvitePeopleDialog={this.toggleInvitePeopleDialog}
-        />
         <div className="main-panel-center flex-row">
           <div className="cur-view-container">
             <div className="cur-view-path">
-              <h3 className="sf-heading">{gettext('Invite Guest')}</h3>
+              <div className="d-flex">
+                <h3 className="sf-heading">{gettext('Invite Guest')}</h3>
+                <SingleDropdownToolbar
+                  withPlusIcon={true}
+                  opList={[{ 'text': gettext('Invite Guest'), 'onClick': this.toggleInvitePeopleDialog }]}
+                />
+              </div>
             </div>
             <div className="cur-view-content">
-              <Content data={this.state} />
+              <Content
+                data={this.state}
+                deleteItem={this.deleteItem}
+              />
             </div>
           </div>
         </div>
@@ -300,11 +305,4 @@ Content.propTypes = {
   data: PropTypes.object.isRequired,
 };
 
-const InvitationsViewPropTypes = {
-  onShowSidePanel: PropTypes.func.isRequired,
-  onSearchedClick: PropTypes.func.isRequired,
-};
-
-InvitationsView.propTypes = InvitationsViewPropTypes;
-
 export default InvitationsView;
