@@ -1,7 +1,8 @@
 import React, { Component } from 'react';
 import PropTypes from 'prop-types';
 import { Dropdown, DropdownToggle, DropdownItem } from 'reactstrap';
-import moment from 'moment';
+import dayjs from 'dayjs';
+import relativeTime from 'dayjs/plugin/relativeTime';
 import { seafileAPI } from '../../utils/seafile-api';
 import { gettext } from '../../utils/constants';
 import toaster from '../../components/toast';
@@ -9,10 +10,12 @@ import EmptyTip from '../../components/empty-tip';
 import ConfirmUnlinkDeviceDialog from '../../components/dialog/confirm-unlink-device';
 import { Utils } from '../../utils/utils';
 
+dayjs.extend(relativeTime);
+
 class Content extends Component {
 
   render() {
-    const {loading, errorMsg, items} = this.props.data;
+    const { loading, errorMsg, items } = this.props.data;
 
     if (loading) {
       return <span className="loading-icon loading-tip"></span>;
@@ -20,10 +23,10 @@ class Content extends Component {
       return <p className="error text-center">{errorMsg}</p>;
     } else {
       const emptyTip = (
-        <EmptyTip>
-          <h2>{gettext('No linked devices')}</h2>
-          <p>{gettext('You have not accessed your files with any client (desktop or mobile) yet. Configure clients on your devices to access your data more comfortably.')}</p>
-        </EmptyTip>
+        <EmptyTip
+          title={gettext('No linked devices')}
+          text={gettext('You have not accessed your files with any client (desktop or mobile) yet. Configure clients on your devices to access your data more comfortably.')}
+        />
       );
 
       const desktopThead = (
@@ -48,7 +51,7 @@ class Content extends Component {
 
       const isDesktop = Utils.isDesktop();
       return items.length ? (
-        <table className={`table-hover ${isDesktop ? '': 'table-thead-hidden'}`}>
+        <table className={`table-hover ${isDesktop ? '' : 'table-thead-hidden'}`}>
           {isDesktop ? desktopThead : mobileThead}
           <tbody>
             {items.map((item, index) => {
@@ -56,7 +59,7 @@ class Content extends Component {
             })}
           </tbody>
         </table>
-      ): emptyTip;
+      ) : emptyTip;
     }
   }
 }
@@ -128,42 +131,40 @@ class Item extends Component {
     });
   };
 
-  render() {
-    if (this.state.unlinked) {
-      return null;
-    }
-
+  renderDesktopItem = () => {
     const data = this.props.data;
-
-    let opClasses = 'sf2-icon-delete unlink-device action-icon';
+    let opClasses = 'sf3-font-delete1 sf3-font unlink-device action-icon';
     opClasses += this.state.isOpIconShown ? '' : ' invisible';
-
-    const desktopItem = (
+    return (
       <tr onMouseOver={this.handleMouseOver} onMouseOut={this.handleMouseOut} onFocus={this.handleMouseOver}>
         <td>{data.platform}</td>
         <td>{data.device_name}</td>
         <td>{data.last_login_ip}</td>
-        <td>{moment(data.last_accessed).fromNow()}</td>
+        <td>{dayjs(data.last_accessed).fromNow()}</td>
         <td>
           <a href="#" className={opClasses} title={gettext('Unlink')} role="button" aria-label={gettext('Unlink')} onClick={this.handleClick}></a>
         </td>
       </tr>
     );
+  };
 
-    const mobileItem = (
+  renderMobileItem = () => {
+    const data = this.props.data;
+    return (
       <tr>
         <td>
           {data.device_name}<br />
           <span className="item-meta-info">{data.last_login_ip}</span>
-          <span className="item-meta-info">{moment(data.last_accessed).fromNow()}</span>
+          <span className="item-meta-info">{dayjs(data.last_accessed).fromNow()}</span>
           <span className="item-meta-info">{data.platform}</span>
         </td>
         <td>
           <Dropdown isOpen={this.state.isOpMenuOpen} toggle={this.toggleOpMenu}>
             <DropdownToggle
               tag="i"
-              className="sf-dropdown-toggle fa fa-ellipsis-v ml-0"
-              title={gettext('More Operations')}
+              className="sf-dropdown-toggle sf3-font sf3-font-more-vertical ml-0"
+              title={gettext('More operations')}
+              aria-label={gettext('More operations')}
               data-toggle="dropdown"
               aria-expanded={this.state.isOpMenuOpen}
             />
@@ -177,10 +178,15 @@ class Item extends Component {
         </td>
       </tr>
     );
+  };
 
+  render() {
+    if (this.state.unlinked) {
+      return null;
+    }
     return (
       <React.Fragment>
-        {this.props.isDesktop ? desktopItem : mobileItem}
+        {this.props.isDesktop ? this.renderDesktopItem() : this.renderMobileItem()}
         {this.state.isConfirmUnlinkDialogOpen &&
         <ConfirmUnlinkDeviceDialog
           executeOperation={this.unlinkDevice}
