@@ -1,16 +1,17 @@
 import React, { Component, Fragment } from 'react';
 import PropTypes from 'prop-types';
 import { Link } from '@gatsbyjs/reach-router';
-import moment from 'moment';
+import dayjs from 'dayjs';
+import relativeTime from 'dayjs/plugin/relativeTime';
 import { gettext, siteRoot, lang, trashReposExpireDays } from '../../utils/constants';
 import { seafileAPI } from '../../utils/seafile-api';
 import { Utils } from '../../utils/utils';
 import toaster from '../../components/toast';
 import Loading from '../../components/loading';
 import EmptyTip from '../../components/empty-tip';
-import CommonToolbar from '../../components/toolbar/common-toolbar';
 
-moment.locale(lang);
+dayjs.locale(lang);
+dayjs.extend(relativeTime);
 
 class MyLibsDeleted extends Component {
 
@@ -38,15 +39,12 @@ class MyLibsDeleted extends Component {
     let deletedRepoList = this.state.deletedRepoList.filter(item => {
       return item.repo_id !== repoID;
     });
-    this.setState({deletedRepoList: deletedRepoList});
+    this.setState({ deletedRepoList: deletedRepoList });
   };
 
   render() {
     return (
       <Fragment>
-        <div className="main-panel-north">
-          <CommonToolbar onSearchedClick={this.props.onSearchedClick} />
-        </div>
         <div className="main-panel-center">
           <div className="cur-view-container">
             <div className="cur-view-path">
@@ -59,10 +57,10 @@ class MyLibsDeleted extends Component {
             <div className="cur-view-content">
               {this.state.isLoading && <Loading />}
               {(!this.state.isLoading && this.state.deletedRepoList.length === 0) &&
-              <EmptyTip>
-                <h2>{gettext('No deleted libraries')}</h2>
-                <p>{gettext('You have not deleted any libraries in the last {placeholder} days. A deleted library will be cleaned automatically after this period.').replace('{placeholder}', trashReposExpireDays)}</p>
-              </EmptyTip>
+              <EmptyTip
+                title={gettext('No deleted libraries')}
+                text={gettext('You have not deleted any libraries in the last {placeholder} days. A deleted library will be cleaned automatically after this period.').replace('{placeholder}', trashReposExpireDays)}
+              />
               }
               {this.state.deletedRepoList.length !== 0 &&
                 <div>
@@ -89,14 +87,14 @@ class DeletedRepoTable extends Component {
       <table>
         <thead>
           <tr>
-            <th style={{width: '4%'}}>{/*img*/}</th>
-            <th style={{width: '52%'}}>{gettext('Name')}</th>
-            <th style={{width: '30%'}}>{gettext('Deleted Time')}</th>
-            <th style={{width: '14%'}}></th>
+            <th style={{ width: '4%' }}>{/* img*/}</th>
+            <th style={{ width: '52%' }}>{gettext('Name')}</th>
+            <th style={{ width: '30%' }}>{gettext('Deleted Time')}</th>
+            <th style={{ width: '14%' }}></th>
           </tr>
         </thead>
         <tbody>
-          { deletedRepos && deletedRepos.map((item) => {
+          {deletedRepos && deletedRepos.map((item) => {
             return (
               <DeletedRepoItem
                 key={item.repo_id}
@@ -126,21 +124,17 @@ class DeletedRepoItem extends Component {
   }
 
   onMouseEnter = () => {
-    if (!this.props.isItemFreezed) {
-      this.setState({
-        hideRestoreMenu: false,
-        highlight: true,
-      });
-    }
+    this.setState({
+      hideRestoreMenu: false,
+      highlight: true,
+    });
   };
 
   onMouseLeave = () => {
-    if (!this.props.isItemFreezed) {
-      this.setState({
-        hideRestoreMenu: true,
-        highlight: false,
-      });
-    }
+    this.setState({
+      hideRestoreMenu: true,
+      highlight: false,
+    });
   };
 
   restoreDeletedRepo = (e) => {
@@ -161,8 +155,8 @@ class DeletedRepoItem extends Component {
   };
 
   render() {
-    let localTime = moment.utc(this.props.repo.del_time).toDate();
-    localTime = moment(localTime).fromNow();
+    let localTime = dayjs.utc(this.props.repo.del_time).toDate();
+    localTime = dayjs(localTime).fromNow();
     let iconUrl = Utils.getLibIconUrl(this.props.repo);
 
     return (
@@ -179,7 +173,8 @@ class DeletedRepoItem extends Component {
         <td>
           <a href="#" onClick={this.restoreDeletedRepo} title={gettext('Restore')}
             role="button" aria-label={gettext('Restore')}
-            className={`sf2-icon-reply action-icon ${this.state.highlight ? '' : 'vh'}`}></a>
+            className={`sf2-icon-reply action-icon ${this.state.highlight ? '' : 'vh'}`}>
+          </a>
         </td>
       </tr>
     );
@@ -187,13 +182,8 @@ class DeletedRepoItem extends Component {
 }
 
 DeletedRepoItem.propTypes = {
-  isItemFreezed: PropTypes.bool.isRequired,
   repo: PropTypes.object.isRequired,
   refreshDeletedRepoList: PropTypes.func.isRequired,
 };
 
-MyLibsDeleted.propTypes = {
-  onSearchedClick: PropTypes.func.isRequired,
-};
-
 export default MyLibsDeleted;
