@@ -1,7 +1,7 @@
 import React from 'react';
 import PropTypes from 'prop-types';
 import { Dropdown, DropdownMenu, DropdownToggle, DropdownItem } from 'reactstrap';
-import { gettext, isPro, folderPermEnabled, enableRepoSnapshotLabel, enableResetEncryptedRepoPassword, isEmailConfigured, enableRepoAutoDel, enableSeaTableIntegration } from '../../utils/constants';
+import { gettext, isPro, folderPermEnabled, enableRepoSnapshotLabel, enableResetEncryptedRepoPassword, isEmailConfigured, enableMultipleOfficeSuite } from '../../utils/constants';
 import { Utils } from '../../utils/utils';
 
 const propTypes = {
@@ -47,12 +47,12 @@ class MylibRepoMenu extends React.Component {
   toggleOperationMenu = (e) => {
     let dataset = e.target ? e.target.dataset : null;
     if (dataset && dataset.toggle && dataset.toggle === 'Rename') {
-      this.setState({isItemMenuShow: !this.state.isItemMenuShow});
+      this.setState({ isItemMenuShow: !this.state.isItemMenuShow });
       return;
     }
 
     this.setState(
-      {isItemMenuShow: !this.state.isItemMenuShow},
+      { isItemMenuShow: !this.state.isItemMenuShow },
       () => {
         if (this.state.isItemMenuShow) {
           this.props.onFreezedItem();
@@ -103,7 +103,7 @@ class MylibRepoMenu extends React.Component {
       operations.push(monitorOp);
     }
 
-    operations.push('Divider', 'History Setting', 'Advanced');
+    operations.push('Divider', 'Advanced');
     // Remove adjacent excess 'Divider'
     for (let i = 0; i < operations.length; i++) {
       if (operations[i] === 'Divider' && operations[i + 1] === 'Divider') {
@@ -120,18 +120,15 @@ class MylibRepoMenu extends React.Component {
     if (this.props.isPC && enableRepoSnapshotLabel) {
       operations.push('Label Current State');
     }
-    if (enableRepoAutoDel) {
-      operations.push('Old Files Auto Delete');
-    }
-    if (enableSeaTableIntegration) {
-      operations.push('SeaTable integration');
+    if (enableMultipleOfficeSuite && isPro) {
+      operations.push('Office Suite');
     }
     return operations;
   };
 
   translateOperations = (item) => {
     let translateResult = '';
-    switch(item) {
+    switch (item) {
       case 'Star':
         translateResult = gettext('Star');
         break;
@@ -150,9 +147,6 @@ class MylibRepoMenu extends React.Component {
       case 'Transfer':
         translateResult = gettext('Transfer');
         break;
-      case 'History Setting':
-        translateResult = gettext('History Setting');
-        break;
       case 'Change Password':
         translateResult = gettext('Change Password');
         break;
@@ -177,15 +171,15 @@ class MylibRepoMenu extends React.Component {
       case 'Share Admin':
         translateResult = gettext('Share Admin');
         break;
-      case 'Old Files Auto Delete':
-        translateResult = gettext('Auto Deletion Setting');
-        break;
       case 'Advanced':
         translateResult = gettext('Advanced');
         break;
       case 'SeaTable integration':
         translateResult = gettext('SeaTable integration');
         break;
+      case 'Office Suite':
+        translateResult = gettext('Office Suite');
+        break;
       default:
         break;
     }
@@ -205,15 +199,15 @@ class MylibRepoMenu extends React.Component {
             tag="i"
             role="button"
             tabIndex="0"
-            className="sf-dropdown-toggle sf2-icon-caret-down"
-            title={gettext('More Operations')}
-            aria-label={gettext('More Operations')}
+            className="sf-dropdown-toggle sf3-font-more sf3-font"
+            title={gettext('More operations')}
+            aria-label={gettext('More operations')}
             onClick={this.onDropdownToggleClick}
             onKeyDown={this.onDropdownToggleKeyDown}
             data-toggle="dropdown"
           />
           <DropdownMenu onMouseMove={this.onDropDownMouseMove}>
-            {operations.map((item, index)=> {
+            {operations.map((item, index) => {
               if (item == 'Divider') {
                 return <DropdownItem key={index} divider />;
               } else if (item == 'Advanced') {
@@ -227,14 +221,14 @@ class MylibRepoMenu extends React.Component {
                     onMouseMove={(e) => {e.stopPropagation();}}
                   >
                     <DropdownToggle
-                      caret
                       className="dropdown-item font-weight-normal rounded-0 d-flex justify-content-between align-items-center pr-2"
                       onMouseEnter={this.toggleAdvancedMenuShown}
                     >
                       {this.translateOperations(item)}
+                      <i className="sf3-font-down sf3-font rotate-270"></i>
                     </DropdownToggle>
                     <DropdownMenu>
-                      {advancedOperations.map((item, index)=> {
+                      {advancedOperations.map((item, index) => {
                         return (<DropdownItem key={index} data-toggle={item} onClick={this.onMenuItemClick} onKeyDown={this.onMenuItemKeyDown}>{this.translateOperations(item)}</DropdownItem>);
                       })}
                     </DropdownMenu>
@@ -259,9 +253,9 @@ class MylibRepoMenu extends React.Component {
       <Dropdown isOpen={this.state.isItemMenuShow} toggle={this.toggleOperationMenu}>
         <DropdownToggle
           tag="i"
-          className="sf-dropdown-toggle fa fa-ellipsis-v ml-0"
-          title={gettext('More Operations')}
-          // onClick={this.clickOperationMenuToggle}
+          className="sf-dropdown-toggle sf3-font sf3-font-more-vertical ml-0"
+          title={gettext('More operations')}
+          aria-label={gettext('More operations')}
           data-toggle="dropdown"
           aria-expanded={this.state.isItemMenuShow}
         />
