@@ -1,7 +1,7 @@
 import React from 'react';
 import ReactDom from 'react-dom';
 import { Router } from '@gatsbyjs/reach-router';
-import { siteRoot } from '../../utils/constants';
+import { siteRoot, enableMultiADFS } from '../../utils/constants';
 import SidePanel from './side-panel';
 
 import OrgStatisticFile from './statistic/statistic-file';
@@ -24,17 +24,19 @@ import OrgGroupsSearchGroups from './org-groups-search-groups';
 import OrgGroupInfo from './org-group-info';
 import OrgGroupRepos from './org-group-repos';
 import OrgGroupMembers from './org-group-members';
-import OrgLibraries from './org-libraries';
+import OrgAllRepos from './libraries/org-all-repos';
+import OrgTrashRepos from './libraries/org-repo-trash';
 import OrgInfo from './org-info';
 import OrgLinks from './org-links';
-import OrgDepartments from './org-departments';
-import OrgDepartmentsList from './org-departments-list';
-import OrgDepartmentItem from './org-department-item';
+
+import Departments from './departments/departments';
+
 import OrgLogs from './org-logs';
 import OrgLogsFileAudit from './org-logs-file-audit';
 import OrgLogsFileUpdate from './org-logs-file-update';
 import OrgLogsPermAudit from './org-logs-perm-audit';
 import OrgSAMLConfig from './org-saml-config';
+import OrgSubscription from './org-subscription';
 
 import '../../css/layout.css';
 import '../../css/toolbar.css';
@@ -67,21 +69,28 @@ class Org extends React.Component {
     if (location.href.indexOf(`${siteRoot}org/departmentadmin`) != -1) {
       currentTab = 'departmentadmin';
     }
-    this.setState({currentTab: currentTab});
+    if (location.href.indexOf(`${siteRoot}org/logadmin/`) != -1) {
+      if (currentTab === 'logadmin') {
+        currentTab = 'fileaudit';
+      }
+    }
+    this.setState({
+      currentTab: currentTab
+    });
   }
 
   onCloseSidePanel = () => {
-    this.setState({isSidePanelClosed: !this.state.isSidePanelClosed});
+    this.setState({ isSidePanelClosed: !this.state.isSidePanelClosed });
   };
 
   tabItemClick = (param) => {
-    this.setState({currentTab: param});
+    this.setState({ currentTab: param });
   };
 
   render() {
     let { isSidePanelClosed, currentTab } = this.state;
     return (
-      <div id="main">
+      <div id="main" className="org-admin">
         <SidePanel isSidePanelClosed={isSidePanelClosed} onCloseSidePanel={this.onCloseSidePanel} currentTab={currentTab} tabItemClick={this.tabItemClick}/>
         <div className="main-panel">
           <Router className="reach-router">
@@ -95,6 +104,7 @@ class Org extends React.Component {
             <OrgMobileDevices path={siteRoot + 'org/deviceadmin/mobile-devices/'} />
             <OrgDevicesErrors path={siteRoot + 'org/deviceadmin/devices-errors/'} />
             <OrgWebSettings path={siteRoot + 'org/web-settings'} />
+            <OrgSubscription path={siteRoot + 'org/subscription'} onCloseSidePanel={this.onCloseSidePanel} />
             <OrgUsers path={siteRoot + 'org/useradmin'} />
             <OrgUsersSearchUsers path={siteRoot + 'org/useradmin/search-users'} />
             <OrgAdmins path={siteRoot + 'org/useradmin/admins/'} />
@@ -106,18 +116,18 @@ class Org extends React.Component {
             <OrgGroupInfo path={siteRoot + 'org/groupadmin/:groupID/'} />
             <OrgGroupRepos path={siteRoot + 'org/groupadmin/:groupID/repos/'} />
             <OrgGroupMembers path={siteRoot + 'org/groupadmin/:groupID/members/'} />
-            <OrgLibraries path={siteRoot + 'org/repoadmin'}/>
+            <OrgAllRepos path={siteRoot + 'org/repoadmin'}/>
+            <OrgTrashRepos path={siteRoot + 'org/repoadmin-trash'}/>
             <OrgLinks path={siteRoot + 'org/publinkadmin'}/>
-            <OrgDepartments path={siteRoot + 'org/departmentadmin'}>
-              <OrgDepartmentsList path='/'/>
-              <OrgDepartmentItem path='groups/:groupID'/>
-            </OrgDepartments>
+            <Departments path={siteRoot + 'org/departmentadmin/'} />
             <OrgLogs path={siteRoot + 'org/logadmin'} currentTab={currentTab} tabItemClick={this.tabItemClick}>
               <OrgLogsFileAudit path='/' />
               <OrgLogsFileUpdate path='file-update' />
               <OrgLogsPermAudit path='perm-audit' />
             </OrgLogs>
-            <OrgSAMLConfig path={siteRoot + 'org/samlconfig/'}/>
+            {enableMultiADFS &&
+              <OrgSAMLConfig path={siteRoot + 'org/samlconfig/'}/>
+            }
           </Router>
         </div>
       </div>
