@@ -1,7 +1,7 @@
 import React, { Component, Fragment } from 'react';
 import PropTypes from 'prop-types';
 import { Link } from '@gatsbyjs/reach-router';
-import { seafileAPI } from '../../utils/seafile-api';
+import { orgAdminAPI } from '../../utils/org-admin-api';
 import { gettext, siteRoot } from '../../utils/constants';
 import { Utils } from '../../utils/utils';
 import Loading from '../../components/loading';
@@ -25,7 +25,7 @@ class OrgGroupRepos extends Component {
   }
 
   componentDidMount() {
-    seafileAPI.orgAdminListGroupRepos(orgID, this.props.groupID).then((res) => {
+    orgAdminAPI.orgAdminListGroupRepos(orgID, this.props.groupID).then((res) => {
       this.setState(Object.assign({
         loading: false
       }, res.data));
@@ -79,7 +79,7 @@ class Content extends Component {
         <table className="table-hover">
           <thead>
             <tr>
-              <th width="4%">{/*icon*/}</th>
+              <th width="4%">{/* icon*/}</th>
               <th width="35%">{gettext('Name')}</th>
               <th width="20%">{gettext('Size')}</th>
               <th width="26%">{gettext('Shared By')}</th>
@@ -138,7 +138,7 @@ class Item extends Component {
 
   deleteRepo = () => {
     const repo = this.props.data;
-    seafileAPI.orgAdminDeleteOrgRepo(orgID, repo.repo_id).then((res) => {
+    orgAdminAPI.orgAdminDeleteOrgRepo(orgID, repo.repo_id).then((res) => {
       this.setState({
         deleted: true,
         isRepoDeleted: true,
@@ -149,7 +149,7 @@ class Item extends Component {
       const errorMsg = Utils.getErrorMsg(error);
       toaster.danger(errorMsg);
 
-      this.setState({isRepoDeleted: false});
+      this.setState({ isRepoDeleted: false });
     });
   };
 
@@ -165,13 +165,13 @@ class Item extends Component {
       <Fragment>
         <tr onMouseOver={this.handleMouseOver} onMouseOut={this.handleMouseOut}>
           <td>
-            <img src={Utils.getLibIconUrl(repo, false)} alt={Utils.getLibIconTitle(repo)} title={Utils.getLibIconTitle(repo)} width="24" />
+            <img src={Utils.getLibIconUrl(repo)} alt={Utils.getLibIconTitle(repo)} title={Utils.getLibIconTitle(repo)} width="24" />
           </td>
           <td>{repo.name}</td>
           <td>{Utils.bytesToSize(repo.size)}</td>
           <td><Link to={`${siteRoot}org/useradmin/info/${encodeURIComponent(repo.shared_by)}/`}>{repo.shared_by_name}</Link></td>
           <td>
-            <a href="#" className={`action-icon sf2-icon-delete${isOpIconShown ? '' : ' invisible'}`} title={gettext('Delete')} onClick={this.handleDeleteIconClick}></a>
+            <a href="#" className={`action-icon sf3-font-delete1 sf3-font${isOpIconShown ? '' : ' invisible'}`} title={gettext('Delete')} onClick={this.handleDeleteIconClick}></a>
           </td>
         </tr>
         {isDeleteRepoDialogOpen && (
@@ -180,6 +180,7 @@ class Item extends Component {
             isRepoDeleted={this.state.isRepoDeleted}
             onDeleteRepo={this.deleteRepo}
             toggle={this.toggleDeleteRepoDialog}
+            isGetShare={false}
           />
         )}
       </Fragment>
