@@ -1,9 +1,8 @@
 import React, { Component, Fragment } from 'react';
 import PropTypes from 'prop-types';
-import { Dropdown, DropdownToggle, DropdownMenu, DropdownItem } from 'reactstrap';
-import { Form, FormGroup, Input, Col } from 'reactstrap';
+import { Dropdown, DropdownToggle, DropdownMenu, DropdownItem, Form, FormGroup, Input, Col } from 'reactstrap';
 import { Utils } from '../../utils/utils';
-import { seafileAPI } from '../../utils/seafile-api';
+import { orgAdminAPI } from '../../utils/org-admin-api';
 import { gettext, orgID, siteRoot } from '../../utils/constants';
 import toaster from '../../components/toast';
 import OrgGroupInfo from '../../models/org-group';
@@ -45,7 +44,7 @@ class GroupItem extends React.Component {
   toggleOperationMenu = (e) => {
     e.stopPropagation();
     this.setState(
-      {isItemMenuShow: !this.state.isItemMenuShow }, () => {
+      { isItemMenuShow: !this.state.isItemMenuShow }, () => {
         if (this.state.isItemMenuShow) {
           this.props.onFreezedItem();
         } else {
@@ -81,7 +80,7 @@ class GroupItem extends React.Component {
         <td> -- </td>
       );
     } else {
-      return(
+      return (
         <td>
           <a href={userInfoHref} className="font-weight-normal">{group.creatorName}</a>
         </td>
@@ -104,8 +103,9 @@ class GroupItem extends React.Component {
             <Dropdown isOpen={this.state.isItemMenuShow} toggle={this.toggleOperationMenu}>
               <DropdownToggle
                 tag="a"
-                className="attr-action-icon fas fa-ellipsis-v"
-                title={gettext('More Operations')}
+                className="attr-action-icon sf3-font sf3-font-more-vertical"
+                title={gettext('More operations')}
+                aria-label={gettext('More operations')}
                 data-toggle="dropdown"
                 aria-expanded={this.state.isItemMenuShow}
                 onClick={this.onDropdownToggleClick}
@@ -139,11 +139,11 @@ class OrgGroupsSearchGroupsResult extends React.Component {
   }
 
   onFreezedItem = () => {
-    this.setState({isItemFreezed: true});
+    this.setState({ isItemFreezed: true });
   };
 
   onUnfreezedItem = () => {
-    this.setState({isItemFreezed: false});
+    this.setState({ isItemFreezed: false });
   };
 
   render() {
@@ -197,7 +197,7 @@ class OrgGroupsSearchGroups extends Component {
     };
   }
 
-  componentDidMount () {
+  componentDidMount() {
     let params = (new URL(document.location)).searchParams;
     this.setState({
       query: params.get('query') || '',
@@ -205,7 +205,7 @@ class OrgGroupsSearchGroups extends Component {
   }
 
   getItems = () => {
-    seafileAPI.orgAdminSearchGroup(orgID, this.state.query.trim()).then(res => {
+    orgAdminAPI.orgAdminSearchGroup(orgID, this.state.query.trim()).then(res => {
       let groupList = res.data.group_list.map(item => {
         return new OrgGroupInfo(item);
       });
@@ -222,7 +222,7 @@ class OrgGroupsSearchGroups extends Component {
   };
 
   deleteGroupItem = (group) => {
-    seafileAPI.orgAdminDeleteOrgGroup(orgID, group.id).then(res => {
+    orgAdminAPI.orgAdminDeleteOrgGroup(orgID, group.id).then(res => {
       this.setState({
         orgGroups: this.state.orgGroups.filter(item => item.id != group.id)
       });
@@ -277,7 +277,7 @@ class OrgGroupsSearchGroups extends Component {
                     </Col>
                   </FormGroup>
                   <FormGroup row>
-                    <Col sm={{size: 5}}>
+                    <Col sm={{ size: 5 }}>
                       <button className="btn btn-outline-primary" disabled={!isSubmitBtnActive} onClick={this.getItems}>{gettext('Submit')}</button>
                     </Col>
                   </FormGroup>
