@@ -3,11 +3,12 @@ import PropTypes from 'prop-types';
 import { navigate } from '@gatsbyjs/reach-router';
 import { Dropdown, DropdownToggle, DropdownMenu, DropdownItem } from 'reactstrap';
 import { siteRoot, gettext, orgID } from '../../utils/constants';
-import { seafileAPI } from '../../utils/seafile-api';
+import { orgAdminAPI } from '../../utils/org-admin-api';
 import { Utils } from '../../utils/utils';
 import toaster from '../../components/toast';
 import OrgGroupInfo from '../../models/org-group';
 import MainPanelTopbar from './main-panel-topbar';
+import ChangeGroupDialog from '../../components/dialog/change-group-dialog';
 
 class Search extends React.Component {
 
@@ -42,11 +43,11 @@ class Search extends React.Component {
   render() {
     return (
       <div className="input-icon">
-        <i className="d-flex input-icon-addon fas fa-search"></i>
+        <i className="d-flex input-icon-addon sf3-font sf3-font-search"></i>
         <input
           type="text"
           className="form-control search-input h-6 mr-1"
-          style={{width: '15rem'}}
+          style={{ width: '15rem' }}
           placeholder={this.props.placeholder}
           value={this.state.value}
           onChange={this.handleInputChange}
@@ -81,7 +82,7 @@ class OrgGroups extends Component {
   }
 
   initData = (page) => {
-    seafileAPI.orgAdminListOrgGroups(orgID, page).then(res => {
+    orgAdminAPI.orgAdminListOrgGroups(orgID, page).then(res => {
       let orgGroups = res.data.groups.map(item => {
         return new OrgGroupInfo(item);
       });
@@ -111,15 +112,15 @@ class OrgGroups extends Component {
   };
 
   onFreezedItem = () => {
-    this.setState({isItemFreezed: true});
+    this.setState({ isItemFreezed: true });
   };
 
   onUnfreezedItem = () => {
-    this.setState({isItemFreezed: false});
+    this.setState({ isItemFreezed: false });
   };
 
   deleteGroupItem = (group) => {
-    seafileAPI.orgAdminDeleteOrgGroup(orgID, group.id).then(res => {
+    orgAdminAPI.orgAdminDeleteOrgGroup(orgID, group.id).then(res => {
       this.setState({
         orgGroups: this.state.orgGroups.filter(item => item.id != group.id)
       });
@@ -132,6 +133,24 @@ class OrgGroups extends Component {
     });
   };
 
+  changeGroupItem = (group) => {
+    orgAdminAPI.orgAdminGroup2Department(orgID, group.id).then(res => {
+      let newGroupList = this.state.orgGroups.map(item => {
+        if (item.id == group.id) {
+          item = new OrgGroupInfo(res.data);
+        }
+        return item;
+      });
+      this.setState({
+        orgGroups: newGroupList
+      });
+      toaster.success(gettext('Successfully change the group'));
+    }).catch(error => {
+      let errMessage = Utils.getErrorMsg(error);
+      toaster.danger(errMessage);
+    });
+  };
+
   searchItems = (keyword) => {
     navigate(`${siteRoot}org/groupadmin/search-groups/?query=${encodeURIComponent(keyword)}`);
   };
@@ -173,6 +192,7 @@ class OrgGroups extends Component {
                         onFreezedItem={this.onFreezedItem}
                         onUnfreezedItem={this.onUnfreezedItem}
                         deleteGroupItem={this.deleteGroupItem}
+                        changeGroupItem={this.changeGroupItem}
                       />
                     );
                   })}
@@ -197,6 +217,7 @@ const GroupItemPropTypes = {
   onFreezedItem: PropTypes.func.isRequired,
   onUnfreezedItem: PropTypes.func.isRequired,
   deleteGroupItem: PropTypes.func.isRequired,
+  changeGroupItem: PropTypes.func.isRequired,
 };
 
 class GroupItem extends React.Component {
@@ -206,7 +227,8 @@ class GroupItem extends React.Component {
     this.state = {
       highlight: false,
       showMenu: false,
-      isItemMenuShow: false
+      isItemMenuShow: false,
+      isChangeDialogOpen: false,
     };
   }
 
@@ -236,7 +258,7 @@ class GroupItem extends React.Component {
   toggleOperationMenu = (e) => {
     e.stopPropagation();
     this.setState(
-      {isItemMenuShow: !this.state.isItemMenuShow }, () => {
+      { isItemMenuShow: !this.state.isItemMenuShow }, () => {
         if (this.state.isItemMenuShow) {
           this.props.onFreezedItem();
         } else {
@@ -253,16 +275,19 @@ class GroupItem extends React.Component {
   toggleDelete = () => {
     this.props.deleteGroupItem(this.props.group);
   };
+  toggleChange = () => {
+    this.props.changeGroupItem(this.props.group);
+  };
+
+  toggleChangeDialog = (e) => {
+    if (e) {
+      e.preventDefault();
+    }
+    this.setState({ isChangeDialogOpen: !this.state.isChangeDialogOpen });
+  };
 
   renderGroupHref = (group) => {
-    let groupInfoHref;
-    if (group.creatorName == 'system admin') {
-      groupInfoHref = siteRoot + 'org/departmentadmin/groups/' + group.id + '/';
-    } else {
-      groupInfoHref = siteRoot + 'org/groupadmin/' + group.id + '/';
-    }
-
-    return groupInfoHref;
+    return siteRoot + 'org/groupadmin/' + group.id + '/';
   };
 
   renderGroupCreator = (group) => {
@@ -272,7 +297,7 @@ class GroupItem extends React.Component {
         <td> -- </td>
       );
     } else {
-      return(
+      return (
         <td>
           <a href={userInfoHref} className="font-weight-normal">{group.creatorName}</a>
         </td>
@@ -295,19 +320,28 @@ class GroupItem extends React.Component {
             <Dropdown isOpen={this.state.isItemMenuShow} toggle={this.toggleOperationMenu}>
               <DropdownToggle
                 tag="a"
-                className="attr-action-icon fas fa-ellipsis-v"
-                title={gettext('More Operations')}
+                className="attr-action-icon sf3-font sf3-font-more-vertical"
+                title={gettext('More operations')}
+                aria-label={gettext('More operations')}
                 data-toggle="dropdown"
                 aria-expanded={this.state.isItemMenuShow}
                 onClick={this.onDropdownToggleClick}
               />
               <DropdownMenu>
                 <DropdownItem onClick={this.toggleDelete}>{gettext('Delete')}</DropdownItem>
+                <DropdownItem onClick={this.toggleChangeDialog}>{gettext('Change to department')}</DropdownItem>
               </DropdownMenu>
             </Dropdown>
           }
+          {this.state.isChangeDialogOpen &&
+            <ChangeGroupDialog
+              groupName={group.groupName}
+              changeGroup2Department={this.toggleChange}
+              toggleDialog={this.toggleChangeDialog} />
+          }
         </td>
       </tr>
+
     );
   }
 
