@@ -1,14 +1,17 @@
 import React, { Fragment } from 'react';
 import PropTypes from 'prop-types';
-import moment from 'moment';
+import dayjs from 'dayjs';
+import relativeTime from 'dayjs/plugin/relativeTime';
 import { Dropdown, DropdownToggle, DropdownMenu, DropdownItem } from 'reactstrap';
-import { seafileAPI } from '../../utils/seafile-api';
+import { orgAdminAPI } from '../../utils/org-admin-api';
 import { siteRoot, gettext, serviceURL } from '../../utils/constants';
 import { Utils } from '../../utils/utils';
 import toaster from '../../components/toast';
 import MainPanelTopbar from './main-panel-topbar';
 import ViewLinkDialog from '../../components/dialog/view-link-dialog';
 
+dayjs.extend(relativeTime);
+
 class OrgLinks extends React.Component {
 
   constructor(props) {
@@ -24,7 +27,7 @@ class OrgLinks extends React.Component {
   }
 
   listOrgLinks = (page) => {
-    seafileAPI.orgAdminListOrgLinks(this.state.page).then(res => {
+    orgAdminAPI.orgAdminListOrgLinks(page).then(res => {
       const data = res.data;
       this.setState({
         linkList: data.link_list,
@@ -35,17 +38,17 @@ class OrgLinks extends React.Component {
   };
 
   onFreezedItem = () => {
-    this.setState({isItemFreezed: true});
+    this.setState({ isItemFreezed: true });
   };
 
   onUnfreezedItem = () => {
-    this.setState({isItemFreezed: false});
+    this.setState({ isItemFreezed: false });
   };
 
   onChangePageNum = (event, num) => {
     event.preventDefault();
     let page = this.state.page;
-    if (num == 1) {
+    if (num === 1) {
       page = page + 1;
     } else {
       page = page - 1;
@@ -54,7 +57,7 @@ class OrgLinks extends React.Component {
   };
 
   deleteOrgLink = (token) => {
-    seafileAPI.orgAdminDeleteOrgLink(token).then(res => {
+    orgAdminAPI.orgAdminDeleteOrgLink(token).then(res => {
       if (res.data.success === true) {
         this.listOrgLinks(this.state.page);
       }
@@ -76,7 +79,7 @@ class OrgLinks extends React.Component {
   };
 
   toggleLinkDialog = () => {
-    this.setState({isShowLinkDialog: !this.state.isShowLinkDialog});
+    this.setState({ isShowLinkDialog: !this.state.isShowLinkDialog });
   };
 
   componentDidMount() {
@@ -100,13 +103,13 @@ class OrgLinks extends React.Component {
                     <th width="50%">{gettext('Name')}</th>
                     <th width="15%">{gettext('Owner')}</th>
                     <th width="15%">{gettext('Created At')}</th>
-                    <th width="10%">{gettext('Count')}</th>
+                    <th width="10%">{gettext('Visit count')}</th>
                     <th width="10%"></th>
                   </tr>
                 </thead>
                 <tbody>
                   {linkList && linkList.map((item, index) => {
-                    return(
+                    return (
                       <React.Fragment key={index}>
                         <RepoItem
                           link={item}
@@ -122,8 +125,8 @@ class OrgLinks extends React.Component {
                 </tbody>
               </table>
               <div className="paginator">
-                {this.state.page != 1 && <a href="#" onClick={(e) => this.onChangePageNum(e, -1)}>{gettext('Previous')}</a>}
-                {(this.state.page != 1 && this.state.pageNext) && <span> | </span>}
+                {this.state.page !== 1 && <a href="#" onClick={(e) => this.onChangePageNum(e, -1)}>{gettext('Previous')}</a>}
+                {(this.state.page !== 1 && this.state.pageNext) && <span> | </span>}
                 {this.state.pageNext && <a href="#" onClick={(e) => this.onChangePageNum(e, 1)}>{gettext('Next')}</a>}
               </div>
             </div>
@@ -177,7 +180,7 @@ class RepoItem extends React.Component {
   toggleOperationMenu = (e) => {
     e.stopPropagation();
     this.setState(
-      {isItemMenuShow: !this.state.isItemMenuShow }, () => {
+      { isItemMenuShow: !this.state.isItemMenuShow }, () => {
         if (this.state.isItemMenuShow) {
           this.props.onFreezedItem();
         } else {
@@ -198,15 +201,16 @@ class RepoItem extends React.Component {
       <tr className={this.state.highlight ? 'tr-highlight' : ''} onMouseEnter={this.onMouseEnter} onMouseLeave={this.onMouseLeave} >
         <td>{link.name}</td>
         <td><a href={href}>{link.owner_name}</a></td>
-        <td>{moment(link.created_time).fromNow()}</td>
+        <td>{dayjs(link.created_time).fromNow()}</td>
         <td>{link.view_count}</td>
         <td className="cursor-pointer text-center">
           {this.state.showMenu &&
             <Dropdown isOpen={this.state.isItemMenuShow} toggle={this.toggleOperationMenu}>
               <DropdownToggle
                 tag="a"
-                className="attr-action-icon fas fa-ellipsis-v"
-                title={gettext('More Operations')}
+                className="attr-action-icon sf3-font sf3-font-more-vertical"
+                title={gettext('More operations')}
+                aria-label={gettext('More operations')}
                 data-toggle="dropdown"
                 aria-expanded={this.state.isItemMenuShow}
                 onClick={this.onDropdownToggleClick}
