@@ -1,15 +1,15 @@
 import React from 'react';
 import PropTypes from 'prop-types';
-import moment from 'moment';
+import dayjs from 'dayjs';
 import { Dropdown, DropdownToggle, DropdownMenu, DropdownItem } from 'reactstrap';
-import { seafileAPI } from '../../utils/seafile-api';
+import { orgAdminAPI } from '../../utils/org-admin-api';
 import { siteRoot, gettext, lang } from '../../utils/constants';
 import { Utils } from '../../utils/utils';
 import toaster from '../../components/toast';
 import OrgLogsFileAuditEvent from '../../models/org-logs-file-audit';
 import '../../css/org-logs.css';
 
-moment.locale(lang);
+dayjs.locale(lang);
 
 class OrgLogsFileAudit extends React.Component {
 
@@ -33,7 +33,7 @@ class OrgLogsFileAudit extends React.Component {
   }
 
   initData = (email, repoID, page) => {
-    seafileAPI.orgAdminListFileAudit(email, repoID, page).then(res => {
+    orgAdminAPI.orgAdminListFileAudit(email, repoID, page).then(res => {
       let eventList = res.data.log_list.map(item => {
         return new OrgLogsFileAuditEvent(item);
       });
@@ -184,7 +184,7 @@ class FileAuditItem extends React.Component {
         <a href={siteRoot + 'org/useradmin/info/' + fileEvent.user_email + '/'}>{fileEvent.user_name}</a>{' '}
         <Dropdown size='sm' isOpen={this.state.userDropdownOpen} toggle={this.toggleUserDropdown}
           className={this.state.highlight ? '' : 'vh'} tag="span">
-          <DropdownToggle tag="i" className="sf-dropdown-toggle sf2-icon-caret-down"></DropdownToggle>
+          <DropdownToggle tag="i" className="sf-dropdown-toggle sf3-font-more sf3-font"></DropdownToggle>
           <DropdownMenu>
             <DropdownItem onClick={this.props.filterUser.bind(this, fileEvent.user_email)}>
               {gettext('Only Show')}{' '}
@@ -225,10 +225,11 @@ class FileAuditItem extends React.Component {
         { fileEvent.repo_name &&
           <Dropdown size='sm' isOpen={this.state.repoDropdownOpen} toggle={this.toggleRepoDropdown}
             className={this.state.highlight ? '' : 'vh'} >
-            <DropdownToggle tag="i" className="sf-dropdown-toggle sf2-icon-caret-down"></DropdownToggle>
+            <DropdownToggle tag="i" className="sf-dropdown-toggle sf3-font-more sf3-font"></DropdownToggle>
             <DropdownMenu>
               <DropdownItem size='sm' onClick={this.props.filterRepo.bind(this, fileEvent.repo_name)}>
-                {gettext('Only Show')}{' '}<span className="font-weight-bold">{fileEvent.repo_name}</span></DropdownItem>
+                {gettext('Only Show')}{' '}<span className="font-weight-bold">{fileEvent.repo_name}</span>
+              </DropdownItem>
             </DropdownMenu>
           </Dropdown>
         }
@@ -238,7 +239,7 @@ class FileAuditItem extends React.Component {
 
   render() {
     let { fileEvent } = this.props;
-    if (this.props.userSelected && fileEvent.user_email !== this.props.userSelected ) {
+    if (this.props.userSelected && fileEvent.user_email !== this.props.userSelected) {
       return null;
     } else if (this.props.repoSelected && fileEvent.repo_name !== this.props.repoSelected) {
       return null;
@@ -249,7 +250,7 @@ class FileAuditItem extends React.Component {
           <td>{this.renderUser(fileEvent)}</td>
           <td>{this.renderType(fileEvent.type)}</td>
           <td>{fileEvent.ip}</td>
-          <td>{moment(fileEvent.time).format('YYYY-MM-DD HH:mm:ss')}</td>
+          <td>{dayjs(fileEvent.time).format('YYYY-MM-DD HH:mm:ss')}</td>
           <td>{this.renderRepo(fileEvent)}</td>
           <td><span title={fileEvent.file_path}>{fileEvent.file_name}</span></td>
         </tr>
