@@ -1,8 +1,8 @@
 import React, { Component } from 'react';
 import PropTypes from 'prop-types';
-import moment from 'moment';
+import dayjs from 'dayjs';
 import { Dropdown, DropdownToggle, DropdownMenu, DropdownItem } from 'reactstrap';
-import { seafileAPI } from '../../utils/seafile-api';
+import { orgAdminAPI } from '../../utils/org-admin-api';
 import { siteRoot, gettext, lang } from '../../utils/constants';
 import { Utils } from '../../utils/utils';
 import toaster from '../../components/toast';
@@ -11,7 +11,7 @@ import ModalPortal from '../../components/modal-portal';
 import FileUpdateDetailDialog from '../../components/dialog/org-logs-file-update-detail';
 import '../../css/org-logs.css';
 
-moment.locale(lang);
+dayjs.locale(lang);
 
 class OrgLogsFileUpdate extends Component {
 
@@ -38,7 +38,7 @@ class OrgLogsFileUpdate extends Component {
   }
 
   initData = (email, repoID, page) => {
-    seafileAPI.orgAdminListFileUpdate(email, repoID, page).then(res => {
+    orgAdminAPI.orgAdminListFileUpdate(email, repoID, page).then(res => {
       let eventList = res.data.log_list.map(item => {
         return new OrgLogsFileUpdateEvent(item);
       });
@@ -210,7 +210,7 @@ class FileUpdateItem extends React.Component {
         <a href={siteRoot + 'org/useradmin/info/' + fileEvent.user_email + '/'}>{fileEvent.user_name}</a>{' '}
         <Dropdown size='sm' isOpen={this.state.userDropdownOpen} toggle={this.toggleUserDropdown}
           className={this.state.highlight ? '' : 'vh'} tag="span">
-          <DropdownToggle tag="i" className="sf-dropdown-toggle sf2-icon-caret-down"></DropdownToggle>
+          <DropdownToggle tag="i" className="sf-dropdown-toggle sf3-font-more sf3-font"></DropdownToggle>
           <DropdownMenu>
             <DropdownItem onClick={this.props.filterUser.bind(this, fileEvent.user_email)}>
               {gettext('Only Show')}{' '}<span className="font-weight-bold">{fileEvent.user_name}</span>
@@ -236,7 +236,7 @@ class FileUpdateItem extends React.Component {
         { fileEvent.repo_name &&
           <Dropdown size='sm' isOpen={this.state.repoDropdownOpen} toggle={this.toggleRepoDropdown}
             className={this.state.highlight ? '' : 'vh'} >
-            <DropdownToggle tag="i" className="sf-dropdown-toggle sf2-icon-caret-down"></DropdownToggle>
+            <DropdownToggle tag="i" className="sf-dropdown-toggle sf3-font-more sf3-font"></DropdownToggle>
             <DropdownMenu>
               <DropdownItem size='sm' onClick={this.props.filterRepo.bind(this, fileEvent.repo_name)}>
                 {gettext('Only Show')}{' '}
@@ -257,14 +257,15 @@ class FileUpdateItem extends React.Component {
     return (
       <td>{fileEvent.description}
         <a className="font-weight-normal text-muted ml-1" href='#'
-          onClick={(e) => this.props.onDetails(e, fileEvent)}>{gettext('Details')}</a>
+          onClick={(e) => this.props.onDetails(e, fileEvent)}>{gettext('Details')}
+        </a>
       </td>
     );
   };
 
   render() {
     let { fileEvent } = this.props;
-    if (this.props.userSelected && fileEvent.user_email !== this.props.userSelected ) {
+    if (this.props.userSelected && fileEvent.user_email !== this.props.userSelected) {
       return null;
     } else if (this.props.repoSelected && fileEvent.repo_name !== this.props.repoSelected) {
       return null;
@@ -273,7 +274,7 @@ class FileUpdateItem extends React.Component {
         <tr className={this.state.highlight ? 'tr-highlight' : ''}
           onMouseEnter={this.onMouseEnter} onMouseLeave={this.onMouseLeave}>
           <td>{this.renderUser(fileEvent)}</td>
-          <td>{moment(fileEvent.time).format('YYYY-MM-DD HH:mm:ss')}</td>
+          <td>{dayjs(fileEvent.time).format('YYYY-MM-DD HH:mm:ss')}</td>
           <td>{this.renderRepo(fileEvent)}</td>
           {this.renderAction(fileEvent)}
         </tr>
