@@ -1,15 +1,15 @@
 import React, { Component } from 'react';
 import PropTypes from 'prop-types';
-import moment from 'moment';
+import dayjs from 'dayjs';
 import { Dropdown, DropdownToggle, DropdownMenu, DropdownItem } from 'reactstrap';
-import { seafileAPI } from '../../utils/seafile-api';
+import { orgAdminAPI } from '../../utils/org-admin-api';
 import { siteRoot, gettext, lang } from '../../utils/constants';
 import { Utils } from '../../utils/utils';
 import toaster from '../../components/toast';
 import OrgLogsFilePermEvent from '../../models/org-logs-perm-audit';
 import '../../css/org-logs.css';
 
-moment.locale(lang);
+dayjs.locale(lang);
 
 class OrgLogsFileUpdate extends Component {
 
@@ -33,7 +33,7 @@ class OrgLogsFileUpdate extends Component {
   }
 
   initData = (email, repoID, page) => {
-    seafileAPI.orgAdminListPermAudit(email, repoID, page).then(res => {
+    orgAdminAPI.orgAdminListPermAudit(email, repoID, page).then(res => {
       let eventList = res.data.log_list.map(item => {
         return new OrgLogsFilePermEvent(item);
       });
@@ -157,7 +157,7 @@ class PermAuditItem extends React.Component {
         <a href={siteRoot + 'org/useradmin/info/' + permEvent.from_user_email + '/'}>{permEvent.from_user_name}</a>{' '}
         <Dropdown size='sm' isOpen={this.state.userDropdownOpen} toggle={this.toggleUserDropdown}
           className={this.state.highlight ? '' : 'vh'} tag="span">
-          <DropdownToggle tag="i" className="sf-dropdown-toggle sf2-icon-caret-down"></DropdownToggle>
+          <DropdownToggle tag="i" className="sf-dropdown-toggle sf3-font-more sf3-font"></DropdownToggle>
           <DropdownMenu>
             <DropdownItem onClick={this.props.filterUser.bind(this, permEvent.from_user_email)}>
               {gettext('Only Show')}{' '}
@@ -222,7 +222,7 @@ class PermAuditItem extends React.Component {
 
   render() {
     let { permEvent } = this.props;
-    if (this.props.userSelected && permEvent.from_user_email !== this.props.userSelected ) {
+    if (this.props.userSelected && permEvent.from_user_email !== this.props.userSelected) {
       return null;
     } else {
       return (
@@ -233,7 +233,7 @@ class PermAuditItem extends React.Component {
           <td>{Utils.sharePerms(permEvent.permission)}</td>
           <td>{this.renderRepo(permEvent)}</td>
           <td>{this.renderFolder(permEvent.folder_name)}</td>
-          <td>{moment(permEvent.time).format('YYYY-MM-DD HH:mm:ss')}</td>
+          <td>{dayjs(permEvent.time).format('YYYY-MM-DD HH:mm:ss')}</td>
         </tr>
       );
     }
