@@ -2,10 +2,11 @@ import React from 'react';
 import PropTypes from 'prop-types';
 import { Dropdown, DropdownToggle, DropdownMenu, DropdownItem } from 'reactstrap';
 import { gettext, siteRoot, orgID, username } from '../../utils/constants';
-import { seafileAPI } from '../../utils/seafile-api';
+import { orgAdminAPI } from '../../utils/org-admin-api';
 import { Utils } from '../../utils/utils';
 import toaster from '../../components/toast';
 import Selector from '../../components/single-selector';
+import CommonOperationConfirmationDialog from '../../components/dialog/common-operation-confirmation-dialog';
 
 const propTypes = {
   user: PropTypes.object,
@@ -55,16 +56,10 @@ class UserItem extends React.Component {
   };
 
   toggleResetPW = () => {
-    const { email, name } = this.props.user;
+    const { email } = this.props.user;
     toaster.success(gettext('Resetting user\'s password, please wait for a moment.'));
-    seafileAPI.orgAdminResetOrgUserPassword(orgID, email).then(res => {
-      let msg;
-      msg = gettext('Successfully reset password to %(passwd)s for user %(user)s.');
-      msg = msg.replace('%(passwd)s', res.data.new_password);
-      msg = msg.replace('%(user)s', name);
-      toaster.success(msg, {
-        duration: 15
-      });
+    orgAdminAPI.orgAdminResetOrgUserPassword(orgID, email).then(res => {
+      toaster.success(res.data.reset_tip);
     }).catch(error => {
       let errMessage = Utils.getErrorMsg(error);
       toaster.danger(errMessage);
@@ -84,6 +79,11 @@ class UserItem extends React.Component {
     this.props.changeStatus(this.props.user.email, isActive);
   };
 
+  setUserInactive = () => {
+    const isActive = false;
+    this.props.changeStatus(this.props.user.email, isActive);
+  };
+
   onDropdownToggleClick = (e) => {
     e.preventDefault();
     this.toggleOperationMenu(e);
@@ -92,7 +92,7 @@ class UserItem extends React.Component {
   toggleOperationMenu = (e) => {
     e.stopPropagation();
     this.setState(
-      {isItemMenuShow: !this.state.isItemMenuShow }, () => {
+      { isItemMenuShow: !this.state.isItemMenuShow }, () => {
         if (this.state.isItemMenuShow) {
           this.props.onFreezedItem();
         } else {
@@ -113,7 +113,7 @@ class UserItem extends React.Component {
       case -2:
         return '--';
       default: // data > 0
-        return Utils.formatSize({bytes: data});
+        return Utils.formatSize({ bytes: data });
     }
   };
 
@@ -126,11 +126,15 @@ class UserItem extends React.Component {
     }
   };
 
+  toggleConfirmInactiveDialog = () => {
+    this.setState({ isConfirmInactiveDialogOpen: !this.state.isConfirmInactiveDialogOpen });
+  };
+
   render() {
-    const { highlight } = this.state;
+    const { highlight, isConfirmInactiveDialogOpen } = this.state;
     let { user, currentTab } = this.props;
     let href = siteRoot + 'org/useradmin/info/' + encodeURIComponent(user.email) + '/';
-    let isOperationMenuShow = (user.email !== username)  && this.state.showMenu;
+    let isOperationMenuShow = (user.email !== username) && this.state.showMenu;
 
     // for 'user status'
     const curStatus = user.is_active ? 'active' : 'inactive';
@@ -143,46 +147,62 @@ class UserItem extends React.Component {
     });
     const currentSelectedStatusOption = this.statusOptions.filter(item => item.isSelected)[0];
 
+    const itemName = '<span class="op-target">' + Utils.HTMLescape(user.name) + '</span>';
+    const confirmSetUserInactiveMsg = gettext('Are you sure you want to set {user_placeholder} inactive?').replace('{user_placeholder}', itemName);
+
     return (
-      <tr className={this.state.highlight ? 'tr-highlight' : ''} onMouseEnter={this.onMouseEnter} onMouseLeave={this.onMouseLeave}>
-        <td>
-          <a href={href}>{user.name}</a>
-        </td>
-        <td>
-          <Selector
-            isDropdownToggleShown={highlight}
-            currentSelectedOption={currentSelectedStatusOption}
-            options={this.statusOptions}
-            selectOption={this.changeStatus}
-            toggleItemFreezed={this.props.toggleItemFreezed}
-          />
-        </td>
-        <td>{`${Utils.formatSize({bytes: user.quota_usage})} / ${this.getQuotaTotal(user.quota_total)}`}</td>
-        <td>
-          {user.ctime} /
-          <br />
-          {user.last_login ? user.last_login : '--'}
-        </td>
-        <td className="text-center cursor-pointer">
-          {isOperationMenuShow && (
-            <Dropdown isOpen={this.state.isItemMenuShow} toggle={this.toggleOperationMenu}>
-              <DropdownToggle
-                tag="a"
-                className="attr-action-icon fas fa-ellipsis-v"
-                title={gettext('More Operations')}
-                data-toggle="dropdown"
-                aria-expanded={this.state.isItemMenuShow}
-                onClick={this.onDropdownToggleClick}
-              />
-              <DropdownMenu>
-                <DropdownItem onClick={this.toggleDelete}>{gettext('Delete')}</DropdownItem>
-                <DropdownItem onClick={this.toggleResetPW}>{gettext('ResetPwd')}</DropdownItem>
-                {currentTab == 'admins' && <DropdownItem onClick={this.toggleRevokeAdmin}>{gettext('Revoke Admin')}</DropdownItem>}
-              </DropdownMenu>
-            </Dropdown>
-          )}
-        </td>
-      </tr>
+      <>
+        <tr className={this.state.highlight ? 'tr-highlight' : ''} onMouseEnter={this.onMouseEnter} onMouseLeave={this.onMouseLeave}>
+          <td>
+            <a href={href}>{user.name}</a>
+          </td>
+          <td>
+            <Selector
+              isDropdownToggleShown={highlight}
+              currentSelectedOption={currentSelectedStatusOption}
+              options={this.statusOptions}
+              selectOption={this.changeStatus}
+              toggleItemFreezed={this.props.toggleItemFreezed}
+              operationBeforeSelect={user.is_active ? this.toggleConfirmInactiveDialog : undefined}
+            />
+          </td>
+          <td>{`${Utils.formatSize({ bytes: user.quota_usage })} / ${this.getQuotaTotal(user.quota_total)}`}</td>
+          <td>
+            {user.ctime} /
+            <br />
+            {user.last_login ? user.last_login : '--'}
+          </td>
+          <td className="text-center cursor-pointer">
+            {isOperationMenuShow && (
+              <Dropdown isOpen={this.state.isItemMenuShow} toggle={this.toggleOperationMenu}>
+                <DropdownToggle
+                  tag="a"
+                  className="attr-action-icon sf3-font sf3-font-more-vertical"
+                  title={gettext('More operations')}
+                  aria-label={gettext('More operations')}
+                  data-toggle="dropdown"
+                  aria-expanded={this.state.isItemMenuShow}
+                  onClick={this.onDropdownToggleClick}
+                />
+                <DropdownMenu>
+                  <DropdownItem onClick={this.toggleDelete}>{gettext('Delete')}</DropdownItem>
+                  <DropdownItem onClick={this.toggleResetPW}>{gettext('ResetPwd')}</DropdownItem>
+                  {currentTab == 'admins' && <DropdownItem onClick={this.toggleRevokeAdmin}>{gettext('Revoke Admin')}</DropdownItem>}
+                </DropdownMenu>
+              </Dropdown>
+            )}
+          </td>
+        </tr>
+        {isConfirmInactiveDialogOpen &&
+        <CommonOperationConfirmationDialog
+          title={gettext('Set user inactive')}
+          message={confirmSetUserInactiveMsg}
+          executeOperation={this.setUserInactive}
+          confirmBtnText={gettext('Set')}
+          toggleDialog={this.toggleConfirmInactiveDialog}
+        />
+        }
+      </>
     );
   }
 }
