@@ -1,7 +1,7 @@
 import React, { Component, Fragment } from 'react';
 import PropTypes from 'prop-types';
-import moment from 'moment';
-import { seafileAPI } from '../../utils/seafile-api';
+import dayjs from 'dayjs';
+import { orgAdminAPI } from '../../utils/org-admin-api';
 import { gettext } from '../../utils/constants';
 import { Utils } from '../../utils/utils';
 import Loading from '../../components/loading';
@@ -26,7 +26,7 @@ class OrgUserOwnedRepos extends Component {
 
   componentDidMount() {
     const email = decodeURIComponent(this.props.email);
-    seafileAPI.orgAdminGetOrgUserOwnedRepos(orgID, email).then((res) => {
+    orgAdminAPI.orgAdminGetOrgUserOwnedRepos(orgID, email).then((res) => {
       this.setState(Object.assign({
         loading: false
       }, res.data));
@@ -75,7 +75,7 @@ class Content extends Component {
         <table className="table-hover">
           <thead>
             <tr>
-              <th width="4%">{/*icon*/}</th>
+              <th width="4%">{/* icon*/}</th>
               <th width="35%">{gettext('Name')}</th>
               <th width="16%">{gettext('Size')}</th>
               <th width="25%">{gettext('Last Update')}</th>
@@ -134,7 +134,7 @@ class Item extends Component {
 
   deleteRepo = () => {
     const repo = this.props.data;
-    seafileAPI.orgAdminDeleteOrgRepo(orgID, repo.repo_id).then((res) => {
+    orgAdminAPI.orgAdminDeleteOrgRepo(orgID, repo.repo_id).then((res) => {
       this.setState({
         deleted: true,
         isRepoDeleted: true,
@@ -145,7 +145,7 @@ class Item extends Component {
       const errorMsg = Utils.getErrorMsg(error);
       toaster.danger(errorMsg);
 
-      this.setState({isRepoDeleted: false});
+      this.setState({ isRepoDeleted: false });
     });
   };
 
@@ -161,13 +161,13 @@ class Item extends Component {
       <Fragment>
         <tr onMouseOver={this.handleMouseOver} onMouseOut={this.handleMouseOut}>
           <td>
-            <img src={Utils.getLibIconUrl(repo, false)} alt={Utils.getLibIconTitle(repo)} title={Utils.getLibIconTitle(repo)} width="24" />
+            <img src={Utils.getLibIconUrl(repo)} alt={Utils.getLibIconTitle(repo)} title={Utils.getLibIconTitle(repo)} width="24" />
           </td>
           <td>{repo.repo_name}</td>
           <td>{Utils.bytesToSize(repo.size)}</td>
-          <td title={moment(repo.last_modified).format('LLLL')}>{moment(repo.last_modified).format('YYYY-MM-DD')}</td>
+          <td title={dayjs(repo.last_modified).format('dddd, MMMM D, YYYY h:mm:ss A')}>{dayjs(repo.last_modified).format('YYYY-MM-DD')}</td>
           <td>
-            <a href="#" className={`action-icon sf2-icon-delete${isOpIconShown ? '' : ' invisible'}`} title={gettext('Delete')} onClick={this.handleDeleteIconClick}></a>
+            <a href="#" className={`action-icon sf3-font-delete1 sf3-font${isOpIconShown ? '' : ' invisible'}`} title={gettext('Delete')} onClick={this.handleDeleteIconClick}></a>
           </td>
         </tr>
         {isDeleteRepoDialogOpen && (
@@ -176,6 +176,7 @@ class Item extends Component {
             isRepoDeleted={this.state.isRepoDeleted}
             onDeleteRepo={this.deleteRepo}
             toggle={this.toggleDeleteRepoDialog}
+            isGetShare={false}
           />
         )}
       </Fragment>
