@@ -5,7 +5,7 @@ import MainPanelTopbar from './main-panel-topbar';
 import AddOrgAdminDialog from '../../components/dialog/org-add-admin-dialog';
 import ModalPortal from '../../components/modal-portal';
 import toaster from '../../components/toast';
-import { seafileAPI } from '../../utils/seafile-api';
+import { orgAdminAPI } from '../../utils/org-admin-api';
 import OrgUserInfo from '../../models/org-user';
 import { gettext, orgID } from '../../utils/constants';
 import { Utils } from '../../utils/utils';
@@ -21,15 +21,15 @@ class OrgUsers extends Component {
   }
 
   toggleAddOrgAdmin = () => {
-    this.setState({isShowAddOrgAdminDialog: !this.state.isShowAddOrgAdminDialog});
+    this.setState({ isShowAddOrgAdminDialog: !this.state.isShowAddOrgAdminDialog });
   };
 
   initOrgAdmin = () => {
-    seafileAPI.orgAdminListOrgUsers(orgID, true).then(res => {
+    orgAdminAPI.orgAdminListOrgUsers(orgID, true).then(res => {
       let userList = res.data.user_list.map(item => {
         return new OrgUserInfo(item);
       });
-      this.setState({orgAdminUsers: userList});
+      this.setState({ orgAdminUsers: userList });
     }).catch(error => {
       let errMessage = Utils.getErrorMsg(error);
       toaster.danger(errMessage);
@@ -37,7 +37,7 @@ class OrgUsers extends Component {
   };
 
   toggleOrgAdminDelete = (email, username) => {
-    seafileAPI.orgAdminDeleteOrgUser(orgID, email).then(res => {
+    orgAdminAPI.orgAdminDeleteOrgUser(orgID, email).then(res => {
       this.setState({
         orgAdminUsers: this.state.orgAdminUsers.filter(item => item.email != email)
       });
@@ -51,7 +51,7 @@ class OrgUsers extends Component {
   };
 
   toggleRevokeAdmin = (email) => {
-    seafileAPI.orgAdminSetOrgAdmin(orgID, email, false).then(res => {
+    orgAdminAPI.orgAdminSetOrgAdmin(orgID, email, false).then(res => {
       this.setState({
         orgAdminUsers: this.state.orgAdminUsers.filter(item => item.email != email)
       });
@@ -70,20 +70,20 @@ class OrgUsers extends Component {
       orgAdminUsers: this.state.orgAdminUsers
     });
     let msg = gettext('Successfully set %s as admin.');
-    msg = msg.replace('%s', userInfo.email);
+    msg = msg.replace('%s', userInfo.name);
     toaster.success(msg);
     this.toggleAddOrgAdmin();
   };
 
   changeStatus = (email, isActive) => {
-    seafileAPI.orgAdminChangeOrgUserStatus(orgID, email, isActive).then(res => {
+    orgAdminAPI.orgAdminChangeOrgUserStatus(orgID, email, isActive).then(res => {
       let users = this.state.orgAdminUsers.map(item => {
         if (item.email == email) {
-          item['is_active']= res.data['is_active'];
+          item['is_active'] = res.data['is_active'];
         }
         return item;
       });
-      this.setState({orgAdminUsers: users});
+      this.setState({ orgAdminUsers: users });
       toaster.success(gettext('Edit succeeded.'));
     }).catch(error => {
       let errMessage = Utils.getErrorMsg(error);
@@ -97,7 +97,7 @@ class OrgUsers extends Component {
     topbarChildren = (
       <Fragment>
         <button className={topBtn} title={gettext('Add admin')} onClick={this.toggleAddOrgAdmin}>
-          <i className="fas fa-plus-square text-secondary mr-1"></i>{gettext('Add admin')}
+          <i className="sf3-font sf3-font-enlarge text-secondary mr-1"></i>{gettext('Add admin')}
         </button>
         {this.state.isShowAddOrgAdminDialog &&
         <ModalPortal>
