@@ -10,9 +10,9 @@ import AddOrgUserDialog from '../../components/dialog/org-add-user-dialog';
 import InviteUserDialog from '../../components/dialog/org-admin-invite-user-dialog';
 import InviteUserViaWeiXinDialog from '../../components/dialog/org-admin-invite-user-via-weixin-dialog';
 import toaster from '../../components/toast';
-import { seafileAPI } from '../../utils/seafile-api';
+import { orgAdminAPI } from '../../utils/org-admin-api';
 import OrgUserInfo from '../../models/org-user';
-import { gettext, invitationLink, orgID, siteRoot, orgEnableAdminInviteUser} from '../../utils/constants';
+import { gettext, invitationLink, orgID, siteRoot, orgEnableAdminInviteUser } from '../../utils/constants';
 import { Utils } from '../../utils/utils';
 
 class Search extends React.Component {
@@ -48,11 +48,11 @@ class Search extends React.Component {
   render() {
     return (
       <div className="input-icon">
-        <i className="d-flex input-icon-addon fas fa-search"></i>
+        <i className="d-flex input-icon-addon sf3-font sf3-font-search"></i>
         <input
           type="text"
           className="form-control search-input h-6 mr-1"
-          style={{width: '15rem'}}
+          style={{ width: '15rem' }}
           placeholder={this.props.placeholder}
           value={this.state.value}
           onChange={this.handleInputChange}
@@ -121,24 +121,24 @@ class OrgUsers extends Component {
   };
 
   toggleImportOrgUsersDialog = () => {
-    this.setState({isImportOrgUsersDialogOpen: !this.state.isImportOrgUsersDialogOpen});
+    this.setState({ isImportOrgUsersDialogOpen: !this.state.isImportOrgUsersDialogOpen });
   };
 
   toggleAddOrgUser = () => {
-    this.setState({isShowAddOrgUserDialog: !this.state.isShowAddOrgUserDialog});
+    this.setState({ isShowAddOrgUserDialog: !this.state.isShowAddOrgUserDialog });
   };
 
   toggleInviteUserDialog = () => {
-    this.setState({isInviteUserDialogOpen: !this.state.isInviteUserDialogOpen});
+    this.setState({ isInviteUserDialogOpen: !this.state.isInviteUserDialogOpen });
   };
 
   toggleInviteUserViaWeiXinDialog = () => {
-    this.setState({isInviteUserViaWeiXinDialogOpen: !this.state.isInviteUserViaWeiXinDialogOpen});
+    this.setState({ isInviteUserViaWeiXinDialogOpen: !this.state.isInviteUserViaWeiXinDialogOpen });
   };
 
   initOrgUsersData = (page) => {
     const { sortBy, sortOrder } = this.state;
-    seafileAPI.orgAdminListOrgUsers(orgID, '', page, sortBy, sortOrder).then(res => {
+    orgAdminAPI.orgAdminListOrgUsers(orgID, '', page, sortBy, sortOrder).then(res => {
       let userList = res.data.user_list.map(item => {
         return new OrgUserInfo(item);
       });
@@ -155,7 +155,7 @@ class OrgUsers extends Component {
 
   importOrgUsers = (file) => {
     toaster.notify(gettext('It may take some time, please wait.'));
-    seafileAPI.orgAdminImportUsersViaFile(orgID, file).then((res) => {
+    orgAdminAPI.orgAdminImportUsersViaFile(orgID, file).then((res) => {
       if (res.data.success.length) {
         const users = res.data.success.map(item => {
           if (item.institution == undefined) {
@@ -178,7 +178,7 @@ class OrgUsers extends Component {
   };
 
   addOrgUser = (email, name, password) => {
-    seafileAPI.orgAdminAddOrgUser(orgID, email, name, password).then(res => {
+    orgAdminAPI.orgAdminAddOrgUser(orgID, email, name, password).then(res => {
       let userInfo = new OrgUserInfo(res.data);
       this.state.orgUsers.unshift(userInfo);
       this.setState({
@@ -196,9 +196,9 @@ class OrgUsers extends Component {
   };
 
   toggleOrgUsersDelete = (email, username) => {
-    seafileAPI.orgAdminDeleteOrgUser(orgID, email).then(res => {
+    orgAdminAPI.orgAdminDeleteOrgUser(orgID, email).then(res => {
       let users = this.state.orgUsers.filter(item => item.email != email);
-      this.setState({orgUsers: users});
+      this.setState({ orgUsers: users });
       let msg = gettext('Deleted user %s');
       msg = msg.replace('%s', username);
       toaster.success(msg);
@@ -209,7 +209,7 @@ class OrgUsers extends Component {
   };
 
   inviteOrgUser = (emails) => {
-    seafileAPI.orgAdminInviteOrgUsers(orgID, emails.split(',')).then(res => {
+    orgAdminAPI.orgAdminInviteOrgUsers(orgID, emails.split(',')).then(res => {
       this.toggleInviteUserDialog();
       let users = res.data.success.map(user => {
         return new OrgUserInfo(user);
@@ -235,15 +235,15 @@ class OrgUsers extends Component {
     });
   };
 
-  changeStatus= (email, isActive) => {
-    seafileAPI.orgAdminChangeOrgUserStatus(orgID, email, isActive).then(res => {
+  changeStatus = (email, isActive) => {
+    orgAdminAPI.orgAdminChangeOrgUserStatus(orgID, email, isActive).then(res => {
       let users = this.state.orgUsers.map(item => {
         if (item.email == email) {
-          item['is_active']= res.data['is_active'];
+          item['is_active'] = res.data['is_active'];
         }
         return item;
       });
-      this.setState({orgUsers: users});
+      this.setState({ orgUsers: users });
       toaster.success(gettext('Edit succeeded.'));
     }).catch(error => {
       let errMessage = Utils.getErrorMsg(error);
@@ -269,14 +269,17 @@ class OrgUsers extends Component {
       <Fragment>
         <button className="btn btn-secondary operation-item" onClick={this.toggleImportOrgUsersDialog}>{gettext('Import users')}</button>
         <button className={topBtn} title={gettext('Add user')} onClick={this.toggleAddOrgUser}>
-          <i className="fas fa-plus-square text-secondary mr-1"></i>{gettext('Add user')}</button>
+          <i className="sf3-font sf3-font-enlarge text-secondary mr-1"></i>{gettext('Add user')}
+        </button>
         {orgEnableAdminInviteUser &&
         <button className={topBtn} title={gettext('Invite users')} onClick={this.toggleInviteUserDialog}>
-          <i className="fas fa-plus-square text-secondary mr-1"></i>{gettext('Invite users')}</button>
+          <i className="sf3-font sf3-font-enlarge text-secondary mr-1"></i>{gettext('Invite users')}
+        </button>
         }
         {invitationLink &&
         <button className={topBtn} title={'通过微信邀请用户'} onClick={this.toggleInviteUserViaWeiXinDialog}>
-          <i className="fas fa-plus-square text-secondary mr-1"></i>{'通过微信邀请用户'}</button>
+          <i className="sf3-font sf3-font-enlarge text-secondary mr-1"></i>{'通过微信邀请用户'}
+        </button>
         }
         {this.state.isImportOrgUsersDialogOpen &&
         <ModalPortal>
