@@ -2,6 +2,7 @@ import React, { Fragment, Component } from 'react';
 import PropTypes from 'prop-types';
 import { Link } from '@gatsbyjs/reach-router';
 import { Dropdown, DropdownToggle, DropdownItem } from 'reactstrap';
+import classnames from 'classnames';
 import { seafileAPI } from '../../utils/seafile-api';
 import { gettext, siteRoot, isPro } from '../../utils/constants';
 import { Utils } from '../../utils/utils';
@@ -10,6 +11,7 @@ import EmptyTip from '../../components/empty-tip';
 import SharePermissionEditor from '../../components/select-editor/share-permission-editor';
 import SharedRepoInfo from '../../models/shared-repo-info';
 import PermSelect from '../../components/dialog/perm-select';
+import FixedWidthTable from '../../components/common/fixed-width-table';
 
 class Content extends Component {
 
@@ -25,54 +27,46 @@ class Content extends Component {
 
     if (loading) {
       return <span className="loading-icon loading-tip"></span>;
-    } else if (errorMsg) {
+    }
+    if (errorMsg) {
       return <p className="error text-center">{errorMsg}</p>;
-    } else {
-      const emptyTip = (
-        <EmptyTip>
-          <h2>{gettext('No libraries shared')}</h2>
-          <p>{gettext('You have not shared any libraries with other users yet. You can share a library with other users by clicking the share icon to the right of a library\'s name in "My Libraries".')}</p>
+    }
+
+    if (!items.length) {
+      return (
+        <EmptyTip
+          title={gettext('No libraries shared')}
+          text={gettext('You have not shared any libraries with other users yet. You can share a library with other users by clicking the share icon to the right of a library\'s name in "My Libraries".')}
+        >
         </EmptyTip>
       );
-
-      // sort
-      const sortByName = sortBy == 'name';
-      const sortIcon = sortOrder == 'asc' ? <span className="fas fa-caret-up"></span> : <span className="fas fa-caret-down"></span>;
-
-      const isDesktop = Utils.isDesktop();
-      const table = (
-        <table className={`table-hover ${isDesktop ? '': 'table-thead-hidden'}`}>
-          <thead>
-            {isDesktop ? (
-              <tr>
-                <th width="4%">{/*icon*/}</th>
-                <th width="34%"><a className="d-block table-sort-op" href="#" onClick={this.sortByName}>{gettext('Name')} {sortByName && sortIcon}</a></th>
-                <th width="30%">{gettext('Share To')}</th>
-                <th width="24%">{gettext('Permission')}</th>
-                <th width="8%"></th>
-              </tr>
-            ) : (
-              <tr>
-                <th width="12%"></th>
-                <th width="80%"></th>
-                <th width="8%"></th>
-              </tr>
-            )}
-          </thead>
-          <tbody>
-            {items.map((item, index) => {
-              return (<Item
-                key={index}
-                isDesktop={isDesktop}
-                item={item}
-              />);
-            })}
-          </tbody>
-        </table>
-      );
-
-      return items.length ? table : emptyTip;
     }
+
+    // sort
+    const sortByName = sortBy == 'name';
+    const sortIcon = sortOrder == 'asc' ? <span className="sf3-font sf3-font-down rotate-180 d-inline-block"></span> : <span className="sf3-font sf3-font-down"></span>;
+
+    const isDesktop = Utils.isDesktop();
+    return (
+      <FixedWidthTable
+        className={classnames('table-hover', { 'table-thead-hidden': !isDesktop })}
+        headers={isDesktop ? [
+          { isFixed: true, width: 40 },
+          { isFixed: false, width: 0.35, children: (<a className="d-block table-sort-op" href="#" onClick={this.sortByName}>{gettext('Name')} {sortByName && sortIcon}</a>) },
+          { isFixed: false, width: 0.3, children: gettext('Share To') },
+          { isFixed: false, width: 0.25, children: gettext('Permission') },
+          { isFixed: false, width: 0.1 },
+        ] : [
+          { isFixed: false, width: 0.12 },
+          { isFixed: false, width: 0.8 },
+          { isFixed: false, width: 0.08 },
+        ]}
+      >
+        {items.map((item, index) => {
+          return (<Item key={index} isDesktop={isDesktop} item={item} />);
+        })}
+      </FixedWidthTable>
+    );
   }
 }
 
@@ -125,11 +119,11 @@ class Item extends Component {
   };
 
   onMouseEnter = () => {
-    this.setState({isOpIconShown: true});
+    this.setState({ isOpIconShown: true });
   };
 
   onMouseLeave = () => {
-    this.setState({isOpIconShown: false});
+    this.setState({ isOpIconShown: false });
   };
 
   changePerm = (permission) => {
@@ -185,7 +179,7 @@ class Item extends Component {
 
   onEditPermission = (event) => {
     event.nativeEvent.stopImmediatePropagation();
-    this.setState({isShowPermEditor: true});
+    this.setState({ isShowPermEditor: true });
   };
 
   render() {
@@ -224,87 +218,88 @@ class Item extends Component {
       share_permission = share_permission.slice(7);
     }
 
-    const desktopItem = (
-      <tr onMouseEnter={this.onMouseEnter} onMouseLeave={this.onMouseLeave} onFocus={this.onMouseEnter}>
-        <td><img src={iconUrl} title={iconTitle} alt={iconTitle} width="24" /></td>
-        <td><Link to={repoUrl}>{item.repo_name}</Link></td>
-        <td>
-          {item.share_type == 'personal' ? <span title={item.contact_email}>{shareTo}</span> : shareTo}
-        </td>
-        <td>
-          {!isShowPermEditor && (
-            <div>
-              <span>{Utils.sharePerms(share_permission) || share_permission_name}</span>
-              {isOpIconShown && (
-                <a href="#"
-                  role="button"
-                  aria-label={gettext('Edit')}
-                  title={gettext('Edit')}
-                  className="fa fa-pencil-alt attr-action-icon"
-                  onClick={this.onEditPermission}>
-                </a>
-              )}
-            </div>
-          )}
-          {isShowPermEditor && (
-            <SharePermissionEditor
+    if (this.props.isDesktop) {
+      return (
+        <tr onMouseEnter={this.onMouseEnter} onMouseLeave={this.onMouseLeave} onFocus={this.onMouseEnter}>
+          <td className="pl10 pr-2"><img src={iconUrl} title={iconTitle} alt={iconTitle} width="24" /></td>
+          <td><Link to={repoUrl}>{item.repo_name}</Link></td>
+          <td>
+            {item.share_type == 'personal' ? <span title={item.contact_email}>{shareTo}</span> : shareTo}
+          </td>
+          <td>
+            {!isShowPermEditor && (
+              <div>
+                <span>{Utils.sharePerms(share_permission) || share_permission_name}</span>
+                {isOpIconShown && (
+                  <a href="#"
+                    role="button"
+                    aria-label={gettext('Edit')}
+                    title={gettext('Edit')}
+                    className="sf3-font sf3-font-rename attr-action-icon"
+                    onClick={this.onEditPermission}>
+                  </a>
+                )}
+              </div>
+            )}
+            {isShowPermEditor && (
+              <SharePermissionEditor
+                repoID={item.repo_id}
+                isTextMode={true}
+                isEditing={true}
+                autoFocus={true}
+                isEditIconShow={this.state.isOpIconShown}
+                currentPermission={share_permission}
+                permissions={this.permissions}
+                onPermissionChanged={this.changePerm}
+              />
+            )}
+          </td>
+          <td><a href="#" role="button" aria-label={gettext('Unshare')} className={`action-icon sf2-icon-x3 ${isOpIconShown ? '' : 'invisible'}`} title={gettext('Unshare')} onClick={this.unshare}></a></td>
+        </tr>
+      );
+    } else {
+      return (
+        <Fragment>
+          <tr>
+            <td><img src={iconUrl} title={iconTitle} alt={iconTitle} width="24" /></td>
+            <td>
+              <Link to={repoUrl}>{item.repo_name}</Link>
+              <span className="item-meta-info-highlighted">{Utils.sharePerms(share_permission)}</span>
+              <br />
+              <span className="item-meta-info">{`${gettext('Share To:')} ${shareTo}`}</span>
+            </td>
+            <td>
+              <Dropdown isOpen={this.state.isOpMenuOpen} toggle={this.toggleOpMenu}>
+                <DropdownToggle
+                  tag="i"
+                  className="sf-dropdown-toggle sf3-font sf3-font-more-vertical ml-0"
+                  title={gettext('More operations')}
+                  aria-label={gettext('More operations')}
+                  data-toggle="dropdown"
+                  aria-expanded={this.state.isOpMenuOpen}
+                />
+                <div className={this.state.isOpMenuOpen ? '' : 'd-none'} onClick={this.toggleOpMenu}>
+                  <div className="mobile-operation-menu-bg-layer"></div>
+                  <div className="mobile-operation-menu">
+                    <DropdownItem className="mobile-menu-item" onClick={this.togglePermSelectDialog}>{gettext('Permission')}</DropdownItem>
+                    <DropdownItem className="mobile-menu-item" onClick={this.unshare}>{gettext('Unshare')}</DropdownItem>
+                  </div>
+                </div>
+              </Dropdown>
+            </td>
+          </tr>
+          {isPermSelectDialogOpen && (
+            <PermSelect
               repoID={item.repo_id}
-              isTextMode={true}
-              isEditing={true}
-              autoFocus={true}
-              isEditIconShow={this.state.isOpIconShown}
-              currentPermission={share_permission}
+              currentPerm={share_permission}
               permissions={this.permissions}
-              onPermissionChanged={this.changePerm}
+              changePerm={this.changePerm}
+              toggleDialog={this.togglePermSelectDialog}
             />
           )}
-        </td>
-        <td><a href="#" role="button" aria-label={gettext('Unshare')} className={`action-icon sf2-icon-x3 ${isOpIconShown ? '': 'invisible'}`} title={gettext('Unshare')} onClick={this.unshare}></a></td>
-      </tr>
-    );
-
-    const mobileItem = (
-      <Fragment>
-        <tr>
-          <td><img src={iconUrl} title={iconTitle} alt={iconTitle} width="24" /></td>
-          <td>
-            <Link to={repoUrl}>{item.repo_name}</Link>
-            <span className="item-meta-info-highlighted">{Utils.sharePerms(share_permission)}</span>
-            <br />
-            <span className="item-meta-info">{`${gettext('Share To:')} ${shareTo}`}</span>
-          </td>
-          <td>
-            <Dropdown isOpen={this.state.isOpMenuOpen} toggle={this.toggleOpMenu}>
-              <DropdownToggle
-                tag="i"
-                className="sf-dropdown-toggle fa fa-ellipsis-v ml-0"
-                title={gettext('More Operations')}
-                data-toggle="dropdown"
-                aria-expanded={this.state.isOpMenuOpen}
-              />
-              <div className={this.state.isOpMenuOpen ? '' : 'd-none'} onClick={this.toggleOpMenu}>
-                <div className="mobile-operation-menu-bg-layer"></div>
-                <div className="mobile-operation-menu">
-                  <DropdownItem className="mobile-menu-item" onClick={this.togglePermSelectDialog}>{gettext('Permission')}</DropdownItem>
-                  <DropdownItem className="mobile-menu-item" onClick={this.unshare}>{gettext('Unshare')}</DropdownItem>
-                </div>
-              </div>
-            </Dropdown>
-          </td>
-        </tr>
-        {isPermSelectDialogOpen && (
-          <PermSelect
-            repoID={item.repo_id}
-            currentPerm={share_permission}
-            permissions={this.permissions}
-            changePerm={this.changePerm}
-            toggleDialog={this.togglePermSelectDialog}
-          />
-        )}
-      </Fragment>
-    );
-
-    return this.props.isDesktop ? desktopItem : mobileItem;
+        </Fragment>
+      );
+    }
   }
 }
 
