@@ -1,8 +1,9 @@
 import React, { Component, Fragment } from 'react';
 import PropTypes from 'prop-types';
 import { Link } from '@gatsbyjs/reach-router';
-import moment from 'moment';
-import { Dropdown, DropdownToggle, DropdownItem, Button } from 'reactstrap';
+import dayjs from 'dayjs';
+import { Dropdown, DropdownToggle, DropdownItem } from 'reactstrap';
+import classnames from 'classnames';
 import { gettext, siteRoot, canGenerateShareLink } from '../../utils/constants';
 import { seafileAPI } from '../../utils/seafile-api';
 import { Utils } from '../../utils/utils';
@@ -12,7 +13,8 @@ import EmptyTip from '../../components/empty-tip';
 import UploadLink from '../../models/upload-link';
 import ShareAdminLink from '../../components/dialog/share-admin-link';
 import CommonOperationConfirmationDialog from '../../components/dialog/common-operation-confirmation-dialog';
-import TopToolbar from '../../components/toolbar/top-toolbar';
+import SingleDropdownToolbar from '../../components/toolbar/single-dropdown-toolbar';
+import FixedWidthTable from '../../components/common/fixed-width-table';
 
 const contentPropTypes = {
   loading: PropTypes.bool.isRequired,
@@ -32,44 +34,37 @@ class Content extends Component {
     if (errorMsg) {
       return <p className="error text-center">{errorMsg}</p>;
     }
-
-    const emptyTip = (
-      <EmptyTip>
-        <h2>{gettext('No upload links')}</h2>
-        <p>{gettext('You have not created any upload links yet. An upload link allows anyone to upload files to a folder or library. You can create an upload link for a folder or library by clicking the share icon to the right of its name.')}</p>
-      </EmptyTip>
-    );
+    if (!items.length) {
+      return (
+        <EmptyTip
+          title={gettext('No upload links')}
+          text={gettext('You have not created any upload links yet. An upload link allows anyone to upload files to a folder or library. You can create an upload link for a folder or library by clicking the share icon to the right of its name.')}
+        />
+      );
+    }
 
     const isDesktop = Utils.isDesktop();
-    const table = (
-      <table className={`table-hover ${isDesktop ? '': 'table-thead-hidden'}`}>
-        <thead>
-          {isDesktop ? (
-            <tr>
-              <th width="4%">{/*icon*/}</th>
-              <th width="30%">{gettext('Name')}</th>
-              <th width="24%">{gettext('Library')}</th>
-              <th width="16%">{gettext('Visits')}</th>
-              <th width="16%">{gettext('Expiration')}</th>
-              <th width="10%">{/*Operations*/}</th>
-            </tr>
-          ) : (
-            <tr>
-              <th width="12%"></th>
-              <th width="80%"></th>
-              <th width="8%"></th>
-            </tr>
-          )}
-        </thead>
-        <tbody>
-          {items.map((item, index) => {
-            return (<Item key={index} isDesktop={isDesktop} item={item} onRemoveLink={this.props.onRemoveLink}/>);
-          })}
-        </tbody>
-      </table>
+    return (
+      <FixedWidthTable
+        className={classnames('table-hover', { 'table-thead-hidden': !isDesktop })}
+        headers={isDesktop ? [
+          { isFixed: true, width: 40 }, // icon
+          { isFixed: false, width: 0.33, children: gettext('Name') },
+          { isFixed: false, width: 0.25, children: gettext('Library') },
+          { isFixed: false, width: 0.16, children: gettext('Visits') },
+          { isFixed: false, width: 0.16, children: gettext('Expiration') },
+          { isFixed: false, width: 0.1 }, // Operations
+        ] : [
+          { isFixed: false, width: 0.12 },
+          { isFixed: false, width: 0.8 },
+          { isFixed: false, width: 0.08 },
+        ]}
+      >
+        {items.map((item, index) => {
+          return (<Item key={index} isDesktop={isDesktop} item={item} onRemoveLink={this.props.onRemoveLink}/>);
+        })}
+      </FixedWidthTable>
     );
-
-    return items.length ? table : emptyTip;
   }
 }
 
@@ -105,11 +100,11 @@ class Item extends Component {
   };
 
   handleMouseOver = () => {
-    this.setState({isOpIconShown: true});
+    this.setState({ isOpIconShown: true });
   };
 
   handleMouseOut = () => {
-    this.setState({isOpIconShown: false});
+    this.setState({ isOpIconShown: false });
   };
 
   viewLink = (e) => {
@@ -127,8 +122,8 @@ class Item extends Component {
     if (!item.expire_date) {
       return '--';
     }
-    const expire_date = moment(item.expire_date).format('YYYY-MM-DD');
-    const expire_time = moment(item.expire_date).format('YYYY-MM-DD HH:mm:ss');
+    const expire_date = dayjs(item.expire_date).format('YYYY-MM-DD');
+    const expire_time = dayjs(item.expire_date).format('YYYY-MM-DD HH:mm:ss');
     return (<span className={item.is_expired ? 'error' : ''} title={expire_time}>{expire_date}</span>);
   };
 
@@ -140,54 +135,54 @@ class Item extends Component {
     const repoUrl = `${siteRoot}library/${item.repo_id}/${encodeURIComponent(item.repo_name)}`;
     const objUrl = `${repoUrl}${Utils.encodePath(item.path)}`;
 
-    const deletedTip = item.obj_id === '' ? <span style={{color:'red'}}>{gettext('(deleted)')}</span> : null;
-    const desktopItem = (
-      <tr onMouseOver={this.handleMouseOver} onMouseOut={this.handleMouseOut} onFocus={this.handleMouseOver}>
-        <td><img src={iconUrl} alt="" width="24" /></td>
-        <td><Link to={objUrl}>{item.obj_name}</Link>{deletedTip}</td>
-        <td><Link to={repoUrl}>{item.repo_name}</Link></td>
-        <td>{item.view_cnt}</td>
-        <td>{this.renderExpiration()}</td>
-        <td>
-          {!item.is_expired && <a href="#" className={`sf2-icon-link action-icon ${isOpIconShown ? '' : 'invisible'}`} title={gettext('View')} aria-label={gettext('View')} role="button" onClick={this.viewLink}></a>}
-          <a href="#" className={`sf2-icon-delete action-icon ${isOpIconShown ? '' : 'invisible'}`} title={gettext('Remove')} aria-label={gettext('Remove')} role="button" onClick={this.removeLink}></a>
-        </td>
-      </tr>
-    );
-
-    const mobileItem = (
-      <tr>
-        <td><img src={iconUrl} alt="" width="24" /></td>
-        <td>
-          <Link to={objUrl}>{item.obj_name}</Link>
-          <br />
-          <span>{item.repo_name}</span><br />
-          <span className="item-meta-info">{gettext('Visits')}: {item.view_cnt}</span>
-          <span className="item-meta-info">{gettext('Expiration')}: {this.renderExpiration()}</span>
-        </td>
-        <td>
-          <Dropdown isOpen={this.state.isOpMenuOpen} toggle={this.toggleOpMenu}>
-            <DropdownToggle
-              tag="i"
-              className="sf-dropdown-toggle fa fa-ellipsis-v ml-0"
-              title={gettext('More Operations')}
-              data-toggle="dropdown"
-              aria-expanded={this.state.isOpMenuOpen}
-            />
-            <div className={this.state.isOpMenuOpen ? '' : 'd-none'} onClick={this.toggleOpMenu}>
-              <div className="mobile-operation-menu-bg-layer"></div>
-              <div className="mobile-operation-menu">
-                {!item.is_expired && <DropdownItem className="mobile-menu-item" onClick={this.viewLink}>{gettext('View')}</DropdownItem>}
-                <DropdownItem className="mobile-menu-item" onClick={this.removeLink}>{gettext('Remove')}</DropdownItem>
-              </div>
-            </div>
-          </Dropdown>
-        </td>
-      </tr>
-    );
     return (
       <Fragment>
-        {this.props.isDesktop ? desktopItem : mobileItem}
+        {this.props.isDesktop ?
+          <tr onMouseOver={this.handleMouseOver} onMouseOut={this.handleMouseOut} onFocus={this.handleMouseOver}>
+            <td className="pl-2 pr-2"><img src={iconUrl} alt="" width="24" /></td>
+            <td>
+              <Link to={objUrl}>{item.obj_name}</Link>
+              {item.obj_id === '' ? <span style={{ color: 'red' }}>{gettext('(deleted)')}</span> : null}
+            </td>
+            <td><Link to={repoUrl}>{item.repo_name}</Link></td>
+            <td>{item.view_cnt}</td>
+            <td>{this.renderExpiration()}</td>
+            <td>
+              {!item.is_expired && <a href="#" className={`sf2-icon-link action-icon op-icon ${isOpIconShown ? '' : 'invisible'}`} title={gettext('View')} aria-label={gettext('View')} role="button" onClick={this.viewLink}></a>}
+              <a href="#" className={`sf3-font-delete1 sf3-font action-icon op-icon ${isOpIconShown ? '' : 'invisible'}`} title={gettext('Remove')} aria-label={gettext('Remove')} role="button" onClick={this.removeLink}></a>
+            </td>
+          </tr>
+          :
+          <tr>
+            <td><img src={iconUrl} alt="" width="24" /></td>
+            <td>
+              <Link to={objUrl}>{item.obj_name}</Link>
+              <br />
+              <span>{item.repo_name}</span><br />
+              <span className="item-meta-info">{gettext('Visits')}: {item.view_cnt}</span>
+              <span className="item-meta-info">{gettext('Expiration')}: {this.renderExpiration()}</span>
+            </td>
+            <td>
+              <Dropdown isOpen={this.state.isOpMenuOpen} toggle={this.toggleOpMenu}>
+                <DropdownToggle
+                  tag="i"
+                  className="sf-dropdown-toggle sf3-font sf3-font-more-vertical ml-0"
+                  title={gettext('More operations')}
+                  aria-label={gettext('More operations')}
+                  data-toggle="dropdown"
+                  aria-expanded={this.state.isOpMenuOpen}
+                />
+                <div className={this.state.isOpMenuOpen ? '' : 'd-none'} onClick={this.toggleOpMenu}>
+                  <div className="mobile-operation-menu-bg-layer"></div>
+                  <div className="mobile-operation-menu">
+                    {!item.is_expired && <DropdownItem className="mobile-menu-item" onClick={this.viewLink}>{gettext('View')}</DropdownItem>}
+                    <DropdownItem className="mobile-menu-item" onClick={this.removeLink}>{gettext('Remove')}</DropdownItem>
+                  </div>
+                </div>
+              </Dropdown>
+            </td>
+          </tr>
+        }
         {isLinkDialogOpen &&
         <ShareAdminLink
           link={item.link}
@@ -201,11 +196,6 @@ class Item extends Component {
 
 Item.propTypes = itemPropTypes;
 
-const propTypes = {
-  onShowSidePanel: PropTypes.func.isRequired,
-  onSearchedClick: PropTypes.func.isRequired
-};
-
 class ShareAdminUploadLinks extends Component {
 
   constructor(props) {
@@ -244,7 +234,7 @@ class ShareAdminUploadLinks extends Component {
       let items = this.state.items.filter(uploadItem => {
         return uploadItem.token !== item.token;
       });
-      this.setState({items: items});
+      this.setState({ items: items });
       const message = gettext('Successfully deleted 1 item.');
       toaster.success(message);
     }).catch((error) => {
@@ -254,13 +244,13 @@ class ShareAdminUploadLinks extends Component {
   };
 
   toggleCleanInvalidUploadLinksDialog = () => {
-    this.setState({isCleanInvalidUploadLinksDialogOpen: !this.state.isCleanInvalidUploadLinksDialogOpen});
+    this.setState({ isCleanInvalidUploadLinksDialogOpen: !this.state.isCleanInvalidUploadLinksDialogOpen });
   };
 
   cleanInvalidUploadLinks = () => {
     seafileAPI.cleanInvalidUploadLinks().then(res => {
       const newItems = this.state.items.filter(item => item.obj_id !== '').filter(item => !item.is_expired);
-      this.setState({items: newItems});
+      this.setState({ items: newItems });
       toaster.success(gettext('Successfully cleaned invalid upload links.'));
     }).catch(error => {
       let errMessage = Utils.getErrorMsg(error);
@@ -271,12 +261,6 @@ class ShareAdminUploadLinks extends Component {
   render() {
     return (
       <Fragment>
-        <TopToolbar
-          onShowSidePanel={this.props.onShowSidePanel}
-          onSearchedClick={this.props.onSearchedClick}
-        >
-          <Button className="operation-item d-none d-md-block" onClick={this.toggleCleanInvalidUploadLinksDialog}>{gettext('Clean invalid upload links')}</Button>
-        </TopToolbar>
         <div className="main-panel-center">
           <div className="cur-view-container">
             <div className="cur-view-path share-upload-nav">
@@ -284,7 +268,14 @@ class ShareAdminUploadLinks extends Component {
                 {canGenerateShareLink && (
                   <li className="nav-item"><Link to={`${siteRoot}share-admin-share-links/`} className="nav-link">{gettext('Share Links')}</Link></li>
                 )}
-                <li className="nav-item"><Link to={`${siteRoot}share-admin-upload-links/`} className="nav-link active">{gettext('Upload Links')}</Link></li>
+                <li className="nav-item">
+                  <Link to={`${siteRoot}share-admin-upload-links/`} className="nav-link active">
+                    {gettext('Upload Links')}
+                    <SingleDropdownToolbar
+                      opList={[{ 'text': gettext('Clean invalid upload links'), 'onClick': this.toggleCleanInvalidUploadLinksDialog }]}
+                    />
+                  </Link>
+                </li>
               </ul>
             </div>
             <div className="cur-view-content">
@@ -311,6 +302,4 @@ class ShareAdminUploadLinks extends Component {
   }
 }
 
-ShareAdminUploadLinks.propTypes = propTypes;
-
 export default ShareAdminUploadLinks;
