@@ -1,60 +1,61 @@
-import React, { Component } from 'react';
+import React, { Component, Fragment } from 'react';
 import PropTypes from 'prop-types';
 import { Dropdown, DropdownToggle, DropdownItem } from 'reactstrap';
 import { Link, navigate } from '@gatsbyjs/reach-router';
-import moment from 'moment';
+import dayjs from 'dayjs';
+import relativeTime from 'dayjs/plugin/relativeTime';
 import { seafileAPI } from '../../utils/seafile-api';
 import { Utils } from '../../utils/utils';
-import { gettext, siteRoot, enableVideoThumbnail } from '../../utils/constants';
+import { gettext, siteRoot, enableVideoThumbnail, enablePDFThumbnail, thumbnailDefaultSize } from '../../utils/constants';
 import EmptyTip from '../../components/empty-tip';
 import Loading from '../../components/loading';
 import toaster from '../../components/toast';
 
+dayjs.extend(relativeTime);
+
 class Content extends Component {
 
   render() {
-    const {loading, errorMsg, items} = this.props.data;
+    const { loading, errorMsg, items } = this.props.data;
 
     if (loading) {
       return <Loading />;
     } else if (errorMsg) {
       return <p className="error text-center">{errorMsg}</p>;
-    } else {
-      const emptyTip = (
-        <EmptyTip>
-          <h2>{gettext('No favorites')}</h2>
-          <p>{gettext('You have not added any libraries, folders or files to your favorites yet. A favorite gives you quick access to your most frequently used objects. You can add a library, folder or file to your favorites by clicking the star to the left of its name.')}</p>
+    } else if (items.length === 0) {
+      return (
+        <EmptyTip
+          title={gettext('No favorites')}
+          text={gettext('You have not added any libraries, folders or files to your favorites yet. A favorite gives you quick access to your most frequently used objects. You can add a library, folder or file to your favorites by clicking the star to the left of its name.')}
+        >
         </EmptyTip>
       );
-
-      const desktopThead = (
-        <thead>
-          <tr>
-            <th width="4%"></th>
-            <th width="40%">{gettext('Name')}</th>
-            <th width="32%">{gettext('Library')}</th>
-            <th width="18%">{gettext('Last Update')}</th>
-            <th width="6%"></th>
-          </tr>
-        </thead>
-      );
-      const mobileThead = (
-        <thead>
-          <tr>
-            <th width="12%"></th>
-            <th width="80%"></th>
-            <th width="8%"></th>
-          </tr>
-        </thead>
-      );
-
+    } else {
       const isDesktop = Utils.isDesktop();
-      return items.length ? (
-        <table className={`table-hover ${isDesktop ? '': 'table-thead-hidden'}`}>
-          {isDesktop ? desktopThead : mobileThead}
-          <TableBody items={items} />
+      return (
+        <table className={`table-hover ${isDesktop ? '' : 'table-thead-hidden'}`}>
+          {isDesktop ?
+            <thead>
+              <tr>
+                <th width="4%"></th>
+                <th width="40%">{gettext('Name')}</th>
+                <th width="32%">{gettext('Library')}</th>
+                <th width="18%">{gettext('Last Update')}</th>
+                <th width="6%"></th>
+              </tr>
+            </thead>
+            :
+            <thead>
+              <tr>
+                <th width="12%"></th>
+                <th width="80%"></th>
+                <th width="8%"></th>
+              </tr>
+            </thead>
+          }
+          <TableBody items={items} isDesktop={isDesktop} />
         </table>
-      ) : emptyTip;
+      );
     }
   }
 }
@@ -79,18 +80,20 @@ class TableBody extends Component {
 
   getThumbnails() {
     let items = this.state.items.filter((item) => {
-      return (Utils.imageCheck(item.obj_name) || (enableVideoThumbnail && Utils.videoCheck(item.obj_name))) && !item.repo_encrypted;
+      return (Utils.imageCheck(item.obj_name) ||
+          (enableVideoThumbnail && Utils.videoCheck(item.obj_name)) ||
+          (enablePDFThumbnail && Utils.pdfCheck(item.obj_name))) &&
+          !item.repo_encrypted && !item.encoded_thumbnail_src && !item.deleted;
     });
     if (items.length == 0) {
       return ;
     }
 
     const len = items.length;
-    const thumbnailSize = 48;
     const _this = this;
-    let getThumbnail = function(i) {
+    let getThumbnail = function (i) {
       const curItem = items[i];
-      seafileAPI.createThumbnail(curItem.repo_id, curItem.path, thumbnailSize).then((res) => {
+      seafileAPI.createThumbnail(curItem.repo_id, curItem.path, thumbnailDefaultSize).then((res) => {
         curItem.encoded_thumbnail_src = res.data.encoded_thumbnail_src;
       }).catch((error) => {
         // do nothing
@@ -109,32 +112,13 @@ class TableBody extends Component {
   }
 
   render() {
-
-    let listItems = this.state.items.map(function(item, index) {
-
-      if (item.path === '/') {
-        item.item_icon_url = Utils.getDefaultLibIconUrl(false);
-      } else {
-        item.item_icon_url = item.is_dir ? Utils.getFolderIconUrl(false) : Utils.getFileIconUrl(item.obj_name);
-      }
-
-      item.encoded_path = Utils.encodePath(item.path);
-
-      item.thumbnail_url = item.encoded_thumbnail_src ? `${siteRoot}${item.encoded_thumbnail_src}` : '';
-      item.dirent_view_url = item.is_dir ? `${siteRoot}library/${item.repo_id}/${item.repo_name}${item.encoded_path}` : `${siteRoot}lib/${item.repo_id}/file${item.encoded_path}`;
-      // item is folder or file
-      if (item.encoded_path !== '/') {
-        item.dirent_view_url = item.dirent_view_url.replace(/\/+$/, '');
-      }
-
-      item.mtime_relative = moment(item.mtime).fromNow();
-
-
-      return <Item key={index} data={item} />;
-    }, this);
-
+    const { items } = this.state;
     return (
-      <tbody>{listItems}</tbody>
+      <tbody>
+        {items.map((item, index) => {
+          return <Item key={index} data={item} isDesktop={this.props.isDesktop} />;
+        })}
+      </tbody>
     );
   }
 }
@@ -142,6 +126,7 @@ class TableBody extends Component {
 TableBody.propTypes = {
   data: PropTypes.object,
   items: PropTypes.array,
+  isDesktop: PropTypes.bool.isRequired,
 };
 
 class Item extends Component {
@@ -173,12 +158,10 @@ class Item extends Component {
     });
   };
 
-  unstar = (e) => {
-    e.preventDefault();
-
+  unstar = () => {
     const data = this.props.data;
     seafileAPI.unstarItem(data.repo_id, data.path).then((res) => {
-      this.setState({unstarred: true});
+      this.setState({ unstarred: true });
     }).catch((error) => {
       let errMessage = Utils.getErrorMsg(error);
       toaster.danger(errMessage);
@@ -194,41 +177,9 @@ class Item extends Component {
     }
   };
 
-  render() {
-
-    if (this.state.unstarred) {
-      return null;
-    }
-
+  renderMobile = () => {
     const data = this.props.data;
-
-    let opClasses = 'sf2-icon-x3 unstar action-icon';
-    opClasses += this.state.showOpIcon ? '' : ' invisible';
     const linkUrl = data.dirent_view_url;
-
-    const desktopItem = (
-      <tr onMouseOver={this.handleMouseOver} onMouseOut={this.handleMouseOut} onFocus={this.handleMouseOver}>
-        <td className="text-center">
-          {
-            data.thumbnail_url ?
-              <img className="thumbnail" src={data.thumbnail_url} alt="" /> :
-              <img src={data.item_icon_url} alt={gettext('icon')} width="24" />
-          }
-        </td>
-        <td>
-          { data.is_dir ?
-            <Link to={linkUrl}>{data.obj_name}</Link> :
-            <a className="normal" href={data.dirent_view_url} target="_blank" rel="noreferrer">{data.obj_name}</a>
-          }
-        </td>
-        <td>{data.repo_name}</td>
-        <td dangerouslySetInnerHTML={{__html:data.mtime_relative}}></td>
-        <td>
-          <a href="#" role="button" className={opClasses} title={gettext('Unstar')} aria-label={gettext('Unstar')} onClick={this.unstar}></a>
-        </td>
-      </tr>
-    );
-
     const mobileItem = (
       <tr>
         <td className="text-center" onClick={this.visitItem}>
@@ -239,20 +190,26 @@ class Item extends Component {
           }
         </td>
         <td onClick={this.visitItem}>
-          { data.is_dir ?
-            <Link to={linkUrl}>{data.obj_name}</Link> :
-            <a className="normal" href={data.dirent_view_url} target="_blank" rel="noreferrer">{data.obj_name}</a>
-          }
+          {data.deleted ? (
+            <>
+              {data.obj_name}
+              <span className="error ml-1">{gettext('deleted')}</span>
+            </>
+          ) : (
+            data.is_dir ?
+              <Link to={linkUrl}>{data.obj_name}</Link> :
+              <a className="normal" href={linkUrl} target="_blank" rel="noreferrer">{data.obj_name}</a>
+          )}
           <br />
           <span className="item-meta-info">{data.repo_name}</span>
-          <span className="item-meta-info" dangerouslySetInnerHTML={{__html:data.mtime_relative}}></span>
+          <span className="item-meta-info" dangerouslySetInnerHTML={{ __html: data.mtime_relative }}></span>
         </td>
         <td>
           <Dropdown isOpen={this.state.isOpMenuOpen} toggle={this.toggleOpMenu}>
             <DropdownToggle
               tag="i"
-              className="sf-dropdown-toggle fa fa-ellipsis-v ml-0"
-              title={gettext('More Operations')}
+              className="sf-dropdown-toggle sf3-font sf3-font-more-vertical ml-0"
+              title={gettext('More operations')}
               data-toggle="dropdown"
               aria-expanded={this.state.isOpMenuOpen}
             />
@@ -266,14 +223,80 @@ class Item extends Component {
         </td>
       </tr>
     );
+    return mobileItem;
+  };
 
-    return Utils.isDesktop() ? desktopItem : mobileItem;
+  renderDesktop = () => {
+    const data = this.props.data;
+    const linkUrl = data.dirent_view_url;
+    const desktopItem = (
+      <tr onMouseOver={this.handleMouseOver} onMouseOut={this.handleMouseOut} onFocus={this.handleMouseOver}>
+        <td className="text-center">
+          {
+            data.thumbnail_url ?
+              <img className="thumbnail" src={data.thumbnail_url} alt="" /> :
+              <img src={data.item_icon_url} alt={gettext('icon')} width="24" />
+          }
+        </td>
+        <td>
+          {data.deleted ? (
+            <>
+              {data.obj_name}
+              <span className="error ml-1">{gettext('deleted')}</span>
+            </>
+          ) : (
+            data.is_dir ?
+              <Link to={linkUrl}>{data.obj_name}</Link> :
+              <a className="normal" href={linkUrl} target="_blank" rel="noreferrer">{data.obj_name}</a>
+          )}
+        </td>
+        <td>{data.repo_name}</td>
+        <td dangerouslySetInnerHTML={{ __html: data.mtime_relative }}></td>
+        <td>
+          <i
+            role="button"
+            className={`sf2-icon-x3 unstar action-icon ${this.state.showOpIcon ? '' : 'invisible'}`}
+            title={gettext('Unstar')}
+            aria-label={gettext('Unstar')}
+            onClick={this.unstar}
+          >
+          </i>
+        </td>
+      </tr>
+    );
+    return desktopItem;
+  };
+
+  render() {
+    const { data: item } = this.props;
+    if (item.path === '/') {
+      item.item_icon_url = Utils.getDefaultLibIconUrl();
+    } else {
+      item.item_icon_url = item.is_dir ? Utils.getFolderIconUrl(false) : Utils.getFileIconUrl(item.obj_name);
+    }
+
+    item.encoded_path = Utils.encodePath(item.path);
+
+    item.thumbnail_url = item.encoded_thumbnail_src ? `${siteRoot}${item.encoded_thumbnail_src}` : '';
+    item.dirent_view_url = item.is_dir ? `${siteRoot}library/${item.repo_id}/${item.repo_name}${item.encoded_path}` : `${siteRoot}lib/${item.repo_id}/file${item.encoded_path}`;
+    // item is folder or file
+    if (item.encoded_path !== '/') {
+      item.dirent_view_url = item.dirent_view_url.replace(/\/+$/, '');
+    }
+
+    item.mtime_relative = item.mtime ? dayjs(item.mtime).fromNow() : '--';
+
+    if (this.state.unstarred) {
+      return null;
+    }
+    return this.props.isDesktop ? this.renderDesktop() : this.renderMobile();
   }
 }
 
 Item.propTypes = {
   data: PropTypes.object,
   items: PropTypes.array,
+  isDesktop: PropTypes.bool.isRequired,
 };
 
 class Starred extends Component {
