@@ -1,8 +1,8 @@
 import React, { Component, Fragment } from 'react';
+import dayjs from 'dayjs';
 import { gettext, siteRoot } from '../../utils/constants';
-import { seafileAPI } from '../../utils/seafile-api';
+import { systemAdminAPI } from '../../utils/system-admin-api';
 import toaster from '../../components/toast';
-import moment from 'moment';
 import MainPanelTopbar from './main-panel-topbar';
 
 class AbuseReports extends Component {
@@ -15,7 +15,7 @@ class AbuseReports extends Component {
   }
 
   listAbuseReports = () => {
-    seafileAPI.sysAdminListAbuseReports().then((res) => {
+    systemAdminAPI.sysAdminListAbuseReports().then((res) => {
       this.setState({
         abuseReportList: res.data.abuse_report_list,
       });
@@ -25,7 +25,7 @@ class AbuseReports extends Component {
   };
 
   updateAbuseReport = (handled, abuseReportId) => {
-    seafileAPI.sysAdminUpdateAbuseReport(handled, abuseReportId).then((res) => {
+    systemAdminAPI.sysAdminUpdateAbuseReport(handled, abuseReportId).then((res) => {
       const abuseReportList = this.state.abuseReportList.map((item, index) => {
         if (item.id === abuseReportId) {
           item.handled = res.data.handled;
@@ -42,9 +42,9 @@ class AbuseReports extends Component {
 
   handleError = (e) => {
     if (e.response) {
-      toaster.danger(e.response.data.error_msg || e.response.data.detail || gettext('Error'), {duration: 3});
+      toaster.danger(e.response.data.error_msg || e.response.data.detail || gettext('Error'), { duration: 3 });
     } else {
-      toaster.danger(gettext('Please check the network.'), {duration: 3});
+      toaster.danger(gettext('Please check the network.'), { duration: 3 });
     }
   };
 
@@ -64,10 +64,14 @@ class AbuseReports extends Component {
           <td>{item.reporter}</td>
           <td>{item.abuse_type}</td>
           <td>{item.description}</td>
-          <td>{moment(item.time).format('YYYY-MM-DD')}</td>
-          <td><p onClick={this.updateAbuseReport.bind(this, handled, abuseReportId)}
-            className="op-target ellipsis ellipsis-op-target cursor-pointer"
-          >{gettext(item.handled.toString())}</p></td>
+          <td>{dayjs(item.time).format('YYYY-MM-DD')}</td>
+          <td>
+            <p
+              onClick={this.updateAbuseReport.bind(this, handled, abuseReportId)}
+              className="op-target ellipsis ellipsis-op-target cursor-pointer"
+            >{gettext(item.handled.toString())}
+            </p>
+          </td>
         </tr>
       );
     });
