@@ -1,16 +1,18 @@
 import React, { Component, Fragment } from 'react';
 import PropTypes from 'prop-types';
-import { seafileAPI } from '../../../utils/seafile-api';
+import dayjs from 'dayjs';
+import relativeTime from 'dayjs/plugin/relativeTime';
+import { systemAdminAPI } from '../../../utils/system-admin-api';
 import { gettext } from '../../../utils/constants';
 import { Utils } from '../../../utils/utils';
 import EmptyTip from '../../../components/empty-tip';
-import moment from 'moment';
 import Loading from '../../../components/loading';
 import Paginator from '../../../components/paginator';
 import LogsNav from './logs-nav';
 import MainPanelTopbar from '../main-panel-topbar';
 import UserLink from '../user-link';
 
+dayjs.extend(relativeTime);
 
 class Content extends Component {
 
@@ -34,8 +36,7 @@ class Content extends Component {
       return <p className="error text-center">{errorMsg}</p>;
     } else {
       const emptyTip = (
-        <EmptyTip>
-          <h2>{gettext('No Admin login logs')}</h2>
+        <EmptyTip text={gettext('No Admin login logs')}>
         </EmptyTip>
       );
       const table = (
@@ -100,7 +101,7 @@ class Item extends Component {
         <td><UserLink email={item.email} name={item.name} /></td>
         <td>{item.login_ip}</td>
         <td>{item.login_success ? gettext('Success') : gettext('Failed')}</td>
-        <td>{moment(item.login_time).fromNow()}</td>
+        <td>{dayjs(item.login_time).fromNow()}</td>
       </tr>
     );
   }
@@ -118,14 +119,14 @@ class AdminLoginLogs extends Component {
       loading: true,
       errorMsg: '',
       logList: [],
-      perPage: 25,
+      perPage: 100,
       currentPage: 1,
       hasNextPage: false,
     };
     this.initPage = 1;
   }
 
-  componentDidMount () {
+  componentDidMount() {
     let urlParams = (new URL(window.location)).searchParams;
     const { currentPage, perPage } = this.state;
     this.setState({
@@ -138,7 +139,7 @@ class AdminLoginLogs extends Component {
 
   getLogsByPage = (page) => {
     let { perPage } = this.state;
-    seafileAPI.sysAdminListAdminLoginLogs(page, perPage).then((res) => {
+    systemAdminAPI.sysAdminListAdminLoginLogs(page, perPage).then((res) => {
       this.setState({
         logList: res.data.data,
         loading: false,
