@@ -1,16 +1,19 @@
 import React, { Component, Fragment } from 'react';
 import PropTypes from 'prop-types';
-import { seafileAPI } from '../../../utils/seafile-api';
+import dayjs from 'dayjs';
+import relativeTime from 'dayjs/plugin/relativeTime';
+import { systemAdminAPI } from '../../../utils/system-admin-api';
 import { gettext, siteRoot, enableSysAdminViewRepo, isPro } from '../../../utils/constants';
 import { Utils } from '../../../utils/utils';
 import EmptyTip from '../../../components/empty-tip';
-import moment from 'moment';
 import Loading from '../../../components/loading';
 import Paginator from '../../../components/paginator';
 import LogsNav from './logs-nav';
 import MainPanelTopbar from '../main-panel-topbar';
 import UserLink from '../user-link';
 
+dayjs.extend(relativeTime);
+
 class Content extends Component {
 
   constructor(props) {
@@ -33,8 +36,7 @@ class Content extends Component {
       return <p className="error text-center">{errorMsg}</p>;
     } else {
       const emptyTip = (
-        <EmptyTip>
-          <h2>{gettext('No Admin operation logs')}</h2>
+        <EmptyTip text={gettext('No Admin operation logs')}>
         </EmptyTip>
       );
       const table = (
@@ -105,6 +107,7 @@ class Item extends Component {
       case 'group_delete': return gettext('Delete Group');
       case 'user_add': return gettext('Add User');
       case 'user_delete': return gettext('Delete User');
+      case 'user_migrate': return gettext('Migrate User');
       default: return '';
     }
   };
@@ -135,38 +138,38 @@ class Item extends Component {
         detailText = gettext('Created library {library_name} with {owner} as its owner')
           .replace('{owner}', '<a href="' + ownerPageUrl + '">' + detail.owner + '</a>');
         if (isPro && enableSysAdminViewRepo) {
-          detailText = detailText.replace('{library_name}', '<a href="' + repoPageUrl + '">' + detail.name + '</a>');
+          detailText = detailText.replace('{library_name}', '<a href="' + repoPageUrl + '">' + Utils.HTMLescape(detail.name) + '</a>');
         } else {
-          detailText = detailText.replace('{library_name}', '<span class="font-weight-bold">' + detail.name + '</span>');
+          detailText = detailText.replace('{library_name}', '<span class="font-weight-bold">' + Utils.HTMLescape(detail.name) + '</span>');
         }
         return detailText;
 
       case 'repo_delete':
         detailText = gettext('Deleted library {library_name}')
-          .replace('{library_name}', '<span class="font-weight-bold">' + detail.name + '</span>');
+          .replace('{library_name}', '<span class="font-weight-bold">' + Utils.HTMLescape(detail.name) + '</span>');
         return detailText;
 
       case 'repo_transfer':
         detailText = gettext('Transferred library {library_name} from {user_from} to {user_to}')
           .replace('{user_from}', '<span class="font-weight-bold">' + detail.from + '</span>')
-          .replace('{user_to}', '<span class="font-weight-bold">' + detail.to+ '</span>');
+          .replace('{user_to}', '<span class="font-weight-bold">' + detail.to + '</span>');
         if (isPro && enableSysAdminViewRepo) {
-          detailText = detailText.replace('{library_name}', '<a href="' + repoPageUrl + '">' + detail.name + '</a>');
+          detailText = detailText.replace('{library_name}', '<a href="' + repoPageUrl + '">' + Utils.HTMLescape(detail.name) + '</a>');
         } else {
-          detailText = detailText.replace('{library_name}', '<span class="font-weight-bold">' + detail.name + '</span>');
+          detailText = detailText.replace('{library_name}', '<span class="font-weight-bold">' + Utils.HTMLescape(detail.name) + '</span>');
         }
         return detailText;
 
       case 'group_create':
         detailText = gettext('Created group {group_name}')
-          .replace('{group_name}', '<a href="' + groupPageUrl + '">' + detail.name+ '</a>');
+          .replace('{group_name}', '<a href="' + groupPageUrl + '">' + detail.name + '</a>');
         return detailText;
 
       case 'group_transfer':
         detailText = gettext('Transferred group {group_name} from {user_from} to {user_to}')
           .replace('{user_from}', '<span class="font-weight-bold">' + detail.from + '</span>')
-          .replace('{user_to}', '<span class="font-weight-bold">' + detail.to+ '</span>')
-          .replace('{group_name}', '<a href="' + groupPageUrl + '">' + detail.name+ '</a>');
+          .replace('{user_to}', '<span class="font-weight-bold">' + detail.to + '</span>')
+          .replace('{group_name}', '<a href="' + groupPageUrl + '">' + detail.name + '</a>');
         return detailText;
 
       case 'group_delete':
@@ -176,12 +179,18 @@ class Item extends Component {
 
       case 'user_add':
         detailText = gettext('Added user {user}')
-          .replace('{user}', '<a href="' + userPageUrl + '">' + detail.email+ '</a>');
+          .replace('{user}', '<a href="' + userPageUrl + '">' + detail.email + '</a>');
         return detailText;
 
       case 'user_delete':
         detailText = gettext('Deleted user {user}')
-          .replace('{user}', '<span class="font-weight-bold">' + detail.email+ '</span>');
+          .replace('{user}', '<span class="font-weight-bold">' + detail.email + '</span>');
+        return detailText;
+
+      case 'user_migrate':
+        detailText = gettext('User migrate from {user_from} to {user_to}')
+          .replace('{user_from}', '<span class="font-weight-bold">' + detail.from + '</span>')
+          .replace('{user_to}', '<span class="font-weight-bold">' + detail.to + '</span>');
         return detailText;
 
       default: return '';
@@ -195,9 +204,9 @@ class Item extends Component {
         <td><UserLink email={item.email} name={item.name} /></td>
         <td>{this.getOperationText(item.operation)}</td>
         <td>
-          <span dangerouslySetInnerHTML={{__html: this.getOperationDetail(item)}}></span>
+          <span dangerouslySetInnerHTML={{ __html: this.getOperationDetail(item) }}></span>
         </td>
-        <td>{moment(item.datetime).fromNow()}</td>
+        <td>{dayjs(item.datetime).fromNow()}</td>
       </tr>
     );
   }
@@ -215,14 +224,14 @@ class AdminOperationLogs extends Component {
       loading: true,
       errorMsg: '',
       logList: [],
-      perPage: 25,
+      perPage: 100,
       currentPage: 1,
       hasNextPage: false,
     };
     this.initPage = 1;
   }
 
-  componentDidMount () {
+  componentDidMount() {
     let urlParams = (new URL(window.location)).searchParams;
     const { currentPage, perPage } = this.state;
     this.setState({
@@ -235,7 +244,7 @@ class AdminOperationLogs extends Component {
 
   getLogsByPage = (page) => {
     let { perPage } = this.state;
-    seafileAPI.sysAdminListAdminLogs(page, perPage).then((res) => {
+    systemAdminAPI.sysAdminListAdminLogs(page, perPage).then((res) => {
       this.setState({
         logList: res.data.data,
         loading: false,
