@@ -12,7 +12,7 @@ class DesktopDevices extends Component {
   render() {
     return (
       <Fragment>
-        <MainPanelTopbar />
+        <MainPanelTopbar {...this.props} />
         <div className="main-panel-center flex-row">
           <div className="cur-view-container">
             <DevicesNav currentItem="desktop" />
