@@ -2,7 +2,7 @@ import React, { Component, Fragment } from 'react';
 import PropTypes from 'prop-types';
 import { Button } from 'reactstrap';
 import { Utils } from '../../../utils/utils';
-import { seafileAPI } from '../../../utils/seafile-api';
+import { systemAdminAPI } from '../../../utils/system-admin-api';
 import { gettext } from '../../../utils/constants';
 import toaster from '../../../components/toast';
 import EmptyTip from '../../../components/empty-tip';
@@ -44,8 +44,7 @@ class Content extends Component {
       return <p className="error text-center mt-4">{errorMsg}</p>;
     } else {
       const emptyTip = (
-        <EmptyTip>
-          <h2>{gettext('No members')}</h2>
+        <EmptyTip text={gettext('No members')}>
         </EmptyTip>
       );
       const table = (
@@ -56,7 +55,7 @@ class Content extends Component {
                 <th width="5%">{/* icon */}</th>
                 <th width="55%">{gettext('Name')}</th>
                 <th width="30%">{gettext('Role')}</th>
-                <th width="10%">{/*Operations*/}</th>
+                <th width="10%">{/* Operations*/}</th>
               </tr>
             </thead>
             <tbody>
@@ -117,19 +116,19 @@ class Item extends Component {
 
   handleMouseEnter = () => {
     if (this.props.isItemFreezed) return;
-    this.setState({highlighted: true});
+    this.setState({ highlighted: true });
   };
 
   handleMouseLeave = () => {
     if (this.props.isItemFreezed) return;
-    this.setState({highlighted: false});
+    this.setState({ highlighted: false });
   };
 
   toggleDeleteDialog = (e) => {
     if (e) {
       e.preventDefault();
     }
-    this.setState({isDeleteDialogOpen: !this.state.isDeleteDialogOpen});
+    this.setState({ isDeleteDialogOpen: !this.state.isDeleteDialogOpen });
   };
 
   removeMember = () => {
@@ -212,12 +211,12 @@ class GroupMembers extends Component {
       memberList: [],
       pageInfo: {},
       currentPage: 1,
-      perPage: 25,
+      perPage: 100,
       isAddMemberDialogOpen: false
     };
   }
 
-  componentDidMount () {
+  componentDidMount() {
 
     let urlParams = (new URL(window.location)).searchParams;
     const { currentPage, perPage } = this.state;
@@ -231,7 +230,7 @@ class GroupMembers extends Component {
 
   getListByPage = (page) => {
     const { perPage } = this.state;
-    seafileAPI.sysAdminListGroupMembers(this.props.groupID, page, perPage).then((res) => {
+    systemAdminAPI.sysAdminListGroupMembers(this.props.groupID, page, perPage).then((res) => {
       this.setState({
         loading: false,
         memberList: res.data.members,
@@ -254,12 +253,12 @@ class GroupMembers extends Component {
     });
   };
 
-  toggleAddMemgerDialog = () => {
-    this.setState({isAddMemberDialogOpen: !this.state.isAddMemberDialogOpen});
+  toggleAddMemberDialog = () => {
+    this.setState({ isAddMemberDialogOpen: !this.state.isAddMemberDialogOpen });
   };
 
   addMembers = (emails) => {
-    seafileAPI.sysAdminAddGroupMember(this.props.groupID, emails).then(res => {
+    systemAdminAPI.sysAdminAddGroupMember(this.props.groupID, emails).then(res => {
       let newMemberList = res.data.success;
       if (newMemberList.length) {
         this.setState({
@@ -275,7 +274,7 @@ class GroupMembers extends Component {
         const msg = gettext('Failed to add {email_placeholder}: {error_msg_placeholder}')
           .replace('{email_placeholder}', item.email)
           .replace('{error_msg_placeholder}', item.error_msg);
-        toaster.danger(msg, {duration: 3});
+        toaster.danger(msg, { duration: 3 });
       });
     }).catch((error) => {
       let errMessage = Utils.getErrorMsg(error);
@@ -284,7 +283,7 @@ class GroupMembers extends Component {
   };
 
   removeMember = (email, name) => {
-    seafileAPI.sysAdminDeleteGroupMember(this.props.groupID, email).then(res => {
+    systemAdminAPI.sysAdminDeleteGroupMember(this.props.groupID, email).then(res => {
       let newRepoList = this.state.memberList.filter(item => {
         return item.email != email;
       });
@@ -300,7 +299,7 @@ class GroupMembers extends Component {
 
   updateMemberRole = (email, role) => {
     let isAdmin = role == 'Admin';
-    seafileAPI.sysAdminUpdateGroupMemberRole(this.props.groupID, email, isAdmin).then(res => {
+    systemAdminAPI.sysAdminUpdateGroupMemberRole(this.props.groupID, email, isAdmin).then(res => {
       let newRepoList = this.state.memberList.map(item => {
         if (item.email == email) {
           item.role = role;
@@ -321,7 +320,7 @@ class GroupMembers extends Component {
     return (
       <Fragment>
         <MainPanelTopbar {...this.props}>
-          <Button className="btn btn-secondary operation-item" onClick={this.toggleAddMemgerDialog}>{gettext('Add Member')}</Button>
+          <Button className="btn btn-secondary operation-item" onClick={this.toggleAddMemberDialog}>{gettext('Add Member')}</Button>
         </MainPanelTopbar>
         <div className="main-panel-center flex-row">
           <div className="cur-view-container">
@@ -348,7 +347,7 @@ class GroupMembers extends Component {
         {isAddMemberDialogOpen &&
           <SysAdminGroupAddMemberDialog
             addMembers={this.addMembers}
-            toggle={this.toggleAddMemgerDialog}
+            toggle={this.toggleAddMemberDialog}
           />
         }
       </Fragment>
