@@ -1,7 +1,7 @@
 import React, { Component, Fragment } from 'react';
 import PropTypes from 'prop-types';
 import { Utils } from '../../../utils/utils';
-import { seafileAPI } from '../../../utils/seafile-api';
+import { systemAdminAPI } from '../../../utils/system-admin-api';
 import { siteRoot, gettext, isPro } from '../../../utils/constants';
 import toaster from '../../../components/toast';
 import EmptyTip from '../../../components/empty-tip';
@@ -27,8 +27,7 @@ class Content extends Component {
       return <p className="error text-center mt-4">{errorMsg}</p>;
     } else {
       const emptyTip = (
-        <EmptyTip>
-          <h2>{gettext('No libraries')}</h2>
+        <EmptyTip text={gettext('No libraries')}>
         </EmptyTip>
       );
       const table = (
@@ -40,7 +39,7 @@ class Content extends Component {
                 <th width="30%">{gettext('Name')}</th>
                 <th width="30%">{gettext('Size')}</th>
                 <th width="25%">{gettext('Shared By')}</th>
-                <th width="10%">{/*Operations*/}</th>
+                <th width="10%">{/* Operations*/}</th>
               </tr>
             </thead>
             <tbody>
@@ -82,18 +81,18 @@ class Item extends Component {
   }
 
   handleMouseEnter = () => {
-    this.setState({isOpIconShown: true});
+    this.setState({ isOpIconShown: true });
   };
 
   handleMouseLeave = () => {
-    this.setState({isOpIconShown: false});
+    this.setState({ isOpIconShown: false });
   };
 
   toggleUnshareRepoDialog = (e) => {
     if (e) {
       e.preventDefault();
     }
-    this.setState({isUnshareRepoDialogOpen: !this.state.isUnshareRepoDialogOpen});
+    this.setState({ isUnshareRepoDialogOpen: !this.state.isUnshareRepoDialogOpen });
   };
 
   unshareRepo = () => {
@@ -171,8 +170,8 @@ class GroupRepos extends Component {
     };
   }
 
-  componentDidMount () {
-    seafileAPI.sysAdminListGroupRepos(this.props.groupID).then((res) => {
+  componentDidMount() {
+    systemAdminAPI.sysAdminListGroupRepos(this.props.groupID).then((res) => {
       this.setState({
         loading: false,
         repoList: res.data.libraries,
@@ -187,7 +186,7 @@ class GroupRepos extends Component {
   }
 
   unshareRepo = (repoID, repoName) => {
-    seafileAPI.sysAdminUnshareRepoFromGroup(this.props.groupID, repoID).then(res => {
+    systemAdminAPI.sysAdminUnshareRepoFromGroup(this.props.groupID, repoID).then(res => {
       let newRepoList = this.state.repoList.filter(item => {
         return item.repo_id != repoID;
       });
