@@ -35,6 +35,7 @@ import UserLinks from './users/user-links';
 import UserGroups from './users/user-groups';
 
 import AllRepos from './repos/all-repos';
+import AllWikis from './repos/all-wikis';
 import SystemRepo from './repos/system-repo';
 import TrashRepos from './repos/trash-repos';
 import SearchRepos from './repos/search-repos';
@@ -46,10 +47,6 @@ import GroupRepos from './groups/group-repos';
 import GroupMembers from './groups/group-members';
 
 import Departments from './departments/departments';
-import DepartmentList from './departments/department-list';
-import SubDepartments from './departments/sub-departments';
-import DepartmentMembers from './departments/department-members';
-import DepartmentLibraries from './departments/department-libraries';
 
 import ShareLinks from './links/share-links';
 import UploadLinks from './links/upload-links';
@@ -160,7 +157,7 @@ class SysAdmin extends React.Component {
     const tmpTab = this.getCurrentTabForPageList(pageList);
     currentTab = tmpTab ? tmpTab : currentTab;
 
-    this.setState({currentTab: currentTab});
+    this.setState({ currentTab: currentTab });
   }
 
   UNSAFE_componentWillMount() {
@@ -172,12 +169,12 @@ class SysAdmin extends React.Component {
   }
 
   getCurrentTabForPageList = (pageList) => {
-    let urlPartList, tab;
+    let urlPartList; let tab;
     const urlBase = `${siteRoot}sys/`;
     for (let i = 0, len = pageList.length; i < len; i++) {
       urlPartList = pageList[i].urlPartList;
       tab = pageList[i].tab;
-      for (let j = 0, jlen = urlPartList.length; j < jlen; j++) {
+      for (let j = 0, len = urlPartList.length; j < len; j++) {
         if (location.href.indexOf(`${urlBase}${urlPartList[j]}`) != -1) {
           return tab;
         }
@@ -186,11 +183,11 @@ class SysAdmin extends React.Component {
   };
 
   onCloseSidePanel = () => {
-    this.setState({isSidePanelClosed: !this.state.isSidePanelClosed});
+    this.setState({ isSidePanelClosed: !this.state.isSidePanelClosed });
   };
 
   tabItemClick = (param) => {
-    this.setState({currentTab: param});
+    this.setState({ currentTab: param });
     if (!Utils.isDesktop() && !this.state.isSidePanelClosed) {
       this.setState({ isSidePanelClosed: true });
     }
@@ -209,7 +206,7 @@ class SysAdmin extends React.Component {
     };
 
     return (
-      <div id="main">
+      <div id="main" className="sys-admin">
         <SidePanel
           isSidePanelClosed={isSidePanelClosed}
           onCloseSidePanel={this.onCloseSidePanel}
@@ -228,6 +225,7 @@ class SysAdmin extends React.Component {
             <MobileDevices path={siteRoot + 'sys/mobile-devices'} {...commonProps} />
             <DeviceErrors path={siteRoot + 'sys/device-errors'} {...commonProps} />
             <AllRepos path={siteRoot + 'sys/all-libraries'} {...commonProps} />
+            <AllWikis path={siteRoot + 'sys/all-wikis'} {...commonProps} />
             <SystemRepo path={siteRoot + 'sys/system-library'} {...commonProps} />
             <TrashRepos path={siteRoot + 'sys/trash-libraries'} {...commonProps} />
             <SearchRepos path={siteRoot + 'sys/search-libraries'} {...commonProps} />
@@ -238,12 +236,7 @@ class SysAdmin extends React.Component {
             <SearchGroups path={siteRoot + 'sys/search-groups'} {...commonProps} />
             <GroupRepos path={siteRoot + 'sys/groups/:groupID/libraries'} {...commonProps} />
             <GroupMembers path={siteRoot + 'sys/groups/:groupID/members'} {...commonProps} />
-            <Departments path={siteRoot + 'sys/departments'}>
-              <DepartmentList path='/' {...commonProps} />
-              <SubDepartments path='/:groupID' {...commonProps} />
-              <DepartmentMembers path='/:groupID/members' {...commonProps} />
-              <DepartmentLibraries path='/:groupID/libraries' {...commonProps} />
-            </Departments>
+            <Departments path={siteRoot + 'sys/departments/'} {...commonProps} />
             <ShareLinks path={siteRoot + 'sys/share-links'} {...commonProps} />
             <UploadLinks path={siteRoot + 'sys/upload-links'} {...commonProps} />
             <Orgs path={siteRoot + 'sys/organizations'} {...commonProps} />
