@@ -1,7 +1,7 @@
 import React, { Component, Fragment } from 'react';
 import PropTypes from 'prop-types';
 import { Utils } from '../../../utils/utils';
-import { seafileAPI } from '../../../utils/seafile-api';
+import { systemAdminAPI } from '../../../utils/system-admin-api';
 import { gettext } from '../../../utils/constants';
 import toaster from '../../../components/toast';
 import Loading from '../../../components/loading';
@@ -19,14 +19,14 @@ class Content extends Component {
   }
 
   toggleSetQuotaDialog = () => {
-    this.setState({isSetQuotaDialogOpen: !this.state.isSetQuotaDialogOpen});
+    this.setState({ isSetQuotaDialogOpen: !this.state.isSetQuotaDialogOpen });
   };
 
   showEditIcon = (action) => {
     return (
       <span
         title={gettext('Edit')}
-        className="fa fa-pencil-alt attr-action-icon"
+        className="sf3-font sf3-font-rename attr-action-icon"
         onClick={action}>
       </span>
     );
@@ -96,8 +96,8 @@ class InstitutionInfo extends Component {
     };
   }
 
-  componentDidMount () {
-    seafileAPI.sysAdminGetInstitution(this.props.institutionID).then((res) => {
+  componentDidMount() {
+    systemAdminAPI.sysAdminGetInstitution(this.props.institutionID).then((res) => {
       this.setState({
         loading: false,
         institutionInfo: res.data
@@ -111,11 +111,11 @@ class InstitutionInfo extends Component {
   }
 
   updateQuota = (quota) => {
-    seafileAPI.sysAdminUpdateInstitution(this.props.institutionID, quota).then(res => {
+    systemAdminAPI.sysAdminUpdateInstitution(this.props.institutionID, quota).then(res => {
       const newInstitutionInfo = Object.assign(this.state.institutionInfo, {
         quota_total: res.data.quota_total,
       });
-      this.setState({institutionInfo: newInstitutionInfo});
+      this.setState({ institutionInfo: newInstitutionInfo });
       toaster.success(gettext('Successfully set quota.'));
     }).catch((error) => {
       let errMessage = Utils.getErrorMsg(error);
