@@ -2,9 +2,10 @@ import React, { Component, Fragment } from 'react';
 import PropTypes from 'prop-types';
 import { Link } from '@gatsbyjs/reach-router';
 import { Button } from 'reactstrap';
-import moment from 'moment';
+import dayjs from 'dayjs';
+import relativeTime from 'dayjs/plugin/relativeTime';
 import { Utils } from '../../../utils/utils';
-import { seafileAPI } from '../../../utils/seafile-api';
+import { systemAdminAPI } from '../../../utils/system-admin-api';
 import { siteRoot, gettext } from '../../../utils/constants';
 import toaster from '../../../components/toast';
 import EmptyTip from '../../../components/empty-tip';
@@ -14,6 +15,8 @@ import MainPanelTopbar from '../main-panel-topbar';
 import SysAdminAddInstitutionDialog from '../../../components/dialog/sysadmin-dialog/sysadmin-add-institution-dialog';
 import Paginator from '../../../components/paginator';
 
+dayjs.extend(relativeTime);
+
 class Content extends Component {
 
   constructor(props) {
@@ -36,8 +39,7 @@ class Content extends Component {
       return <p className="error text-center mt-4">{errorMsg}</p>;
     } else {
       const emptyTip = (
-        <EmptyTip>
-          <h2>{gettext('No institutions')}</h2>
+        <EmptyTip text={gettext('No institutions')}>
         </EmptyTip>
       );
       const table = (
@@ -101,18 +103,18 @@ class Item extends Component {
   }
 
   handleMouseEnter = () => {
-    this.setState({isOpIconShown: true});
+    this.setState({ isOpIconShown: true });
   };
 
   handleMouseLeave = () => {
-    this.setState({isOpIconShown: false});
+    this.setState({ isOpIconShown: false });
   };
 
   toggleDeleteDialog = (e) => {
     if (e) {
       e.preventDefault();
     }
-    this.setState({isDeleteDialogOpen: !this.state.isDeleteDialogOpen});
+    this.setState({ isDeleteDialogOpen: !this.state.isDeleteDialogOpen });
   };
 
   deleteInstitution = () => {
@@ -130,9 +132,9 @@ class Item extends Component {
       <Fragment>
         <tr onMouseEnter={this.handleMouseEnter} onMouseLeave={this.handleMouseLeave}>
           <td><Link to={`${siteRoot}sys/institutions/${item.id}/info/`}>{item.name}</Link></td>
-          <td>{moment(item.ctime).fromNow()}</td>
+          <td>{dayjs(item.ctime).fromNow()}</td>
           <td>
-            <a href="#" className={`action-icon sf2-icon-delete ${isOpIconShown ? '' : 'invisible'}`} title={gettext('Delete')} onClick={this.toggleDeleteDialog}></a>
+            <a href="#" className={`action-icon sf3-font-delete1 sf3-font ${isOpIconShown ? '' : 'invisible'}`} title={gettext('Delete')} onClick={this.toggleDeleteDialog}></a>
           </td>
         </tr>
         {isDeleteDialogOpen &&
@@ -162,7 +164,7 @@ class Institutions extends Component {
       loading: true,
       errorMsg: '',
       institutionList: [],
-      perPage: 25,
+      perPage: 100,
       currentPage: 1,
       hasNextPage: false,
       isAddInstitutionDialogOpen: false,
@@ -170,7 +172,7 @@ class Institutions extends Component {
     this.initPage = 1;
   }
 
-  componentDidMount () {
+  componentDidMount() {
     let urlParams = (new URL(window.location)).searchParams;
     const { currentPage, perPage } = this.state;
     this.setState({
@@ -183,7 +185,7 @@ class Institutions extends Component {
 
   getInstitutionsByPage = (page) => {
     let { perPage } = this.state;
-    seafileAPI.sysAdminListInstitutions(page, perPage).then((res) => {
+    systemAdminAPI.sysAdminListInstitutions(page, perPage).then((res) => {
       this.setState({
         loading: false,
         institutionList: res.data.institution_list,
@@ -205,14 +207,14 @@ class Institutions extends Component {
   };
 
   toggleAddInstitutionDialog = () => {
-    this.setState({isAddInstitutionDialogOpen: !this.state.isAddInstitutionDialogOpen});
+    this.setState({ isAddInstitutionDialogOpen: !this.state.isAddInstitutionDialogOpen });
   };
 
   addInstitution = (name) => {
-    seafileAPI.sysAdminAddInstitution(name).then(res => {
+    systemAdminAPI.sysAdminAddInstitution(name).then(res => {
       let institutionList = this.state.institutionList;
       institutionList.push(res.data);
-      this.setState({institutionList: institutionList});
+      this.setState({ institutionList: institutionList });
     }).catch((error) => {
       let errMessage = Utils.getErrorMsg(error);
       toaster.danger(errMessage);
@@ -220,11 +222,11 @@ class Institutions extends Component {
   };
 
   deleteInstitution = (institutionID) => {
-    seafileAPI.sysAdminDeleteInstitution(institutionID).then(res => {
+    systemAdminAPI.sysAdminDeleteInstitution(institutionID).then(res => {
       let institutionList = this.state.institutionList.filter(inst => {
         return inst.id != institutionID;
       });
-      this.setState({institutionList: institutionList});
+      this.setState({ institutionList: institutionList });
       toaster.success(gettext('Successfully deleted 1 item.'));
     }).catch((error) => {
       let errMessage = Utils.getErrorMsg(error);
