@@ -1,9 +1,10 @@
 import React, { Component, Fragment } from 'react';
 import PropTypes from 'prop-types';
 import { Button } from 'reactstrap';
-import moment from 'moment';
+import dayjs from 'dayjs';
+import relativeTime from 'dayjs/plugin/relativeTime';
 import { Utils } from '../../../utils/utils';
-import { seafileAPI } from '../../../utils/seafile-api';
+import { systemAdminAPI } from '../../../utils/system-admin-api';
 import { gettext } from '../../../utils/constants';
 import toaster from '../../../components/toast';
 import EmptyTip from '../../../components/empty-tip';
@@ -13,6 +14,8 @@ import OpMenu from '../../../components/dialog/op-menu';
 import MainPanelTopbar from '../main-panel-topbar';
 import UserLink from '../user-link';
 
+dayjs.extend(relativeTime);
+
 class Content extends Component {
 
   constructor(props) {
@@ -23,11 +26,11 @@ class Content extends Component {
   }
 
   onFreezedItem = () => {
-    this.setState({isItemFreezed: true});
+    this.setState({ isItemFreezed: true });
   };
 
   onUnfreezedItem = () => {
-    this.setState({isItemFreezed: false});
+    this.setState({ isItemFreezed: false });
   };
 
   getPreviousPage = () => {
@@ -46,8 +49,7 @@ class Content extends Component {
       return <p className="error text-center mt-4">{errorMsg}</p>;
     } else {
       const emptyTip = (
-        <EmptyTip>
-          <h2>{gettext('No invitations')}</h2>
+        <EmptyTip text={gettext('No invitations')}>
         </EmptyTip>
       );
 
@@ -160,7 +162,7 @@ class Item extends Component {
   };
 
   onMenuItemClick = (operation) => {
-    switch(operation) {
+    switch (operation) {
       case 'Delete':
         this.deleteItem();
         break;
@@ -208,18 +210,18 @@ class Item extends Component {
           </td>
           <td>{this.getInviteTypeText()}</td>
           <td>
-            <span title={moment(item.invite_time).format('llll')}>{moment(item.invite_time).fromNow()}</span>
+            <span title={dayjs(item.invite_time).format('dddd, MMMM D, YYYY h:mm:ss A')}>{dayjs(item.invite_time).fromNow()}</span>
           </td>
           <td>
             {item.accept_time ?
-              <span title={moment(item.accept_time).format('llll')}>{moment(item.accept_time).fromNow()}</span> :
+              <span title={dayjs(item.accept_time).format('dddd, MMMM D, YYYY h:mm:ss A')}>{dayjs(item.accept_time).fromNow()}</span> :
               '--'
             }
           </td>
           <td>
             {item.is_expired ?
-              <span className="text-red">{moment(item.expire_time).format('YYYY-MM-DD HH:mm')}</span> :
-              moment(item.expire_time).format('YYYY-MM-DD HH:mm')
+              <span className="text-red">{dayjs(item.expire_time).format('YYYY-MM-DD HH:mm')}</span> :
+              dayjs(item.expire_time).format('YYYY-MM-DD HH:mm')
             }
           </td>
           <td>
@@ -258,11 +260,11 @@ class Invitations extends Component {
       totalItemCount: 0,
       hasNextPage: false,
       currentPage: 1,
-      perPage: 25
+      perPage: 100
     };
   }
 
-  componentDidMount () {
+  componentDidMount() {
     let urlParams = (new URL(window.location)).searchParams;
     const { currentPage, perPage } = this.state;
     this.setState({
@@ -275,7 +277,7 @@ class Invitations extends Component {
 
   getItemsByPage = (page) => {
     let { perPage } = this.state;
-    seafileAPI.sysAdminListInvitations(page, perPage).then(res => {
+    systemAdminAPI.sysAdminListInvitations(page, perPage).then(res => {
       this.setState({
         loading: false,
         items: res.data.invitation_list,
@@ -292,11 +294,11 @@ class Invitations extends Component {
 
   deleteItem = (targetItem) => {
     const token = targetItem.token;
-    seafileAPI.sysAdminDeleteInvitation(token).then(res => {
+    systemAdminAPI.sysAdminDeleteInvitation(token).then(res => {
       let items = this.state.items.filter(item => {
         return item.token != token;
       });
-      this.setState({items: items});
+      this.setState({ items: items });
       toaster.success(gettext('Successfully deleted 1 item.'));
     }).catch((error) => {
       let errMessage = Utils.getErrorMsg(error);
@@ -305,7 +307,7 @@ class Invitations extends Component {
   };
 
   deleteItemInBatch = () => {
-    seafileAPI.sysAdminDeleteExpiredInvitations().then(res => {
+    systemAdminAPI.sysAdminDeleteExpiredInvitations().then(res => {
       const prevItems = this.state.items;
       const items = this.state.items.filter(item => !item.is_expired || item.accept_time);
       if (items.length < prevItems.length) {
