@@ -1,18 +1,21 @@
 import React, { Component, Fragment } from 'react';
 import PropTypes from 'prop-types';
 import { navigate } from '@gatsbyjs/reach-router';
-import { seafileAPI } from '../../../utils/seafile-api';
+import dayjs from 'dayjs';
+import relativeTime from 'dayjs/plugin/relativeTime';
+import { systemAdminAPI } from '../../../utils/system-admin-api';
 import { gettext } from '../../../utils/constants';
 import toaster from '../../../components/toast';
 import { Utils } from '../../../utils/utils';
 import EmptyTip from '../../../components/empty-tip';
-import moment from 'moment';
 import Loading from '../../../components/loading';
 import Paginator from '../../../components/paginator';
 import LinksNav from './links-nav';
 import MainPanelTopbar from '../main-panel-topbar';
 import UserLink from '../user-link';
 
+dayjs.extend(relativeTime);
+
 class Content extends Component {
 
   constructor(props) {
@@ -49,13 +52,12 @@ class Content extends Component {
       return <p className="error text-center">{errorMsg}</p>;
     } else {
       const emptyTip = (
-        <EmptyTip>
-          <h2>{gettext('No share links')}</h2>
+        <EmptyTip text={gettext('No share links')}>
         </EmptyTip>
       );
 
-      const initialSortIcon = <span className="fas fa-sort"></span>;
-      const sortIcon = <span className={`fas ${sortOrder == 'asc' ? 'fa-caret-up' : 'fa-caret-down'}`}></span>;
+      const initialSortIcon = <span className="sf3-font sf3-font-sort3"></span>;
+      const sortIcon = <span className={`sf3-font ${sortOrder == 'asc' ? 'sf3-font-down rotate-180 d-inline-block' : 'sf3-font-down'}`}></span>;
       const table = (
         <Fragment>
           <table className="table-hover">
@@ -68,10 +70,10 @@ class Content extends Component {
                   <a className="d-inline-block table-sort-op" href="#" onClick={this.sortByTime}>{gettext('Created At')} {sortBy == 'ctime' ? sortIcon : initialSortIcon}</a>
                 </th>
                 <th width="10%">
-                  <a className="d-inline-block table-sort-op" href="#" onClick={this.sortByCount}>{gettext('Count')} {sortBy == 'view_cnt' ? sortIcon : initialSortIcon}</a>
+                  <a className="d-inline-block table-sort-op" href="#" onClick={this.sortByCount}>{gettext('Visit count')} {sortBy == 'view_cnt' ? sortIcon : initialSortIcon}</a>
                 </th>
                 <th width="11%">{gettext('Expiration')}</th>
-                <th width="10%">{/*Operations*/}</th>
+                <th width="10%">{/* Operations*/}</th>
               </tr>
             </thead>
             {items &&
@@ -148,21 +150,21 @@ class Item extends Component {
     if (!item.expire_date) {
       return '--';
     }
-    const expire_date = moment(item.expire_date).format('YYYY-MM-DD');
-    const expire_time = moment(item.expire_date).format('YYYY-MM-DD HH:mm:ss');
+    const expire_date = dayjs(item.expire_date).format('YYYY-MM-DD');
+    const expire_time = dayjs(item.expire_date).format('YYYY-MM-DD HH:mm:ss');
     return (<span className={item.is_expired ? 'error' : ''} title={expire_time}>{expire_date}</span>);
   };
 
   render() {
     let { isOpIconShown } = this.state;
     let { item } = this.props;
-    let deleteIcon = `action-icon sf2-icon-delete ${isOpIconShown ? '' : 'invisible'}`;
+    let deleteIcon = `action-icon sf3-font-delete1 sf3-font ${isOpIconShown ? '' : 'invisible'}`;
     return (
       <tr onMouseOver={this.handleMouseOver} onMouseOut={this.handleMouseOut}>
         <td>{item.obj_name}</td>
         <td>{item.token}</td>
         <td><UserLink email={item.creator_email} name={item.creator_name} /></td>
-        <td>{moment(item.ctime).fromNow()}</td>
+        <td>{dayjs(item.ctime).fromNow()}</td>
         <td>{item.view_cnt}</td>
         <td>{this.renderExpiration()}</td>
         <td>
@@ -187,7 +189,7 @@ class ShareLinks extends Component {
       loading: true,
       errorMsg: '',
       shareLinkList: [],
-      perPage: 25,
+      perPage: 100,
       currentPage: 1,
       hasNextPage: false,
       sortBy: '',
@@ -196,7 +198,7 @@ class ShareLinks extends Component {
     this.initPage = 1;
   }
 
-  componentDidMount () {
+  componentDidMount() {
     let urlParams = (new URL(window.location)).searchParams;
     const { currentPage, perPage, sortBy, sortOrder } = this.state;
     this.setState({
@@ -211,7 +213,7 @@ class ShareLinks extends Component {
 
   getShareLinksByPage = (page) => {
     const { perPage, sortBy, sortOrder } = this.state;
-    seafileAPI.sysAdminListShareLinks(page, perPage, sortBy, sortOrder).then((res) => {
+    systemAdminAPI.sysAdminListShareLinks(page, perPage, sortBy, sortOrder).then((res) => {
       this.setState({
         shareLinkList: res.data.share_link_list,
         loading: false,
@@ -245,11 +247,11 @@ class ShareLinks extends Component {
   };
 
   deleteShareLink = (linkToken) => {
-    seafileAPI.sysAdminDeleteShareLink(linkToken).then(res => {
+    systemAdminAPI.sysAdminDeleteShareLink(linkToken).then(res => {
       let newShareLinkList = this.state.shareLinkList.filter(item =>
         item.token != linkToken
       );
-      this.setState({shareLinkList: newShareLinkList});
+      this.setState({ shareLinkList: newShareLinkList });
     }).catch(error => {
       let errMessage = Utils.getErrorMsg(error);
       toaster.danger(errMessage);
