@@ -1,17 +1,19 @@
 import React, { Component, Fragment } from 'react';
 import PropTypes from 'prop-types';
-import { seafileAPI } from '../../../utils/seafile-api';
+import dayjs from 'dayjs';
+import relativeTime from 'dayjs/plugin/relativeTime';
+import { systemAdminAPI } from '../../../utils/system-admin-api';
 import { gettext } from '../../../utils/constants';
 import toaster from '../../../components/toast';
 import { Utils } from '../../../utils/utils';
 import EmptyTip from '../../../components/empty-tip';
-import moment from 'moment';
 import Loading from '../../../components/loading';
 import Paginator from '../../../components/paginator';
 import LinksNav from './links-nav';
 import MainPanelTopbar from '../main-panel-topbar';
 import UserLink from '../user-link';
 
+dayjs.extend(relativeTime);
 
 class Content extends Component {
 
@@ -35,8 +37,7 @@ class Content extends Component {
       return <p className="error text-center">{errorMsg}</p>;
     } else {
       const emptyTip = (
-        <EmptyTip>
-          <h2>{gettext('No upload links')}</h2>
+        <EmptyTip text={gettext('No upload links')}>
         </EmptyTip>
       );
       const table = (
@@ -48,9 +49,9 @@ class Content extends Component {
                 <th width="18%">{gettext('Token')}</th>
                 <th width="18%">{gettext('Owner')}</th>
                 <th width="15%">{gettext('Created At')}</th>
-                <th width="10%">{gettext('Count')}</th>
+                <th width="10%">{gettext('Visit count')}</th>
                 <th width="11%">{gettext('Expiration')}</th>
-                <th width="10%">{/*Operations*/}</th>
+                <th width="10%">{/* Operations*/}</th>
               </tr>
             </thead>
             {items &&
@@ -125,22 +126,22 @@ class Item extends Component {
     if (!item.expire_date) {
       return '--';
     }
-    const expire_date = moment(item.expire_date).format('YYYY-MM-DD');
-    const expire_time = moment(item.expire_date).format('YYYY-MM-DD HH:mm:ss');
+    const expire_date = dayjs(item.expire_date).format('YYYY-MM-DD');
+    const expire_time = dayjs(item.expire_date).format('YYYY-MM-DD HH:mm:ss');
     return (<span className={item.is_expired ? 'error' : ''} title={expire_time}>{expire_date}</span>);
   };
 
   render() {
     let { isOpIconShown } = this.state;
     let { item } = this.props;
-    let deleteIcon = `action-icon sf2-icon-delete ${isOpIconShown ? '' : 'invisible'}`;
+    let deleteIcon = `action-icon sf3-font-delete1 sf3-font ${isOpIconShown ? '' : 'invisible'}`;
     return (
       <Fragment>
         <tr onMouseOver={this.handleMouseOver} onMouseOut={this.handleMouseOut}>
           <td>{item.path}</td>
           <td>{item.token}</td>
           <td><UserLink email={item.creator_email} name={item.creator_name} /></td>
-          <td>{moment(item.ctime).fromNow()}</td>
+          <td>{dayjs(item.ctime).fromNow()}</td>
           <td>{item.view_cnt}</td>
           <td>{this.renderExpiration()}</td>
           <td>
@@ -167,7 +168,7 @@ class UploadLinks extends Component {
       loading: true,
       errorMsg: '',
       uploadLinkList: [],
-      perPage: 25,
+      perPage: 100,
       currentPage: 1,
       hasNextPage: false,
     };
@@ -187,7 +188,7 @@ class UploadLinks extends Component {
 
   getUploadLinksByPage = (page) => {
     let { perPage } = this.state;
-    seafileAPI.sysAdminListAllUploadLinks(page, perPage).then((res) => {
+    systemAdminAPI.sysAdminListAllUploadLinks(page, perPage).then((res) => {
       this.setState({
         uploadLinkList: res.data.upload_link_list,
         loading: false,
@@ -203,11 +204,11 @@ class UploadLinks extends Component {
   };
 
   deleteUploadLink = (linkToken) => {
-    seafileAPI.sysAdminDeleteUploadLink(linkToken).then(res => {
+    systemAdminAPI.sysAdminDeleteUploadLink(linkToken).then(res => {
       let newUploadLinkList = this.state.uploadLinkList.filter(item =>
         item.token != linkToken
       );
-      this.setState({uploadLinkList: newUploadLinkList});
+      this.setState({ uploadLinkList: newUploadLinkList });
     }).catch(error => {
       let errMessage = Utils.getErrorMsg(error);
       toaster.danger(errMessage);
