@@ -1,20 +1,23 @@
 import React, { Component, Fragment } from 'react';
 import PropTypes from 'prop-types';
-import { seafileAPI } from '../../../utils/seafile-api';
+import dayjs from 'dayjs';
+import relativeTime from 'dayjs/plugin/relativeTime';
+import { Button } from 'reactstrap';
+import { systemAdminAPI } from '../../../utils/system-admin-api';
 import { gettext } from '../../../utils/constants';
 import { Utils } from '../../../utils/utils';
 import EmptyTip from '../../../components/empty-tip';
-import moment from 'moment';
 import Loading from '../../../components/loading';
 import Paginator from '../../../components/paginator';
 import LogsNav from './logs-nav';
-import { Button } from 'reactstrap';
 import MainPanelTopbar from '../main-panel-topbar';
 import UserLink from '../user-link';
 import ModalPortal from '../../../components/modal-portal';
 import CommitDetails from '../../../components/dialog/commit-details';
 import LogsExportExcelDialog from '../../../components/dialog/sysadmin-dialog/sysadmin-logs-export-excel-dialog';
 
+dayjs.extend(relativeTime);
+
 class Content extends Component {
 
   getPreviousPage = () => {
@@ -33,8 +36,7 @@ class Content extends Component {
       return <p className="error text-center">{errorMsg}</p>;
     } else {
       const emptyTip = (
-        <EmptyTip>
-          <h2>{gettext('No file update logs')}</h2>
+        <EmptyTip text={gettext('No file update logs')}>
         </EmptyTip>
       );
       const table = (
@@ -129,7 +131,7 @@ class Item extends Component {
       <Fragment>
         <tr onMouseOver={this.handleMouseOver} onMouseOut={this.handleMouseOut}>
           <td><UserLink email={item.email} name={item.name} /></td>
-          <td>{moment(item.time).fromNow()}</td>
+          <td>{dayjs(item.time).fromNow()}</td>
           <td>{item.repo_name ? item.repo_name : gettext('Deleted')}</td>
           <td>
             {item.file_operation}
@@ -167,7 +169,7 @@ class FileUpdateLogs extends Component {
       loading: true,
       errorMsg: '',
       logList: [],
-      perPage: 25,
+      perPage: 100,
       currentPage: 1,
       hasNextPage: false,
       isExportExcelDialogOpen: false,
@@ -176,10 +178,10 @@ class FileUpdateLogs extends Component {
   }
 
   toggleExportExcelDialog = () => {
-    this.setState({isExportExcelDialogOpen: !this.state.isExportExcelDialogOpen});
+    this.setState({ isExportExcelDialogOpen: !this.state.isExportExcelDialogOpen });
   };
 
-  componentDidMount () {
+  componentDidMount() {
     let urlParams = (new URL(window.location)).searchParams;
     const { currentPage, perPage } = this.state;
     this.setState({
@@ -192,7 +194,7 @@ class FileUpdateLogs extends Component {
 
   getLogsByPage = (page) => {
     let { perPage } = this.state;
-    seafileAPI.sysAdminListFileUpdateLogs(page, perPage).then((res) => {
+    systemAdminAPI.sysAdminListFileUpdateLogs(page, perPage).then((res) => {
       this.setState({
         logList: res.data.file_update_log_list,
         loading: false,
