@@ -1,11 +1,12 @@
 import React, { Component, Fragment } from 'react';
 import PropTypes from 'prop-types';
-import { seafileAPI } from '../../../utils/seafile-api';
+import dayjs from 'dayjs';
+import relativeTime from 'dayjs/plugin/relativeTime';
+import { systemAdminAPI } from '../../../utils/system-admin-api';
 import { gettext } from '../../../utils/constants';
 import { Utils } from '../../../utils/utils';
 import { Button } from 'reactstrap';
 import EmptyTip from '../../../components/empty-tip';
-import moment from 'moment';
 import Loading from '../../../components/loading';
 import Paginator from '../../../components/paginator';
 import LogsNav from './logs-nav';
@@ -14,6 +15,7 @@ import UserLink from '../user-link';
 import LogsExportExcelDialog from '../../../components/dialog/sysadmin-dialog/sysadmin-logs-export-excel-dialog';
 import ModalPortal from '../../../components/modal-portal';
 
+dayjs.extend(relativeTime);
 
 class Content extends Component {
 
@@ -33,8 +35,7 @@ class Content extends Component {
       return <p className="error text-center">{errorMsg}</p>;
     } else {
       const emptyTip = (
-        <EmptyTip>
-          <h2>{gettext('No login logs')}</h2>
+        <EmptyTip text={gettext('No login logs')}>
         </EmptyTip>
       );
       const table = (
@@ -115,7 +116,7 @@ class Item extends Component {
         <td><UserLink email={item.email} name={item.name} /></td>
         <td>{item.login_ip}</td>
         <td>{item.log_success ? gettext('Success') : gettext('Failed')}</td>
-        <td>{moment(item.login_time).fromNow()}</td>
+        <td>{dayjs(item.login_time).fromNow()}</td>
       </tr>
     );
   }
@@ -133,7 +134,7 @@ class LoginLogs extends Component {
       loading: true,
       errorMsg: '',
       logList: [],
-      perPage: 25,
+      perPage: 100,
       currentPage: 1,
       hasNextPage: false,
       isExportExcelDialogOpen: false,
@@ -142,10 +143,10 @@ class LoginLogs extends Component {
   }
 
   toggleExportExcelDialog = () => {
-    this.setState({isExportExcelDialogOpen: !this.state.isExportExcelDialogOpen});
+    this.setState({ isExportExcelDialogOpen: !this.state.isExportExcelDialogOpen });
   };
 
-  componentDidMount () {
+  componentDidMount() {
     let urlParams = (new URL(window.location)).searchParams;
     const { currentPage, perPage } = this.state;
     this.setState({
@@ -158,7 +159,7 @@ class LoginLogs extends Component {
 
   getLogsByPage = (page) => {
     let { perPage } = this.state;
-    seafileAPI.sysAdminListLoginLogs(page, perPage).then((res) => {
+    systemAdminAPI.sysAdminListLoginLogs(page, perPage).then((res) => {
       this.setState({
         logList: res.data.login_log_list,
         loading: false,
