@@ -1,9 +1,10 @@
 import React, { Component, Fragment } from 'react';
 import PropTypes from 'prop-types';
 import { Link } from '@gatsbyjs/reach-router';
-import moment from 'moment';
+import dayjs from 'dayjs';
+import relativeTime from 'dayjs/plugin/relativeTime';
 import { Button } from 'reactstrap';
-import { seafileAPI } from '../../../utils/seafile-api';
+import { systemAdminAPI } from '../../../utils/system-admin-api';
 import { gettext, siteRoot } from '../../../utils/constants';
 import { Utils } from '../../../utils/utils';
 import LogsExportExcelDialog from '../../../components/dialog/sysadmin-dialog/sysadmin-logs-export-excel-dialog';
@@ -15,6 +16,8 @@ import MainPanelTopbar from '../main-panel-topbar';
 import UserLink from '../user-link';
 import LogsNav from './logs-nav';
 
+dayjs.extend(relativeTime);
+
 class Content extends Component {
 
   getPreviousPage = () => {
@@ -33,8 +36,7 @@ class Content extends Component {
       return <p className="error text-center">{errorMsg}</p>;
     } else {
       const emptyTip = (
-        <EmptyTip>
-          <h2>{gettext('No permission logs')}</h2>
+        <EmptyTip text={gettext('No permission logs')}>
         </EmptyTip>
       );
       const table = (
@@ -91,25 +93,6 @@ Content.propTypes = {
 
 class Item extends Component {
 
-  constructor(props) {
-    super(props);
-    this.state = {
-      isOpIconShown: false,
-    };
-  }
-
-  handleMouseOver = () => {
-    this.setState({
-      isOpIconShown: true
-    });
-  };
-
-  handleMouseOut = () => {
-    this.setState({
-      isOpIconShown: false
-    });
-  };
-
   getActionTextByEType = (etype) => {
     if (etype.indexOf('add') != -1) {
       return gettext('Add');
@@ -123,13 +106,12 @@ class Item extends Component {
   };
 
   getShareTo = (item) => {
-    switch(item.share_type) {
+    switch (item.share_type) {
       case 'user':
         return <UserLink email={item.to_user_email} name={item.to_user_name} />;
       case 'group':
-        return <Link to={`${siteRoot}sys/groups/${item.to_group_id}/libraries/`}>{item.to_group_name}</Link>;
       case 'department':
-        return <Link to={`${siteRoot}sys/departments/${item.to_group_id}/`}>{item.to_group_name}</Link>;
+        return <Link to={`${siteRoot}sys/groups/${item.to_group_id}/libraries/`}>{item.to_group_name}</Link>;
       case 'all':
         return <Link to={`${siteRoot}org/`}>{gettext('All')}</Link>;
       default:
@@ -140,14 +122,14 @@ class Item extends Component {
   render() {
     let { item } = this.props;
     return (
-      <tr onMouseOver={this.handleMouseOver} onMouseOut={this.handleMouseOut}>
+      <tr>
         <td><UserLink email={item.from_user_email} name={item.from_user_name} /></td>
         <td>{this.getShareTo(item)}</td>
         <td>{this.getActionTextByEType(item.etype)}</td>
         <td>{Utils.sharePerms(item.permission)}</td>
         <td>{item.repo_name ? item.repo_name : gettext('Deleted')}</td>
         <td>{item.folder}</td>
-        <td>{moment(item.date).fromNow()}</td>
+        <td>{dayjs(item.date).fromNow()}</td>
       </tr>
     );
   }
@@ -165,7 +147,7 @@ class SharePermissionLogs extends Component {
       loading: true,
       errorMsg: '',
       logList: [],
-      perPage: 25,
+      perPage: 100,
       currentPage: 1,
       hasNextPage: false,
       isExportExcelDialogOpen: false,
@@ -174,10 +156,10 @@ class SharePermissionLogs extends Component {
   }
 
   toggleExportExcelDialog = () => {
-    this.setState({isExportExcelDialogOpen: !this.state.isExportExcelDialogOpen});
+    this.setState({ isExportExcelDialogOpen: !this.state.isExportExcelDialogOpen });
   };
 
-  componentDidMount () {
+  componentDidMount() {
     let urlParams = (new URL(window.location)).searchParams;
     const { currentPage, perPage } = this.state;
     this.setState({
@@ -190,7 +172,7 @@ class SharePermissionLogs extends Component {
 
   getLogsByPage = (page) => {
     let { perPage } = this.state;
-    seafileAPI.sysAdminListSharePermissionLogs(page, perPage).then((res) => {
+    systemAdminAPI.sysAdminListSharePermissionLogs(page, perPage).then((res) => {
       this.setState({
         logList: res.data.share_permission_log_list,
         loading: false,
