@@ -2,7 +2,7 @@ import React, { Component, Fragment } from 'react';
 import PropTypes from 'prop-types';
 import { Row, Col } from 'reactstrap';
 import { Utils } from '../../../utils/utils';
-import { seafileAPI } from '../../../utils/seafile-api';
+import { systemAdminAPI } from '../../../utils/system-admin-api';
 import { gettext, serviceURL } from '../../../utils/constants';
 import toaster from '../../../components/toast';
 import Loading from '../../../components/loading';
@@ -24,22 +24,22 @@ class Content extends Component {
   }
 
   toggleSetQuotaDialog = () => {
-    this.setState({isSetQuotaDialogOpen: !this.state.isSetQuotaDialogOpen});
+    this.setState({ isSetQuotaDialogOpen: !this.state.isSetQuotaDialogOpen });
   };
 
   toggleSetNameDialog = () => {
-    this.setState({isSetNameDialogOpen: !this.state.isSetNameDialogOpen});
+    this.setState({ isSetNameDialogOpen: !this.state.isSetNameDialogOpen });
   };
 
   toggleSetMaxUserNumberDialog = () => {
-    this.setState({isSetMaxUserNumberDialogOpen: !this.state.isSetMaxUserNumberDialogOpen});
+    this.setState({ isSetMaxUserNumberDialogOpen: !this.state.isSetMaxUserNumberDialogOpen });
   };
 
   showEditIcon = (action) => {
     return (
       <span
         title={gettext('Edit')}
-        className="fa fa-pencil-alt attr-action-icon"
+        className="sf3-font sf3-font-rename attr-action-icon"
         onClick={action}>
       </span>
     );
@@ -52,7 +52,7 @@ class Content extends Component {
     } else if (errorMsg) {
       return <p className="error text-center">{errorMsg}</p>;
     } else {
-      const { org_name, users_count, max_user_number, groups_count, quota, quota_usage, enable_saml_login, url_prefix, metadata_url, domain } = this.props.orgInfo;
+      const { org_name, users_count, max_user_number, groups_count, quota, quota_usage, enable_saml_login, metadata_url, domain } = this.props.orgInfo;
       const { isSetQuotaDialogOpen, isSetNameDialogOpen, isSetMaxUserNumberDialogOpen } = this.state;
       return (
         <Fragment>
@@ -89,19 +89,25 @@ class Content extends Component {
                 <dt className="info-item-heading">{gettext('SAML Config')}</dt>
                 <dd className="info-item-content">
                   <Row className="my-4">
-                    <Col md="3">{gettext('Custom SAML Login URL')}</Col>
-                    <Col md="6">{`${serviceURL}/org/custom/${url_prefix}`}</Col>
+                    <Col md="4">Identifier (Entity ID)</Col>
+                    <Col md="6">{`${serviceURL}/org/custom/${this.props.orgID}/saml2/metadata/`}</Col>
                   </Row>
                 </dd>
                 <dd className="info-item-content">
                   <Row className="my-4">
-                    <Col md="3">{gettext('App Federation Metadata URL')}</Col>
+                    <Col md="4">Reply URL (Assertion Consumer Service URL)</Col>
+                    <Col md="6">{`${serviceURL}/org/custom/${this.props.orgID}/saml2/acs/`}</Col>
+                  </Row>
+                </dd>
+                <dd className="info-item-content">
+                  <Row className="my-4">
+                    <Col md="4">SAML App Federation Metadata URL</Col>
                     <Col md="6">{metadata_url}</Col>
                   </Row>
                 </dd>
                 <dd className="info-item-content">
                   <Row className="my-4">
-                    <Col md="3">{gettext('Email Domain')}</Col>
+                    <Col md="4">{gettext('Email Domain')}</Col>
                     <Col md="6">{domain}</Col>
                   </Row>
                 </dd>
@@ -141,6 +147,7 @@ Content.propTypes = {
   getDeviceErrorsListByPage: PropTypes.func,
   resetPerPage: PropTypes.func,
   curPerPage: PropTypes.number,
+  orgID: PropTypes.string,
   orgInfo: PropTypes.object,
   updateQuota: PropTypes.func.isRequired,
   updateName: PropTypes.func.isRequired,
@@ -158,8 +165,8 @@ class OrgInfo extends Component {
     };
   }
 
-  componentDidMount () {
-    seafileAPI.sysAdminGetOrg(this.props.orgID).then((res) => {
+  componentDidMount() {
+    systemAdminAPI.sysAdminGetOrg(this.props.orgID).then((res) => {
       this.setState({
         loading: false,
         orgInfo: res.data
@@ -173,12 +180,12 @@ class OrgInfo extends Component {
   }
 
   updateQuota = (quota) => {
-    const data = {quota: quota};
-    seafileAPI.sysAdminUpdateOrg(this.props.orgID, data).then(res => {
+    const data = { quota: quota };
+    systemAdminAPI.sysAdminUpdateOrg(this.props.orgID, data).then(res => {
       const newOrgInfo = Object.assign(this.state.orgInfo, {
         quota: res.data.quota
       });
-      this.setState({orgInfo: newOrgInfo});
+      this.setState({ orgInfo: newOrgInfo });
       toaster.success(gettext('Successfully set quota.'));
     }).catch((error) => {
       let errMessage = Utils.getErrorMsg(error);
@@ -187,12 +194,12 @@ class OrgInfo extends Component {
   };
 
   updateName = (orgName) => {
-    const data = {orgName: orgName};
-    seafileAPI.sysAdminUpdateOrg(this.props.orgID, data).then(res => {
+    const data = { orgName: orgName };
+    systemAdminAPI.sysAdminUpdateOrg(this.props.orgID, data).then(res => {
       const newOrgInfo = Object.assign(this.state.orgInfo, {
         org_name: res.data.org_name
       });
-      this.setState({orgInfo: newOrgInfo});
+      this.setState({ orgInfo: newOrgInfo });
       toaster.success(gettext('Successfully set name.'));
     }).catch((error) => {
       let errMessage = Utils.getErrorMsg(error);
@@ -201,12 +208,12 @@ class OrgInfo extends Component {
   };
 
   updateMaxUserNumber = (newValue) => {
-    const data = {maxUserNumber: newValue};
-    seafileAPI.sysAdminUpdateOrg(this.props.orgID, data).then(res => {
+    const data = { maxUserNumber: newValue };
+    systemAdminAPI.sysAdminUpdateOrg(this.props.orgID, data).then(res => {
       const newOrgInfo = Object.assign(this.state.orgInfo, {
         max_user_number: res.data.max_user_number
       });
-      this.setState({orgInfo: newOrgInfo});
+      this.setState({ orgInfo: newOrgInfo });
       toaster.success(gettext('Successfully set max number of members.'));
     }).catch((error) => {
       let errMessage = Utils.getErrorMsg(error);
