@@ -1,7 +1,7 @@
 import React, { Component, Fragment } from 'react';
 import PropTypes from 'prop-types';
 import { Utils } from '../../../utils/utils';
-import { seafileAPI } from '../../../utils/seafile-api';
+import { systemAdminAPI } from '../../../utils/system-admin-api';
 import { gettext } from '../../../utils/constants';
 import toaster from '../../../components/toast';
 import EmptyTip from '../../../components/empty-tip';
@@ -20,8 +20,7 @@ class Content extends Component {
       return <p className="error text-center mt-4">{errorMsg}</p>;
     } else {
       const emptyTip = (
-        <EmptyTip>
-          <h2>{gettext('No libraries')}</h2>
+        <EmptyTip text={gettext('No libraries')}>
         </EmptyTip>
       );
       const table = (
@@ -31,7 +30,7 @@ class Content extends Component {
               <tr>
                 <th width="5%"></th>
                 <th width="30%">{gettext('Name')}</th>
-                <th width="35%">{gettext('ID')}</th>
+                <th width="35%">{'ID'}</th>
                 <th width="20%">{gettext('Owner')}</th>
                 <th width="10%">{/* Operations */}</th>
               </tr>
@@ -71,18 +70,18 @@ class Item extends Component {
   }
 
   handleMouseEnter = () => {
-    this.setState({isOpIconShown: true});
+    this.setState({ isOpIconShown: true });
   };
 
   handleMouseLeave = () => {
-    this.setState({isOpIconShown: false});
+    this.setState({ isOpIconShown: false });
   };
 
   toggleDeleteDialog = (e) => {
     if (e) {
       e.preventDefault();
     }
-    this.setState({isDeleteDialogOpen: !this.state.isDeleteDialogOpen});
+    this.setState({ isDeleteDialogOpen: !this.state.isDeleteDialogOpen });
   };
 
   deleteRepo = () => {
@@ -114,7 +113,7 @@ class Item extends Component {
             }
           </td>
           <td>
-            <a href="#" className={`action-icon sf2-icon-delete ${isOpIconShown ? '' : 'invisible'}`} title={gettext('Delete')} onClick={this.toggleDeleteDialog}></a>
+            <a href="#" className={`action-icon sf3-font-delete1 sf3-font ${isOpIconShown ? '' : 'invisible'}`} title={gettext('Delete')} onClick={this.toggleDeleteDialog}></a>
           </td>
         </tr>
         {isDeleteDialogOpen &&
@@ -148,13 +147,13 @@ class OrgRepos extends Component {
     };
   }
 
-  componentDidMount () {
-    seafileAPI.sysAdminGetOrg(this.props.orgID).then((res) => {
+  componentDidMount() {
+    systemAdminAPI.sysAdminGetOrg(this.props.orgID).then((res) => {
       this.setState({
         orgName: res.data.org_name
       });
     });
-    seafileAPI.sysAdminListOrgRepos(this.props.orgID).then((res) => {
+    systemAdminAPI.sysAdminListOrgRepos(this.props.orgID).then((res) => {
       this.setState({
         loading: false,
         repoList: res.data.repo_list
@@ -168,11 +167,11 @@ class OrgRepos extends Component {
   }
 
   deleteRepo = (repoID) => {
-    seafileAPI.sysAdminDeleteRepo(repoID).then(res => {
+    systemAdminAPI.sysAdminDeleteRepo(repoID).then(res => {
       let newRepoList = this.state.repoList.filter(item => {
         return item.repo_id != repoID;
       });
-      this.setState({repoList: newRepoList});
+      this.setState({ repoList: newRepoList });
       toaster.success(gettext('Successfully deleted 1 item.'));
     }).catch((error) => {
       let errMessage = Utils.getErrorMsg(error);
