@@ -1,9 +1,10 @@
 import React, { Component, Fragment } from 'react';
 import PropTypes from 'prop-types';
 import { Button } from 'reactstrap';
-import moment from 'moment';
+import dayjs from 'dayjs';
+import relativeTime from 'dayjs/plugin/relativeTime';
 import { Utils } from '../../../utils/utils';
-import { seafileAPI } from '../../../utils/seafile-api';
+import { systemAdminAPI } from '../../../utils/system-admin-api';
 import { gettext, username } from '../../../utils/constants';
 import toaster from '../../../components/toast';
 import EmptyTip from '../../../components/empty-tip';
@@ -16,6 +17,8 @@ import MainPanelTopbar from '../main-panel-topbar';
 import UserLink from '../user-link';
 import OrgNav from './org-nav';
 
+dayjs.extend(relativeTime);
+
 class Content extends Component {
 
   constructor(props) {
@@ -30,11 +33,11 @@ class Content extends Component {
   };
 
   onFreezedItem = () => {
-    this.setState({isItemFreezed: true});
+    this.setState({ isItemFreezed: true });
   };
 
   onUnfreezedItem = () => {
-    this.setState({isItemFreezed: false});
+    this.setState({ isItemFreezed: false });
   };
 
   render() {
@@ -45,8 +48,7 @@ class Content extends Component {
       return <p className="error text-center mt-4">{errorMsg}</p>;
     } else {
       const emptyTip = (
-        <EmptyTip>
-          <h2>{gettext('No members')}</h2>
+        <EmptyTip text={gettext('No members')}>
         </EmptyTip>
       );
       const table = (
@@ -56,7 +58,7 @@ class Content extends Component {
               <tr>
                 <th width="25%">{gettext('Name')}</th>
                 <th width="15%">{gettext('Status')}</th>
-                <th width="15%">{gettext('Membership')}</th>
+                <th width="15%">{gettext('Role')}</th>
                 <th width="15%">{gettext('Space Used')}</th>
                 <th width="25%">{gettext('Created At')}{' / '}{gettext('Last Login')}</th>
                 <th width="5%">{/* Operations */}</th>
@@ -132,7 +134,7 @@ class Item extends Component {
   };
 
   onMenuItemClick = (operation) => {
-    switch(operation) {
+    switch (operation) {
       case 'Delete':
         this.toggleDeleteDialog();
         break;
@@ -148,21 +150,29 @@ class Item extends Component {
     if (e) {
       e.preventDefault();
     }
-    this.setState({isDeleteDialogOpen: !this.state.isDeleteDialogOpen});
+    this.setState({ isDeleteDialogOpen: !this.state.isDeleteDialogOpen });
   };
 
   toggleResetPasswordDialog = (e) => {
     if (e) {
       e.preventDefault();
     }
-    this.setState({isResetPasswordDialogOpen: !this.state.isResetPasswordDialogOpen});
+    this.setState({ isResetPasswordDialogOpen: !this.state.isResetPasswordDialogOpen });
   };
 
-  updateStatus= (statusOption) => {
+  toggleConfirmInactiveDialog = () => {
+    this.setState({ isConfirmInactiveDialogOpen: !this.state.isConfirmInactiveDialogOpen });
+  };
+
+  updateStatus = (statusOption) => {
     this.props.updateStatus(this.props.item.email, statusOption.value);
   };
 
-  updateMembership= (membershipOption) => {
+  setUserInactive = () => {
+    this.props.updateStatus(this.props.item.email, 'inactive');
+  };
+
+  updateMembership = (membershipOption) => {
     this.props.updateMembership(this.props.item.email, membershipOption.value);
   };
 
@@ -172,7 +182,7 @@ class Item extends Component {
   };
 
   resetPassword = () => {
-    seafileAPI.sysAdminResetUserPassword(this.props.item.email).then(res => {
+    systemAdminAPI.sysAdminResetUserPassword(this.props.item.email).then(res => {
       toaster.success(res.data.reset_tip);
     }).catch((error) => {
       let errMessage = Utils.getErrorMsg(error);
@@ -182,7 +192,7 @@ class Item extends Component {
 
   translateOperations = (item) => {
     let translateResult = '';
-    switch(item) {
+    switch (item) {
       case 'Delete':
         translateResult = gettext('Delete');
         break;
@@ -214,11 +224,12 @@ class Item extends Component {
 
   render() {
     const { item } = this.props;
-    const { highlight, isOpIconShown, isDeleteDialogOpen, isResetPasswordDialogOpen } = this.state;
+    const { highlight, isOpIconShown, isDeleteDialogOpen, isResetPasswordDialogOpen, isConfirmInactiveDialogOpen } = this.state;
 
     const itemName = '<span class="op-target">' + Utils.HTMLescape(item.name) + '</span>';
     let deleteDialogMsg = gettext('Are you sure you want to delete {placeholder} ?').replace('{placeholder}', itemName);
     let resetPasswordDialogMsg = gettext('Are you sure you want to reset the password of {placeholder} ?').replace('{placeholder}', itemName);
+    const confirmSetUserInactiveMsg = gettext('Are you sure you want to set {user_placeholder} inactive?').replace('{user_placeholder}', itemName);
 
     // for 'user status'
     const curStatus = item.active ? 'active' : 'inactive';
@@ -232,7 +243,7 @@ class Item extends Component {
     const currentSelectedStatusOption = this.statusOptions.filter(item => item.isSelected)[0];
 
     // for 'user membership'
-    const curMembership = item.is_org_staff? 'Admin' : 'Member';
+    const curMembership = item.is_org_staff ? 'Admin' : 'Member';
     this.membershipOptions = ['Admin', 'Member'].map(item => {
       return {
         value: item,
@@ -253,6 +264,7 @@ class Item extends Component {
               options={this.statusOptions}
               selectOption={this.updateStatus}
               toggleItemFreezed={this.props.toggleItemFreezed}
+              operationBeforeSelect={item.active ? this.toggleConfirmInactiveDialog : undefined}
             />
           </td>
           <td>
@@ -266,7 +278,7 @@ class Item extends Component {
           </td>
           <td>{`${Utils.bytesToSize(item.quota_usage)} / ${item.quota_total > 0 ? Utils.bytesToSize(item.quota_total) : '--'}`}</td>
           <td>
-            {moment(item.create_time).format('YYYY-MM-DD HH:mm:ss')}{' / '}{item.last_login ? moment(item.last_login).fromNow() : '--'}
+            {dayjs(item.create_time).format('YYYY-MM-DD HH:mm:ss')}{' / '}{item.last_login ? dayjs(item.last_login).fromNow() : '--'}
           </td>
           <td>
             {(isOpIconShown && item.email != username) &&
@@ -298,6 +310,15 @@ class Item extends Component {
             toggleDialog={this.toggleResetPasswordDialog}
           />
         }
+        {isConfirmInactiveDialogOpen &&
+        <CommonOperationConfirmationDialog
+          title={gettext('Set user inactive')}
+          message={confirmSetUserInactiveMsg}
+          executeOperation={this.setUserInactive}
+          confirmBtnText={gettext('Set')}
+          toggleDialog={this.toggleConfirmInactiveDialog}
+        />
+        }
       </Fragment>
     );
   }
@@ -327,13 +348,13 @@ class OrgUsers extends Component {
     };
   }
 
-  componentDidMount () {
-    seafileAPI.sysAdminGetOrg(this.props.orgID).then((res) => {
+  componentDidMount() {
+    systemAdminAPI.sysAdminGetOrg(this.props.orgID).then((res) => {
       this.setState({
         orgName: res.data.org_name
       });
     });
-    seafileAPI.sysAdminListOrgUsers(this.props.orgID).then((res) => {
+    systemAdminAPI.sysAdminListOrgUsers(this.props.orgID).then((res) => {
       this.setState({
         loading: false,
         userList: res.data.users
@@ -347,15 +368,15 @@ class OrgUsers extends Component {
   }
 
   toggleAddUserDialog = () => {
-    this.setState({isAddUserDialogOpen: !this.state.isAddUserDialogOpen});
+    this.setState({ isAddUserDialogOpen: !this.state.isAddUserDialogOpen });
   };
 
   addUser = (newUserInfo) => {
     const { email, name, password } = newUserInfo;
-    seafileAPI.sysAdminAddOrgUser(this.props.orgID, email, name, password).then(res => {
+    systemAdminAPI.sysAdminAddOrgUser(this.props.orgID, email, name, password).then(res => {
       let userList = this.state.userList;
       userList.unshift(res.data);
-      this.setState({userList: userList});
+      this.setState({ userList: userList });
     }).catch((error) => {
       let errMessage = Utils.getErrorMsg(error);
       toaster.danger(errMessage);
@@ -363,11 +384,11 @@ class OrgUsers extends Component {
   };
 
   deleteUser = (orgID, email) => {
-    seafileAPI.sysAdminDeleteOrgUser(orgID, email).then(res => {
+    systemAdminAPI.sysAdminDeleteOrgUser(orgID, email).then(res => {
       let newUserList = this.state.userList.filter(item => {
         return item.email != email;
       });
-      this.setState({userList: newUserList});
+      this.setState({ userList: newUserList });
       toaster.success(gettext('Successfully deleted 1 item.'));
     }).catch((error) => {
       let errMessage = Utils.getErrorMsg(error);
@@ -377,14 +398,14 @@ class OrgUsers extends Component {
 
   updateStatus = (email, statusValue) => {
     const isActive = statusValue == 'active';
-    seafileAPI.sysAdminUpdateOrgUser(this.props.orgID, email, 'active', isActive).then(res => {
+    systemAdminAPI.sysAdminUpdateOrgUser(this.props.orgID, email, 'active', isActive).then(res => {
       let newUserList = this.state.userList.map(item => {
         if (item.email == email) {
           item.active = res.data.active;
         }
         return item;
       });
-      this.setState({userList: newUserList});
+      this.setState({ userList: newUserList });
     }).catch((error) => {
       let errMessage = Utils.getErrorMsg(error);
       toaster.danger(errMessage);
@@ -393,14 +414,14 @@ class OrgUsers extends Component {
 
   updateMembership = (email, membershipValue) => {
     const isOrgStaff = membershipValue == 'Admin';
-    seafileAPI.sysAdminUpdateOrgUser(this.props.orgID, email, 'is_org_staff', isOrgStaff).then(res => {
+    systemAdminAPI.sysAdminUpdateOrgUser(this.props.orgID, email, 'is_org_staff', isOrgStaff).then(res => {
       let newUserList = this.state.userList.map(item => {
         if (item.email == email) {
           item.is_org_staff = res.data.is_org_staff;
         }
         return item;
       });
-      this.setState({userList: newUserList});
+      this.setState({ userList: newUserList });
     }).catch((error) => {
       let errMessage = Utils.getErrorMsg(error);
       toaster.danger(errMessage);
