@@ -1,13 +1,13 @@
 import React, { Component, Fragment } from 'react';
 import PropTypes from 'prop-types';
 import { Link } from '@gatsbyjs/reach-router';
-import moment from 'moment';
+import dayjs from 'dayjs';
 import { Utils } from '../../../utils/utils';
 import { siteRoot, gettext } from '../../../utils/constants';
 import EmptyTip from '../../../components/empty-tip';
 import Loading from '../../../components/loading';
 import Paginator from '../../../components/paginator';
-import { seafileAPI } from '../../../utils/seafile-api';
+import { systemAdminAPI } from '../../../utils/system-admin-api';
 import RoleSelector from '../../../components/single-selector';
 import CommonOperationConfirmationDialog from '../../../components/dialog/common-operation-confirmation-dialog';
 import UserLink from '../user-link';
@@ -44,8 +44,7 @@ class Content extends Component {
       return <p className="error text-center mt-4">{errorMsg}</p>;
     } else {
       const emptyTip = (
-        <EmptyTip>
-          <h2>{gettext('No organizations')}</h2>
+        <EmptyTip text={gettext('No organizations')}>
         </EmptyTip>
       );
       const table = (
@@ -117,21 +116,21 @@ class Item extends Component {
 
   handleMouseEnter = () => {
     if (this.props.isItemFreezed) return;
-    this.setState({highlighted: true});
+    this.setState({ highlighted: true });
   };
 
   handleMouseLeave = () => {
     if (this.props.isItemFreezed) return;
-    this.setState({highlighted: false});
+    this.setState({ highlighted: false });
   };
 
   toggleDeleteDialog = (e) => {
     if (e) {
       e.preventDefault();
     }
-    this.setState({isDeleteDialogOpen: !this.state.isDeleteDialogOpen}, () => {
+    this.setState({ isDeleteDialogOpen: !this.state.isDeleteDialogOpen }, () => {
       if (this.state.isDeleteDialogOpen) {
-        seafileAPI.sysAdminGetOrg(this.props.item.org_id).then((res) => {
+        systemAdminAPI.sysAdminGetOrg(this.props.item.org_id).then((res) => {
           let orgName = '<span class="op-target">' + Utils.HTMLescape(res.data.org_name) + '</span>';
           let userCount = '<span class="op-target">' + Utils.HTMLescape(res.data.users_count) + '</span>';
           let repoCount = '<span class="op-target">' + Utils.HTMLescape(res.data.repos_count) + '</span>';
@@ -140,7 +139,7 @@ class Item extends Component {
             gettext('{userCount} user(s) and {repoCount} libraries of this organization will also be deleted.')
               .replace('{userCount}', userCount)
               .replace('{repoCount}', repoCount);
-          this.setState({deleteDialogMsg: deleteDialogMsg});
+          this.setState({ deleteDialogMsg: deleteDialogMsg });
         }).catch(error => {
           let errorMsg = Utils.getErrorMsg(error);
           toaster.danger(errorMsg);
@@ -200,9 +199,9 @@ class Item extends Component {
             />
           </td>
           <td>{`${Utils.bytesToSize(item.quota_usage)} / ${item.quota > 0 ? Utils.bytesToSize(item.quota) : '--'}`}</td>
-          <td>{moment(item.ctime).format('YYYY-MM-DD HH:mm:ss')}</td>
+          <td>{dayjs(item.ctime).format('YYYY-MM-DD HH:mm:ss')}</td>
           <td>
-            <a href="#" className={`action-icon sf2-icon-delete ${highlighted ? '' : 'invisible'}`} title={gettext('Delete')} onClick={this.toggleDeleteDialog}></a>
+            <a href="#" className={`action-icon sf3-font-delete1 sf3-font ${highlighted ? '' : 'invisible'}`} title={gettext('Delete')} onClick={this.toggleDeleteDialog}></a>
           </td>
         </tr>
         {isDeleteDialogOpen &&
