@@ -2,7 +2,7 @@ import React, { Component, Fragment } from 'react';
 import { navigate } from '@gatsbyjs/reach-router';
 import { Button } from 'reactstrap';
 import { Utils } from '../../../utils/utils';
-import { seafileAPI } from '../../../utils/seafile-api';
+import { systemAdminAPI } from '../../../utils/system-admin-api';
 import { siteRoot, gettext } from '../../../utils/constants';
 import toaster from '../../../components/toast';
 import SysAdminAddOrgDialog from '../../../components/dialog/sysadmin-dialog/sysadmin-add-org-dialog';
@@ -20,7 +20,7 @@ class Orgs extends Component {
       errorMsg: '',
       orgList: [],
       currentPage: 1,
-      perPage: 25,
+      perPage: 100,
       hasNextPage: false,
       isAddOrgDialogOpen: false
     };
@@ -39,7 +39,7 @@ class Orgs extends Component {
 
   getItemsByPage = (page) => {
     const { perPage } = this.state;
-    seafileAPI.sysAdminListOrgs(page, perPage).then((res) => {
+    systemAdminAPI.sysAdminListOrgs(page, perPage).then((res) => {
       this.setState({
         loading: false,
         orgList: res.data.organizations,
@@ -63,20 +63,20 @@ class Orgs extends Component {
   };
 
   toggleAddOrgDialog = () => {
-    this.setState({isAddOrgDialogOpen: !this.state.isAddOrgDialogOpen});
+    this.setState({ isAddOrgDialogOpen: !this.state.isAddOrgDialogOpen });
   };
 
   updateRole = (orgID, role) => {
     let orgInfo = {};
     orgInfo.role = role;
-    seafileAPI.sysAdminUpdateOrg(orgID, orgInfo).then(res => {
+    systemAdminAPI.sysAdminUpdateOrg(orgID, orgInfo).then(res => {
       let newOrgList = this.state.orgList.map(org => {
         if (org.org_id == orgID) {
           org.role = role;
         }
         return org;
       });
-      this.setState({orgList: newOrgList});
+      this.setState({ orgList: newOrgList });
       toaster.success(gettext('Edit succeeded'));
     }).catch((error) => {
       let errMessage = Utils.getErrorMsg(error);
@@ -86,10 +86,10 @@ class Orgs extends Component {
 
   addOrg = (data) => {
     const { orgName, ownerEmail, password } = data;
-    seafileAPI.sysAdminAddOrg(orgName, ownerEmail, password).then(res => {
+    systemAdminAPI.sysAdminAddOrg(orgName, ownerEmail, password).then(res => {
       let orgList = this.state.orgList;
       orgList.unshift(res.data);
-      this.setState({orgList: orgList});
+      this.setState({ orgList: orgList });
     }).catch((error) => {
       let errMessage = Utils.getErrorMsg(error);
       toaster.danger(errMessage);
@@ -97,11 +97,11 @@ class Orgs extends Component {
   };
 
   deleteOrg = (orgID) => {
-    seafileAPI.sysAdminDeleteOrg(orgID).then(res => {
+    systemAdminAPI.sysAdminDeleteOrg(orgID).then(res => {
       let orgList = this.state.orgList.filter(org => {
         return org.org_id != orgID;
       });
-      this.setState({orgList: orgList});
+      this.setState({ orgList: orgList });
       toaster.success(gettext('Successfully deleted 1 item.'));
     }).catch((error) => {
       let errMessage = Utils.getErrorMsg(error);
