@@ -1,7 +1,7 @@
 import React, { Component, Fragment } from 'react';
 import { Form, FormGroup, Input, Label, Col } from 'reactstrap';
 import { Utils } from '../../../utils/utils';
-import { seafileAPI } from '../../../utils/seafile-api';
+import { systemAdminAPI } from '../../../utils/system-admin-api';
 import { gettext } from '../../../utils/constants';
 import toaster from '../../../components/toast';
 import MainPanelTopbar from '../main-panel-topbar';
@@ -21,7 +21,7 @@ class SearchOrgs extends Component {
     };
   }
 
-  componentDidMount () {
+  componentDidMount() {
     let params = (new URL(document.location)).searchParams;
     this.setState({
       query: params.get('query') || ''
@@ -29,7 +29,7 @@ class SearchOrgs extends Component {
   }
 
   getItems = () => {
-    seafileAPI.sysAdminSearchOrgs(this.state.query.trim()).then(res => {
+    systemAdminAPI.sysAdminSearchOrgs(this.state.query.trim()).then(res => {
       this.setState({
         loading: false,
         orgList: res.data.organization_list
@@ -45,14 +45,14 @@ class SearchOrgs extends Component {
   updateRole = (orgID, role) => {
     let orgInfo = {};
     orgInfo.role = role;
-    seafileAPI.sysAdminUpdateOrg(orgID, orgInfo).then(res => {
+    systemAdminAPI.sysAdminUpdateOrg(orgID, orgInfo).then(res => {
       let newOrgList = this.state.orgList.map(org => {
         if (org.org_id == orgID) {
           org.role = role;
         }
         return org;
       });
-      this.setState({orgList: newOrgList});
+      this.setState({ orgList: newOrgList });
       toaster.success(gettext('Edit succeeded'));
     }).catch((error) => {
       let errMessage = Utils.getErrorMsg(error);
@@ -61,11 +61,11 @@ class SearchOrgs extends Component {
   };
 
   deleteOrg = (orgID) => {
-    seafileAPI.sysAdminDeleteOrg(orgID).then(res => {
+    systemAdminAPI.sysAdminDeleteOrg(orgID).then(res => {
       let orgList = this.state.orgList.filter(org => {
         return org.org_id != orgID;
       });
-      this.setState({orgList: orgList});
+      this.setState({ orgList: orgList });
       toaster.success(gettext('Successfully deleted 1 item.'));
     }).catch((error) => {
       let errMessage = Utils.getErrorMsg(error);
@@ -117,7 +117,7 @@ class SearchOrgs extends Component {
                     </Col>
                   </FormGroup>
                   <FormGroup row>
-                    <Col sm={{size: 5, offset: 1}}>
+                    <Col sm={{ size: 5, offset: 1 }}>
                       <button className="btn btn-outline-primary" disabled={!isSubmitBtnActive} onClick={this.getItems}>{gettext('Submit')}</button>
                     </Col>
                   </FormGroup>
