@@ -2,7 +2,7 @@ import React, { Component, Fragment } from 'react';
 import { navigate } from '@gatsbyjs/reach-router';
 import { Button } from 'reactstrap';
 import { Utils } from '../../../utils/utils';
-import { seafileAPI } from '../../../utils/seafile-api';
+import { systemAdminAPI } from '../../../utils/system-admin-api';
 import { gettext, siteRoot } from '../../../utils/constants';
 import toaster from '../../../components/toast';
 import SysAdminCreateRepoDialog from '../../../components/dialog/sysadmin-dialog/sysadmin-create-repo-dialog';
@@ -20,13 +20,13 @@ class AllRepos extends Component {
       errorMsg: '',
       repos: [],
       pageInfo: {},
-      perPage: 25,
+      perPage: 100,
       sortBy: '',
       isCreateRepoDialogOpen: false
     };
   }
 
-  componentDidMount () {
+  componentDidMount() {
     let urlParams = (new URL(window.location)).searchParams;
     const { currentPage = 1, perPage, sortBy } = this.state;
     this.setState({
@@ -39,12 +39,12 @@ class AllRepos extends Component {
   }
 
   toggleCreateRepoDialog = () => {
-    this.setState({isCreateRepoDialogOpen: !this.state.isCreateRepoDialogOpen});
+    this.setState({ isCreateRepoDialogOpen: !this.state.isCreateRepoDialogOpen });
   };
 
   getReposByPage = (page) => {
     const { perPage, sortBy } = this.state;
-    seafileAPI.sysAdminListAllRepos(page, perPage, sortBy).then((res) => {
+    systemAdminAPI.sysAdminListAllRepos(page, perPage, sortBy).then((res) => {
       this.setState({
         loading: false,
         repos: res.data.repos,
@@ -83,7 +83,7 @@ class AllRepos extends Component {
   };
 
   createRepo = (repoName, Owner) => {
-    seafileAPI.sysAdminCreateRepo(repoName, Owner).then(res => {
+    systemAdminAPI.sysAdminCreateRepo(repoName, Owner).then(res => {
       this.state.repos.unshift(res.data);
       this.setState({
         repos: this.state.repos
@@ -128,10 +128,10 @@ class AllRepos extends Component {
   };
 
   getValueLength(str) {
-    let code, len = 0;
+    let code; let len = 0;
     for (let i = 0, length = str.length; i < length; i++) {
       code = str.charCodeAt(i);
-      if (code === 10) { //solve enter problem
+      if (code === 10) { // solve enter problem
         len += 2;
       } else if (code < 0x007f) {
         len += 1;
@@ -150,7 +150,7 @@ class AllRepos extends Component {
       <Fragment>
         <MainPanelTopbar search={this.getSearch()} {...this.props}>
           <Button className="btn btn-secondary operation-item" onClick={this.toggleCreateRepoDialog}>
-            <i className="fas fa-plus-square text-secondary mr-1"></i>{gettext('New Library')}
+            <i className="sf3-font sf3-font-enlarge text-secondary mr-1"></i>{gettext('New Library')}
           </Button>
         </MainPanelTopbar>
         <div className="main-panel-center flex-row">
