@@ -1,11 +1,14 @@
 import React, { Fragment } from 'react';
 import PropTypes from 'prop-types';
 import { Link } from '@gatsbyjs/reach-router';
-import moment from 'moment';
+import dayjs from 'dayjs';
+import relativeTime from 'dayjs/plugin/relativeTime';
 import { gettext } from '../../../utils/constants';
 import { Utils } from '../../../utils/utils';
 import Loading from '../../../components/loading';
 
+dayjs.extend(relativeTime);
+
 class DirentItem extends React.Component {
 
   constructor(props) {
@@ -41,7 +44,7 @@ class DirentItem extends React.Component {
     this.props.downloadDirent(this.props.dirent);
   };
 
-  render () {
+  render() {
     let { isOpIconShown } = this.state;
     let { dirent, fromSystemRepo } = this.props;
     let iconUrl = Utils.getDirentIcon(dirent);
@@ -58,14 +61,14 @@ class DirentItem extends React.Component {
           </td>
           <td>
             {isOpIconShown && fromSystemRepo &&
-              <a href="#" className="op-icon sf2-icon-delete" title={gettext('Delete')} onClick={this.deleteDirent}></a>
+              <a href="#" className="op-icon sf3-font-delete1 sf3-font" title={gettext('Delete')} onClick={this.deleteDirent}></a>
             }
             {isOpIconShown && dirent.is_file &&
-            <a href="#" className="op-icon sf2-icon-download" title={gettext('Download')} onClick={this.downloadDirent}></a>
+            <a href="#" className="op-icon sf3-font sf3-font-download1" title={gettext('Download')} onClick={this.downloadDirent}></a>
             }
           </td>
           <td>{dirent.size}</td>
-          <td>{moment(dirent.mtime).fromNow()}</td>
+          <td>{dayjs(dirent.mtime).fromNow()}</td>
         </tr>
       </Fragment>
     );
@@ -98,9 +101,9 @@ class DirContent extends React.Component {
         <table className="table-hover">
           <thead>
             <tr>
-              <th width="5%">{/*icon*/}</th>
+              <th width="5%">{/* icon*/}</th>
               <th width="55%">{gettext('Name')}</th>
-              <th width="10%">{/*operation*/}</th>
+              <th width="10%">{/* operation*/}</th>
               <th width="15%">{gettext('Size')}</th>
               <th width="15%">{gettext('Last Update')}</th>
             </tr>
