@@ -1,9 +1,10 @@
 import React, { Component, Fragment } from 'react';
 import PropTypes from 'prop-types';
 import { Button } from 'reactstrap';
-import moment from 'moment';
+import dayjs from 'dayjs';
+import relativeTime from 'dayjs/plugin/relativeTime';
 import { Utils } from '../../../utils/utils';
-import { seafileAPI } from '../../../utils/seafile-api';
+import { systemAdminAPI } from '../../../utils/system-admin-api';
 import { gettext } from '../../../utils/constants';
 import toaster from '../../../components/toast';
 import EmptyTip from '../../../components/empty-tip';
@@ -19,6 +20,8 @@ import ReposNav from './repos-nav';
 
 const { trashReposExpireDays } = window.sysadmin.pageOptions;
 
+dayjs.extend(relativeTime);
+
 class Content extends Component {
 
   constructor(props) {
@@ -29,11 +32,11 @@ class Content extends Component {
   }
 
   onFreezedItem = () => {
-    this.setState({isItemFreezed: true});
+    this.setState({ isItemFreezed: true });
   };
 
   onUnfreezedItem = () => {
-    this.setState({isItemFreezed: false});
+    this.setState({ isItemFreezed: false });
   };
 
   getPreviousPageList = () => {
@@ -52,8 +55,7 @@ class Content extends Component {
       return <p className="error text-center mt-4">{errorMsg}</p>;
     } else {
       const emptyTip = (
-        <EmptyTip>
-          <h2>{gettext('No deleted libraries')}</h2>
+        <EmptyTip text={gettext('No deleted libraries')}>
         </EmptyTip>
       );
       const table = (
@@ -62,11 +64,11 @@ class Content extends Component {
           <table className="table-hover">
             <thead>
               <tr>
-                <th width="5%">{/*icon*/}</th>
+                <th width="5%">{/* icon*/}</th>
                 <th width="43%">{gettext('Name')}</th>
                 <th width="27%">{gettext('Owner')}</th>
                 <th width="20%">{gettext('Deleted Time')}</th>
-                <th width="5%">{/*Operations*/}</th>
+                <th width="5%">{/* Operations*/}</th>
               </tr>
             </thead>
             <tbody>
@@ -154,7 +156,7 @@ class Item extends Component {
 
   onDeleteRepo = () => {
     const repo = this.props.repo;
-    seafileAPI.sysAdminDeleteTrashRepo(repo.id).then((res) => {
+    systemAdminAPI.sysAdminDeleteTrashRepo(repo.id).then((res) => {
       this.props.onDeleteRepo(repo);
       const msg = gettext('Successfully deleted {name}.').replace('{name}', repo.name);
       toaster.success(msg);
@@ -166,7 +168,7 @@ class Item extends Component {
 
   onRestoreRepo = () => {
     const repo = this.props.repo;
-    seafileAPI.sysAdminRestoreTrashRepo(repo.id).then((res) => {
+    systemAdminAPI.sysAdminRestoreTrashRepo(repo.id).then((res) => {
       this.props.onRestoreRepo(repo);
       let message = gettext('Successfully restored the library.');
       toaster.success(message);
@@ -180,19 +182,19 @@ class Item extends Component {
     if (e) {
       e.preventDefault();
     }
-    this.setState({isDeleteRepoDialogOpen: !this.state.isDeleteRepoDialogOpen});
+    this.setState({ isDeleteRepoDialogOpen: !this.state.isDeleteRepoDialogOpen });
   };
 
   toggleRestoreRepoDialog = (e) => {
     if (e) {
       e.preventDefault();
     }
-    this.setState({isRestoreRepoDialogOpen: !this.state.isRestoreRepoDialogOpen});
+    this.setState({ isRestoreRepoDialogOpen: !this.state.isRestoreRepoDialogOpen });
   };
 
   translateOperations = (item) => {
     let translateResult = '';
-    switch(item) {
+    switch (item) {
       case 'Restore':
         translateResult = gettext('Restore');
         break;
@@ -207,7 +209,7 @@ class Item extends Component {
   };
 
   onMenuItemClick = (operation) => {
-    switch(operation) {
+    switch (operation) {
       case 'Restore':
         this.toggleRestoreRepoDialog();
         break;
@@ -219,7 +221,7 @@ class Item extends Component {
     }
   };
 
-  render () {
+  render() {
     const { repo } = this.props;
     const { isOpIconShown, isDeleteRepoDialogOpen, isRestoreRepoDialogOpen } = this.state;
     const iconUrl = Utils.getLibIconUrl(repo);
@@ -236,7 +238,7 @@ class Item extends Component {
               <UserLink email={repo.owner} name={repo.owner_name} /> :
               repo.group_name}
           </td>
-          <td>{moment(repo.delete_time).fromNow()}</td>
+          <td>{dayjs(repo.delete_time).fromNow()}</td>
           <td>
             {isOpIconShown && (
               <OpMenu
@@ -294,12 +296,12 @@ class TrashRepos extends Component {
       errorMsg: '',
       repos: [],
       pageInfo: {},
-      perPage: 25,
+      perPage: 100,
       isCleanTrashDialogOpen: false
     };
   }
 
-  componentDidMount () {
+  componentDidMount() {
     let urlParams = (new URL(window.location)).searchParams;
     const { currentPage = 1, perPage } = this.state;
     this.setState({
@@ -311,12 +313,12 @@ class TrashRepos extends Component {
   }
 
   toggleCleanTrashDialog = () => {
-    this.setState({isCleanTrashDialogOpen: !this.state.isCleanTrashDialogOpen});
+    this.setState({ isCleanTrashDialogOpen: !this.state.isCleanTrashDialogOpen });
   };
 
   getReposByPage = (page) => {
     let perPage = this.state.perPage;
-    seafileAPI.sysAdminListTrashRepos(page, perPage).then((res) => {
+    systemAdminAPI.sysAdminListTrashRepos(page, perPage).then((res) => {
       this.setState({
         repos: res.data.repos,
         pageInfo: res.data.page_info,
@@ -357,8 +359,8 @@ class TrashRepos extends Component {
   };
 
   cleanTrash = () => {
-    seafileAPI.sysAdminCleanTrashRepos().then(res => {
-      this.setState({repos: []});
+    systemAdminAPI.sysAdminCleanTrashRepos().then(res => {
+      this.setState({ repos: [] });
       toaster.success(gettext('Successfully cleared trash.'));
     }).catch(error => {
       let errMessage = Utils.getErrorMsg(error);
@@ -374,7 +376,7 @@ class TrashRepos extends Component {
   };
 
   searchRepos = (owner) => {
-    seafileAPI.sysAdminSearchTrashRepos(owner).then((res) => {
+    systemAdminAPI.sysAdminSearchTrashRepos(owner).then((res) => {
       this.setState({
         repos: res.data.repos,
         pageInfo: null,
