@@ -1,7 +1,28 @@
 import React from 'react';
+import {
+  Chart as ChartJS,
+  CategoryScale,
+  LinearScale,
+  PointElement,
+  LineElement,
+  Title,
+  Tooltip,
+  Legend,
+} from 'chart.js';
 import { Line } from 'react-chartjs-2';
 import PropTypes from 'prop-types';
 import { Utils } from '../../../utils/utils';
+import Loading from '../../../components/loading';
+
+ChartJS.register(
+  CategoryScale,
+  LinearScale,
+  PointElement,
+  LineElement,
+  Title,
+  Tooltip,
+  Legend
+);
 
 const propTypes = {
   labels: PropTypes.array.isRequired,
@@ -19,7 +40,7 @@ class StatisticChart extends React.Component {
     super(props);
     this.state = {
       data: {},
-      opations: {}
+      options: {}
     };
   }
 
@@ -31,10 +52,14 @@ class StatisticChart extends React.Component {
       datasets: filesData
     };
     let options = {
-      title: {
-        display: true,
-        fontSize: 14,
-        text: chartTitle,
+      plugins: {
+        title: {
+          display: true,
+          font: { weight: 'bold', size: 20 },
+          align: 'center',
+          text: chartTitle,
+          color: '#666',
+        },
       },
       elements: {
         line: {
@@ -51,7 +76,7 @@ class StatisticChart extends React.Component {
       },
       tooltips: {
         callbacks: {
-          label: function(tooltipItem, data) {
+          label: function (tooltipItem, data) {
             if (isTitleCallback) {
               return _this.titleCallback(tooltipItem, data);
             }
@@ -65,23 +90,25 @@ class StatisticChart extends React.Component {
         }
       },
       scales: {
-        yAxes: [{
+        y: {
+          display: true,
+          beginAtZero: true,
+          suggestedMax: suggestedMaxNumbers,
           ticks: {
-            beginAtZero: true,
-            suggestedMax: suggestedMaxNumbers,
-            callback: function(value, index, values) {
+            callback: function (value, index, values) {
               if (isTicksCallback) {
                 return _this.ticksCallback(value, index, values);
               }
               return value;
             }
           }
-        }],
-        xAxes: [{
+        },
+        x: {
+          display: true,
           ticks: {
             maxTicksLimit: 20
           }
-        }]
+        }
       }
     };
     this.setState({
@@ -95,7 +122,7 @@ class StatisticChart extends React.Component {
       labels: nextProps.labels,
       datasets: nextProps.filesData
     };
-    this.setState({data: data});
+    this.setState({ data: data });
   }
 
   titleCallback = (tooltipItem, data) => {
@@ -109,11 +136,13 @@ class StatisticChart extends React.Component {
   render() {
 
     let { data, options } = this.state;
+    if (Object.keys(data).length === 0 && Object.keys(options).length === 0) {
+      return <Loading />;
+    }
     return (
-      <Line
-        data={data}
-        options={options}
-      />
+      <>
+        <Line data={data} options={options} />
+      </>
     );
   }
 }
