@@ -1,10 +1,10 @@
 import React, { Fragment } from 'react';
-import moment from 'moment';
+import dayjs from 'dayjs';
 import { gettext } from '../../../utils/constants';
 import MainPanelTopbar from '../main-panel-topbar';
 import StatisticNav from './statistic-nav';
 import StatisticCommonTool from './statistic-common-tool';
-import { seafileAPI } from '../../../utils/seafile-api';
+import { systemAdminAPI } from '../../../utils/system-admin-api';
 import StatisticChart from './statistic-chart';
 import Loading from '../../../components/loading';
 import { Utils } from '../../../utils/utils';
@@ -23,20 +23,20 @@ class StatisticUsers extends React.Component {
 
   getActiviesFiles = (startTime, endTime, groupBy) => {
     let { filesData } = this.state;
-    seafileAPI.sysAdminStatisticActiveUsers(startTime, endTime, groupBy).then((res) => {
-      let labels = [],
-        count = [];
+    systemAdminAPI.sysAdminStatisticActiveUsers(startTime, endTime, groupBy).then((res) => {
+      let labels = [];
+      let count = [];
       let data = res.data;
       if (Array.isArray(data)) {
         data.forEach(item => {
-          labels.push(moment(item.datetime).format('YYYY-MM-DD'));
+          labels.push(dayjs(item.datetime).format('YYYY-MM-DD'));
           count.push(item.count);
         });
         let userCount = {
           label: gettext('Active Users'),
           data: count,
           borderColor: '#fd913a',
-          backgroundColor: '#fd913a'};
+          backgroundColor: '#fd913a' };
         filesData = [userCount];
       }
       this.setState({
