@@ -1,7 +1,7 @@
 import React, { Component, Fragment } from 'react';
 import { Button, Form, FormGroup, Input, Col } from 'reactstrap';
 import { Utils } from '../../../utils/utils';
-import { seafileAPI } from '../../../utils/seafile-api';
+import { systemAdminAPI } from '../../../utils/system-admin-api';
 import { gettext } from '../../../utils/constants';
 import Paginator from '../../../components/paginator';
 import toaster from '../../../components/toast';
@@ -26,7 +26,7 @@ class SearchUsers extends Component {
         current_page: 1,
       },
       currentPage: 1,
-      perPage: 25,
+      perPage: 100,
       hasUserSelected: false,
       selectedUserList: [],
       isAllUsersSelected: false,
@@ -35,22 +35,24 @@ class SearchUsers extends Component {
     };
   }
 
-  componentDidMount () {
+  componentDidMount() {
     let params = (new URL(document.location)).searchParams;
     const { currentPage, perPage } = this.state;
     this.setState({
       query: params.get('query') || '',
       currentPage: parseInt(params.get('page') || currentPage),
       perPage: parseInt(params.get('per_page') || perPage)
-    }, () => {this.getItems(this.state.currentPage);});
+    }, () => {
+      this.getItems(this.state.currentPage);
+    });
   }
 
   toggleBatchSetQuotaDialog = () => {
-    this.setState({isBatchSetQuotaDialogOpen: !this.state.isBatchSetQuotaDialogOpen});
+    this.setState({ isBatchSetQuotaDialogOpen: !this.state.isBatchSetQuotaDialogOpen });
   };
 
   toggleBatchDeleteUserDialog = () => {
-    this.setState({isBatchDeleteUserDialogOpen: !this.state.isBatchDeleteUserDialogOpen});
+    this.setState({ isBatchDeleteUserDialogOpen: !this.state.isBatchDeleteUserDialogOpen });
   };
 
   onUserSelected = (item) => {
@@ -112,7 +114,7 @@ class SearchUsers extends Component {
   };
 
   getItems = (page) => {
-    seafileAPI.sysAdminSearchUsers(this.state.query.trim(), page, this.state.perPage).then(res => {
+    systemAdminAPI.sysAdminSearchUsers(this.state.query.trim(), page, this.state.perPage).then(res => {
       this.setState({
         userList: res.data.user_list,
         loading: false,
@@ -135,11 +137,11 @@ class SearchUsers extends Component {
   };
 
   deleteUser = (email, username) => {
-    seafileAPI.sysAdminDeleteUser(email).then(res => {
+    systemAdminAPI.sysAdminDeleteUser(email).then(res => {
       let newUserList = this.state.userList.filter(item => {
         return item.email != email;
       });
-      this.setState({userList: newUserList});
+      this.setState({ userList: newUserList });
       let msg = gettext('Deleted user %s');
       msg = msg.replace('%s', username);
       toaster.success(msg);
@@ -153,7 +155,7 @@ class SearchUsers extends Component {
     let emails = this.state.selectedUserList.map(user => {
       return user.email;
     });
-    seafileAPI.sysAdminSetUserQuotaInBatch(emails, quotaTotal).then(res => {
+    systemAdminAPI.sysAdminSetUserQuotaInBatch(emails, quotaTotal).then(res => {
       let userList = this.state.userList.map(item => {
         res.data.success.forEach(resultUser => {
           if (item.email == resultUser.email) {
@@ -162,7 +164,7 @@ class SearchUsers extends Component {
         });
         return item;
       });
-      this.setState({userList: userList});
+      this.setState({ userList: userList });
     }).catch((error) => {
       let errMessage = Utils.getErrorMsg(error);
       toaster.danger(errMessage);
@@ -173,11 +175,11 @@ class SearchUsers extends Component {
     let emails = this.state.selectedUserList.map(user => {
       return user.email;
     });
-    seafileAPI.sysAdminDeleteUserInBatch(emails).then(res => {
+    systemAdminAPI.sysAdminDeleteUserInBatch(emails).then(res => {
       if (res.data.success.length) {
         let oldUserList = this.state.userList;
         let newUserList = oldUserList.filter(oldUser => {
-          return !res.data.success.some(deletedUser =>{
+          return !res.data.success.some(deletedUser => {
             return deletedUser.email == oldUser.email;
           });
         });
@@ -203,14 +205,14 @@ class SearchUsers extends Component {
   };
 
   updateUser = (email, key, value) => {
-    seafileAPI.sysAdminUpdateUser(email, key, value).then(res => {
+    systemAdminAPI.sysAdminUpdateUser(email, key, value).then(res => {
       let newUserList = this.state.userList.map(item => {
         if (item.email == email) {
-          item[key]= res.data[key];
+          item[key] = res.data[key];
         }
         return item;
       });
-      this.setState({userList: newUserList});
+      this.setState({ userList: newUserList });
       const msg = (key == 'is_active' && value) ?
         res.data.update_status_tip : gettext('Edit succeeded');
       toaster.success(msg);
@@ -221,14 +223,14 @@ class SearchUsers extends Component {
   };
 
   updateAdminRole = (email, role) => {
-    seafileAPI.sysAdminUpdateAdminRole(email, role).then(res => {
+    systemAdminAPI.sysAdminUpdateAdminRole(email, role).then(res => {
       let newUserList = this.state.userList.map(item => {
         if (item.email == email) {
           item.admin_role = res.data.role;
         }
         return item;
       });
-      this.setState({userList: newUserList});
+      this.setState({ userList: newUserList });
       toaster.success(gettext('Edit succeeded'));
     }).catch((error) => {
       let errMessage = Utils.getErrorMsg(error);
@@ -237,7 +239,7 @@ class SearchUsers extends Component {
   };
 
   revokeAdmin = (email, name) => {
-    seafileAPI.sysAdminUpdateUser(email, 'is_staff', false).then(res => {
+    systemAdminAPI.sysAdminUpdateUser(email, 'is_staff', false).then(res => {
       let userList = this.state.userList.filter(item => {
         return item.email != email;
       });
@@ -276,7 +278,7 @@ class SearchUsers extends Component {
     if (e.keyCode === 13) {
       const { isSubmitBtnActive } = this.state;
       if (isSubmitBtnActive) {
-        this.getItems();
+        this.getItems(1);
       }
     }
   };
@@ -314,8 +316,13 @@ class SearchUsers extends Component {
                     </Col>
                   </FormGroup>
                   <FormGroup row>
-                    <Col sm={{size: 5}}>
-                      <button className="btn btn-outline-primary" disabled={!isSubmitBtnActive} onClick={this.getItems}>{gettext('Submit')}</button>
+                    <Col sm={{ size: 5 }}>
+                      <button
+                        className="btn btn-outline-primary"
+                        disabled={!isSubmitBtnActive}
+                        onClick={() => this.getItems(1)}
+                      >{gettext('Submit')}
+                      </button>
                     </Col>
                   </FormGroup>
                 </Form>
@@ -329,6 +336,7 @@ class SearchUsers extends Component {
                   loading={this.state.loading}
                   errorMsg={this.state.errorMsg}
                   items={this.state.userList}
+                  curPerPage={this.state.perPage}
                   updateUser={this.updateUser}
                   deleteUser={this.deleteUser}
                   updateAdminRole={this.updateAdminRole}
