@@ -2,7 +2,7 @@ import React, { Component, Fragment } from 'react';
 import PropTypes from 'prop-types';
 import { FormGroup, Label, Input, Button } from 'reactstrap';
 import { Utils } from '../../../utils/utils';
-import { seafileAPI } from '../../../utils/seafile-api';
+import { systemAdminAPI } from '../../../utils/system-admin-api';
 import { gettext, isPro } from '../../../utils/constants';
 import toaster from '../../../components/toast';
 import Loading from '../../../components/loading';
@@ -11,8 +11,9 @@ import SysAdminSetUploadDownloadRateLimitDialog from '../../../components/dialog
 import SysAdminUpdateUserDialog from '../../../components/dialog/sysadmin-dialog/update-user';
 import MainPanelTopbar from '../main-panel-topbar';
 import Nav from './user-nav';
+import Selector from '../../../components/single-selector';
 
-const { twoFactorAuthEnabled } = window.sysadmin.pageOptions;
+const { twoFactorAuthEnabled, availableRoles } = window.sysadmin.pageOptions;
 
 class Content extends Component {
 
@@ -24,20 +25,21 @@ class Content extends Component {
       isSetQuotaDialogOpen: false,
       isSetUserUploadRateLimitDialogOpen: false,
       isSetUserDownloadRateLimitDialogOpen: false,
-      isUpdateUserDialogOpen: false
+      isUpdateUserDialogOpen: false,
+      highlight: false
     };
   }
 
   toggleSetQuotaDialog = () => {
-    this.setState({isSetQuotaDialogOpen: !this.state.isSetQuotaDialogOpen});
+    this.setState({ isSetQuotaDialogOpen: !this.state.isSetQuotaDialogOpen });
   };
 
   toggleSetUserUploadRateLimitDialog = () => {
-    this.setState({isSetUserUploadRateLimitDialogOpen: !this.state.isSetUserUploadRateLimitDialogOpen});
+    this.setState({ isSetUserUploadRateLimitDialogOpen: !this.state.isSetUserUploadRateLimitDialogOpen });
   };
 
   toggleSetUserDownloadRateLimitDialog = () => {
-    this.setState({isSetUserDownloadRateLimitDialogOpen: !this.state.isSetUserDownloadRateLimitDialogOpen});
+    this.setState({ isSetUserDownloadRateLimitDialogOpen: !this.state.isSetUserDownloadRateLimitDialogOpen });
   };
 
   updateQuota = (value) => {
@@ -45,10 +47,10 @@ class Content extends Component {
   };
 
   updateUploadDownloadRateLimit = (uploadOrDownload, value) => {
-    if (uploadOrDownload == 'upload'){
+    if (uploadOrDownload == 'upload') {
       this.props.updateUser('upload_rate_limit', value);
     }
-    if (uploadOrDownload == 'download'){
+    if (uploadOrDownload == 'download') {
       this.props.updateUser('download_rate_limit', value);
     }
   };
@@ -69,14 +71,10 @@ class Content extends Component {
     this.toggleDialog('login_id', gettext('Set Login ID'));
   };
 
-  toggleSetUserComtactEmailDialog = () => {
+  toggleSetUserContactEmailDialog = () => {
     this.toggleDialog('contact_email', gettext('Set Contact Email'));
   };
 
-  toggleSetUserReferenceIDDialog = () => {
-    this.toggleDialog('reference_id', gettext('Set Reference ID'));
-  };
-
   updateValue = (value) => {
     this.props.updateUser(this.state.currentKey, value);
   };
@@ -89,7 +87,7 @@ class Content extends Component {
     return (
       <span
         title={gettext('Edit')}
-        className="fa fa-pencil-alt attr-action-icon"
+        className="sf3-font sf3-font-rename attr-action-icon"
         onClick={action}>
       </span>
     );
@@ -97,6 +95,7 @@ class Content extends Component {
 
   render() {
     const { loading, errorMsg } = this.props;
+    const { highlight } = this.state;
     if (loading) {
       return <Loading />;
     } else if (errorMsg) {
@@ -113,7 +112,7 @@ class Content extends Component {
           <dl className="m-0">
             <dt className="info-item-heading">{gettext('Avatar')}</dt>
             <dd className="info-item-content">
-              <img src={user.avatar_url} alt={user.name} width="80" className="rounded"  />
+              <img src={user.avatar_url} alt={user.name} width="80" className="rounded" />
             </dd>
 
             <dt className="info-item-heading">{gettext('Email')}</dt>
@@ -141,13 +140,18 @@ class Content extends Component {
             <dt className="info-item-heading">{gettext('Contact Email')}</dt>
             <dd className="info-item-content">
               {user.contact_email || '--'}
-              {this.showEditIcon(this.toggleSetUserComtactEmailDialog)}
+              {this.showEditIcon(this.toggleSetUserContactEmailDialog)}
             </dd>
 
-            <dt className="info-item-heading">{gettext('Reference ID')}</dt>
+            <dt className="info-item-heading">{gettext('Role')}</dt>
             <dd className="info-item-content">
-              {user.reference_id|| '--'}
-              {this.showEditIcon(this.toggleSetUserReferenceIDDialog)}
+              <Selector
+                isDropdownToggleShown={highlight}
+                currentSelectedOption={this.props.currentSelectedRoleOption}
+                options={this.props.roleOptions}
+                selectOption={this.props.updateRole}
+                toggleItemFreezed={this.props.toggleItemFreezed}
+              />
             </dd>
 
             <dt className="info-item-heading">{gettext('Space Used / Quota')}</dt>
@@ -249,10 +253,10 @@ class User extends Component {
     };
   }
 
-  componentDidMount () {
+  componentDidMount() {
     // avatar size: 160
     const email = decodeURIComponent(this.props.email);
-    seafileAPI.sysAdminGetUser(email, 160).then((res) => {
+    systemAdminAPI.sysAdminGetUser(email).then((res) => {
       this.setState({
         loading: false,
         userInfo: res.data
@@ -267,9 +271,9 @@ class User extends Component {
 
   updateUser = (key, value) => {
     const email = this.state.userInfo.email;
-    seafileAPI.sysAdminUpdateUser(email, key, value).then(res => {
+    systemAdminAPI.sysAdminUpdateUser(email, key, value).then(res => {
       let userInfo = this.state.userInfo;
-      userInfo[key]= res.data[key];
+      userInfo[key] = res.data[key];
       this.setState({
         userInfo: userInfo
       });
@@ -280,9 +284,14 @@ class User extends Component {
     });
   };
 
+
+  updateRole = (roleOption) => {
+    this.updateUser('role', roleOption.value);
+  };
+
   disable2FA = () => {
     const email = this.state.userInfo.email;
-    seafileAPI.sysAdminDeleteTwoFactorAuth(email).then(res => {
+    systemAdminAPI.sysAdminDeleteTwoFactorAuth(email).then(res => {
       let userInfo = this.state.userInfo;
       userInfo.has_default_device = false;
       this.setState({
@@ -297,7 +306,7 @@ class User extends Component {
   toggleForce2fa = (e) => {
     const email = this.state.userInfo.email;
     const checked = e.target.checked;
-    seafileAPI.sysAdminSetForceTwoFactorAuth(email, checked).then(res => {
+    systemAdminAPI.sysAdminSetForceTwoFactorAuth(email, checked).then(res => {
       let userInfo = this.state.userInfo;
       userInfo.is_force_2fa = checked;
       this.setState({
@@ -309,8 +318,34 @@ class User extends Component {
     });
   };
 
+  translateRole = (role) => {
+    switch (role) {
+      case 'default':
+        return gettext('Default');
+      case 'guest':
+        return gettext('Guest');
+      default:
+        return role;
+    }
+  };
+
   render() {
     const { userInfo } = this.state;
+    let currentSelectedRoleOption;
+    const { role: curRole } = userInfo;
+    this.roleOptions = availableRoles.map(item => {
+      return {
+        value: item,
+        text: this.translateRole(item),
+        isSelected: item == curRole
+      };
+    });
+    currentSelectedRoleOption = this.roleOptions.filter(item => item.isSelected)[0] || {
+      value: curRole,
+      text: this.translateRole(curRole),
+      isSelected: true
+    };
+
     return (
       <Fragment>
         <MainPanelTopbar {...this.props} />
@@ -322,6 +357,9 @@ class User extends Component {
                 loading={this.state.loading}
                 errorMsg={this.state.errorMsg}
                 userInfo={this.state.userInfo}
+                roleOptions={this.roleOptions}
+                currentSelectedRoleOption={currentSelectedRoleOption}
+                updateRole={this.updateRole}
                 updateUser={this.updateUser}
                 disable2FA={this.disable2FA}
                 toggleForce2fa={this.toggleForce2fa}
