@@ -1,9 +1,10 @@
 import React, { Component, Fragment } from 'react';
 import PropTypes from 'prop-types';
 import { Link } from '@gatsbyjs/reach-router';
-import moment from 'moment';
+import dayjs from 'dayjs';
+import relativeTime from 'dayjs/plugin/relativeTime';
 import { Utils } from '../../../utils/utils';
-import { seafileAPI } from '../../../utils/seafile-api';
+import { systemAdminAPI } from '../../../utils/system-admin-api';
 import { isPro, siteRoot, gettext } from '../../../utils/constants';
 import toaster from '../../../components/toast';
 import EmptyTip from '../../../components/empty-tip';
@@ -15,6 +16,7 @@ import MainPanelTopbar from '../main-panel-topbar';
 import Nav from './user-nav';
 
 const { enableSysAdminViewRepo } = window.sysadmin.pageOptions;
+dayjs.extend(relativeTime);
 
 class Content extends Component {
 
@@ -26,11 +28,11 @@ class Content extends Component {
   }
 
   onFreezedItem = () => {
-    this.setState({isItemFreezed: true});
+    this.setState({ isItemFreezed: true });
   };
 
   onUnfreezedItem = () => {
-    this.setState({isItemFreezed: false});
+    this.setState({ isItemFreezed: false });
   };
 
   render() {
@@ -41,8 +43,7 @@ class Content extends Component {
       return <p className="error text-center mt-4">{errorMsg}</p>;
     } else {
       const emptyTip = (
-        <EmptyTip>
-          <h2>{gettext('No libraries')}</h2>
+        <EmptyTip text={gettext('No libraries')}>
         </EmptyTip>
       );
       const table = (
@@ -125,7 +126,7 @@ class Item extends Component {
   };
 
   toggleDeleteDialog = () => {
-    this.setState({isDeleteDialogOpen: !this.state.isDeleteDialogOpen});
+    this.setState({ isDeleteDialogOpen: !this.state.isDeleteDialogOpen });
   };
 
   deleteRepo = () => {
@@ -133,11 +134,11 @@ class Item extends Component {
   };
 
   toggleTransferDialog = () => {
-    this.setState({isTransferDialogOpen: !this.state.isTransferDialogOpen});
+    this.setState({ isTransferDialogOpen: !this.state.isTransferDialogOpen });
   };
 
-  transferRepo = (owner) => {
-    this.props.transferRepo(this.props.item.id, owner.email);
+  transferRepo = (owner, reshare) => {
+    this.props.transferRepo(this.props.item.id, owner.email, reshare);
     this.toggleTransferDialog();
   };
 
@@ -171,7 +172,7 @@ class Item extends Component {
   };
 
   onMenuItemClick = (operation) => {
-    switch(operation) {
+    switch (operation) {
       case 'Delete':
         this.toggleDeleteDialog();
         break;
@@ -197,7 +198,7 @@ class Item extends Component {
           <td><img src={iconUrl} title={iconTitle} alt={iconTitle} width="24" /></td>
           <td>{this.renderRepoName()}</td>
           <td>{Utils.bytesToSize(item.size)}</td>
-          <td>{moment(item.last_modified).fromNow()}</td>
+          <td>{dayjs(item.last_modified).fromNow()}</td>
           <td>
             {isOpIconShown &&
             <OpMenu
@@ -222,7 +223,7 @@ class Item extends Component {
         {isTransferDialogOpen &&
         <TransferDialog
           itemName={item.name}
-          submit={this.transferRepo}
+          onTransferRepo={this.transferRepo}
           canTransferToDept={false}
           toggleDialog={this.toggleTransferDialog}
         />
@@ -253,14 +254,14 @@ class Repos extends Component {
     };
   }
 
-  componentDidMount () {
+  componentDidMount() {
     const email = decodeURIComponent(this.props.email);
-    seafileAPI.sysAdminGetUser(email).then((res) => {
+    systemAdminAPI.sysAdminGetUser(email).then((res) => {
       this.setState({
         userInfo: res.data
       });
     });
-    seafileAPI.sysAdminListReposByOwner(email).then(res => {
+    systemAdminAPI.sysAdminListReposByOwner(email).then(res => {
       this.setState({
         loading: false,
         repoList: res.data.repos
@@ -274,11 +275,11 @@ class Repos extends Component {
   }
 
   deleteRepo = (repoID) => {
-    seafileAPI.sysAdminDeleteRepo(repoID).then(res => {
+    systemAdminAPI.sysAdminDeleteRepo(repoID).then(res => {
       let newRepoList = this.state.repoList.filter(item => {
         return item.id != repoID;
       });
-      this.setState({repoList: newRepoList});
+      this.setState({ repoList: newRepoList });
       toaster.success(gettext('Successfully deleted 1 item.'));
     }).catch((error) => {
       let errMessage = Utils.getErrorMsg(error);
@@ -286,12 +287,12 @@ class Repos extends Component {
     });
   };
 
-  transferRepo = (repoID, email) => {
-    seafileAPI.sysAdminTransferRepo(repoID, email).then((res) => {
+  transferRepo = (repoID, email, reshare) => {
+    systemAdminAPI.sysAdminTransferRepo(repoID, email, reshare).then((res) => {
       let newRepoList = this.state.repoList.filter(item => {
         return item.id != repoID;
       });
-      this.setState({repoList: newRepoList});
+      this.setState({ repoList: newRepoList });
       let message = gettext('Successfully transferred the library.');
       toaster.success(message);
     }).catch(error => {
