@@ -1,9 +1,10 @@
 import React, { Component, Fragment } from 'react';
 import PropTypes from 'prop-types';
 import { Link } from '@gatsbyjs/reach-router';
-import moment from 'moment';
+import dayjs from 'dayjs';
+import relativeTime from 'dayjs/plugin/relativeTime';
 import { Utils } from '../../../utils/utils';
-import { seafileAPI } from '../../../utils/seafile-api';
+import { systemAdminAPI } from '../../../utils/system-admin-api';
 import { isPro, siteRoot, gettext } from '../../../utils/constants';
 import EmptyTip from '../../../components/empty-tip';
 import Loading from '../../../components/loading';
@@ -12,6 +13,7 @@ import UserLink from '../user-link';
 import Nav from './user-nav';
 
 const { enableSysAdminViewRepo } = window.sysadmin.pageOptions;
+dayjs.extend(relativeTime);
 
 class Content extends Component {
   render() {
@@ -21,35 +23,28 @@ class Content extends Component {
     } else if (errorMsg) {
       return <p className="error text-center mt-4">{errorMsg}</p>;
     } else {
-      const emptyTip = (
-        <EmptyTip>
-          <h2>{gettext('No libraries')}</h2>
-        </EmptyTip>
-      );
       const table = (
-        <Fragment>
-          <table className="table-hover">
-            <thead>
-              <tr>
-                <th width="5%"></th>
-                <th width="35%">{gettext('Name')}</th>
-                <th width="20%">{gettext('Share From')}</th>
-                <th width="20%">{gettext('Size')}</th>
-                <th width="20%">{gettext('Last Update')}</th>
-              </tr>
-            </thead>
-            <tbody>
-              {items.map((item, index) => {
-                return (<Item
-                  key={index}
-                  item={item}
-                />);
-              })}
-            </tbody>
-          </table>
-        </Fragment>
+        <table className="table-hover">
+          <thead>
+            <tr>
+              <th width="5%"></th>
+              <th width="35%">{gettext('Name')}</th>
+              <th width="20%">{gettext('Share From')}</th>
+              <th width="20%">{gettext('Size')}</th>
+              <th width="20%">{gettext('Last Update')}</th>
+            </tr>
+          </thead>
+          <tbody>
+            {items.map((item, index) => {
+              return (<Item
+                key={index}
+                item={item}
+              />);
+            })}
+          </tbody>
+        </table>
       );
-      return items.length ? table : emptyTip;
+      return items.length ? table : <EmptyTip text={gettext('No libraries')} />;
     }
   }
 }
@@ -85,7 +80,7 @@ class Item extends Component {
       link = <UserLink email={item.owner_email} name={item.owner_name} />;
     } else {
       const groupID = item.owner_email.substring(0, index);
-      link = <Link to={`${siteRoot}sys/departments/${groupID}/`}>{item.owner_name}</Link>;
+      link = <Link to={`${siteRoot}sys/groups/${groupID}/libraries/`}>{item.owner_name}</Link>;
     }
     return link;
   };
@@ -95,15 +90,13 @@ class Item extends Component {
     const iconUrl = Utils.getLibIconUrl(item);
     const iconTitle = Utils.getLibIconTitle(item);
     return (
-      <Fragment>
-        <tr>
-          <td><img src={iconUrl} title={iconTitle} alt={iconTitle} width="24" /></td>
-          <td>{this.renderRepoName()}</td>
-          <td>{this.getOwnerLink()}</td>
-          <td>{Utils.bytesToSize(item.size)}</td>
-          <td>{moment(item.last_modify).fromNow()}</td>
-        </tr>
-      </Fragment>
+      <tr>
+        <td><img src={iconUrl} title={iconTitle} alt={iconTitle} width="24" /></td>
+        <td>{this.renderRepoName()}</td>
+        <td>{this.getOwnerLink()}</td>
+        <td>{Utils.bytesToSize(item.size)}</td>
+        <td>{dayjs(item.last_modify).fromNow()}</td>
+      </tr>
     );
   }
 }
@@ -124,14 +117,14 @@ class Repos extends Component {
     };
   }
 
-  componentDidMount () {
+  componentDidMount() {
     const email = decodeURIComponent(this.props.email);
-    seafileAPI.sysAdminGetUser(email).then((res) => {
+    systemAdminAPI.sysAdminGetUser(email).then((res) => {
       this.setState({
         userInfo: res.data
       });
     });
-    seafileAPI.sysAdminListShareInRepos(email).then(res => {
+    systemAdminAPI.sysAdminListShareInRepos(email).then(res => {
       this.setState({
         loading: false,
         repoList: res.data.repo_list
