@@ -1,9 +1,10 @@
 import React, { Component, Fragment } from 'react';
 import PropTypes from 'prop-types';
-import moment from 'moment';
+import dayjs from 'dayjs';
+import relativeTime from 'dayjs/plugin/relativeTime';
 import { Link } from '@gatsbyjs/reach-router';
 import { Utils } from '../../../utils/utils';
-import { seafileAPI } from '../../../utils/seafile-api';
+import { systemAdminAPI } from '../../../utils/system-admin-api';
 import { isPro, username, gettext, multiInstitution, siteRoot } from '../../../utils/constants';
 import toaster from '../../../components/toast';
 import EmptyTip from '../../../components/empty-tip';
@@ -16,6 +17,7 @@ import CommonOperationConfirmationDialog from '../../../components/dialog/common
 import UserLink from '../user-link';
 
 const { availableRoles, availableAdminRoles, institutions } = window.sysadmin.pageOptions;
+dayjs.extend(relativeTime);
 
 class Content extends Component {
 
@@ -31,11 +33,11 @@ class Content extends Component {
   };
 
   onFreezedItem = () => {
-    this.setState({isItemFreezed: true});
+    this.setState({ isItemFreezed: true });
   };
 
   onUnfreezedItem = () => {
-    this.setState({isItemFreezed: false});
+    this.setState({ isItemFreezed: false });
   };
 
   getPreviousPage = () => {
@@ -57,26 +59,20 @@ class Content extends Component {
       curPerPage, hasNextPage, currentPage,
       sortBy, sortOrder
     } = this.props;
+
     if (loading) {
       return <Loading />;
     } else if (errorMsg) {
       return <p className="error text-center mt-4">{errorMsg}</p>;
     } else {
-      const emptyTip = (
-        <EmptyTip>
-          <h2>{gettext('No users')}</h2>
-        </EmptyTip>
-      );
-
-
       let columns = [];
 
       let sortIcon;
       if (sortBy == '') {
         // initial sort icon
-        sortIcon = <span className="fas fa-sort"></span>;
+        sortIcon = <span className="sf3-font sf3-font-sort3"></span>;
       } else {
-        sortIcon = <span className={`fas ${sortOrder == 'asc' ? 'fa-caret-up' : 'fa-caret-down'}`}></span>;
+        sortIcon = <span className={`sf3-font ${sortOrder == 'asc' ? 'sf3-font-down rotate-180 d-inline-block' : 'sf3-font-down'}`}></span>;
       }
       const spaceText = gettext('Space Used');
       const spaceEl =
@@ -89,28 +85,28 @@ class Content extends Component {
       const colCreatedText = `${gettext('Created At')} / ${gettext('Last Login')} / ${gettext('Last Access')}`;
       if (isPro) {
         columns.push(
-          {width: '20%', text: colNameText},
-          {width: '15%', text: gettext('Status')},
-          {width: '15%', text: gettext('Role')}
+          { width: '20%', text: colNameText },
+          { width: '15%', text: gettext('Status') },
+          { width: '15%', text: gettext('Role') }
         );
       } else {
         columns.push(
-          {width: '30%', text: colNameText},
-          {width: '20%', text: gettext('Status')}
+          { width: '30%', text: colNameText },
+          { width: '20%', text: gettext('Status') }
         );
       }
       if (multiInstitution && !isAdmin) {
         columns.push(
-          {width: '14%', text: colSpaceText},
-          {width: '14%', text: gettext('Institution')},
-          {width: '14%', text: colCreatedText},
-          {width: '5%', text: ''}
+          { width: '14%', text: colSpaceText },
+          { width: '14%', text: gettext('Institution') },
+          { width: '14%', text: colCreatedText },
+          { width: '5%', text: '' }
         );
       } else {
         columns.push(
-          {width: '20%', text: colSpaceText},
-          {width: '22%', text: colCreatedText},
-          {width: '5%', text: ''}
+          { width: '20%', text: colSpaceText },
+          { width: '22%', text: colCreatedText },
+          { width: '5%', text: '' }
         );
       }
 
@@ -129,21 +125,26 @@ class Content extends Component {
             </thead>
             <tbody>
               {items.map((item, index) => {
-                return (<Item
-                  key={index}
-                  item={item}
-                  isItemFreezed={this.state.isItemFreezed}
-                  onFreezedItem={this.onFreezedItem}
-                  onUnfreezedItem={this.onUnfreezedItem}
-                  toggleItemFreezed={this.toggleItemFreezed}
-                  updateUser={this.props.updateUser}
-                  deleteUser={this.props.deleteUser}
-                  updateAdminRole={this.props.updateAdminRole}
-                  revokeAdmin={this.props.revokeAdmin}
-                  onUserSelected={this.props.onUserSelected}
-                  isAdmin={this.props.isAdmin}
-                  isLDAPImported={this.props.isLDAPImported}
-                />);
+                if (index < this.props.curPerPage) {
+                  return (
+                    <Item
+                      key={index}
+                      item={item}
+                      isItemFreezed={this.state.isItemFreezed}
+                      onFreezedItem={this.onFreezedItem}
+                      onUnfreezedItem={this.onUnfreezedItem}
+                      toggleItemFreezed={this.toggleItemFreezed}
+                      updateUser={this.props.updateUser}
+                      deleteUser={this.props.deleteUser}
+                      updateAdminRole={this.props.updateAdminRole}
+                      revokeAdmin={this.props.revokeAdmin}
+                      onUserSelected={this.props.onUserSelected}
+                      isAdmin={this.props.isAdmin}
+                      isLDAPImported={this.props.isLDAPImported}
+                    />
+                  );
+                }
+                return null;
               })}
             </tbody>
           </table>
@@ -160,7 +161,11 @@ class Content extends Component {
         </Fragment>
       );
 
-      return items.length ? table : emptyTip;
+      return (
+        <div>
+          {items.length ? table : <EmptyTip text={gettext('No users')} />}
+        </div>
+      );
     }
   }
 }
@@ -187,7 +192,7 @@ Content.propTypes = {
   onUserSelected: PropTypes.func,
   curPerPage: PropTypes.number,
   hasNextPage: PropTypes.bool,
-  sortOrder: PropTypes.string,
+  sortOrder: PropTypes.string
 };
 
 class Item extends Component {
@@ -200,7 +205,8 @@ class Item extends Component {
       isSetQuotaDialogOpen: false,
       isDeleteUserDialogOpen: false,
       isResetUserPasswordDialogOpen: false,
-      isRevokeAdminDialogOpen: false
+      isRevokeAdminDialogOpen: false,
+      isConfirmInactiveDialogOpen: false
     };
   }
 
@@ -231,26 +237,30 @@ class Item extends Component {
   };
 
   toggleSetQuotaDialog = () => {
-    this.setState({isSetQuotaDialogOpen: !this.state.isSetQuotaDialogOpen});
+    this.setState({ isSetQuotaDialogOpen: !this.state.isSetQuotaDialogOpen });
   };
 
   toggleDeleteUserDialog = () => {
-    this.setState({isDeleteUserDialogOpen: !this.state.isDeleteUserDialogOpen});
+    this.setState({ isDeleteUserDialogOpen: !this.state.isDeleteUserDialogOpen });
   };
 
   toggleResetUserPasswordDialog = () => {
-    this.setState({isResetUserPasswordDialogOpen: !this.state.isResetUserPasswordDialogOpen});
+    this.setState({ isResetUserPasswordDialogOpen: !this.state.isResetUserPasswordDialogOpen });
   };
 
   toggleRevokeAdminDialog = () => {
-    this.setState({isRevokeAdminDialogOpen: !this.state.isRevokeAdminDialogOpen});
+    this.setState({ isRevokeAdminDialogOpen: !this.state.isRevokeAdminDialogOpen });
+  };
+
+  toggleConfirmInactiveDialog = () => {
+    this.setState({ isConfirmInactiveDialogOpen: !this.state.isConfirmInactiveDialogOpen });
   };
 
   onUserSelected = () => {
     this.props.onUserSelected(this.props.item);
   };
 
-  updateStatus= (roleOption) => {
+  updateStatus = (roleOption) => {
     const isActive = roleOption.value == 'active';
     if (isActive) {
       toaster.notify(gettext('It may take some time, please wait.'));
@@ -258,6 +268,10 @@ class Item extends Component {
     this.props.updateUser(this.props.item.email, 'is_active', isActive);
   };
 
+  setUserInactive = () => {
+    this.props.updateUser(this.props.item.email, 'is_active', false);
+  };
+
   updateRole = (roleOption) => {
     this.props.updateUser(this.props.item.email, 'role', roleOption.value);
   };
@@ -316,7 +330,7 @@ class Item extends Component {
 
   resetPassword = () => {
     toaster.notify(gettext('It may take some time, please wait.'));
-    seafileAPI.sysAdminResetUserPassword(this.props.item.email).then(res => {
+    systemAdminAPI.sysAdminResetUserPassword(this.props.item.email).then(res => {
       toaster.success(res.data.reset_tip);
     }).catch((error) => {
       let errMessage = Utils.getErrorMsg(error);
@@ -363,7 +377,7 @@ class Item extends Component {
   };
 
   onMenuItemClick = (operation) => {
-    switch(operation) {
+    switch (operation) {
       case 'Delete':
         this.toggleDeleteUserDialog();
         break;
@@ -386,13 +400,15 @@ class Item extends Component {
       isSetQuotaDialogOpen,
       isDeleteUserDialogOpen,
       isResetUserPasswordDialogOpen,
-      isRevokeAdminDialogOpen
+      isRevokeAdminDialogOpen,
+      isConfirmInactiveDialogOpen
     } = this.state;
 
     const itemName = '<span class="op-target">' + Utils.HTMLescape(item.name) + '</span>';
     const deleteDialogMsg = gettext('Are you sure you want to delete {placeholder} ?').replace('{placeholder}', itemName);
     const resetPasswordDialogMsg = gettext('Are you sure you want to reset the password of {placeholder} ?').replace('{placeholder}', itemName);
     const revokeAdminDialogMsg = gettext('Are you sure you want to revoke the admin permission of {placeholder} ?').replace('{placeholder}', itemName);
+    const confirmSetUserInactiveMsg = gettext('Are you sure you want to set {user_placeholder} inactive?').replace('{user_placeholder}', itemName);
 
     // for 'user status'
     const curStatus = item.is_active ? 'active' : 'inactive';
@@ -473,6 +489,7 @@ class Item extends Component {
               options={this.statusOptions}
               selectOption={this.updateStatus}
               toggleItemFreezed={this.props.toggleItemFreezed}
+              operationBeforeSelect={item.is_active ? this.toggleConfirmInactiveDialog : undefined}
             />
           </td>
           {isPro &&
@@ -500,7 +517,7 @@ class Item extends Component {
             {`${Utils.bytesToSize(item.quota_usage)} / ${item.quota_total > 0 ? Utils.bytesToSize(item.quota_total) : '--'}`}
             <span
               title={gettext('Edit')}
-              className={`fa fa-pencil-alt attr-action-icon ${isOpIconShown ? '' : 'invisible'}`}
+              className={`sf3-font sf3-font-rename attr-action-icon ${isOpIconShown ? '' : 'invisible'}`}
               onClick={this.toggleSetQuotaDialog}>
             </span>
           </td>
@@ -516,11 +533,11 @@ class Item extends Component {
             </td>
           }
           <td>
-            {`${item.create_time ? moment(item.create_time).format('YYYY-MM-DD HH:mm') : '--'} /`}
+            {`${item.create_time ? dayjs(item.create_time).format('YYYY-MM-DD HH:mm') : '--'} /`}
             <br />
-            {`${item.last_login ? moment(item.last_login).fromNow() : '--'}`}
+            {`${item.last_login ? dayjs(item.last_login).fromNow() : '--'}`}
             <br />
-            {`${item.last_access_time ? moment(item.last_access_time).fromNow() : '--'}`}
+            {`${item.last_access_time ? dayjs(item.last_access_time).fromNow() : '--'}`}
           </td>
           <td>
             {(item.email != username && isOpIconShown) &&
@@ -567,6 +584,15 @@ class Item extends Component {
             toggleDialog={this.toggleRevokeAdminDialog}
           />
         }
+        {isConfirmInactiveDialogOpen &&
+          <CommonOperationConfirmationDialog
+            title={gettext('Set user inactive')}
+            message={confirmSetUserInactiveMsg}
+            executeOperation={this.setUserInactive}
+            confirmBtnText={gettext('Set')}
+            toggleDialog={this.toggleConfirmInactiveDialog}
+          />
+        }
       </Fragment>
     );
   }
