@@ -3,7 +3,7 @@ import { navigate } from '@gatsbyjs/reach-router';
 import { Button } from 'reactstrap';
 import PropTypes from 'prop-types';
 import { Utils } from '../../../utils/utils';
-import { seafileAPI } from '../../../utils/seafile-api';
+import { systemAdminAPI } from '../../../utils/system-admin-api';
 import { isPro, gettext, siteRoot } from '../../../utils/constants';
 import toaster from '../../../components/toast';
 import SysAdminUserSetQuotaDialog from '../../../components/dialog/sysadmin-dialog/set-quota';
@@ -16,6 +16,7 @@ import SysAdminAdminUser from '../../../models/sysadmin-admin-user';
 import MainPanelTopbar from '../main-panel-topbar';
 import Search from '../search';
 import UsersNav from './users-nav';
+import UsersFilterBar from './users-filter-bar';
 import Content from './users-content';
 
 const { availableRoles } = window.sysadmin.pageOptions;
@@ -35,7 +36,7 @@ class Users extends Component {
       userList: [],
       hasNextPage: false,
       currentPage: 1,
-      perPage: 25,
+      perPage: 100,
       hasUserSelected: false,
       selectedUserList: [],
       isAllUsersSelected: false,
@@ -43,11 +44,13 @@ class Users extends Component {
       isAddUserDialogOpen: false,
       isBatchSetQuotaDialogOpen: false,
       isBatchDeleteUserDialogOpen: false,
-      isBatchAddAdminDialogOpen: false
+      isBatchAddAdminDialogOpen: false,
+      is_active: '',
+      role: ''
     };
   }
 
-  componentDidMount () {
+  componentDidMount() {
     if (this.props.isAdmin) { // 'Admin' page
       this.getUserList(); // no pagination
     } else {
@@ -55,13 +58,17 @@ class Users extends Component {
       const {
         currentPage, perPage,
         sortBy = '',
-        sortOrder = 'asc'
+        sortOrder = 'asc',
+        is_active,
+        role
       } = this.state;
       this.setState({
         perPage: parseInt(urlParams.get('per_page') || perPage),
         currentPage: parseInt(urlParams.get('page') || currentPage),
         sortBy: urlParams.get('order_by') || sortBy,
-        sortOrder: urlParams.get('direction') || sortOrder
+        sortOrder: urlParams.get('direction') || sortOrder,
+        is_active: urlParams.get('is_active') || is_active,
+        role: urlParams.get('role') || role
       }, () => {
         this.getUsersListByPage(this.state.currentPage);
       });
@@ -69,19 +76,19 @@ class Users extends Component {
   }
 
   toggleImportUserDialog = () => {
-    this.setState({isImportUserDialogOpen: !this.state.isImportUserDialogOpen});
+    this.setState({ isImportUserDialogOpen: !this.state.isImportUserDialogOpen });
   };
 
   toggleAddUserDialog = () => {
-    this.setState({isAddUserDialogOpen: !this.state.isAddUserDialogOpen});
+    this.setState({ isAddUserDialogOpen: !this.state.isAddUserDialogOpen });
   };
 
   toggleBatchSetQuotaDialog = () => {
-    this.setState({isBatchSetQuotaDialogOpen: !this.state.isBatchSetQuotaDialogOpen});
+    this.setState({ isBatchSetQuotaDialogOpen: !this.state.isBatchSetQuotaDialogOpen });
   };
 
   toggleBatchDeleteUserDialog = () => {
-    this.setState({isBatchDeleteUserDialogOpen: !this.state.isBatchDeleteUserDialogOpen});
+    this.setState({ isBatchDeleteUserDialogOpen: !this.state.isBatchDeleteUserDialogOpen });
   };
 
   onUserSelected = (item) => {
@@ -100,8 +107,8 @@ class Users extends Component {
         hasUserSelected = true;
         selectedUserList.push(user);
       } else {
-        selectedUserList = selectedUserList.filter(thisuser => {
-          return thisuser.email != user.email;
+        selectedUserList = selectedUserList.filter(thisUser => {
+          return thisUser.email != user.email;
         });
       }
       return user;
@@ -144,7 +151,7 @@ class Users extends Component {
 
   getUserList = () => {
   // get admins
-    seafileAPI.sysAdminListAdmins().then(res => {
+    systemAdminAPI.sysAdminListAdmins().then(res => {
       let users = res.data.admin_user_list.map(user => {
         return new SysAdminAdminUser(user);
       });
@@ -161,9 +168,9 @@ class Users extends Component {
   };
 
   getUsersListByPage = (page) => {
-    const { perPage, sortBy, sortOrder } = this.state;
+    const { perPage, sortBy, sortOrder, is_active, role } = this.state;
     const { isLDAPImported } = this.props;
-    seafileAPI.sysAdminListUsers(page, perPage, isLDAPImported, sortBy, sortOrder).then(res => {
+    systemAdminAPI.sysAdminListUsers(page, perPage, isLDAPImported, sortBy, sortOrder, is_active, role).then(res => {
       let users = res.data.data.map(user => {return new SysAdminUser(user);});
       this.setState({
         userList: users,
@@ -179,30 +186,70 @@ class Users extends Component {
     });
   };
 
+  updateURLSearchParams = (obj) => {
+    let url = new URL(location.href);
+    let searchParams = new URLSearchParams(url.search);
+    for (const key in obj) {
+      searchParams.set(key, obj[key]);
+    }
+    url.search = searchParams.toString();
+    navigate(url.toString());
+  };
+
+  // is_active: '1', '0', '' (active, inactive, all)
+  onStatusChange = (is_active) => {
+    this.setState({
+      is_active: is_active,
+      currentPage: 1
+    }, () => {
+      const { currentPage, perPage } = this.state;
+      this.updateURLSearchParams({
+        'page': currentPage,
+        'per_page': perPage,
+        'is_active': is_active
+      });
+      this.getUsersListByPage(currentPage);
+    });
+  };
+
+  onRoleChange = (role) => {
+    this.setState({
+      role: role,
+      currentPage: 1
+    }, () => {
+      const { currentPage, perPage } = this.state;
+      this.updateURLSearchParams({
+        'page': currentPage,
+        'per_page': perPage,
+        'role': role
+      });
+      this.getUsersListByPage(currentPage);
+    });
+  };
+
   sortByQuotaUsage = () => {
     this.setState({
       sortBy: 'quota_usage',
       sortOrder: this.state.sortOrder == 'asc' ? 'desc' : 'asc',
       currentPage: 1
     }, () => {
-      let url = new URL(location.href);
-      let searchParams = new URLSearchParams(url.search);
-      const { currentPage, sortBy, sortOrder } = this.state;
-      searchParams.set('page', currentPage);
-      searchParams.set('order_by', sortBy);
-      searchParams.set('direction', sortOrder);
-      url.search = searchParams.toString();
-      navigate(url.toString());
+      const { currentPage, perPage, sortBy, sortOrder } = this.state;
+      this.updateURLSearchParams({
+        'page': currentPage,
+        'per_page': perPage,
+        'order_by': sortBy,
+        'direction': sortOrder
+      });
       this.getUsersListByPage(currentPage);
     });
   };
 
   deleteUser = (email, username) => {
-    seafileAPI.sysAdminDeleteUser(email).then(res => {
+    systemAdminAPI.sysAdminDeleteUser(email).then(res => {
       let newUserList = this.state.userList.filter(item => {
         return item.email != email;
       });
-      this.setState({userList: newUserList});
+      this.setState({ userList: newUserList });
       let msg = gettext('Deleted user %s');
       msg = msg.replace('%s', username);
       toaster.success(msg);
@@ -216,7 +263,7 @@ class Users extends Component {
     let emails = this.state.selectedUserList.map(user => {
       return user.email;
     });
-    seafileAPI.sysAdminSetUserQuotaInBatch(emails, quotaTotal).then(res => {
+    systemAdminAPI.sysAdminSetUserQuotaInBatch(emails, quotaTotal).then(res => {
       let userList = this.state.userList.map(item => {
         res.data.success.forEach(resultUser => {
           if (item.email == resultUser.email) {
@@ -225,7 +272,7 @@ class Users extends Component {
         });
         return item;
       });
-      this.setState({userList: userList});
+      this.setState({ userList: userList });
     }).catch((error) => {
       let errMessage = Utils.getErrorMsg(error);
       toaster.danger(errMessage);
@@ -236,11 +283,11 @@ class Users extends Component {
     let emails = this.state.selectedUserList.map(user => {
       return user.email;
     });
-    seafileAPI.sysAdminDeleteUserInBatch(emails).then(res => {
+    systemAdminAPI.sysAdminDeleteUserInBatch(emails).then(res => {
       if (res.data.success.length) {
         let oldUserList = this.state.userList;
         let newUserList = oldUserList.filter(oldUser => {
-          return !res.data.success.some(deletedUser =>{
+          return !res.data.success.some(deletedUser => {
             return deletedUser.email == oldUser.email;
           });
         });
@@ -267,7 +314,7 @@ class Users extends Component {
 
   importUserInBatch = (file) => {
     toaster.notify(gettext('It may take some time, please wait.'));
-    seafileAPI.sysAdminImportUserViaFile(file).then((res) => {
+    systemAdminAPI.sysAdminImportUserViaFile(file).then((res) => {
       if (res.data.success.length) {
         const users = res.data.success.map(item => {
           if (item.institution == undefined) {
@@ -292,7 +339,7 @@ class Users extends Component {
   addUser = (data) => {
     toaster.notify(gettext('It may take some time, please wait.'));
     const { email, name, role, password } = data;
-    seafileAPI.sysAdminAddUser(email, name, role, password).then((res) => {
+    systemAdminAPI.sysAdminAddUser(email, name, role, password).then((res) => {
       let userList = this.state.userList;
       userList.unshift(res.data);
       this.setState({
@@ -314,14 +361,14 @@ class Users extends Component {
   };
 
   updateUser = (email, key, value) => {
-    seafileAPI.sysAdminUpdateUser(email, key, value).then(res => {
+    systemAdminAPI.sysAdminUpdateUser(email, key, value).then(res => {
       let newUserList = this.state.userList.map(item => {
         if (item.email == email) {
-          item[key]= res.data[key];
+          item[key] = res.data[key];
         }
         return item;
       });
-      this.setState({userList: newUserList});
+      this.setState({ userList: newUserList });
       const msg = (key == 'is_active' && value) ?
         res.data.update_status_tip : gettext('Edit succeeded');
       toaster.success(msg);
@@ -332,14 +379,14 @@ class Users extends Component {
   };
 
   updateAdminRole = (email, role) => {
-    seafileAPI.sysAdminUpdateAdminRole(email, role).then(res => {
+    systemAdminAPI.sysAdminUpdateAdminRole(email, role).then(res => {
       let newUserList = this.state.userList.map(item => {
         if (item.email == email) {
           item.admin_role = res.data.role;
         }
         return item;
       });
-      this.setState({userList: newUserList});
+      this.setState({ userList: newUserList });
       toaster.success(gettext('Edit succeeded'));
     }).catch((error) => {
       let errMessage = Utils.getErrorMsg(error);
@@ -348,7 +395,7 @@ class Users extends Component {
   };
 
   revokeAdmin = (email, name) => {
-    seafileAPI.sysAdminUpdateUser(email, 'is_staff', false).then(res => {
+    systemAdminAPI.sysAdminUpdateUser(email, 'is_staff', false).then(res => {
       let userList = this.state.userList.filter(item => {
         return item.email != email;
       });
@@ -395,11 +442,11 @@ class Users extends Component {
   };
 
   toggleBatchAddAdminDialog = () => {
-    this.setState({isBatchAddAdminDialogOpen: !this.state.isBatchAddAdminDialogOpen});
+    this.setState({ isBatchAddAdminDialogOpen: !this.state.isBatchAddAdminDialogOpen });
   };
 
   addAdminInBatch = (emails) => {
-    seafileAPI.sysAdminAddAdminInBatch(emails).then(res => {
+    systemAdminAPI.sysAdminAddAdminInBatch(emails).then(res => {
       let users = res.data.success.map(user => {
         return new SysAdminAdminUser(user);
       });
@@ -434,6 +481,8 @@ class Users extends Component {
   render() {
     const { isAdmin, isLDAPImported } = this.props;
     const {
+      is_active,
+      role,
       hasUserSelected,
       isImportUserDialogOpen,
       isAddUserDialogOpen,
@@ -441,6 +490,7 @@ class Users extends Component {
       isBatchSetQuotaDialogOpen,
       isBatchAddAdminDialogOpen
     } = this.state;
+    const curTab = this.getCurrentNavItem();
     return (
       <Fragment>
         <MainPanelTopbar search={this.getSearch()} {...this.props}>
@@ -454,8 +504,16 @@ class Users extends Component {
         </MainPanelTopbar>
         <div className="main-panel-center flex-row">
           <div className="cur-view-container">
-            <UsersNav currentItem={this.getCurrentNavItem()} />
+            <UsersNav currentItem={curTab} />
             <div className="cur-view-content">
+              {curTab == 'database' &&
+              <UsersFilterBar
+                isActive={is_active}
+                role={role}
+                onStatusChange={this.onStatusChange}
+                onRoleChange={this.onRoleChange}
+              />
+              }
               <Content
                 isAdmin={isAdmin}
                 isLDAPImported={isLDAPImported}
