@@ -1,6 +1,6 @@
 import React, { Component, Fragment } from 'react';
 import PropTypes from 'prop-types';
-import { seafileAPI } from '../../../utils/seafile-api';
+import { systemAdminAPI } from '../../../utils/system-admin-api';
 import { gettext } from '../../../utils/constants';
 import { Utils } from '../../../utils/utils';
 import toaster from '../../../components/toast';
@@ -60,7 +60,7 @@ class VirusFileItem extends Component {
 
   translateOperations = (item) => {
     let translateResult = '';
-    switch(item) {
+    switch (item) {
       case 'delete':
         translateResult = gettext('Delete');
         break;
@@ -76,8 +76,8 @@ class VirusFileItem extends Component {
 
   render() {
     const virusFile = this.props.virusFile;
-    let fileStatus = '',
-      fileOpList = [];
+    let fileStatus = '';
+    let fileOpList = [];
     if (virusFile.has_deleted) {
       fileStatus = <span className="text-green">{gettext('Deleted')}</span>;
     } else if (virusFile.has_ignored) {
@@ -135,11 +135,11 @@ class Content extends Component {
   }
 
   onFreezedItem = () => {
-    this.setState({isItemFreezed: true});
+    this.setState({ isItemFreezed: true });
   };
 
   onUnfreezedItem = () => {
-    this.setState({isItemFreezed: false});
+    this.setState({ isItemFreezed: false });
   };
 
   getPreviousPage = () => {
@@ -216,7 +216,7 @@ class AllVirusFiles extends Component {
       errorMsg: '',
       virusFiles: [],
       currentPage: 1,
-      perPage: 25,
+      perPage: 100,
       hasNextPage: false
     };
   }
@@ -236,7 +236,7 @@ class AllVirusFiles extends Component {
 
   getListByPage = (page) => {
     const { perPage } = this.state;
-    seafileAPI.listVirusFiles(page, perPage).then((res) => {
+    systemAdminAPI.sysAdminListVirusFiles(page, perPage).then((res) => {
       const data = res.data;
       this.setState({
         loading: false,
@@ -261,15 +261,15 @@ class AllVirusFiles extends Component {
 
   handleFile = (virusID, op) => {
     let request;
-    switch(op) {
+    switch (op) {
       case 'delete':
-        request = seafileAPI.deleteVirusFile(virusID);
+        request = systemAdminAPI.sysAdminDeleteVirusFile(virusID);
         break;
       case 'ignore':
-        request = seafileAPI.toggleIgnoreVirusFile(virusID, true);
+        request = systemAdminAPI.sysAdminToggleIgnoreVirusFile(virusID, true);
         break;
       case 'do-not-ignore':
-        request = seafileAPI.toggleIgnoreVirusFile(virusID, false);
+        request = systemAdminAPI.sysAdminToggleIgnoreVirusFile(virusID, false);
         break;
     }
     request.then((res) => {
