@@ -1,7 +1,7 @@
 import React, { Component, Fragment } from 'react';
 import PropTypes from 'prop-types';
 import { Button } from 'reactstrap';
-import { seafileAPI } from '../../../utils/seafile-api';
+import { systemAdminAPI } from '../../../utils/system-admin-api';
 import { gettext } from '../../../utils/constants';
 import { Utils } from '../../../utils/utils';
 import toaster from '../../../components/toast';
@@ -64,7 +64,7 @@ class VirusFileItem extends Component {
 
   translateOperations = (item) => {
     let translateResult = '';
-    switch(item) {
+    switch (item) {
       case 'delete':
         translateResult = gettext('Delete');
         break;
@@ -84,8 +84,8 @@ class VirusFileItem extends Component {
 
   render() {
     const virusFile = this.props.virusFile;
-    let fileStatus = '',
-      fileOpList = [];
+    let fileStatus = '';
+    let fileOpList = [];
     if (virusFile.has_deleted) {
       fileStatus = <span className="text-green">{gettext('Deleted')}</span>;
     } else if (virusFile.has_ignored) {
@@ -149,11 +149,11 @@ class Content extends Component {
   }
 
   onFreezedItem = () => {
-    this.setState({isItemFreezed: true});
+    this.setState({ isItemFreezed: true });
   };
 
   onUnfreezedItem = () => {
-    this.setState({isItemFreezed: false});
+    this.setState({ isItemFreezed: false });
   };
 
   getPreviousPage = () => {
@@ -239,7 +239,7 @@ class UnhandledVirusFiles extends Component {
       selectedItems: [],
 
       currentPage: 1,
-      perPage: 25,
+      perPage: 100,
       hasNextPage: false
     };
   }
@@ -260,7 +260,7 @@ class UnhandledVirusFiles extends Component {
   getListByPage = (page) => {
     const { perPage } = this.state;
     const hasHandled = false;
-    seafileAPI.listVirusFiles(page, perPage, hasHandled).then((res) => {
+    systemAdminAPI.sysAdminListVirusFiles(page, perPage, hasHandled).then((res) => {
       const data = res.data;
       const items = data.virus_file_list.map(item => {
         item.isSelected = false;
@@ -289,15 +289,15 @@ class UnhandledVirusFiles extends Component {
 
   handleFile = (virusID, op) => {
     let request;
-    switch(op) {
+    switch (op) {
       case 'delete':
-        request = seafileAPI.deleteVirusFile(virusID);
+        request = systemAdminAPI.sysAdminDeleteVirusFile(virusID);
         break;
       case 'ignore':
-        request = seafileAPI.toggleIgnoreVirusFile(virusID, true);
+        request = systemAdminAPI.sysAdminToggleIgnoreVirusFile(virusID, true);
         break;
       case 'do-not-ignore':
-        request = seafileAPI.toggleIgnoreVirusFile(virusID, false);
+        request = systemAdminAPI.sysAdminToggleIgnoreVirusFile(virusID, false);
         break;
     }
     request.then((res) => {
@@ -354,7 +354,7 @@ class UnhandledVirusFiles extends Component {
         }
       })
       .map(item => item.virus_id);
-    seafileAPI.batchProcessVirusFiles(virusIDs, op).then((res) => {
+    systemAdminAPI.sysAdminBatchProcessVirusFiles(virusIDs, op).then((res) => {
       let fileList = this.state.virusFiles;
       res.data.success.forEach(item => {
         let file = fileList.find(file => file.virus_id == item.virus_id);
