@@ -86,8 +86,8 @@ class WorkWeixinDepartmentsTreeNode extends Component {
   render() {
     const { isChildrenShow, department, checkedDepartmentId } = this.props;
     let toggleClass = classNames({
-      'folder-toggle-icon fa fa-caret-down': department.children && this.state.isChildrenShow,
-      'folder-toggle-icon fa fa-caret-right': department.children && !this.state.isChildrenShow,
+      'folder-toggle-icon sf3-font sf3-font-down rotate-270': department.children && this.state.isChildrenShow,
+      'folder-toggle-icon sf3-font sf3-font-down': department.children && !this.state.isChildrenShow,
     });
     let nodeInnerClass = classNames({
       'tree-node-inner': true,
@@ -115,18 +115,21 @@ class WorkWeixinDepartmentsTreeNode extends Component {
               style={this.state.active ? {} : { opacity: 0 }}
             >
               <DropdownToggle
-                tag='i'
-                className='fa fa-ellipsis-v cursor-pointer attr-action-icon'
-                title={gettext('More Operations')}
+                tag='span'
+                className='cursor-pointer right-icon'
+                title={gettext('More operations')}
+                aria-label={gettext('More operations')}
                 data-toggle="dropdown"
                 aria-expanded={this.state.dropdownOpen}
               >
+                <i className="sf3-font sf3-font-more"></i>
               </DropdownToggle>
               <DropdownMenu className="drop-list" right={true}>
                 <DropdownItem
                   onClick={this.importDepartmentDialogToggle.bind(this, department)}
                   id={department.id}
-                >{'导入部门'}</DropdownItem>
+                >{'导入部门'}
+                </DropdownItem>
               </DropdownMenu>
             </Dropdown>
             }
