@@ -25,7 +25,8 @@ class SharedUploadLink extends React.Component {
 
   onFileUploadSuccess = (direntObject) => {
     const { name } = direntObject;
-    seafileAPI.shareLinksUploadDone(token, Utils.joinPath(path, name));
+    const isDir = direntObject.type === 'dir';
+    seafileAPI.shareLinksUploadDone(token, Utils.joinPath(path, name), isDir);
   };
 
   render() {
@@ -37,9 +38,10 @@ class SharedUploadLink extends React.Component {
         </div>
         <div className="o-auto">
           <div className="py-4 px-6 mx-auto rounded" id="upload-link-panel">
-            <h3 className="h5" dangerouslySetInnerHTML={{__html: gettext('Upload files to {folder_name_placeholder}')
-              .replace('{folder_name_placeholder}', `<span class="op-target">${Utils.HTMLescape(dirName)}</span>`)}}></h3>
-            <p className="small shared-by" dangerouslySetInnerHTML={{__html: `${gettext('shared by:')} ${sharedBy.avatar} ${sharedBy.name}`}}></p>
+            <h3 className="h5 d-flex text-nowrap" dangerouslySetInnerHTML={{ __html: gettext('Upload files to {folder_name_placeholder}')
+              .replace('{folder_name_placeholder}', `<span class="op-target text-truncate mx-1">${Utils.HTMLescape(dirName)}</span>`) }}>
+            </h3>
+            <p className="small shared-by" dangerouslySetInnerHTML={{ __html: `${gettext('shared by:')} ${sharedBy.avatar} ${sharedBy.name}` }}></p>
             {noQuota ? (
               <div className="py-6 text-center">
                 <span className="sf3-font sf3-font-tips warning-icon"></span>
@@ -47,10 +49,7 @@ class SharedUploadLink extends React.Component {
               </div>
             ) : (
               <Fragment>
-                <ol className="small text-gray">
-                  <li className="tip-list-item">{gettext('Folder upload is limited to Chrome, Firefox 50+, and Microsoft Edge.')}</li>
-                  {maxUploadFileSize && <li className="tip-list-item">{gettext('File size should be smaller than {max_size_placeholder}.').replace('{max_size_placeholder}', Utils.bytesToSize(maxUploadFileSize * 1000 * 1000))}</li>}
-                </ol>
+                {maxUploadFileSize && <p className="small text-gray m-0">{gettext('File size should be smaller than {max_size_placeholder}.').replace('{max_size_placeholder}', Utils.bytesToSize(maxUploadFileSize * 1000 * 1000))}</p>}
                 <div id="upload-link-drop-zone" className="text-center mt-2 mb-4">
                   <span className="sf3-font sf3-font-upload upload-icon"></span>
                   <p className="small text-gray mb-0">{gettext('Drag and drop files or folders here.')}</p>
