@@ -39,7 +39,7 @@ class UploadListItem extends React.Component {
       }
     }
 
-    this.setState({uploadState: uploadState});
+    this.setState({ uploadState: uploadState });
   }
 
   onUploadCancel = (e) => {
@@ -89,33 +89,53 @@ class UploadListItem extends React.Component {
                   {resumableFile.isUploading() && (
                     <div className="progress-container">
                       <div className="progress">
-                        <div className="progress-bar" role="progressbar" style={{width: `${progress}%`}} aria-valuenow={progress} aria-valuemin="0" aria-valuemax="100"></div>
+                        <div className="progress-bar" role="progressbar" style={{ width: `${progress}%` }} aria-valuenow={progress} aria-valuemin="0" aria-valuemax="100"></div>
                       </div>
                       {(resumableFile.remainingTime === -1) && <div className="progress-text">{gettext('Preparing to upload...')}</div>}
                       {(resumableFile.remainingTime > 0) && <div className="progress-text">{gettext('Remaining')}{' '}{Utils.formatTime(resumableFile.remainingTime)}</div>}
-                      {(resumableFile.remainingTime === 0) && <div className="progress-text">{gettext('Indexing...')}</div>}
+                      {(resumableFile.remainingTime === 0) && <div className="progress-text">{gettext('Saving...')}</div>}
                     </div>
                   )}
                   {!resumableFile.isUploading() && (
                     <div className="progress-container d-flex align-items-center">
                       <div className="progress">
-                        <div className="progress-bar" role="progressbar" style={{width: `${progress}%`}} aria-valuenow={progress} aria-valuemin="0" aria-valuemax="100"></div>
+                        <div className="progress-bar" role="progressbar" style={{ width: `${progress}%` }} aria-valuenow={progress} aria-valuemin="0" aria-valuemax="100"></div>
                       </div>
                     </div>
                   )}
                 </Fragment>
               }
-              {(resumableFile.size < (100 * 1000 * 1000)) &&
-                <div className="progress-container d-flex align-items-center">
-                  <div className="progress">
-                    <div className="progress-bar" role="progressbar" style={{width: `${progress}%`}} aria-valuenow={progress} aria-valuemin="0" aria-valuemax="100"></div>
+              {(resumableFile.size < (100 * 1000 * 1000)) && (
+                <>
+                  <div className="progress-container d-flex align-items-center">
+                    <div className="progress">
+                      <div className="progress-bar" role="progressbar" style={{ width: `${progress}%` }} aria-valuenow={progress} aria-valuemin="0" aria-valuemax="100"></div>
+                    </div>
                   </div>
-                </div>
-              }
+                  {this.state.uploadState === UPLOAD_UPLOADING && (
+                    <>
+                      {progress == 0 && <p className="progress-text mb-0">{gettext('Waiting...')}</p>}
+                      {progress > 0 && <p className="progress-text mb-0">{`${gettext('Uploading...')} ${progress}%`}</p>}
+                    </>
+                  )}
+                  {this.state.uploadState === UPLOAD_ISSAVING && (
+                    <p className="progress-text mb-0">{gettext('Saving...')}</p>
+                  )}
+                </>
+              )}
             </Fragment>
           }
+          {this.state.uploadState === UPLOAD_UPLOADED && (
+            <div className="d-flex align-items-center">
+              <span className="upload-success-icon sf2-icon-tick mr-2"></span>
+              <span className="upload-success-msg">{gettext('Uploaded')}</span>
+            </div>
+          )}
           {this.state.uploadState === UPLOAD_ERROR && (
-            <div className="message err-message ml-0" dangerouslySetInnerHTML={{__html: error}}></div>
+            <div className="d-flex align-items-center">
+              <span className="upload-failure-icon sf3-font sf3-font-info mr-2"></span>
+              <span className="upload-failure-msg" dangerouslySetInnerHTML={{ __html: error }}></span>
+            </div>
           )}
         </td>
         <td className="upload-operation">
@@ -126,12 +146,6 @@ class UploadListItem extends React.Component {
             {this.state.uploadState === UPLOAD_ERROR && (
               <a href="#" onClick={this.onUploadRetry} role="button">{gettext('Retry')}</a>
             )}
-            {this.state.uploadState === UPLOAD_ISSAVING && (
-              <span className="saving">{gettext('Saving...')}</span>
-            )}
-            {this.state.uploadState === UPLOAD_UPLOADED && (
-              <span className="uploaded">{gettext('Uploaded')}</span>
-            )}
           </Fragment>
         </td>
       </tr>
