@@ -1,11 +1,14 @@
 import React, { Fragment } from 'react';
 import PropTypes from 'prop-types';
 import { Button, ButtonDropdown, DropdownToggle, DropdownMenu, DropdownItem } from 'reactstrap';
+import { Utils } from '../../utils/utils';
 import { gettext } from '../../utils/constants';
 import UploadListItem from './upload-list-item';
 import ForbidUploadListItem from './forbid-upload-list-item';
 
 const propTypes = {
+  totalProgress: PropTypes.number.isRequired,
+  uploadBitrate: PropTypes.number.isRequired,
   uploadFileList: PropTypes.array.isRequired,
   forbidUploadFileList: PropTypes.array.isRequired,
   onCancelAllUploading: PropTypes.func.isRequired,
@@ -13,7 +16,7 @@ const propTypes = {
   onUploadRetry: PropTypes.func.isRequired,
   onFileUpload: PropTypes.func.isRequired,
   onFolderUpload: PropTypes.func.isRequired,
-  allFilesUploaded: PropTypes.bool.isRequired
+  isUploading: PropTypes.bool.isRequired
 };
 
 class UploadProgressDialog extends React.Component {
@@ -44,7 +47,18 @@ class UploadProgressDialog extends React.Component {
   };
 
   render() {
-    let { allFilesUploaded } = this.props;
+    const { totalProgress, uploadBitrate, uploadFileList, forbidUploadFileList, isUploading } = this.props;
+    const filesUploadedMsg = gettext('{uploaded_files_num}/{all_files_num} Files')
+      .replace('{uploaded_files_num}', uploadFileList.filter(file => file.isSaved).length)
+      .replace('{all_files_num}', uploadFileList.length);
+    let filesFailedMsg;
+    if (!isUploading) {
+      const failedNum = uploadFileList.filter(file => file.error).length + forbidUploadFileList.length;
+      if (failedNum > 0) {
+        filesFailedMsg = gettext('{failed_files_num} file(s) failed to upload')
+          .replace('{failed_files_num}', failedNum);
+      }
+    }
     return (
       <Fragment>
         <div className="text-center">
@@ -57,18 +71,43 @@ class UploadProgressDialog extends React.Component {
           </ButtonDropdown>
           <Button color="primary" outline={true} className="ml-4"
             onClick={this.props.onCancelAllUploading}
-            disabled={allFilesUploaded}>
+            disabled={!isUploading}>
             {gettext('Cancel All')}
           </Button>
         </div>
-        <div className="mt-4 mh-2">
+        {totalProgress > 0 && (
+          <div id="upload-link-total-progress-container" className={`${!isUploading ? 'd-flex align-items-center' : ''} px-6 py-2`}>
+            <div className="d-flex align-items-center flex-fill">
+              {isUploading ? (
+                <>
+                  <span>{gettext('File Uploading...')}</span>
+                  <span className="ml-2">{`${totalProgress}% (${Utils.formatBitRate(uploadBitrate)})`}</span>
+                </>
+              ) : (
+                <>
+                  {filesFailedMsg ?
+                    <p className="m-0 error">{filesFailedMsg}</p> :
+                    <p className="m-0">{gettext('All files uploaded')}</p>
+                  }
+                </>
+              )}
+              {uploadFileList.length > 0 && <span className="ml-auto">{filesUploadedMsg}</span>}
+            </div>
+            {isUploading && (
+              <div className="progress">
+                <div className="progress-bar" role="progressbar" style={{ width: `${totalProgress}%` }} aria-valuenow={totalProgress} aria-valuemin="0" aria-valuemax="100"></div>
+              </div>
+            )}
+          </div>
+        )}
+        <div className="mh-2">
           <table className="table-thead-hidden">
             <thead>
               <tr>
-                <th width="35%">{gettext('name')}</th>
-                <th width="15%">{gettext('size')}</th>
-                <th width="35%">{gettext('progress')}</th>
-                <th width="15%">{gettext('state')}</th>
+                <th width="40%" scope="col">{gettext('name')}</th>
+                <th width="15%" scope="col">{gettext('size')}</th>
+                <th width="30%" scope="col">{gettext('progress')}</th>
+                <th width="15%" scope="col">{gettext('state')}</th>
               </tr>
             </thead>
             <tbody>
