@@ -2,7 +2,7 @@ import React from 'react';
 import ReactDom from 'react-dom';
 import PropTypes from 'prop-types';
 import { navigate } from '@gatsbyjs/reach-router';
-import moment from 'moment';
+import dayjs from 'dayjs';
 import { Utils } from './utils/utils';
 import { gettext, siteRoot, mediaUrl, logoPath, logoWidth, logoHeight, siteTitle } from './utils/constants';
 import { seafileAPI } from './utils/seafile-api';
@@ -33,7 +33,7 @@ class RepoHistory extends React.Component {
       isLoading: true,
       errorMsg: '',
       currentPage: 1,
-      perPage: 25,
+      perPage: 100,
       hasNextPage: false,
       items: []
     };
@@ -79,7 +79,7 @@ class RepoHistory extends React.Component {
   onSearchedClick = (selectedItem) => {
     if (selectedItem.is_dir === true) {
       let url = siteRoot + 'library/' + selectedItem.repo_id + '/' + selectedItem.repo_name + selectedItem.path;
-      navigate(url, {repalce: true});
+      navigate(url, { replace: true });
     } else {
       let url = siteRoot + 'lib/' + selectedItem.repo_id + '/file' + Utils.encodePath(selectedItem.path);
       let newWindow = window.open('about:blank');
@@ -93,6 +93,9 @@ class RepoHistory extends React.Component {
   };
 
   render() {
+    let title = gettext('{placeholder} Modification History');
+    title = title.replace('{placeholder}', '<span class="op-target text-truncate mx-1">' + Utils.HTMLescape(repoName) + '</span>');
+
     return (
       <React.Fragment>
         <div className="h-100 d-flex flex-column">
@@ -105,9 +108,9 @@ class RepoHistory extends React.Component {
           <div className="flex-auto container-fluid pt-4 pb-6 o-auto">
             <div className="row">
               <div className="col-md-10 offset-md-1">
-                <h2>{Utils.generateDialogTitle(gettext('{placeholder} Modification History'), repoName)}</h2>
+                <h2 dangerouslySetInnerHTML={{ __html: title }} className="d-flex text-nowrap"></h2>
                 <a href="#" className="go-back" title={gettext('Back')} onClick={this.goBack} role="button" aria-label={gettext('Back')}>
-                  <span className="fas fa-chevron-left"></span>
+                  <span className="sf3-font sf3-font-down rotate-90 d-inline-block"></span>
                 </a>
                 {userPerm == 'rw' && <p className="tip">{gettext('Tip: a snapshot will be generated after modification, which records the library state after the modification.')}</p>}
                 <Content
@@ -134,18 +137,18 @@ class Content extends React.Component {
   constructor(props) {
     super(props);
     this.theadData = showLabel ? [
-      {width: '43%', text: gettext('Description')},
-      {width: '12%', text: gettext('Time')},
-      {width: '9%', text: gettext('Modifier')},
-      {width: '12%', text: `${gettext('Device')} / ${gettext('Version')}`},
-      {width: '12%', text: gettext('Labels')},
-      {width: '12%', text: ''}
+      { width: '43%', text: gettext('Description') },
+      { width: '12%', text: gettext('Time') },
+      { width: '9%', text: gettext('Modifier') },
+      { width: '12%', text: `${gettext('Device')} / ${gettext('Version')}` },
+      { width: '12%', text: gettext('Labels') },
+      { width: '12%', text: '' }
     ] : [
-      {width: '43%', text: gettext('Description')},
-      {width: '15%', text: gettext('Time')},
-      {width: '15%', text: gettext('Modifier')},
-      {width: '15%', text: `${gettext('Device')} / ${gettext('Version')}`},
-      {width: '12%', text: ''}
+      { width: '43%', text: gettext('Description') },
+      { width: '15%', text: gettext('Time') },
+      { width: '15%', text: gettext('Modifier') },
+      { width: '15%', text: `${gettext('Device')} / ${gettext('Version')}` },
+      { width: '12%', text: '' }
     ];
   }
 
@@ -226,11 +229,11 @@ class Item extends React.Component {
   }
 
   handleMouseOver = () => {
-    this.setState({isIconShown: true});
+    this.setState({ isIconShown: true });
   };
 
   handleMouseOut = () => {
-    this.setState({isIconShown: false});
+    this.setState({ isIconShown: false });
   };
 
   showCommitDetails = (e) => {
@@ -289,7 +292,7 @@ class Item extends React.Component {
             <a href="#" className="details" onClick={this.showCommitDetails} role="button">{gettext('Details')}</a>
             }
           </td>
-          <td title={moment(item.time).format('LLLL')}>{moment(item.time).format('YYYY-MM-DD')}</td>
+          <td title={dayjs(item.time).format('dddd, MMMM D, YYYY h:mm:ss A')}>{dayjs(item.time).format('YYYY-MM-DD')}</td>
           <td>{name}</td>
           <td>
             {item.client_version ? `${item.device_name} / ${item.client_version}` : 'API / --'}
@@ -300,15 +303,15 @@ class Item extends React.Component {
               return <span key={index} className="commit-label">{item}</span>;
             })}
             {userPerm == 'rw' &&
-            <a href="#" role="button" className={`attr-action-icon fa fa-pencil-alt ${isIconShown ? '': 'invisible'}`} title={gettext('Edit')} aria-label={gettext('Edit')} onClick={this.editLabel}></a>
+            <a href="#" role="button" className={`attr-action-icon sf3-font sf3-font-rename ${isIconShown ? '' : 'invisible'}`} title={gettext('Edit')} aria-label={gettext('Edit')} onClick={this.editLabel}></a>
             }
           </td>
           }
           <td>
             {userPerm == 'rw' && (
               item.isFirstCommit ?
-                <span className={isIconShown ? '': 'invisible'}>{gettext('Current Version')}</span> :
-                <a href={`${siteRoot}repo/${repoID}/snapshot/?commit_id=${item.commit_id}`} className={isIconShown ? '': 'invisible'}>{gettext('View Snapshot')}</a>
+                <span className={isIconShown ? '' : 'invisible'}>{gettext('Current Version')}</span> :
+                <a href={`${siteRoot}repo/${repoID}/snapshot/?commit_id=${item.commit_id}`} className={isIconShown ? '' : 'invisible'}>{gettext('View Snapshot')}</a>
             )}
           </td>
         </tr>
