@@ -3,9 +3,11 @@ import PropTypes from 'prop-types';
 import MD5 from 'MD5';
 import ReactDom from 'react-dom';
 import { Button, Dropdown, DropdownToggle, DropdownItem, UncontrolledTooltip } from 'reactstrap';
-import moment from 'moment';
+import dayjs from 'dayjs';
+import relativeTime from 'dayjs/plugin/relativeTime';
 import Account from './components/common/account';
-import { useGoFileserver, fileServerRoot, gettext, siteRoot, mediaUrl, logoPath, logoWidth, logoHeight, siteTitle, thumbnailSizeForOriginal } from './utils/constants';
+import { useGoFileserver, fileServerRoot, gettext, siteRoot, mediaUrl, logoPath, logoWidth, logoHeight, siteTitle,
+  thumbnailSizeForOriginal, thumbnailDefaultSize, thumbnailSizeForGrid } from './utils/constants';
 import { Utils } from './utils/utils';
 import { seafileAPI } from './utils/seafile-api';
 import Loading from './components/loading';
@@ -18,11 +20,14 @@ import SaveSharedDirDialog from './components/dialog/save-shared-dir-dialog';
 import CopyMoveDirentProgressDialog from './components/dialog/copy-move-dirent-progress-dialog';
 import RepoInfoBar from './components/repo-info-bar';
 import RepoTag from './models/repo-tag';
+import { GRID_MODE, LIST_MODE } from './components/dir-view-mode/constants';
+import { MetadataAIOperationsProvider } from './hooks/metadata-ai-operation';
 
 import './css/shared-dir-view.css';
 import './css/grid-view.css';
 
-moment.locale(window.app.config.lang);
+dayjs.locale(window.app.config.lang);
+dayjs.extend(relativeTime);
 
 let loginUser = window.app.pageOptions.name;
 let {
@@ -30,7 +35,7 @@ let {
   repoID, relativePath,
   mode, thumbnailSize, zipped,
   trafficOverLimit, canDownload,
-  noQuota, canUpload, enableVideoThumbnail
+  noQuota, canUpload, enableVideoThumbnail, enablePDFThumbnail
 } = window.shared.pageOptions;
 
 const showDownloadIcon = !trafficOverLimit && canDownload;
@@ -44,6 +49,8 @@ class SharedDirView extends React.Component {
       errorMsg: '',
       items: [],
 
+      currentMode: mode,
+
       isAllItemsSelected: false,
       selectedItems: [],
 
@@ -77,6 +84,11 @@ class SharedDirView extends React.Component {
       });
     }
 
+    this.listItems(thumbnailSize);
+    this.getShareLinkRepoTags();
+  }
+
+  listItems = (thumbnailSize) => {
     seafileAPI.listSharedDir(token, relativePath, thumbnailSize).then((res) => {
       const items = res.data['dirent_list'].map(item => {
         item.isSelected = false;
@@ -87,7 +99,7 @@ class SharedDirView extends React.Component {
         errorMsg: '',
         items: Utils.sortDirentsInSharedDir(items, this.state.sortBy, this.state.sortOrder)
       });
-      this.getThumbnails();
+      this.getThumbnails(thumbnailSize);
     }).catch((error) => {
       let errorMsg = Utils.getErrorMsg(error);
       this.setState({
@@ -95,9 +107,7 @@ class SharedDirView extends React.Component {
         errorMsg: errorMsg
       });
     });
-
-    this.getShareLinkRepoTags();
-  }
+  };
 
   sortItems = (sortBy, sortOrder) => {
     this.setState({
@@ -107,11 +117,12 @@ class SharedDirView extends React.Component {
     });
   };
 
-  getThumbnails = () => {
+  getThumbnails = (thumbnailSize) => {
     let items = this.state.items.filter((item) => {
       return !item.is_dir &&
         (Utils.imageCheck(item.file_name) ||
-        (enableVideoThumbnail && Utils.videoCheck(item.file_name))) &&
+        (enableVideoThumbnail && Utils.videoCheck(item.file_name)) ||
+        (enablePDFThumbnail && Utils.pdfCheck(item.file_name))) &&
         !item.encoded_thumbnail_src;
     });
     if (items.length == 0) {
@@ -120,7 +131,7 @@ class SharedDirView extends React.Component {
 
     const len = items.length;
     const _this = this;
-    let getThumbnail = function(i) {
+    let getThumbnail = function (i) {
       const curItem = items[i];
       seafileAPI.getShareLinkThumbnail(token, curItem.file_path, thumbnailSize).then((res) => {
         curItem.encoded_thumbnail_src = res.data.encoded_thumbnail_src;
@@ -230,10 +241,10 @@ class SharedDirView extends React.Component {
         return;
       }
       // init state: total is 0
-      let asyncOperationProgress = !data.total ? 0 : parseInt((data.done/data.total * 100).toFixed(2));
+      let asyncOperationProgress = !data.total ? 0 : parseInt((data.done / data.total * 100).toFixed(2));
 
       this.getAsyncCopyMoveProgress();
-      this.setState({asyncOperationProgress: asyncOperationProgress});
+      this.setState({ asyncOperationProgress: asyncOperationProgress });
     } catch (error) {
       this.setState({
         asyncOperationProgress: 0,
@@ -281,7 +292,7 @@ class SharedDirView extends React.Component {
       });
     }).catch((error) => {
       let errMessage = Utils.getErrorMsg(error);
-      this.setState({errMessage: errMessage});
+      this.setState({ errMessage: errMessage });
     });
   };
 
@@ -323,7 +334,10 @@ class SharedDirView extends React.Component {
     return {
       'name': name,
       'url': fileURL,
-      'src': src
+      'parentDir': item.file_path.slice(0, item.file_path.indexOf(name)),
+      'thumbnail': `${siteRoot}thumbnail/${token}/${thumbnailSizeForOriginal}${Utils.encodePath(item.file_path)}`,
+      'src': src,
+      'downloadURL': fileURL + '&dl=1',
     };
   };
 
@@ -399,14 +413,14 @@ class SharedDirView extends React.Component {
       file_name: name,
       file_path: Utils.joinPath(relativePath, name),
       is_dir: false,
-      last_modified: moment().format(),
+      last_modified: dayjs().format(),
       size: size
     };
     const folderItems = this.state.items.filter(item => { return item.is_dir; });
     // put the new file as the first file
     let items = Array.from(this.state.items);
     items.splice(folderItems.length, 0, newItem);
-    this.setState({items: items});
+    this.setState({ items: items });
     seafileAPI.shareLinksUploadDone(token, Utils.joinPath(dirPath, name));
   };
 
@@ -419,9 +433,9 @@ class SharedDirView extends React.Component {
           usedRepoTags.push(usedRepoTag);
         }
       });
-      this.setState({usedRepoTags: usedRepoTags});
-      if (usedRepoTags.length != 0 && relativePath == '/') {
-        this.setState({isRepoInfoBarShow: true});
+      this.setState({ usedRepoTags: usedRepoTags });
+      if (Utils.isDesktop() && usedRepoTags.length != 0 && relativePath == '/') {
+        this.setState({ isRepoInfoBarShow: true });
       }
     }).catch(error => {
       let errMessage = Utils.getErrorMsg(error);
@@ -429,11 +443,27 @@ class SharedDirView extends React.Component {
     });
   };
 
+  switchMode = (mode) => {
+    const { currentMode } = this.state;
+    if (mode == currentMode) {
+      return;
+    } else {
+      this.setState({
+        currentMode: mode,
+        isLoading: true
+      }, () => {
+        const thumbnailSize = mode == LIST_MODE ? thumbnailDefaultSize : thumbnailSizeForGrid;
+        this.listItems(thumbnailSize);
+      });
+    }
+  };
+
   render() {
+    const { currentMode: mode } = this.state;
     const isDesktop = Utils.isDesktop();
     const modeBaseClass = 'btn btn-secondary btn-icon sf-view-mode-btn';
     return (
-      <React.Fragment>
+      <MetadataAIOperationsProvider repoID={repoID} enableMetadata={false} enableOCR={false} repoInfo={{ permission: 'r' }} >
         <div className="h-100 d-flex flex-column">
           <div className="top-header d-flex justify-content-between">
             <a href={siteRoot}>
@@ -443,32 +473,35 @@ class SharedDirView extends React.Component {
           </div>
           <div className="o-auto">
             <div className="shared-dir-view-main">
-              <h2 className="h3">{dirName}</h2>
+              <h2 className="h3 text-truncate" title={dirName}>{dirName}</h2>
               <p>{gettext('Shared by: ')}{sharedBy}</p>
               <div className="d-flex justify-content-between align-items-center op-bar">
-                <p className="m-0 mr-4 ellipsis d-flex align-items-center"><span className="flex-none">{gettext('Current path: ')}</span>{this.renderPath()}</p>
+                <p className="m-0 mr-4 ellipsis d-flex align-items-center">{gettext('Current path: ')}{this.renderPath()}</p>
                 <div className="flex-none">
                   {isDesktop &&
                   <div className="view-mode btn-group">
-                    <a
-                      href={`?p=${encodeURIComponent(relativePath)}&mode=list`}
-                      className={`${modeBaseClass} sf2-icon-list-view ${mode == 'list' ? 'current-mode' : ''}`}
+                    <button
+                      className={`${modeBaseClass} sf2-icon-list-view ${mode == LIST_MODE ? 'current-mode' : ''}`}
                       title={gettext('List')}
                       aria-label={gettext('List')}
-                    ></a>
-                    <a
-                      href={`?p=${encodeURIComponent(relativePath)}&mode=grid`}
-                      className={`${modeBaseClass} sf2-icon-grid-view ${mode == 'grid' ? 'current-mode' : ''}`}
+                      onClick={this.switchMode.bind(this, LIST_MODE)}
+                    >
+                    </button>
+                    <button
+                      className={`${modeBaseClass} sf2-icon-grid-view ${mode == GRID_MODE ? 'current-mode' : ''}`}
                       title={gettext('Grid')}
                       aria-label={gettext('Grid')}
-                    ></a>
+                      onClick={this.switchMode.bind(this, GRID_MODE)}
+                    >
+                    </button>
                   </div>
                   }
                   {canUpload && (
                     <Button disabled={noQuota}
                       title={noQuota ? gettext('The owner of this library has run out of space.') : ''}
                       onClick={this.onUploadFile} className="ml-2 shared-dir-op-btn shared-dir-upload-btn"
-                    >{gettext('Upload')}</Button>
+                    >{gettext('Upload')}
+                    </Button>
                   )}
                   {showDownloadIcon &&
                   <Fragment>
@@ -518,6 +551,7 @@ class SharedDirView extends React.Component {
                 isDesktop={isDesktop}
                 isLoading={this.state.isLoading}
                 errorMsg={this.state.errorMsg}
+                mode={mode}
                 items={this.state.items}
                 sortBy={this.state.sortBy}
                 sortOrder={this.state.sortOrder}
@@ -566,10 +600,11 @@ class SharedDirView extends React.Component {
             closeImagePopup={this.closeImagePopup}
             moveToPrevImage={this.moveToPrevImage}
             moveToNextImage={this.moveToNextImage}
+            enableRotate={false}
           />
         </ModalPortal>
         }
-      </React.Fragment>
+      </MetadataAIOperationsProvider>
     );
   }
 }
@@ -604,7 +639,7 @@ class Content extends React.Component {
   render() {
     const {
       isDesktop,
-      isLoading, errorMsg, items,
+      isLoading, errorMsg, mode, items,
       sortBy, sortOrder,
       isAllItemsSelected
     } = this.props;
@@ -623,6 +658,7 @@ class Content extends React.Component {
           return <Item
             key={index}
             isDesktop={isDesktop}
+            mode={mode}
             item={item}
             zipDownloadFolder={this.props.zipDownloadFolder}
             showImagePopup={this.props.showImagePopup}
@@ -647,8 +683,8 @@ class Content extends React.Component {
       );
     }
 
-    const sortIcon = <span className={`fas ${sortOrder == 'asc' ? 'fa-caret-up' : 'fa-caret-down'}`}></span>;
-    return mode == 'list' ? (
+    const sortIcon = <span className={`sf3-font ${sortOrder == 'asc' ? 'sf3-font-down rotate-180 d-inline-block' : 'sf3-font-down'}`}></span>;
+    return mode == LIST_MODE ? (
       <table className="table-hover">
         <thead>
           <tr>
@@ -672,6 +708,7 @@ class Content extends React.Component {
         {items.map((item, index) => {
           return <GridItem
             key={index}
+            mode={mode}
             item={item}
             zipDownloadFolder={this.props.zipDownloadFolder}
             showImagePopup={this.props.showImagePopup}
@@ -687,6 +724,7 @@ Content.propTypes = {
   isLoading: PropTypes.bool,
   isAllItemsSelected: PropTypes.bool,
   errorMsg: PropTypes.string,
+  mode: PropTypes.string,
   items: PropTypes.array,
   sortItems: PropTypes.func,
   sortBy: PropTypes.string,
@@ -708,15 +746,15 @@ class Item extends React.Component {
   }
 
   toggleOpMenu = () => {
-    this.setState({isOpMenuOpen: !this.state.isOpMenuOpen});
+    this.setState({ isOpMenuOpen: !this.state.isOpMenuOpen });
   };
 
   handleMouseOver = () => {
-    this.setState({isIconShown: true});
+    this.setState({ isIconShown: true });
   };
 
   handleMouseOut = () => {
-    this.setState({isIconShown: false});
+    this.setState({ isIconShown: false });
   };
 
   zipDownloadFolder = (e) => {
@@ -739,7 +777,7 @@ class Item extends React.Component {
   };
 
   render() {
-    const { item, isDesktop } = this.props;
+    const { item, isDesktop, mode } = this.props;
     const { isIconShown } = this.state;
 
     let toolTipID = '';
@@ -763,7 +801,7 @@ class Item extends React.Component {
           </td>
           <td></td>
           <td></td>
-          <td title={moment(item.last_modified).format('llll')}>{moment(item.last_modified).fromNow()}</td>
+          <td title={dayjs(item.last_modified).format('dddd, MMMM D, YYYY h:mm:ss A')}>{dayjs(item.last_modified).fromNow()}</td>
           <td>
             {showDownloadIcon &&
             <a role="button" className={`action-icon sf2-icon-download${isIconShown ? '' : ' invisible'}`} href="#" onClick={this.zipDownloadFolder} title={gettext('Download')} aria-label={gettext('Download')}>
@@ -777,15 +815,16 @@ class Item extends React.Component {
           <td>
             <a href={`?p=${encodeURIComponent(item.folder_path.substr(0, item.folder_path.length - 1))}&mode=${mode}`}>{item.folder_name}</a>
             <br />
-            <span className="item-meta-info">{moment(item.last_modified).fromNow()}</span>
+            <span className="item-meta-info">{dayjs(item.last_modified).fromNow()}</span>
           </td>
           <td>
             {showDownloadIcon &&
             <Dropdown isOpen={this.state.isOpMenuOpen} toggle={this.toggleOpMenu}>
               <DropdownToggle
                 tag="i"
-                className="sf-dropdown-toggle fa fa-ellipsis-v ml-0"
-                title={gettext('More Operations')}
+                className="sf-dropdown-toggle sf3-font sf3-font-more-vertical ml-0"
+                title={gettext('More operations')}
+                aria-label={gettext('More operations')}
                 data-toggle="dropdown"
                 aria-expanded={this.state.isOpMenuOpen}
               />
@@ -826,7 +865,7 @@ class Item extends React.Component {
                   {item.file_tags.map((fileTag, index) => {
                     let length = item.file_tags.length;
                     return (
-                      <span className="file-tag" key={fileTag.file_tag_id} style={{zIndex:length - index, backgroundColor:fileTag.tag_color}}></span>
+                      <span className="file-tag" key={fileTag.file_tag_id} style={{ zIndex: length - index, backgroundColor: fileTag.tag_color }}></span>
                     );
                   })}
                 </div>
@@ -837,7 +876,7 @@ class Item extends React.Component {
             )}
           </td>
           <td>{Utils.bytesToSize(item.size)}</td>
-          <td title={moment(item.last_modified).format('llll')}>{moment(item.last_modified).fromNow()}</td>
+          <td title={dayjs(item.last_modified).format('dddd, MMMM D, YYYY h:mm:ss A')}>{dayjs(item.last_modified).fromNow()}</td>
           <td>
             {showDownloadIcon &&
             <a className={`action-icon sf2-icon-download${isIconShown ? '' : ' invisible'}`} href={`${fileURL}&dl=1`} title={gettext('Download')} aria-label={gettext('Download')}></a>
@@ -856,15 +895,16 @@ class Item extends React.Component {
             <a href={fileURL} onClick={this.handleFileClick}>{item.file_name}</a>
             <br />
             <span className="item-meta-info">{Utils.bytesToSize(item.size)}</span>
-            <span className="item-meta-info">{moment(item.last_modified).fromNow()}</span>
+            <span className="item-meta-info">{dayjs(item.last_modified).fromNow()}</span>
           </td>
           <td>
             {showDownloadIcon &&
             <Dropdown isOpen={this.state.isOpMenuOpen} toggle={this.toggleOpMenu}>
               <DropdownToggle
                 tag="i"
-                className="sf-dropdown-toggle fa fa-ellipsis-v ml-0"
-                title={gettext('More Operations')}
+                className="sf-dropdown-toggle sf3-font sf3-font-more-vertical ml-0"
+                title={gettext('More operations')}
+                aria-label={gettext('More operations')}
                 data-toggle="dropdown"
                 aria-expanded={this.state.isOpMenuOpen}
               />
@@ -885,6 +925,7 @@ class Item extends React.Component {
 
 Item.propTypes = {
   isDesktop: PropTypes.bool,
+  mode: PropTypes.string,
   item: PropTypes.object,
   sortItems: PropTypes.func,
   sortBy: PropTypes.string,
@@ -905,11 +946,11 @@ class GridItem extends React.Component {
   }
 
   handleMouseOver = () => {
-    this.setState({isIconShown: true});
+    this.setState({ isIconShown: true });
   };
 
   handleMouseOut = () => {
-    this.setState({isIconShown: false});
+    this.setState({ isIconShown: false });
   };
 
   zipDownloadFolder = (e) => {
@@ -928,7 +969,7 @@ class GridItem extends React.Component {
   };
 
   render() {
-    const item = this.props.item;
+    const { item, mode } = this.props;
     const { isIconShown } = this.state;
 
     if (item.is_dir) {
@@ -936,7 +977,7 @@ class GridItem extends React.Component {
       return (
         <li className="grid-item" onMouseOver={this.handleMouseOver} onMouseOut={this.handleMouseOut} onFocus={this.handleMouseOver}>
           <a href={folderURL} className="grid-file-img-link d-block">
-            <img src={Utils.getFolderIconUrl(false, 192)} alt="" width="96" height="96" />
+            <img src={Utils.getFolderIconUrl(false, 192)} alt="" width="80" height="80" />
           </a>
           <a href={folderURL} className="grid-file-name grid-file-name-link">{item.folder_name}</a>
           {showDownloadIcon &&
@@ -953,7 +994,7 @@ class GridItem extends React.Component {
           <a href={fileURL} className="grid-file-img-link d-block" onClick={this.handleFileClick}>
             {thumbnailURL ?
               <img className="thumbnail" src={thumbnailURL} alt="" /> :
-              <img src={Utils.getFileIconUrl(item.file_name, 192)} alt="" width="96" height="96" />
+              <img src={Utils.getFileIconUrl(item.file_name)} alt="" width="80" height="80" />
             }
           </a>
           <a href={fileURL} className="grid-file-name grid-file-name-link" onClick={this.handleFileClick}>{item.file_name}</a>
@@ -968,6 +1009,7 @@ class GridItem extends React.Component {
 }
 
 GridItem.propTypes = {
+  mode: PropTypes.string,
   item: PropTypes.object,
   zipDownloadFolder: PropTypes.func,
   showImagePopup: PropTypes.func,
