@@ -3,10 +3,11 @@ import ReactDom from 'react-dom';
 import SharedFileView from './components/shared-file-view/shared-file-view';
 import SharedFileViewTip from './components/shared-file-view/shared-file-view-tip';
 import VideoPlayer from './components/video-player';
+import { MimetypesKind } from './utils/constants';
 
 import './css/video-file-view.css';
 
-const { rawPath, err } = window.shared.pageOptions;
+const { rawPath, err, fileExt } = window.shared.pageOptions;
 
 class SharedFileViewImage extends React.Component {
   render() {
@@ -19,14 +20,14 @@ class FileContent extends React.Component {
     if (err) {
       return <SharedFileViewTip />;
     }
-
     const videoJsOptions = {
       autoplay: false,
       controls: true,
       preload: 'auto',
       playbackRates: [0.5, 1, 1.5, 2],
       sources: [{
-        src: rawPath
+        src: rawPath,
+        type: MimetypesKind[fileExt] || 'video/mp4'
       }]
     };
     return (
