@@ -88,11 +88,11 @@ class UserNotificationsDialog extends React.Component {
   };
 
   toggleDropDownMenu = () => {
-    this.setState({isItemMenuShow: !this.state.isItemMenuShow});
+    this.setState({ isItemMenuShow: !this.state.isItemMenuShow });
   };
 
   onHandleScroll = () => {
-    if (!this.state.hasNextPage || this.state.isLoading ||!this.tableRef) {
+    if (!this.state.hasNextPage || this.state.isLoading || !this.tableRef) {
       return;
     }
     if (this.notificationTableRef.offsetHeight + this.notificationTableRef.scrollTop + 1 >= this.tableRef.offsetHeight) {
@@ -104,15 +104,28 @@ class UserNotificationsDialog extends React.Component {
     return (
       <div className="notification-header-close">
         <Dropdown isOpen={this.state.isItemMenuShow} toggle={this.toggleDropDownMenu}>
-          <DropdownToggle tag="span" data-toggle="dropdown" aria-expanded={this.state.isItemMenuShow} className="notification-dropdown-toggle">
-            <span className="sf3-font sf3-font-more-level item-dropdown-icon"></span>
+          <DropdownToggle
+            tag="span"
+            data-toggle="dropdown"
+            aria-expanded={this.state.isItemMenuShow}
+            className="notification-dropdown-toggle"
+          >
+            <button type="button" className="close seahub-modal-btn" aria-label={gettext('More')}>
+              <span className="seahub-modal-btn-inner">
+                <i className="sf3-font sf3-font-more" aria-hidden="true"></i>
+              </span>
+            </button>
           </DropdownToggle>
           <DropdownMenu right={true} className="dtable-dropdown-menu large">
             <DropdownItem onClick={this.markAllRead}>{gettext('Mark all read')}</DropdownItem>
             <DropdownItem onClick={this.clearAll}>{gettext('Clear')}</DropdownItem>
           </DropdownMenu>
         </Dropdown>
-        <span className="sf3-font sf3-font-x-01 notification-close-icon" onClick={this.toggle}></span>
+        <button type="button" className="close seahub-modal-btn" aria-label={gettext('Close')} onClick={this.toggle}>
+          <span className="seahub-modal-btn-inner">
+            <i className="sf3-font sf3-font-x-01" aria-hidden="true"></i>
+          </span>
+        </button>
       </div>
     );
   };
@@ -126,13 +139,13 @@ class UserNotificationsDialog extends React.Component {
     else {
       const isDesktop = Utils.isDesktop();
       const theadData = isDesktop ? [
-        {width: '7%', text: ''},
-        {width: '73%', text: gettext('Message')},
-        {width: '20%', text: gettext('Time')}
+        { width: '7%', text: '' },
+        { width: '73%', text: gettext('Message') },
+        { width: '20%', text: gettext('Time') }
       ] : [
-        {width: '15%', text: ''},
-        {width: '52%', text: gettext('Message')},
-        {width: '33%', text: gettext('Time')}
+        { width: '15%', text: '' },
+        { width: '52%', text: gettext('Message') },
+        { width: '33%', text: gettext('Time') }
       ];
       content = (
         <table className="table-hover" ref={ref => this.tableRef = ref}>
