@@ -49,7 +49,7 @@ class ViewFileText extends React.Component {
       isSaving: false,
       participants: [],
     };
-    this.onSave=this.onSave.bind(this);
+    this.onSave = this.onSave.bind(this);
     this.isParticipant = false;
   }
 
@@ -61,7 +61,7 @@ class ViewFileText extends React.Component {
     });
   };
 
-  onSave () {
+  onSave() {
     if (!this.isParticipant) {
       this.addParticipant();
     }
@@ -117,8 +117,21 @@ class ViewFileText extends React.Component {
 
   componentDidMount() {
     this.getParticipants();
+    window.addEventListener('keydown', this.saveFile);
   }
 
+  componentWillUnmount() {
+    window.removeEventListener('keydown', this.saveFile);
+  }
+
+  saveFile = (e) => {
+    if ((e.ctrlKey || e.metaKey) && e.key == 's' && this.state.needSave) {
+      // `Ctrl + S` or `Cmd + S`(in Mac)
+      e.preventDefault();
+      this.onSave();
+    }
+  };
+
   render() {
     return (
       <FileView
