@@ -17,7 +17,6 @@ from seahub.api2.throttling import UserRateThrottle
 from seahub.api2.authentication import TokenAuthentication
 from seahub.base.templatetags.seahub_tags import email2nickname
 from seahub.avatar.templatetags.avatar_tags import api_avatar_url
-from seahub.drafts.models import Draft
 
 logger = logging.getLogger(__name__)
 
@@ -41,13 +40,14 @@ class ActivitiesView(APIView):
         except ValueError:
             per_page = 25
 
+        op_user = request.GET.get('op_user', '')
         start = (page - 1) * per_page
         count = per_page
 
         email = request.user.username
 
         try:
-            events = get_user_activities(email, start, count)
+            events = get_user_activities(email, start, count, op_user)
         except Exception as e:
             logger.error(e)
             error_msg = 'Internal Server Error'
@@ -66,12 +66,7 @@ class ActivitiesView(APIView):
             d['author_name'] = email2nickname(e.op_user)
             d['author_contact_email'] = email2contact_email(e.op_user)
 
-            try:
-                avatar_size = int(request.GET.get('avatar_size', 72))
-            except ValueError as e:
-                avatar_size = 72
-
-            url, is_default, date_uploaded = api_avatar_url(e.op_user, avatar_size)
+            url, is_default, date_uploaded = api_avatar_url(e.op_user)
             d['avatar_url'] = url
             d['time'] = utc_datetime_to_isoformat_timestr(e.timestamp)
 
@@ -86,19 +81,6 @@ class ActivitiesView(APIView):
                 d['old_name'] = os.path.basename(e.old_path)
             elif e.op_type == 'publish':
                 d['old_path'] = e.old_path
-            elif d['name'].endswith('(draft).md'):
-                if e.op_type in ('create', 'edit') and e.obj_type == 'file':
-                    try:
-                        draft = Draft.objects.filter(username=e.op_user,
-                                                     origin_repo_id=e.repo_id,
-                                                     draft_file_path=e.path)
-                        if draft:
-                            draft = draft[0]
-                            d['draft_id'] = draft.id
-                        else:
-                            Draft.DoesNotExist
-                    except Draft.DoesNotExist:
-                        pass
 
             events_list.append(d)
 
