@@ -11,8 +11,11 @@ from django.utils.translation import gettext as _
 from seaserv import seafile_api, ccnet_api
 from pysearpc import SearpcError
 
+from seahub.avatar.settings import GROUP_AVATAR_DEFAULT_SIZE
+from seahub.avatar.templatetags.group_avatar_tags import get_default_group_avatar_url, api_grp_avatar_url
 from seahub.base.accounts import User
 from seahub.base.templatetags.seahub_tags import email2nickname
+from seahub.settings import CLOUD_MODE, MULTI_TENANCY
 from seahub.utils import is_valid_username, is_pro_version
 from seahub.utils.timeutils import timestamp_to_isoformat_timestr
 from seahub.group.utils import is_group_member, is_group_admin, \
@@ -22,7 +25,10 @@ from seahub.admin_log.models import GROUP_CREATE, GROUP_DELETE, GROUP_TRANSFER
 from seahub.api2.utils import api_error
 from seahub.api2.throttling import UserRateThrottle
 from seahub.api2.authentication import TokenAuthentication
+from seahub.api2.permissions import IsProVersion
 from seahub.share.models import ExtraGroupsSharePermission
+from seahub.utils.ccnet_db import CcnetDB
+
 
 logger = logging.getLogger(__name__)
 
@@ -351,3 +357,88 @@ class AdminSearchGroup(APIView):
             result.append(group_info)
 
         return Response({"group_list": result})
+    
+
+class AdminDepartments(APIView):
+    """
+    List all departments
+    """
+    authentication_classes = (TokenAuthentication, SessionAuthentication)
+    permission_classes = (IsAdminUser,)
+    throttle_classes = (UserRateThrottle,)
+
+    def get(self, request):
+        try:
+            all_groups = ccnet_api.list_all_departments()
+        except Exception as e:
+            logger.error(e)
+            error_msg = 'Internal Server Error'
+            return api_error(status.HTTP_500_INTERNAL_SERVER_ERROR, error_msg)
+
+        try:
+            avatar_size = int(request.GET.get('avatar_size', GROUP_AVATAR_DEFAULT_SIZE))
+        except ValueError:
+            avatar_size = GROUP_AVATAR_DEFAULT_SIZE
+
+        
+        result = []
+        for group in all_groups:
+            try:
+                avatar_url, is_default, date_uploaded = api_grp_avatar_url(group.id, avatar_size)
+            except:
+                avatar_url = get_default_group_avatar_url()
+            created_at = timestamp_to_isoformat_timestr(group.timestamp)
+            department_info = {
+                "id": group.id,
+                "email": '%s@seafile_group' % str(group.id),
+                "parent_group_id": group.parent_group_id,
+                "name": group.group_name,
+                "owner": group.creator_name,
+                "created_at": created_at,
+                "avatar_url": request.build_absolute_uri(avatar_url),
+            }
+            result.append(department_info)
+
+        return Response(result)
+
+
+class AdminGroupToDeptView(APIView):
+    """group to department"""
+    authentication_classes = (TokenAuthentication, SessionAuthentication)
+    permission_classes = (IsAdminUser, IsProVersion)
+    throttle_classes = (UserRateThrottle,)
+
+    def post(self, request, group_id):
+        """ Admin change a group
+
+        group to department
+
+        Permission checking:
+        1. Admin user;
+        """
+        if not request.user.admin_permissions.can_manage_group():
+            return api_error(status.HTTP_403_FORBIDDEN, 'Permission denied.')
+
+        # recourse check
+        group_id = int(group_id)
+        group = ccnet_api.get_group(group_id)
+        if group.creator_name == 'system admin':
+            error_msg = 'Group %s is already a department' % group_id
+            return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
+        
+        if not group:
+            error_msg = 'Group %d not found.' % group_id
+            return api_error(status.HTTP_404_NOT_FOUND, error_msg)
+
+        # group to department
+        try:
+            ccnet_db = CcnetDB()
+            ccnet_db.change_groups_into_departments(group_id)
+            seafile_api.set_group_quota(group_id, -2)
+        except Exception as e:
+            logger.error(e)
+            error_msg = 'Internal Server Error'
+            return api_error(status.HTTP_500_INTERNAL_SERVER_ERROR, error_msg)
+        
+        group_info = get_group_info(group_id)
+        return Response(group_info)
