@@ -12,6 +12,7 @@ from rest_framework import status
 from seaserv import ccnet_api, seafile_api
 
 from seahub.auth.utils import get_virtual_id_by_email
+from seahub.organizations.settings import ORG_MEMBER_QUOTA_DEFAULT
 from seahub.utils import is_valid_email
 from seahub.utils.file_size import get_file_size_unit
 from seahub.utils.timeutils import timestamp_to_isoformat_timestr
@@ -77,6 +78,9 @@ def get_org_detailed_info(org):
     users = ccnet_api.get_org_emailusers(org.url_prefix, -1, -1)
     org_info['users_count'] = len(users)
 
+    active_users_count = len([m for m in users if m.is_active])
+    org_info['active_users_count'] = active_users_count
+
     repos = seafile_api.get_org_repo_list(org_id, -1, -1)
     org_info['repos_count'] = len(repos)
 
@@ -90,7 +94,6 @@ def get_org_detailed_info(org):
         org_saml_config = OrgSAMLConfig.objects.get_config_by_org_id(org_id)
         if org_saml_config:
             org_info['enable_saml_login'] = True
-            org_info['url_prefix'] = org.url_prefix
             org_info['metadata_url'] = org_saml_config.metadata_url
             org_info['domain'] = org_saml_config.domain
 
@@ -231,6 +234,20 @@ class AdminOrganizations(APIView):
             logger.error(e)
             error_msg = 'Internal Server Error'
             return api_error(status.HTTP_500_INTERNAL_SERVER_ERROR, error_msg)
+        
+        quota = request.data.get('quota', None)
+        if quota:
+            try:
+                quota_mb = int(quota)
+                quota = quota_mb * get_file_size_unit('MB')
+                seafile_api.set_org_quota(org_id, quota)
+            except ValueError as e:
+                logger.error(e)
+                return api_error(status.HTTP_400_BAD_REQUEST, "Quota is not valid")
+            
+        if ORG_MEMBER_QUOTA_ENABLED:
+            member_limit = request.data.get('member_limit', ORG_MEMBER_QUOTA_DEFAULT)
+            OrgMemberQuota.objects.set_quota(org_id, member_limit)
 
         org = ccnet_api.get_org_by_id(org_id)
         try:
@@ -461,3 +478,30 @@ class AdminSearchOrganization(APIView):
             result.append(org_info)
 
         return Response({'organization_list': result})
+
+
+class AdminOrganizationsBaseInfo(APIView):
+    authentication_classes = (TokenAuthentication, SessionAuthentication)
+    permission_classes = (IsAdminUser, IsProVersion)
+    throttle_classes = (UserRateThrottle,)
+
+    def get(self, request):
+        '''
+        Get base info of organizations in bulk by ids
+        '''
+        if not MULTI_TENANCY:
+            error_msg = 'Feature is not enabled.'
+            return api_error(status.HTTP_403_FORBIDDEN, error_msg)
+
+        org_ids = request.GET.getlist('org_ids',[])
+        orgs = []
+        for org_id in org_ids:
+            try:
+                org = ccnet_api.get_org_by_id(int(org_id))
+                if not org:
+                    continue
+            except:
+                continue
+            base_info = {'org_id': org.org_id, 'org_name': org.org_name}
+            orgs.append(base_info)
+        return Response({'organization_list': orgs})
