@@ -22,9 +22,12 @@ from ldap.controls.libldap import SimplePagedResultsControl
 from seaserv import seafile_api, ccnet_api
 
 from seahub.api2.authentication import TokenAuthentication
+from seahub.api2.endpoints.utils import is_org_user
 from seahub.api2.throttling import UserRateThrottle
-from seahub.api2.utils import api_error, to_python_boolean
+from seahub.api2.utils import api_error, to_python_boolean, get_user_common_info
 from seahub.api2.models import TokenV2
+from seahub.organizations.models import OrgSettings
+from seahub.organizations.views import gen_org_url_prefix
 from seahub.utils.ccnet_db import get_ccnet_db_name
 import seahub.settings as settings
 from seahub.settings import SEND_EMAIL_ON_ADDING_SYSTEM_MEMBER, INIT_PASSWD, \
@@ -40,13 +43,15 @@ from seahub.utils import is_valid_username2, is_org_context, \
         is_pro_version, normalize_cache_key, is_valid_email, \
         IS_EMAIL_CONFIGURED, send_html_email, get_site_name, \
         gen_shared_link, gen_shared_upload_link
+from seahub.utils.db_api import SeafileDB
 
 from seahub.utils.file_size import get_file_size_unit, byte_to_kb
 from seahub.utils.timeutils import timestamp_to_isoformat_timestr, \
         datetime_to_isoformat_timestr
 from seahub.utils.user_permissions import get_user_role
 from seahub.utils.repo import normalize_repo_status_code
-from seahub.constants import DEFAULT_ADMIN
+from seahub.utils.ccnet_db import CcnetDB
+from seahub.constants import DEFAULT_ADMIN, DEFAULT_ORG
 from seahub.role_permissions.models import AdminRole
 from seahub.role_permissions.utils import get_available_roles
 from seahub.utils.licenseparse import user_number_over_limit
@@ -62,37 +67,14 @@ from seahub.auth.models import SocialAuthUser
 
 from seahub.options.models import UserOptions
 from seahub.share.models import FileShare, UploadLinkShare
-from seahub.settings import ENABLE_LDAP, LDAP_FILTER, ENABLE_SASL, SASL_MECHANISM
-
-try:
-    from seahub.settings import LDAP_SERVER_URL, LDAP_BASE_DN, LDAP_ADMIN_DN, LDAP_ADMIN_PASSWORD, LDAP_LOGIN_ATTR
-except ImportError:
-    LDAP_SERVER_URL = ''
-    LDAP_BASE_DN = ''
-    LDAP_ADMIN_DN = ''
-    LDAP_ADMIN_PASSWORD = ''
-    LDAP_LOGIN_ATTR = ''
-
-try:
-    from seahub.settings import ENABLE_MULTI_LDAP, MULTI_LDAP_1_SERVER_URL, MULTI_LDAP_1_BASE_DN, \
-         MULTI_LDAP_1_ADMIN_DN, MULTI_LDAP_1_ADMIN_PASSWORD, MULTI_LDAP_1_LOGIN_ATTR
-except ImportError:
-    ENABLE_MULTI_LDAP = False
-    MULTI_LDAP_1_SERVER_URL = ''
-    MULTI_LDAP_1_BASE_DN = ''
-    MULTI_LDAP_1_ADMIN_DN = ''
-    MULTI_LDAP_1_ADMIN_PASSWORD = ''
-    MULTI_LDAP_1_LOGIN_ATTR = ''
-
-
-LDAP_PROVIDER = getattr(settings, 'LDAP_PROVIDER', 'ldap')
-LDAP_USER_OBJECT_CLASS = getattr(settings, 'LDAP_USER_OBJECT_CLASS', 'person')
-MULTI_LDAP_1_USER_OBJECT_CLASS = getattr(settings, 'MULTI_LDAP_1_USER_OBJECT_CLASS', 'person')
-MULTI_LDAP_1_PROVIDER = getattr(settings, 'MULTI_LDAP_1_PROVIDER', 'ldap1')
-MULTI_LDAP_1_FILTER = getattr(settings, 'MULTI_LDAP_1_FILTER', '')
-MULTI_LDAP_1_ENABLE_SASL = getattr(settings, 'MULTI_LDAP_1_ENABLE_SASL', False)
-MULTI_LDAP_1_SASL_MECHANISM = getattr(settings, 'MULTI_LDAP_1_SASL_MECHANISM', '')
-
+from seahub.utils.ldap import ENABLE_LDAP, LDAP_FILTER, ENABLE_SASL, SASL_MECHANISM, ENABLE_SSO_USER_CHANGE_PASSWORD, \
+    LDAP_PROVIDER, LDAP_SERVER_URL, LDAP_BASE_DN, LDAP_ADMIN_DN, LDAP_ADMIN_PASSWORD, LDAP_LOGIN_ATTR, LDAP_USER_OBJECT_CLASS, \
+    ENABLE_MULTI_LDAP, MULTI_LDAP_1_SERVER_URL, MULTI_LDAP_1_BASE_DN, MULTI_LDAP_1_ADMIN_DN, \
+    MULTI_LDAP_1_ADMIN_PASSWORD, MULTI_LDAP_1_LOGIN_ATTR, \
+    MULTI_LDAP_1_PROVIDER, MULTI_LDAP_1_FILTER, \
+    MULTI_LDAP_1_ENABLE_SASL, MULTI_LDAP_1_SASL_MECHANISM, MULTI_LDAP_1_USER_OBJECT_CLASS, \
+    MULTI_LDAP_1_PROVIDER, MULTI_LDAP_1_FILTER, MULTI_LDAP_1_ENABLE_SASL, MULTI_LDAP_1_SASL_MECHANISM, \
+    LDAP_FOLLOW_REFERRALS, MULTI_LDAP_1_FOLLOW_REFERRALS
 
 logger = logging.getLogger(__name__)
 json_content_type = 'application/json; charset=utf-8'
@@ -108,10 +90,7 @@ class UserObj(object):
 
 
 def get_user_objs_from_ccnet(email_list):
-    db_name, error_msg = get_ccnet_db_name()
-    if error_msg:
-        logger.error(error_msg)
-        return list(), api_error(status.HTTP_500_INTERNAL_SERVER_ERROR, 'Internal Server Error')
+    db_name = get_ccnet_db_name()
 
     if not email_list:
         return list(), None
@@ -133,11 +112,11 @@ def get_user_objs_from_ccnet(email_list):
     return user_objs, None
 
 
-def ldap_bind(server_url, dn, authc_id, password, enable_sasl, sasl_mechanism):
+def ldap_bind(server_url, dn, authc_id, password, enable_sasl, sasl_mechanism, follow_referrals):
     bind_conn = ldap.initialize(server_url)
 
     try:
-        bind_conn.set_option(ldap.OPT_REFERRALS, 0)
+        bind_conn.set_option(ldap.OPT_REFERRALS, 1 if follow_referrals else 0)
     except Exception as e:
         raise Exception('Failed to set referrals option: %s' % e)
 
@@ -161,9 +140,9 @@ def ldap_bind(server_url, dn, authc_id, password, enable_sasl, sasl_mechanism):
 
 
 def get_ldap_users(server_url, admin_dn, admin_password, enable_sasl, sasl_mechanism, base_dn,
-                   login_attr, serch_filter, object_class):
+                   login_attr, serch_filter, object_class, follow_referrals):
     try:
-        admin_bind = ldap_bind(server_url, admin_dn, admin_dn, admin_password, enable_sasl, sasl_mechanism)
+        admin_bind = ldap_bind(server_url, admin_dn, admin_dn, admin_password, enable_sasl, sasl_mechanism, follow_referrals)
     except Exception as e:
         raise Exception(e)
 
@@ -313,14 +292,16 @@ def get_user_share_link_info(fileshare):
     if fileshare.s_type == 'f':
         obj_id = seafile_api.get_file_id_by_path(repo_id, path)
         data['size'] = seafile_api.get_file_size(repo.store_id,
-                repo.version, obj_id)
+                                                 repo.version, obj_id)
     else:
         data['size'] = ''
 
     return data
 
 
-def create_user_info(request, email, role, nickname, contact_email, quota_total_mb):
+def create_user_info(request, email, role, nickname,
+                     contact_email, quota_total_mb,
+                     login_id):
     # update additional user info
 
     if is_pro_version() and role:
@@ -344,15 +325,27 @@ def create_user_info(request, email, role, nickname, contact_email, quota_total_
         else:
             seafile_api.set_user_quota(email, quota_total)
 
+    if login_id is not None:
+        Profile.objects.add_or_update(email, login_id=login_id)
+
 
 def update_user_info(request, user, password, is_active, is_staff, role,
-                     nickname, login_id, contact_email, reference_id,
+                     nickname, login_id, contact_email,
                      quota_total_mb, institution_name,
                      upload_rate_limit, download_rate_limit):
 
+    email = user.username
+
     # update basic user info
     if is_active is not None:
         user.is_active = is_active
+        if not is_active:
+            # del tokens and personal repo api tokens (not department)
+            from seahub.utils import inactive_user
+            try:
+                inactive_user(email)
+            except Exception as e:
+                logger.error("Failed to inactive_user %s: %s." % (email, e))
 
     if password:
         user.set_password(password)
@@ -363,8 +356,6 @@ def update_user_info(request, user, password, is_active, is_staff, role,
     # update user
     user.save()
 
-    email = user.username
-
     # update additional user info
     if is_pro_version() and role:
         User.objects.update_role(email, role)
@@ -382,13 +373,6 @@ def update_user_info(request, user, password, is_active, is_staff, role,
         key = normalize_cache_key(email, CONTACT_CACHE_PREFIX)
         cache.set(key, contact_email, CONTACT_CACHE_TIMEOUT)
 
-    if reference_id is not None:
-        if reference_id.strip():
-            ccnet_api.set_reference_id(email, reference_id.strip())
-        else:
-            # remove reference id
-            ccnet_api.set_reference_id(email, None)
-
     if institution_name is not None:
         Profile.objects.add_or_update(email, institution=institution_name)
         if institution_name == '':
@@ -427,7 +411,6 @@ def get_user_info(email):
 
     info['is_staff'] = user.is_staff
     info['is_active'] = user.is_active
-    info['reference_id'] = user.reference_id if user.reference_id else ''
 
     orgs = ccnet_api.get_orgs_by_user(email)
     try:
@@ -537,7 +520,7 @@ class AdminUsers(APIView):
     throttle_classes = (UserRateThrottle, )
 
     def get_info_of_users_order_by_quota_usage(self, source, direction,
-            page, per_page):
+                                               page, per_page, is_active=None, role=None):
 
         # get user's quota usage info
         user_usage_dict = {}
@@ -568,7 +551,14 @@ class AdminUsers(APIView):
 
         # sort
         users.sort(key=lambda item: item.quota_usage,
-                reverse = direction == 'desc')
+                   reverse=direction == 'desc')
+        if is_active == '1':
+            users = [u for u in users if u.is_active]
+        elif is_active == '0':
+            users = [u for u in users if not u.is_active]
+
+        if role:
+            users = [u for u in users if get_user_role(u) == role]
 
         data = []
         MULTI_INSTITUTION = getattr(settings, 'MULTI_INSTITUTION', False)
@@ -621,12 +611,15 @@ class AdminUsers(APIView):
         try:
             page = int(request.GET.get('page', '1'))
             per_page = int(request.GET.get('per_page', '25'))
+            is_active = request.GET.get('is_active', None)
+            role = request.GET.get('role', None)
         except ValueError:
             page = 1
             per_page = 25
+            is_active, role = None, None
 
         start = (page - 1) * per_page
-
+        limit = per_page + 1
         source = request.GET.get('source', 'DB').lower().strip()
         if source not in ['db', 'ldapimport']:
             # source: 'DB' or 'LDAPImport', default is 'DB'
@@ -659,7 +652,10 @@ class AdminUsers(APIView):
                     data = self.get_info_of_users_order_by_quota_usage(source,
                                                                        direction,
                                                                        page,
-                                                                       per_page)
+                                                                       per_page,
+                                                                       is_active,
+                                                                       role,
+                                                                       )
                 except Exception as e:
                     logger.error(e)
                     error_msg = 'Internal Server Error'
@@ -668,7 +664,11 @@ class AdminUsers(APIView):
                 result = {'data': data, 'total_count': total_count}
                 return Response(result)
             else:
-                users = ccnet_api.get_emailusers('DB', start, per_page)
+                try:
+                    ccnet_db = CcnetDB()
+                    users, total_count = ccnet_db.list_eligible_users(start, limit, is_active, role)
+                except Exception:
+                    users = ccnet_api.get_emailusers('DB', start, per_page)
 
         elif source == 'ldapimport':
             ldap_users_count = multi_ldap_users_count = 0
@@ -711,6 +711,15 @@ class AdminUsers(APIView):
                 users = all_ldap_users[start: start + per_page]
 
         data = []
+        email_list = [user.email for user in users]
+        social_auth_user_queryset = SocialAuthUser.objects.filter(username__in=email_list)
+        social_auth_user_dict = {}
+        for item in social_auth_user_queryset:
+            if item.username in social_auth_user_dict:
+                social_auth_user_dict[item.username].append(item)
+            else:
+                social_auth_user_dict[item.username] = [item]
+
         for user in users:
             profile = Profile.objects.get_profile_by_user(user.email)
 
@@ -753,7 +762,14 @@ class AdminUsers(APIView):
                 info['last_access_time'] = get_user_last_access_time(user.email, '')
 
             if getattr(settings, 'MULTI_INSTITUTION', False):
-                info['institution'] = profile.institution if profile else ''
+                if profile and profile.institution and \
+                        profile.institution.lower() != "null":
+                    info['institution'] = profile.institution
+                else:
+                    info['institution'] = ''
+
+            social_auth_user = social_auth_user_dict.get(user.email, [])
+            info['social_auth'] = [{'provider': item.provider, 'uid': item.uid} for item in social_auth_user]
 
             data.append(info)
 
@@ -845,12 +861,21 @@ class AdminUsers(APIView):
             error_msg = 'password required.'
             return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
 
+        login_id = request.data.get("login_id", None)
+        if login_id is not None:
+            login_id = login_id.strip()
+            username_by_login_id = Profile.objects.get_username_by_login_id(login_id)
+            if username_by_login_id is not None:
+                return api_error(status.HTTP_400_BAD_REQUEST,
+                                 _("Login id %s already exists." % login_id))
+
         # create user
         try:
             user_obj = User.objects.create_user(email, password, is_staff, is_active)
             create_user_info(request, email=user_obj.username, role=role,
                              nickname=name, contact_email=email,
-                             quota_total_mb=quota_total_mb)
+                             quota_total_mb=quota_total_mb,
+                             login_id=login_id)
         except Exception as e:
             logger.error(e)
             error_msg = 'Internal Server Error'
@@ -862,9 +887,7 @@ class AdminUsers(APIView):
             try:
                 send_html_email(_('You are invited to join %s') % get_site_name(),
                                 'sysadmin/user_add_email.html',
-                                c,
-                                None,
-                                [email2contact_email(email)])
+                                c, None, [email2contact_email(email)])
 
                 add_user_tip = _('Successfully added user %(user)s. An email notification has been sent.') % {'user': email}
             except Exception as e:
@@ -918,7 +941,7 @@ class AdminLDAPUsers(APIView):
         try:
             ldap_users = get_ldap_users(LDAP_SERVER_URL, LDAP_ADMIN_DN, LDAP_ADMIN_PASSWORD,
                                         ENABLE_SASL, SASL_MECHANISM, LDAP_BASE_DN, LDAP_LOGIN_ATTR,
-                                        LDAP_FILTER, LDAP_USER_OBJECT_CLASS)
+                                        LDAP_FILTER, LDAP_USER_OBJECT_CLASS, LDAP_FOLLOW_REFERRALS)
         except Exception as e:
             logger.error(e)
             error_msg = 'Internal Server Error'
@@ -931,7 +954,7 @@ class AdminLDAPUsers(APIView):
                                                   MULTI_LDAP_1_ADMIN_PASSWORD, MULTI_LDAP_1_ENABLE_SASL,
                                                   MULTI_LDAP_1_SASL_MECHANISM, MULTI_LDAP_1_BASE_DN,
                                                   MULTI_LDAP_1_LOGIN_ATTR, MULTI_LDAP_1_FILTER,
-                                                  MULTI_LDAP_1_USER_OBJECT_CLASS)
+                                                  MULTI_LDAP_1_USER_OBJECT_CLASS, MULTI_LDAP_1_FOLLOW_REFERRALS)
             except Exception as e:
                 logger.error(e)
                 error_msg = 'Internal Server Error'
@@ -1018,7 +1041,7 @@ class AdminSearchUser(APIView):
 
             # search user from profile
             searched_profile = Profile.objects.filter((Q(nickname__icontains=query_str)) | \
-                                                       Q(contact_email__icontains=query_str))[:10]
+                                                      Q(contact_email__icontains=query_str))[:10]
 
             for profile in searched_profile:
                 email = profile.user
@@ -1073,7 +1096,6 @@ class AdminSearchUser(APIView):
                     ccnet_users = ccnet_ldap_import_users[-per_page:]
 
             # search user from profile
-            profile_users = []
             all_ccnet_users = ccnet_db_users + ccnet_ldap_import_users
             all_profile_users = []
 
@@ -1192,18 +1214,10 @@ class AdminUser(APIView):
 
     def get(self, request, email):
 
-        if not (request.user.admin_permissions.can_manage_user() or \
-            request.user.admin_permissions.can_update_user()):
+        if not (request.user.admin_permissions.can_manage_user() or
+                request.user.admin_permissions.can_update_user()):
             return api_error(status.HTTP_403_FORBIDDEN, 'Permission denied.')
 
-        avatar_size = request.data.get('avatar_size', 64)
-        try:
-            avatar_size = int(avatar_size)
-        except Exception as e:
-            logger.error(e)
-            error_msg = 'avatar_size invalid.'
-            return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
-
         try:
             User.objects.get(email=email)
         except User.DoesNotExist:
@@ -1211,7 +1225,7 @@ class AdminUser(APIView):
             return api_error(status.HTTP_404_NOT_FOUND, error_msg)
 
         user_info = get_user_info(email)
-        user_info['avatar_url'], _, _ = api_avatar_url(email, avatar_size)
+        user_info['avatar_url'], _, _ = api_avatar_url(email)
         if is_pro_version():
             user_info['upload_rate_limit'] = byte_to_kb(seafile_api.get_user_upload_rate_limit(email))
             user_info['download_rate_limit'] = byte_to_kb(seafile_api.get_user_download_rate_limit(email))
@@ -1229,8 +1243,8 @@ class AdminUser(APIView):
 
     def put(self, request, email):
 
-        if not (request.user.admin_permissions.can_manage_user() or \
-            request.user.admin_permissions.can_update_user()):
+        if not (request.user.admin_permissions.can_manage_user() or
+                request.user.admin_permissions.can_update_user()):
             return api_error(status.HTTP_403_FORBIDDEN, 'Permission denied.')
 
         # basic user info check
@@ -1290,14 +1304,6 @@ class AdminUser(APIView):
 
         password = request.data.get("password")
 
-        reference_id = request.data.get("reference_id", None)
-        if reference_id:
-            if ' ' in reference_id:
-                return api_error(status.HTTP_400_BAD_REQUEST, 'Reference ID can not contain spaces.')
-            primary_id = ccnet_api.get_primary_id(reference_id)
-            if primary_id:
-                return api_error(status.HTTP_400_BAD_REQUEST, 'Reference ID %s already exists.' % reference_id)
-
         quota_total_mb = request.data.get("quota_total", None)
         if quota_total_mb:
             try:
@@ -1377,7 +1383,6 @@ class AdminUser(APIView):
                              nickname=name,
                              login_id=login_id,
                              contact_email=contact_email,
-                             reference_id=reference_id,
                              quota_total_mb=quota_total_mb,
                              institution_name=institution,
                              upload_rate_limit=upload_rate_limit,
@@ -1402,7 +1407,7 @@ class AdminUser(APIView):
                 try:
                     send_html_email(_(u'Your account on %s is activated') % get_site_name(),
                                     'sysadmin/user_activation_email.html',
-                                    {'username': user_obj.email},
+                                    {'username': email2contact_email(user_obj.email)},
                                     None,
                                     [email2contact_email(user_obj.email)])
                     update_status_tip = _('Edit succeeded, an email has been sent.')
@@ -1467,6 +1472,17 @@ class AdminUserResetPassword(APIView):
             error_msg = 'email invalid'
             return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
 
+        has_bind_social_auth = False
+        if SocialAuthUser.objects.filter(username=email).exists():
+            has_bind_social_auth = True
+
+        can_reset_password = True
+        if has_bind_social_auth and (not ENABLE_SSO_USER_CHANGE_PASSWORD):
+            can_reset_password = False
+
+        if not can_reset_password:
+            return api_error(status.HTTP_400_BAD_REQUEST, _('Unable to reset password.'))
+
         try:
             user = User.objects.get(email=email)
         except User.DoesNotExist as e:
@@ -1474,6 +1490,30 @@ class AdminUserResetPassword(APIView):
             error_msg = 'email invalid.'
             return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
 
+        profile = Profile.objects.get_profile_by_user(email)
+        if IS_EMAIL_CONFIGURED and profile and profile.contact_email:
+
+            from seahub.utils import get_site_name
+            from django.utils.http import int_to_base36
+            from seahub.auth.tokens import default_token_generator
+
+            site_name = get_site_name()
+            contact_email = profile.contact_email
+            email_template_name = 'sysadmin/short_time_linving_password_reset_link.html'
+            c = {
+                'email': contact_email,
+                'uid': int_to_base36(user.id),
+                'user': user,
+                'token': default_token_generator.make_token(user),
+            }
+
+            send_html_email(_("Reset Password on %s") % site_name,
+                            email_template_name, c, None,
+                            [email2contact_email(user.username)])
+
+            reset_tip = _(f'A password reset link has been sent to {contact_email}.')
+            return Response({'reset_tip': reset_tip})
+
         if isinstance(INIT_PASSWD, FunctionType):
             new_password = INIT_PASSWD()
         else:
@@ -1838,26 +1878,6 @@ class AdminUpdateUserCcnetEmail(APIView):
         except Exception as e:
             logger.error(e)
 
-        try:
-            from seahub.drafts.models import Draft
-            draft_list = Draft.objects.filter(username=old_ccnet_email)
-            for draft in draft_list:
-                draft.username = new_ccnet_email
-                draft.save()
-            logger.debug('the drafts_draft table in seahub database was successfully updated')
-        except Exception as e:
-            logger.error(e)
-
-        try:
-            from seahub.drafts.models import DraftReviewer
-            draftreviewer_list = DraftReviewer.objects.filter(reviewer=old_ccnet_email)
-            for draftreviewer in draftreviewer_list:
-                draftreviewer.reviewer = new_ccnet_email
-                draftreviewer.save()
-            logger.debug('the drafts_draftreviewer table in seahub database was successfully updated')
-        except Exception as e:
-            logger.error(e)
-
         try:
             from seahub.file_participants.models import FileParticipant
             fileparticipant_list = FileParticipant.objects.filter(username=old_ccnet_email)
@@ -2039,3 +2059,86 @@ class AdminUpdateUserCcnetEmail(APIView):
             logger.error(e)
 
         return Response({'success': True})
+
+
+class AdminUserList(APIView):
+    authentication_classes = (TokenAuthentication, SessionAuthentication)
+    permission_classes = (IsAdminUser, )
+    throttle_classes = (UserRateThrottle, )
+
+    def post(self, request):
+        """return user_list by user_id_list
+        """
+        # argument check
+        user_id_list = request.data.get('user_id_list')
+        if not isinstance(user_id_list, list):
+            error_msg = 'user_id_list invalid.'
+            return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
+
+        # main
+        user_list = list()
+        for user_id in user_id_list:
+            if not isinstance(user_id, str):
+                continue
+            user_info = get_user_common_info(user_id)
+            user_list.append(user_info)
+
+        return Response({'user_list': user_list})
+
+
+class AdminUserConvertToTeamView(APIView):
+    authentication_classes = (TokenAuthentication, SessionAuthentication)
+    permission_classes = (IsAdminUser,)
+    throttle_classes = (UserRateThrottle,)
+
+    def post(self, request):
+        username = request.data.get('email')
+        if not username:
+            return api_error(status.HTTP_400_BAD_REQUEST, 'email invalid.')
+
+        # resource check
+        try:
+            user = User.objects.get(email=username)
+        except User.DoesNotExist:
+            error_msg = 'User %s not found.' % username
+            return api_error(status.HTTP_404_NOT_FOUND, error_msg)
+
+        if is_org_user(username):
+            error_msg = 'User is already in team.'
+            return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
+
+        org_role = DEFAULT_ORG
+
+        url_prefix = gen_org_url_prefix(3)
+        if url_prefix is None:
+            error_msg = 'Internal Server Error'
+            return api_error(status.HTTP_500_INTERNAL_SERVER_ERROR, error_msg)
+
+        # Use the nickname as the org_name, but the org_name does not support emoji
+        nickname = email2nickname(username)
+        nickname_characters = []
+        for character in nickname:
+            if len(character.encode('utf-8')) > 3:
+                nickname_characters.append('_')
+            else:
+                nickname_characters.append(character)
+        org_name = ''.join(nickname_characters)
+
+        try:
+            # 1. Create a new org, and add the user(username) to org as a team admin
+            #    by ccnet_api.create_org
+            org_id = ccnet_api.create_org(org_name, url_prefix, username)
+            # 2. Update org-settings
+            new_org = ccnet_api.get_org_by_id(org_id)
+            OrgSettings.objects.add_or_update(new_org, org_role)
+            # 3. Add user's repo to OrgRepo
+            owned_repos = seafile_api.get_owned_repo_list(username, ret_corrupted=True)
+            owned_repo_ids = [item.repo_id for item in owned_repos]
+            seafile_db = SeafileDB()
+            seafile_db.add_repos_to_org_user(org_id, username, owned_repo_ids)
+        except Exception as e:
+            logger.error(e)
+            error_msg = 'Internal Server Error'
+            return api_error(status.HTTP_500_INTERNAL_SERVER_ERROR, error_msg)
+
+        return Response({'success': True})
