@@ -23,14 +23,14 @@ from seahub.utils import check_filename_with_rename, is_valid_dirent_name, \
         normalize_dir_path, is_pro_version, FILEEXT_TYPE_MAP, get_file_type_and_ext
 from seahub.utils.timeutils import timestamp_to_isoformat_timestr
 from seahub.utils.file_tags import get_files_tags_in_dir
-from seahub.utils.file_types import IMAGE, VIDEO, XMIND, SEADOC
+from seahub.utils.file_types import IMAGE, VIDEO, XMIND, SEADOC, PDF
 from seahub.base.models import UserStarredFiles
 from seahub.base.templatetags.seahub_tags import email2nickname, \
         email2contact_email
 from seahub.utils.repo import parse_repo_perm
 from seahub.constants import PERMISSION_INVISIBLE
 
-from seahub.settings import ENABLE_VIDEO_THUMBNAIL, THUMBNAIL_ROOT
+from seahub.settings import ENABLE_VIDEO_THUMBNAIL, THUMBNAIL_ROOT, THUMBNAIL_DEFAULT_SIZE
 
 from seaserv import seafile_api
 from pysearpc import SearpcError
@@ -105,19 +105,6 @@ def get_dir_file_info_list(username, request_type, repo_obj, parent_dir,
             logger.error(e)
             files_tags_in_dir = {}
 
-        try:
-            from seahub.tags.models import FileUUIDMap
-            from seahub.seadoc.models import SeadocDraft, SeadocRevision
-            file_uuid_queryset = FileUUIDMap.objects.get_fileuuidmaps_by_parent_path(
-                repo_id, parent_dir)
-            file_uuid_list = [item.uuid for item in file_uuid_queryset]
-            seadoc_draft_queryset = SeadocDraft.objects.list_by_doc_uuids(
-                file_uuid_list)
-            seadoc_revision_queryset = SeadocRevision.objects.list_by_doc_uuids(
-                file_uuid_list)
-        except Exception as e:
-            logger.error(e)
-
         for dirent in file_list:
 
             file_name = dirent.obj_name
@@ -175,7 +162,7 @@ def get_dir_file_info_list(username, request_type, repo_obj, parent_dir,
                 fileExt = os.path.splitext(file_name)[1][1:].lower()
                 file_type = FILEEXT_TYPE_MAP.get(fileExt)
 
-                if file_type in (IMAGE, XMIND) or \
+                if file_type in (IMAGE, XMIND, PDF) or \
                         (file_type == VIDEO and ENABLE_VIDEO_THUMBNAIL):
 
                     # if thumbnail has already been created, return its src.
@@ -186,30 +173,6 @@ def get_dir_file_info_list(username, request_type, repo_obj, parent_dir,
                     if os.path.exists(thumbnail_file_path):
                         src = get_thumbnail_src(repo_id, thumbnail_size, file_path)
                         file_info['encoded_thumbnail_src'] = quote(src)
-
-            # sdoc
-            filetype, fileext = get_file_type_and_ext(file_info['name'])
-            if filetype == SEADOC:
-                try:
-                    file_uuid_map = file_uuid_queryset.filter(
-                        filename=file_name).first()
-                    if file_uuid_map:
-                        sdoc_draft = seadoc_draft_queryset.filter(
-                            doc_uuid=file_uuid_map.uuid).first()
-                        if sdoc_draft:
-                            file_info['is_sdoc_draft'] = True
-                        else:
-                            file_info['is_sdoc_draft'] = False
-                        sdoc_revision = seadoc_revision_queryset.filter(
-                            doc_uuid=file_uuid_map.uuid).first()
-                        if sdoc_revision:
-                            file_info['is_sdoc_revision'] = True
-                            file_info['revision_id'] = sdoc_revision.revision_id
-                        else:
-                            file_info['is_sdoc_revision'] = False
-                except Exception as e:
-                    logger.error(e)
-
             file_info_list.append(file_info)
 
     dir_info_list.sort(key=lambda x: x['name'].lower())
@@ -265,7 +228,7 @@ class DirView(APIView):
             return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
 
         with_thumbnail = to_python_boolean(with_thumbnail)
-        thumbnail_size = request.GET.get('thumbnail_size', 48)
+        thumbnail_size = request.GET.get('thumbnail_size', THUMBNAIL_DEFAULT_SIZE)
         try:
             thumbnail_size = int(thumbnail_size)
         except ValueError:
