@@ -32,7 +32,8 @@ from seahub.share.utils import is_repo_admin, share_dir_to_user, \
         check_group_share_out_permission, normalize_custom_permission_name
 from seahub.utils import (is_org_context, is_valid_username,
                           send_perm_audit_msg)
-from seahub.share.signals import share_repo_to_user_successful, share_repo_to_group_successful
+from seahub.share.signals import share_repo_to_user_successful, share_repo_to_group_successful, \
+    change_repo_perm_successful, delete_repo_perm_successful
 from seahub.constants import PERMISSION_READ, PERMISSION_READ_WRITE, \
         PERMISSION_ADMIN
 from seahub.utils.repo import get_available_repo_perms
@@ -60,10 +61,13 @@ class DirSharedItemsEndpoint(APIView):
             org_id = request.user.org.org_id
             if path == '/':
                 share_items = seafile_api.list_org_repo_shared_to(org_id,
-                        repo_owner, repo_id)
+                                                                  repo_owner,
+                                                                  repo_id)
             else:
                 share_items = seafile_api.get_org_shared_users_for_subdir(org_id,
-                        repo_id, path, repo_owner)
+                                                                          repo_id,
+                                                                          path,
+                                                                          repo_owner)
         else:
             repo_owner = seafile_api.get_repo_owner(repo_id)
             if path == '/':
@@ -76,7 +80,7 @@ class DirSharedItemsEndpoint(APIView):
         admin_users = ExtraSharePermission.objects.get_admin_users_by_repo(repo_id)
         ret = []
         for item in share_items:
-            avatar_url, is_default, date_uploaded = api_avatar_url(item.user, 72)
+            avatar_url, is_default, date_uploaded = api_avatar_url(item.user)
             ret.append({
                 "share_type": "user",
                 "user_info": {
@@ -97,10 +101,13 @@ class DirSharedItemsEndpoint(APIView):
             org_id = request.user.org.org_id
             if path == '/':
                 share_items = seafile_api.list_org_repo_shared_group(org_id,
-                        repo_owner, repo_id)
+                                                                     repo_owner,
+                                                                     repo_id)
             else:
                 share_items = seafile_api.get_org_shared_groups_for_subdir(org_id,
-                        repo_id, path, repo_owner)
+                                                                           repo_id,
+                                                                           path,
+                                                                           repo_owner)
         else:
             repo_owner = seafile_api.get_repo_owner(repo_id)
             if path == '/':
@@ -128,11 +135,10 @@ class DirSharedItemsEndpoint(APIView):
                                 org_id, repo_id, path, repo_owner, group_id)
                 else:
                     if path == '/':
-                        seafile_api.unset_group_repo(repo_id, group_id,
-                                repo_owner)
+                        seafile_api.unset_group_repo(repo_id, group_id, repo_owner)
                     else:
-                        seafile_api.unshare_subdir_for_group(
-                                repo_id, path, repo_owner, group_id)
+                        seafile_api.unshare_subdir_for_group(repo_id, path,
+                                                             repo_owner, group_id)
                 continue
 
             ret.append({
@@ -219,6 +225,9 @@ class DirSharedItemsEndpoint(APIView):
     def post(self, request, repo_id, format=None):
         """Update shared item permission.
         """
+        if not request.user.permissions.can_share_repo():
+            return api_error(status.HTTP_403_FORBIDDEN, 'Permission denied.')
+
         username = request.user.username
         repo = seafile_api.get_repo(repo_id)
         if not repo:
@@ -260,6 +269,19 @@ class DirSharedItemsEndpoint(APIView):
 
                 update_user_dir_permission(repo_id, path, repo_owner, shared_to, permission)
 
+            org_id = None
+            if is_org_context(request):
+                org_id = request.user.org.org_id
+            change_repo_perm_successful.send(
+                sender=None,
+                from_user=username,
+                to_user=shared_to,
+                repo=repo,
+                path=path,
+                permission=permission,
+                org_id=org_id
+            )
+
             send_perm_audit_msg('modify-repo-perm', username, shared_to,
                                 repo_id, path, permission)
 
@@ -291,6 +313,10 @@ class DirSharedItemsEndpoint(APIView):
                             content_type=json_content_type)
 
     def put(self, request, repo_id, format=None):
+
+        if not request.user.permissions.can_share_repo():
+            return api_error(status.HTTP_403_FORBIDDEN, 'Permission denied.')
+
         username = request.user.username
         repo = seafile_api.get_repo(repo_id)
         if not repo:
@@ -354,8 +380,7 @@ class DirSharedItemsEndpoint(APIView):
 
                         if not is_org_user(to_user, int(org_id)):
                             org_name = request.user.org.org_name
-                            error_msg = 'User %s is not member of organization %s.' \
-                                    % (to_user, org_name)
+                            error_msg = f'User {to_user} is not member of organization {org_name}.'
 
                             result['failed'].append({
                                 'email': to_user,
@@ -363,7 +388,8 @@ class DirSharedItemsEndpoint(APIView):
                             })
                             continue
 
-                        # when calling seafile API to share authority related functions, change the uesrname to repo owner.
+                        # when calling seafile API to share authority related functions,
+                        # change the uesrname to repo owner.
                         repo_owner = seafile_api.get_org_repo_owner(repo_id)
                         # can't share to owner
                         if to_user == repo_owner:
@@ -388,7 +414,7 @@ class DirSharedItemsEndpoint(APIView):
 
                         share_dir_to_user(repo, path, repo_owner, username, to_user, permission, None)
 
-                    avatar_url, is_default, date_uploaded = api_avatar_url(to_user, 72)
+                    avatar_url, is_default, date_uploaded = api_avatar_url(to_user)
                     result['success'].append({
                         "share_type": "user",
                         "user_info": {
@@ -463,7 +489,8 @@ class DirSharedItemsEndpoint(APIView):
                 try:
                     org_id = None
                     if is_org_context(request):
-                        # when calling seafile API to share authority related functions, change the uesrname to repo owner.
+                        # when calling seafile API to share authority related functions,
+                        # change the uesrname to repo owner.
                         repo_owner = seafile_api.get_org_repo_owner(repo_id)
                         org_id = request.user.org.org_id
 
@@ -499,9 +526,14 @@ class DirSharedItemsEndpoint(APIView):
                     continue
 
         return HttpResponse(json.dumps(result),
-            status=200, content_type=json_content_type)
+                            status=200,
+                            content_type=json_content_type)
 
     def delete(self, request, repo_id, format=None):
+
+        if not request.user.permissions.can_share_repo():
+            return api_error(status.HTTP_403_FORBIDDEN, 'Permission denied.')
+
         username = request.user.username
         repo = seafile_api.get_repo(repo_id)
         if not repo:
@@ -542,8 +574,20 @@ class DirSharedItemsEndpoint(APIView):
 
             # Delete share permission at ExtraSharePermission table.
             if path == '/':
-                ExtraSharePermission.objects.delete_share_permission(repo_id, 
+                ExtraSharePermission.objects.delete_share_permission(repo_id,
                                                                      shared_to)
+
+            org_id = None
+            if is_org_context(request):
+                org_id = request.user.org.org_id
+            delete_repo_perm_successful.send(
+                sender=None,
+                from_user=username,
+                to_user=shared_to,
+                repo=repo,
+                path=path,
+                org_id=org_id
+            )
             send_perm_audit_msg('delete-repo-perm', username, shared_to,
                                 repo_id, path, permission)
 
@@ -575,8 +619,8 @@ class DirSharedItemsEndpoint(APIView):
 
             # delete share permission if repo is deleted
             if path == '/':
-                ExtraGroupsSharePermission.objects.delete_share_permission(repo_id, 
-                                                                          group_id)
+                ExtraGroupsSharePermission.objects.delete_share_permission(repo_id,
+                                                                           group_id)
             send_perm_audit_msg('delete-repo-perm', username, group_id,
                                 repo_id, path, permission)
 
