@@ -21,24 +21,22 @@ from seahub.api2.utils import api_error
 
 from seahub.utils import check_filename_with_rename, is_pro_version, \
     gen_inner_file_upload_url, is_valid_dirent_name, normalize_file_path, \
-    normalize_dir_path, get_file_type_and_ext, check_filename_or_rename
+    normalize_dir_path, get_file_type_and_ext, check_filename_or_rename, gen_file_get_url, gen_file_upload_url
 from seahub.utils.timeutils import timestamp_to_isoformat_timestr
 from seahub.views import check_folder_permission
 from seahub.utils.file_op import check_file_lock, if_locked_by_online_office
 from seahub.views.file import can_preview_file, can_edit_file
 from seahub.constants import PERMISSION_READ_WRITE
 from seahub.utils.repo import parse_repo_perm, is_repo_admin, is_repo_owner
-from seahub.utils.file_types import MARKDOWN, TEXT, SEADOC, MARKDOWN_SUPPORT_CONVERT_TYPES, SDOC_SUPPORT_CONVERT_TYPES
+from seahub.utils.file_types import SEADOC, \
+        MARKDOWN_SUPPORT_CONVERT_TYPES, SDOC_SUPPORT_CONVERT_TYPES, \
+        DOCX_SUPPORT_CONVERT_TYPES
 from seahub.tags.models import FileUUIDMap
-from seahub.seadoc.models import SeadocHistoryName, SeadocDraft, SeadocCommentReply
+from seahub.seadoc.models import SeadocHistoryName, SeadocCommentReply
 from seahub.base.models import FileComment
 from seahub.settings import MAX_UPLOAD_FILE_NAME_LEN, OFFICE_TEMPLATE_ROOT
-from seahub.api2.endpoints.utils import convert_file
+from seahub.api2.endpoints.utils import convert_file, sdoc_convert_to_docx
 from seahub.seadoc.utils import get_seadoc_file_uuid
-
-from seahub.drafts.models import Draft
-from seahub.drafts.utils import is_draft_file, get_file_draft
-
 from seaserv import seafile_api
 from pysearpc import SearpcError
 
@@ -168,9 +166,8 @@ class FileView(APIView):
         username = request.user.username
         parent_dir = os.path.dirname(path)
 
-        is_draft = request.POST.get('is_draft', '')
-
         if operation == 'create':
+
             # resource check
             try:
                 parent_dir_id = seafile_api.get_dir_id_by_path(repo_id, parent_dir)
@@ -184,21 +181,11 @@ class FileView(APIView):
                 return api_error(status.HTTP_404_NOT_FOUND, error_msg)
 
             # permission check
-            if parse_repo_perm(check_folder_permission(request, repo_id, parent_dir)).can_edit_on_web is False:
+            if parse_repo_perm(check_folder_permission(request, repo_id,
+                                                       parent_dir)).can_create is False:
                 error_msg = 'Permission denied.'
                 return api_error(status.HTTP_403_FORBIDDEN, error_msg)
 
-            if is_draft.lower() == 'true':
-                file_name = os.path.basename(path)
-                file_dir = os.path.dirname(path)
-
-                draft_type = os.path.splitext(file_name)[0][-7:]
-                file_type = os.path.splitext(file_name)[-1]
-
-                if draft_type != '(draft)':
-                    f = os.path.splitext(file_name)[0]
-                    path = file_dir + '/' + f + '(draft)' + file_type
-
             # create new empty file
             new_file_name = os.path.basename(path)
 
@@ -213,25 +200,44 @@ class FileView(APIView):
             except Exception as e:
                 if str(e) == 'Too many files in library.':
                     error_msg = _("The number of files in library exceeds the limit")
-                    from seahub.api2.views import HTTP_442_TOO_MANY_FILES_IN_LIBRARY
-                    return api_error(HTTP_442_TOO_MANY_FILES_IN_LIBRARY, error_msg)
+                    from seahub.api2.views import HTTP_447_TOO_MANY_FILES_IN_LIBRARY
+                    return api_error(HTTP_447_TOO_MANY_FILES_IN_LIBRARY, error_msg)
                 else:
                     logger.error(e)
                     error_msg = 'Internal Server Error'
                     return api_error(status.HTTP_500_INTERNAL_SERVER_ERROR, error_msg)
 
-            if is_draft.lower() == 'true':
-                Draft.objects.add(username, repo, path, file_exist=False)
+            LANGUAGE_DICT = {
+                'cs': 'cs-CZ',
+                'de': 'de-DE',
+                'en': 'en-US',
+                'es': 'es-ES',
+                'fr': 'fr-FR',
+                'it': 'it-IT',
+                'lv': 'lv-LV',
+                'nl': 'nl-NL',
+                'pl': 'pl-PL',
+                'pt-br': 'pt-BR',
+                'ru': 'ru-RU',
+                'sv': 'sv-SE',
+                'vi': 'vi-VN',
+                'uk': 'uk-UA',
+                'el': 'el-GR',
+                'ko': 'ko-KR',
+                'ja': 'ja-JP',
+                'zh-cn': 'zh-CN',
+                'zh-tw': 'zh-TW'
+            }
 
-            # update office file by template
-            if new_file_name.endswith('.xlsx'):
-                empty_file_path = os.path.join(OFFICE_TEMPLATE_ROOT, 'empty.xlsx')
-            elif new_file_name.endswith('.pptx'):
-                empty_file_path = os.path.join(OFFICE_TEMPLATE_ROOT, 'empty.pptx')
-            elif new_file_name.endswith('.docx'):
-                empty_file_path = os.path.join(OFFICE_TEMPLATE_ROOT, 'empty.docx')
-            else:
-                empty_file_path = ''
+            empty_file_path = ''
+            not_used, file_extension = os.path.splitext(new_file_name)
+            if file_extension in ('.xlsx', '.pptx', '.docx', '.docxf'):
+                # update office file by template
+                empty_file_path = os.path.join(OFFICE_TEMPLATE_ROOT, f'empty{file_extension}')
+                language_code_path = LANGUAGE_DICT.get(request.LANGUAGE_CODE)
+                if language_code_path:
+                    empty_file_path = os.path.join(OFFICE_TEMPLATE_ROOT, 'new',
+                                                   language_code_path, f'new{file_extension}')
 
             if empty_file_path:
                 # get file server update url
@@ -256,6 +262,10 @@ class FileView(APIView):
 
             new_file_path = posixpath.join(parent_dir, new_file_name)
             file_info = self.get_file_info(username, repo_id, new_file_path)
+            # gen doc_uuid
+            if new_file_name.endswith('.sdoc'):
+                doc_uuid = get_seadoc_file_uuid(repo, new_file_path)
+                file_info['doc_uuid'] = doc_uuid
             return Response(file_info)
 
         if operation == 'rename':
@@ -314,24 +324,15 @@ class FileView(APIView):
             except SearpcError as e:
                 logger.error(e)
                 error_msg = 'Internal Server Error'
+                if str(e) == 'File type is not allowed':
+                    error_msg = _('File extension is not in the whitelist')
+                    return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
                 return api_error(status.HTTP_500_INTERNAL_SERVER_ERROR, error_msg)
 
             new_file_path = posixpath.join(parent_dir, new_file_name)
 
             # rename draft file
             filetype, fileext = get_file_type_and_ext(new_file_name)
-            if filetype == MARKDOWN or filetype == TEXT:
-                is_draft = is_draft_file(repo.id, path)
-                review = get_file_draft(repo.id, path, is_draft)
-                draft_id = review['draft_id']
-                if is_draft:
-                    try:
-                        draft = Draft.objects.get(pk=draft_id)
-                        draft.draft_file_path = new_file_path
-                        draft.save()
-                    except Draft.DoesNotExist:
-                        pass
-
             file_info = self.get_file_info(username, repo_id, new_file_path)
             return Response(file_info)
 
@@ -530,12 +531,13 @@ class FileView(APIView):
             dst_type = request.data.get('dst_type')
 
             extension = Path(path).suffix
-            if extension not in ['.md', '.sdoc']:
+            if extension not in ['.md', '.sdoc', '.docx']:
                 error_msg = 'path invalid.'
                 return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
 
             if (extension == '.md' and dst_type not in MARKDOWN_SUPPORT_CONVERT_TYPES) or \
-                    (extension == '.sdoc' and dst_type not in SDOC_SUPPORT_CONVERT_TYPES):
+                    (extension == '.sdoc' and dst_type not in SDOC_SUPPORT_CONVERT_TYPES) or \
+                    (extension == '.docx' and dst_type not in DOCX_SUPPORT_CONVERT_TYPES):
                 error_msg = 'dst_type invalid.'
                 return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
 
@@ -572,30 +574,72 @@ class FileView(APIView):
 
             if extension == '.md':
                 src_type = 'markdown'
-                filename = filename[:-2] + 'sdoc'
+                new_filename = filename[:-2] + 'sdoc'
+            if extension == '.docx':
+                src_type = 'docx'
+                new_filename = filename[:-4] + 'sdoc'
             elif extension == '.sdoc':
                 src_type = 'sdoc'
-                filename = filename[:-4] + 'md'
+                if dst_type == 'markdown':
+                    new_filename = filename[:-4] + 'md'
+                if dst_type == 'docx':
+                    new_filename = filename[:-4] + 'docx'
 
-            new_file_name = check_filename_or_rename(repo_id, parent_dir, filename)
-            new_file_path = posixpath.join(parent_dir, new_file_name)
+            new_filename = check_filename_or_rename(repo_id, parent_dir, new_filename)
+            new_file_path = posixpath.join(parent_dir, new_filename)
 
-            download_token = seafile_api.get_fileserver_access_token(repo_id, file_id, 'download', username)
+            download_token = seafile_api.get_fileserver_access_token(repo_id,
+                                                                     file_id,
+                                                                     'download',
+                                                                     username)
+            download_url = gen_file_get_url(download_token, filename)
 
             obj_id = json.dumps({'parent_dir': parent_dir})
-            upload_token = seafile_api.get_fileserver_access_token(repo_id, obj_id, 'upload-link', username,
+            upload_token = seafile_api.get_fileserver_access_token(repo_id,
+                                                                   obj_id,
+                                                                   'upload-link',
+                                                                   username,
                                                                    use_onetime=True)
-            doc_uuid = get_seadoc_file_uuid(repo, path)
 
-            try:
-                resp = convert_file(path, username, doc_uuid, download_token, upload_token, src_type, dst_type)
-                if resp.status_code == 500:
-                    logger.error('convert file error status: %s body: %s', resp.status_code, resp.text)
-                    return api_error(status.HTTP_500_INTERNAL_SERVER_ERROR, 'Internal Server Error')
-            except Exception as e:
-                logger.error(e)
-                error_msg = 'Internal Server Error'
-                return api_error(status.HTTP_500_INTERNAL_SERVER_ERROR, error_msg)
+            upload_url = gen_file_upload_url(upload_token, 'upload-api')
+
+            if extension == '.sdoc':
+                doc_uuid = get_seadoc_file_uuid(repo, path)
+            else:
+                doc_uuid = get_seadoc_file_uuid(repo, new_file_path)
+
+            if dst_type != 'docx':
+                # md, docx file convert to sdoc
+                try:
+                    resp = convert_file(path, username, doc_uuid,
+                                        download_url, upload_url,
+                                        src_type, dst_type)
+                except Exception as e:
+                    logger.error(e)
+                    error_msg = 'Internal Server Error'
+                    return api_error(status.HTTP_500_INTERNAL_SERVER_ERROR, error_msg)
+
+                if resp.status_code != 200:
+                    logger.error('convert file error status: %s body: %s',
+                                 resp.status_code, resp.text)
+                    return api_error(status.HTTP_500_INTERNAL_SERVER_ERROR,
+                                     'Internal Server Error')
+            else:
+                # sdoc file convert to docx
+                try:
+                    resp = sdoc_convert_to_docx(path, username, doc_uuid,
+                                                download_url, upload_url,
+                                                src_type, dst_type)
+                except Exception as e:
+                    logger.error(e)
+                    error_msg = 'Internal Server Error'
+                    return api_error(status.HTTP_500_INTERNAL_SERVER_ERROR, error_msg)
+
+                if resp.status_code != 200:
+                    logger.error('convert file error status: %s body: %s',
+                                 resp.status_code, resp.text)
+                    return api_error(status.HTTP_500_INTERNAL_SERVER_ERROR,
+                                     'Internal Server Error')
 
             file_info = self.get_file_info(username, repo_id, new_file_path)
             return Response(file_info)
@@ -788,7 +832,7 @@ class FileView(APIView):
 
         if is_locked and not locked_by_me:
             error_msg = _("File is locked")
-            return api_error(status.HTTP_403_FORBIDDEN, error_msg)
+            return api_error(status.HTTP_423_LOCKED, error_msg)
 
         # delete file
         file_name = os.path.basename(path)
@@ -810,7 +854,6 @@ class FileView(APIView):
                 FileUUIDMap.objects.delete_fileuuidmap_by_path(
                     repo_id, parent_dir, file_name, is_dir=False)
                 SeadocHistoryName.objects.filter(doc_uuid=file_uuid).delete()
-                SeadocDraft.objects.filter(doc_uuid=file_uuid).delete()
                 SeadocCommentReply.objects.filter(doc_uuid=file_uuid).delete()
         except Exception as e:
             logger.error(e)
