@@ -24,11 +24,13 @@ from seahub.api2.endpoints.utils import (
 from seahub.base.templatetags.seahub_tags import email2nickname, \
         email2contact_email
 from seahub.base.accounts import User
+from seahub.organizations.models import OrgAdminSettings, DISABLE_ORG_ENCRYPTED_LIBRARY
+from seahub.organizations.views import org_user_exists
 from seahub.signals import repo_created
-from seahub.group.utils import is_group_admin
+from seahub.group.utils import is_group_admin, is_group_member
 from seahub.utils import is_valid_dirent_name, is_org_context, \
         is_pro_version, normalize_dir_path, is_valid_username, \
-        send_perm_audit_msg, is_valid_org_id
+        send_perm_audit_msg, is_valid_org_id, transfer_repo
 from seahub.utils.repo import (
     get_library_storages, get_repo_owner, get_available_repo_perms
 )
@@ -39,12 +41,15 @@ from seahub.share.utils import share_dir_to_user, share_dir_to_group, update_use
         check_user_share_out_permission, update_group_dir_permission, \
         check_group_share_out_permission, check_user_share_in_permission, \
         normalize_custom_permission_name
+from seahub.share.models import FileShare, UploadLinkShare
+
 from seahub.constants import PERMISSION_READ, PERMISSION_READ_WRITE, \
         PERMISSION_PREVIEW, PERMISSION_PREVIEW_EDIT
 from seahub.views import check_folder_permission
 
 from seahub.settings import ENABLE_STORAGE_CLASSES, STORAGE_CLASS_MAPPING_POLICY, \
-        ENCRYPTED_LIBRARY_VERSION
+        ENCRYPTED_LIBRARY_VERSION, ENCRYPTED_LIBRARY_PWD_HASH_ALGO, \
+        ENCRYPTED_LIBRARY_PWD_HASH_PARAMS
 
 logger = logging.getLogger(__name__)
 
@@ -102,6 +107,12 @@ class GroupOwnedLibraries(APIView):
             error_msg = 'NOT allow to create encrypted library.'
             return api_error(status.HTTP_403_FORBIDDEN, error_msg)
 
+        if org_id and org_id > 0:
+            disable_encrypted_library = OrgAdminSettings.objects.filter(org_id=org_id, key=DISABLE_ORG_ENCRYPTED_LIBRARY).first()
+            if (disable_encrypted_library is not None) and int(disable_encrypted_library.value):
+                return None, api_error(status.HTTP_403_FORBIDDEN,
+                                       'NOT allow to create encrypted library.')
+
         permission = request.data.get('permission', PERMISSION_READ_WRITE)
         if permission not in [PERMISSION_READ, PERMISSION_READ_WRITE]:
             error_msg = 'permission invalid.'
@@ -139,6 +150,8 @@ class GroupOwnedLibraries(APIView):
                                                            permission,
                                                            password,
                                                            enc_version=ENCRYPTED_LIBRARY_VERSION,
+                                                           pwd_hash_algo=ENCRYPTED_LIBRARY_PWD_HASH_ALGO or None,
+                                                           pwd_hash_params=ENCRYPTED_LIBRARY_PWD_HASH_PARAMS or None,
                                                            storage_id=storage_id)
             else:
                 # STORAGE_CLASS_MAPPING_POLICY == 'REPO_ID_MAPPING'
@@ -1396,3 +1409,122 @@ class GroupOwnedLibraryUserShareInLibrary(APIView):
                             repo_id, '/', permission)
 
         return Response({'success': True})
+
+
+class GroupOwnedLibraryTransferView(APIView):
+
+    authentication_classes = (TokenAuthentication, SessionAuthentication)
+    permission_classes = (IsAuthenticated, IsProVersion)
+    throttle_classes = (UserRateThrottle,)
+
+    @api_check_group
+    @add_org_context
+    def put(self, request, group_id, repo_id, org_id):
+        """ Transfer a library.
+
+        Permission checking:
+        1. is group admin;
+        """
+        # argument check
+        new_owner = request.data.get('email', None)
+        is_share = request.data.get('reshare', False)
+        if not new_owner:
+            error_msg = 'Email invalid.'
+            return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
+
+        if '@seafile_group' not in new_owner:
+            error_msg = 'Email invalid.'
+            return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
+
+        new_group_id = int(new_owner.split('@')[0])
+        if new_group_id == int(group_id):
+            error_msg = 'Cannot transfer to its owner'
+            return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
+        
+        try:
+            new_group = ccnet_api.get_group(new_group_id)
+        except Exception as e:
+            logger.error(e)
+            error_msg = 'Internal Server Error'
+            return api_error(status.HTTP_500_INTERNAL_SERVER_ERROR, error_msg)
+
+        if not new_group:
+            error_msg = 'Group %d not found.' % group_id
+            return api_error(status.HTTP_404_NOT_FOUND, error_msg)
+        
+        if new_group.creator_name != 'system admin':
+            error_msg = 'Group %d invalid' % group_id
+            return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
+        
+        username = request.user.username
+        if not is_group_member(new_group_id, username):
+            error_msg = 'Permission denied.'
+            return api_error(status.HTTP_403_FORBIDDEN, error_msg)
+            
+        if org_id:
+            org_id = int(org_id)
+            if not ccnet_api.get_org_by_id(org_id):
+                error_msg = 'Organization %s not found.' % org_id
+                return api_error(status.HTTP_404_NOT_FOUND, error_msg)
+
+        # permission check
+        if org_id:
+            repo_owner = seafile_api.get_org_repo_owner(repo_id)
+        else:
+            repo_owner = seafile_api.get_repo_owner(repo_id)
+        cur_group_id = int(group_id)
+        
+        if not is_group_admin(cur_group_id, username):
+            error_msg = 'Permission denied.'
+            return api_error(status.HTTP_403_FORBIDDEN, error_msg)        
+
+        # resource check
+        repo = seafile_api.get_repo(repo_id)
+        if not repo:
+            error_msg = 'Library %s not found.' % repo_id
+            return api_error(status.HTTP_404_NOT_FOUND, error_msg)
+        
+        # preparation before transfer repo
+        pub_repos = []
+        if org_id:
+            # get all org pub repos
+            pub_repos = seafile_api.list_org_inner_pub_repos_by_owner(
+                    org_id, repo_owner)
+        else:
+            # get all pub repos
+            if not request.cloud_mode:
+                pub_repos = seafile_api.list_inner_pub_repos_by_owner(repo_owner)
+        # transfer repo
+        try:
+            transfer_repo(repo_id, new_owner, is_share, org_id)
+        except Exception as e:
+            logger.error(e)
+            error_msg = 'Internal Server Error'
+            return api_error(status.HTTP_500_INTERNAL_SERVER_ERROR, error_msg)
+
+        # reshare repo to links
+        try:
+            UploadLinkShare.objects.filter(username=repo_owner, repo_id=repo_id).update(username=new_owner)
+            FileShare.objects.filter(username=repo_owner, repo_id=repo_id).update(username=new_owner)
+        except Exception as e:
+            logger.error(e)
+            error_msg = 'Internal Server Error'
+            return api_error(status.HTTP_500_INTERNAL_SERVER_ERROR, error_msg)
+
+        # check if current repo is pub-repo
+        # if YES, reshare current repo to public
+        for pub_repo in pub_repos:
+            if repo_id != pub_repo.id:
+                continue
+
+            if org_id:
+                seafile_api.set_org_inner_pub_repo(org_id, repo_id,
+                        pub_repo.permission)
+            else:
+                seafile_api.add_inner_pub_repo(
+                        repo_id, pub_repo.permission)
+
+            break
+
+        return Response({'success': True})
+    
\ No newline at end of file
