@@ -24,18 +24,21 @@ from urllib.parse import quote
 from seaserv import seafile_api
 from pysearpc import SearpcError
 
-from seahub.api2.utils import api_error
+from seahub.api2.utils import api_error, send_share_link_emails
 from seahub.api2.authentication import TokenAuthentication
 from seahub.api2.throttling import UserRateThrottle
 from seahub.api2.permissions import CanGenerateShareLink, IsProVersion
+from seahub.base.accounts import User
+from seahub.base.templatetags.seahub_tags import email2nickname
 from seahub.constants import PERMISSION_READ_WRITE, PERMISSION_READ, \
         PERMISSION_PREVIEW_EDIT, PERMISSION_PREVIEW
-from seahub.share.models import FileShare, UploadLinkShare, check_share_link_access
+from seahub.share.models import FileShare, UploadLinkShare, check_share_link_access, check_share_link_access_by_scope
 from seahub.share.decorators import check_share_link_count
+from seahub.share.utils import VALID_SHARE_LINK_SCOPE, SCOPE_SPECIFIC_USERS, SCOPE_SPECIFIC_EMAILS
 from seahub.utils import gen_shared_link, is_org_context, normalize_file_path, \
-        normalize_dir_path, is_pro_version, get_file_type_and_ext, \
-        check_filename_with_rename, gen_file_upload_url, \
-        get_password_strength_level, is_valid_password
+    normalize_dir_path, is_pro_version, get_file_type_and_ext, \
+    check_filename_with_rename, gen_file_upload_url, \
+    get_password_strength_level, is_valid_password, is_valid_email, string2list, gen_file_get_url_by_sharelink
 from seahub.utils.file_op import if_locked_by_online_office
 from seahub.utils.file_types import IMAGE, VIDEO, XMIND
 from seahub.utils.file_tags import get_tagged_files, get_files_tags_in_dir
@@ -45,13 +48,13 @@ from seahub.utils.repo import parse_repo_perm
 from seahub.thumbnail.utils import get_share_link_thumbnail_src
 from seahub.settings import SHARE_LINK_EXPIRE_DAYS_MAX, \
         SHARE_LINK_EXPIRE_DAYS_MIN, SHARE_LINK_LOGIN_REQUIRED, \
-        SHARE_LINK_EXPIRE_DAYS_DEFAULT, \
-        ENABLE_SHARE_LINK_AUDIT, ENABLE_VIDEO_THUMBNAIL, \
+        SHARE_LINK_EXPIRE_DAYS_DEFAULT, THUMBNAIL_DEFAULT_SIZE, \
+        ENABLE_VIDEO_THUMBNAIL, \
         THUMBNAIL_ROOT, ENABLE_UPLOAD_LINK_VIRUS_CHECK
 from seahub.wiki.models import Wiki
 from seahub.views.file import can_edit_file
 from seahub.views import check_folder_permission
-from seahub.signals import upload_file_successful
+from seahub.signals import upload_file_successful, upload_folder_successful
 from seahub.repo_tags.models import RepoTags
 
 logger = logging.getLogger(__name__)
@@ -105,13 +108,15 @@ def get_share_link_info(fileshare):
 
     data['token'] = token
     data['link'] = gen_shared_link(token, fileshare.s_type)
+    data['download_link'] = gen_file_get_url_by_sharelink(token)
+    data['show_download_link'] = fileshare.show_download_link
     data['view_cnt'] = fileshare.view_cnt
     data['ctime'] = ctime
     data['expire_date'] = expire_date
     data['is_expired'] = fileshare.is_expired()
     data['permissions'] = fileshare.get_permissions()
     data['password'] = fileshare.get_password()
-
+    data['user_scope'] = fileshare.user_scope
     data['can_edit'] = False
     if repo and path != '/' and not data['is_dir']:
         try:
@@ -178,6 +183,15 @@ class ShareLinks(APIView):
         1. default(NOT guest) user;
         """
 
+        try:
+            current_page = int(request.GET.get('page', '1'))
+            per_page = int(request.GET.get('per_page', '25'))
+        except ValueError:
+            current_page = 1
+            per_page = 25
+
+        offset = per_page * (current_page - 1)
+
         username = request.user.username
 
         repo_id = request.GET.get('repo_id', '')
@@ -186,7 +200,7 @@ class ShareLinks(APIView):
         fileshares = []
         # get all share links of current user
         if not repo_id and not path:
-            fileshares = FileShare.objects.filter(username=username)
+            fileshares = FileShare.objects.filter(username=username)[offset:offset + per_page]
 
         # share links in repo
         if repo_id and not path:
@@ -196,7 +210,7 @@ class ShareLinks(APIView):
                 return api_error(status.HTTP_404_NOT_FOUND, error_msg)
 
             fileshares = FileShare.objects.filter(username=username) \
-                                          .filter(repo_id=repo_id)
+                                          .filter(repo_id=repo_id)[offset:offset + per_page]
 
         # share links by repo and path
         if repo_id and path:
@@ -218,7 +232,7 @@ class ShareLinks(APIView):
 
             fileshares = FileShare.objects.filter(username=username) \
                                           .filter(repo_id=repo_id) \
-                                          .filter(path=path)
+                                          .filter(path=path)[offset:offset + per_page]
 
         repo_object_dict = {}
         repo_folder_permission_dict = {}
@@ -272,12 +286,15 @@ class ShareLinks(APIView):
             link_info['is_dir'] = True if s_type == 'd' else False
             link_info['token'] = token
             link_info['link'] = gen_shared_link(token, s_type)
+            link_info['download_link'] = gen_file_get_url_by_sharelink(token)
+            link_info['show_download_link'] = fs.show_download_link
             link_info['view_cnt'] = fs.view_cnt
             link_info['ctime'] = datetime_to_isoformat_timestr(fs.ctime) if fs.ctime else ''
             link_info['expire_date'] = datetime_to_isoformat_timestr(fs.expire_date) if fs.expire_date else ''
             link_info['is_expired'] = fs.is_expired()
             link_info['permissions'] = fs.get_permissions()
             link_info['password'] = fs.get_password()
+            link_info['user_scope'] = fs.user_scope
 
             tmp_key = f"{repo_id}_{path}"
             link_info['repo_folder_permission'] = repo_folder_permission_dict.get(tmp_key, "")
@@ -477,6 +494,37 @@ class ShareLinks(APIView):
                                                    password, expire_date,
                                                    permission=perm, org_id=org_id)
 
+        user_scope = request.data.get('user_scope', '')
+        emails_list = []
+        if user_scope and user_scope in VALID_SHARE_LINK_SCOPE:
+            if user_scope == SCOPE_SPECIFIC_USERS:
+
+                emails = request.data.get('emails', [])
+                emails_to_add = []
+
+                for username in emails:
+                    try:
+                        User.objects.get(email=username)
+                    except User.DoesNotExist:
+                        continue
+                    emails_to_add.append(username)
+
+                fs.authed_details = json.dumps(
+                    {'authed_users': emails_to_add}
+                )
+            elif user_scope == SCOPE_SPECIFIC_EMAILS:
+                emails_str = request.data.get('emails', '')
+                emails_list = string2list(emails_str)
+                emails_list = [e for e in emails_list if is_valid_email(e)]
+                fs.authed_details = json.dumps(
+                    {'authed_emails': emails_list}
+                )
+
+            fs.user_scope = user_scope
+            fs.save()
+        if emails_list:
+            shared_from = email2nickname(username)
+            send_share_link_emails(emails_list, fs, shared_from)
         link_info = get_share_link_info(fs)
         return Response(link_info)
 
@@ -519,7 +567,7 @@ class ShareLinks(APIView):
             if not fs.is_owner(username):
                 result['failed'].append({
                     'token': token,
-                    'error_msg': 'Permission denied.'
+                    'error_msg': _('Permission denied.')
                     })
                 continue
 
@@ -539,7 +587,7 @@ class ShareLinks(APIView):
                 logger.error(e)
                 result['failed'].append({
                     'token': token,
-                    'error_msg': 'Internal Server Error'
+                    'error_msg': _('Internal Server Error')
                     })
                 continue
 
@@ -712,6 +760,12 @@ class ShareLink(APIView):
             fs.expire_date = expire_date
             fs.save()
 
+        user_scope = request.data.get('user_scope', '')
+        if user_scope and user_scope in VALID_SHARE_LINK_SCOPE:
+            fs.user_scope = user_scope
+            fs.authed_details = None
+            fs.save()
+
         link_info = get_share_link_info(fs)
         return Response(link_info)
 
@@ -839,12 +893,12 @@ class ShareLinkDirents(APIView):
 
         Permission checking:
         1, If enable SHARE_LINK_LOGIN_REQUIRED, user must have been authenticated.
-        2, If enable ENABLE_SHARE_LINK_AUDIT, user must have been authenticated, or have been audited.
+        2, If enable SHARE_LINK_SCOPE, user must have been authenticated by specific scope.
         3, If share link is encrypted, share link password must have been checked.
         """
 
         # argument check
-        thumbnail_size = request.GET.get('thumbnail_size', 48)
+        thumbnail_size = request.GET.get('thumbnail_size', THUMBNAIL_DEFAULT_SIZE)
         try:
             thumbnail_size = int(thumbnail_size)
         except ValueError:
@@ -859,16 +913,9 @@ class ShareLinkDirents(APIView):
             error_msg = 'Permission denied.'
             return api_error(status.HTTP_403_FORBIDDEN, error_msg)
 
-        # check share link audit
-        if is_pro_version() and ENABLE_SHARE_LINK_AUDIT and \
-                not request.user.is_authenticated and \
-                not request.session.get('anonymous_email'):
-            error_msg = 'Permission denied.'
-            return api_error(status.HTTP_403_FORBIDDEN, error_msg)
-
         # resource check
         try:
-            share_link = FileShare.objects.get(token=token)
+            share_link = FileShare.objects.get_valid_dir_link_by_token(token=token)
         except FileShare.DoesNotExist:
             error_msg = 'Share link %s not found.' % token
             return api_error(status.HTTP_404_NOT_FOUND, error_msg)
@@ -878,6 +925,10 @@ class ShareLinkDirents(APIView):
             error_msg = 'Permission denied.'
             return api_error(status.HTTP_403_FORBIDDEN, error_msg)
 
+        if not check_share_link_access_by_scope(request, share_link):
+            error_msg = 'Permission denied.'
+            return api_error(status.HTTP_403_FORBIDDEN, error_msg)
+
         if share_link.s_type != 'd':
             error_msg = 'Share link %s is not a folder share link.' % token
             return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
@@ -966,7 +1017,7 @@ class ShareLinkUpload(APIView):
         """ Only used for get seafhttp upload link for a folder share link.
         Permission checking:
         1, If enable SHARE_LINK_LOGIN_REQUIRED, user must have been authenticated.
-        2, If enable ENABLE_SHARE_LINK_AUDIT, user must have been authenticated, or have been audited.
+        2, If enable SHARE_LINK_SCOPE, user must have been authenticated by specific scope.
         3, If share link is encrypted, share link password must have been checked.
         4, Share link must be a folder share link and has can_upload permission.
         """
@@ -977,16 +1028,9 @@ class ShareLinkUpload(APIView):
             error_msg = 'Permission denied.'
             return api_error(status.HTTP_403_FORBIDDEN, error_msg)
 
-        # check share link audit
-        if is_pro_version() and ENABLE_SHARE_LINK_AUDIT and \
-                not request.user.is_authenticated and \
-                not request.session.get('anonymous_email'):
-            error_msg = 'Permission denied.'
-            return api_error(status.HTTP_403_FORBIDDEN, error_msg)
-
         # resource check
         try:
-            share_link = FileShare.objects.get(token=token)
+            share_link = FileShare.objects.get_valid_dir_link_by_token(token=token)
         except FileShare.DoesNotExist:
             error_msg = 'Share link %s not found.' % token
             return api_error(status.HTTP_404_NOT_FOUND, error_msg)
@@ -1018,6 +1062,10 @@ class ShareLinkUpload(APIView):
             error_msg = 'Permission denied.'
             return api_error(status.HTTP_403_FORBIDDEN, error_msg)
 
+        if not check_share_link_access_by_scope(request, share_link):
+            error_msg = 'Permission denied.'
+            return api_error(status.HTTP_403_FORBIDDEN, error_msg)
+
         if not share_link.get_permissions()['can_upload']:
             error_msg = 'Permission denied.'
             return api_error(status.HTTP_403_FORBIDDEN, error_msg)
@@ -1062,7 +1110,7 @@ class ShareLinkUploadDone(APIView):
 
         Permission checking:
         1, If enable SHARE_LINK_LOGIN_REQUIRED, user must have been authenticated.
-        2, If enable ENABLE_SHARE_LINK_AUDIT, user must have been authenticated, or have been audited.
+        2, If enable SHARE_LINK_SCOPE, user must have been authenticated by specific scope.
         3, If share link is encrypted, share link password must have been checked.
         4, Share link must be a folder share link and has can_upload permission.
         """
@@ -1072,14 +1120,13 @@ class ShareLinkUploadDone(APIView):
         share_link = None
         upload_link = None
 
-        try:
-            share_link = FileShare.objects.get(token=token)
-        except FileShare.DoesNotExist:
-            upload_link = UploadLinkShare.objects.get(token=token)
-        except UploadLinkShare.DoesNotExist:
+        share_link = FileShare.objects.get_valid_dir_link_by_token(token=token)
+        upload_link = UploadLinkShare.objects.filter(token=token).first()
+
+        if not (share_link or upload_link):
             error_msg = 'token %s not found.' % token
             return api_error(status.HTTP_404_NOT_FOUND, error_msg)
-
+        
         if share_link:
 
             # check if login required
@@ -1088,18 +1135,15 @@ class ShareLinkUploadDone(APIView):
                 error_msg = 'Permission denied.'
                 return api_error(status.HTTP_403_FORBIDDEN, error_msg)
 
-            # check share link audit
-            if is_pro_version() and ENABLE_SHARE_LINK_AUDIT and \
-                    not request.user.is_authenticated and \
-                    not request.session.get('anonymous_email'):
-                error_msg = 'Permission denied.'
-                return api_error(status.HTTP_403_FORBIDDEN, error_msg)
-
             # check share link validation
             if share_link.is_encrypted() and not check_share_link_access(request, token):
                 error_msg = 'Share link is encrypted.'
                 return api_error(status.HTTP_403_FORBIDDEN, error_msg)
 
+            if not check_share_link_access_by_scope(request, share_link):
+                error_msg = 'Permission denied.'
+                return api_error(status.HTTP_403_FORBIDDEN, error_msg)
+
             if not share_link.get_permissions()['can_upload']:
                 error_msg = 'Share link has no can_upload permission'
                 return api_error(status.HTTP_403_FORBIDDEN, error_msg)
@@ -1120,40 +1164,24 @@ class ShareLinkUploadDone(APIView):
                 return api_error(status.HTTP_404_NOT_FOUND, error_msg)
 
             parent_dir = share_link.path
-            if seafile_api.check_permission_by_path(repo_id, parent_dir, share_link.username) != 'rw':
+            link_owner = share_link.username
+            if seafile_api.check_permission_by_path(repo_id,
+                                                    parent_dir,
+                                                    link_owner) != 'rw':
                 error_msg = 'Permission denied.'
                 return api_error(status.HTTP_403_FORBIDDEN, error_msg)
 
-            file_path = request.data.get('file_path')
-            if not file_path:
-                error_msg = 'file_path invalid.'
-                return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
-
-            file_id = seafile_api.get_file_id_by_path(repo_id, file_path)
-            if not file_id:
-                error_msg = 'File %s not found.' % file_path
-                return api_error(status.HTTP_404_NOT_FOUND, error_msg)
-
-            # send singal
-            upload_file_successful.send(sender=None,
-                                        repo_id=repo_id,
-                                        file_path=file_path,
-                                        owner=share_link.username)
-
-            return Response({'success': True})
-
         if upload_link:
 
-            if upload_link.is_encrypted() and not check_share_link_access(request,
-                                                                          token,
-                                                                          is_upload_link=True):
+            if upload_link.is_encrypted() and not \
+                    check_share_link_access(request, token, is_upload_link=True):
                 error_msg = 'Permission denied.'
                 return api_error(status.HTTP_403_FORBIDDEN, error_msg)
 
             if upload_link.is_expired():
                 error_msg = 'Upload link is expired'
                 return api_error(status.HTTP_403_FORBIDDEN, error_msg)
-
+            
             repo_id = upload_link.repo_id
             repo = seafile_api.get_repo(repo_id)
             if not repo:
@@ -1161,26 +1189,44 @@ class ShareLinkUploadDone(APIView):
                 return api_error(status.HTTP_404_NOT_FOUND, error_msg)
 
             parent_dir = upload_link.path
-            if seafile_api.check_permission_by_path(repo_id, parent_dir, upload_link.username) != 'rw':
+            link_owner = upload_link.username
+            if seafile_api.check_permission_by_path(repo_id,
+                                                    parent_dir,
+                                                    link_owner) != 'rw':
                 error_msg = 'Permission denied.'
                 return api_error(status.HTTP_403_FORBIDDEN, error_msg)
+            
+        # send signal
+        dirent_path = request.data.get('file_path')
+        if not dirent_path:
+            error_msg = 'file_path invalid.'
+            return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
 
-            file_path = request.data.get('file_path')
-            if not file_path:
-                error_msg = 'file_path invalid.'
-                return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
-
-            file_id = seafile_api.get_file_id_by_path(repo_id, file_path)
-            if not file_id:
-                error_msg = 'File %s not found.' % file_path
+        is_dir = request.data.get('is_dir', 'false')
+        if is_dir.lower() == 'true':
+            dir_id = seafile_api.get_dir_id_by_path(repo_id, dirent_path)
+            if not dir_id:
+                error_msg = 'Folder %s not found.' % dirent_path
                 return api_error(status.HTTP_404_NOT_FOUND, error_msg)
 
+            # send singal
+            upload_folder_successful.send(sender=None,
+                                          repo_id=repo_id,
+                                          folder_path=dirent_path,
+                                          owner=link_owner)
+        else:
+            file_id = seafile_api.get_file_id_by_path(repo_id, dirent_path)
+            if not file_id:
+                error_msg = 'File %s not found.' % dirent_path
+                return api_error(status.HTTP_404_NOT_FOUND, error_msg)
+
+            # send singal
             upload_file_successful.send(sender=None,
                                         repo_id=repo_id,
-                                        file_path=file_path,
-                                        owner=upload_link.username)
+                                        file_path=dirent_path,
+                                        owner=link_owner)
 
-            return Response({'success': True})
+        return Response({'success': True})
 
 
 class ShareLinkSaveFileToRepo(APIView):
@@ -1380,7 +1426,10 @@ class ShareLinkRepoTags(APIView):
         tag_id_file_list_dict = defaultdict(list)
         for repo_tag in repo_tags:
             tagged_files = get_tagged_files(repo, repo_tag.pk)['tagged_files']
-            tagged_files = [item for item in tagged_files if item.get('parent_path') and item.get('parent_path').startswith(share_link.path.rstrip('/'))]
+            tagged_files = [
+                item for item in tagged_files
+                if item.get('parent_path') and item.get('parent_path').startswith(share_link.path.rstrip('/'))
+            ]
             tag_id_file_list_dict[repo_tag.pk] = tagged_files
 
         # generate response
@@ -1456,7 +1505,7 @@ class ShareLinksCleanInvalid(APIView):
         username = request.user.username
         share_links = FileShare.objects.filter(username=username)
 
-        for share_link in share_links:
+        for share_link in share_links.iterator(chunk_size=1000):
 
             if share_link.is_expired():
                 share_link.delete()
