@@ -7,6 +7,7 @@ from django.conf import settings
 from django.core.cache import cache as default_cache
 from django.core.exceptions import ImproperlyConfigured
 from rest_framework.settings import api_settings
+from rest_framework.throttling import BaseThrottle
 import time
 
 from seahub.utils.ip import get_remote_ip
@@ -207,6 +208,22 @@ class UserRateThrottle(SimpleRateThrottle):
             'ident': ident
         }
 
+class ShareLinkZipTaskThrottle(SimpleRateThrottle):
+
+    scope = 'share_link_zip_task'
+
+    def get_cache_key(self, request, view):
+        if request.user.is_authenticated:
+            ident = request.user.id
+        else:
+            ident = self.get_ident(request)
+        
+        return self.cache_format % {
+            'scope': self.scope,
+            'ident': ident
+        }
+
+
 
 class ScopedRateThrottle(SimpleRateThrottle):
     """
