@@ -2,21 +2,31 @@
 from seahub.api2.base import APIView
 from seahub.api2.utils import json_response
 from seahub import settings
-from seahub.utils import HAS_OFFICE_CONVERTER, HAS_FILE_SEARCH, is_pro_version
+from seahub.utils import HAS_OFFICE_CONVERTER, HAS_FILE_SEARCH, is_pro_version, HAS_FILE_SEASEARCH
 
 from constance import config
 
+
 class ServerInfoView(APIView):
     """
     Returns the server info (version, supported features).
     """
     @json_response
     def get(self, request, format=None):
+
         info = {
             'version': settings.SEAFILE_VERSION,
-            'encrypted_library_version': settings.ENCRYPTED_LIBRARY_VERSION if settings.ENCRYPTED_LIBRARY_VERSION >= 3 else 2,
         }
 
+        if settings.ENCRYPTED_LIBRARY_VERSION >= 3:
+            info['encrypted_library_version'] = settings.ENCRYPTED_LIBRARY_VERSION
+        else:
+            info['encrypted_library_version'] = 2
+
+        if settings.ENCRYPTED_LIBRARY_PWD_HASH_ALGO:
+            info['encrypted_library_pwd_hash_algo'] = settings.ENCRYPTED_LIBRARY_PWD_HASH_ALGO
+            info['encrypted_library_pwd_hash_params'] = settings.ENCRYPTED_LIBRARY_PWD_HASH_PARAMS
+
         features = ['seafile-basic']
 
         if is_pro_version():
@@ -25,7 +35,7 @@ class ServerInfoView(APIView):
         if HAS_OFFICE_CONVERTER:
             features.append('office-preview')
 
-        if HAS_FILE_SEARCH:
+        if HAS_FILE_SEARCH or HAS_FILE_SEASEARCH:
             features.append('file-search')
 
         if config.DISABLE_SYNC_WITH_ANY_FOLDER:
