@@ -1,6 +1,7 @@
 # Copyright (c) 2012-2016 Seafile Ltd.
 import hashlib
 import logging
+import jwt
 from datetime import datetime
 from django.conf import settings
 # Avoid shadowing the login() view below.
@@ -17,9 +18,10 @@ from django.utils.translation import gettext as _
 from django.views.decorators.cache import never_cache
 from saml2.ident import decode
 from seaserv import seafile_api, ccnet_api
-
+from seahub.settings import SSO_SECRET_KEY
 from seahub.auth import REDIRECT_FIELD_NAME, get_backends
 from seahub.auth import login as auth_login
+from seahub.auth.models import SocialAuthUser
 from seahub.auth.decorators import login_required
 from seahub.auth.forms import AuthenticationForm, CaptchaAuthenticationForm, \
         PasswordResetForm, SetPasswordForm, PasswordChangeForm, \
@@ -33,7 +35,8 @@ from seahub.base.accounts import User, UNUSABLE_PASSWORD
 from seahub.options.models import UserOptions
 from seahub.profile.models import Profile
 from seahub.two_factor.views.login import is_device_remembered
-from seahub.utils import is_ldap_user, get_site_name, is_valid_email
+from seahub.utils import render_error, get_site_name, is_valid_email, get_service_url
+from seahub.utils.http import rate_limit
 from seahub.utils.ip import get_remote_ip
 from seahub.utils.file_size import get_quota_from_string
 from seahub.utils.two_factor_auth import two_factor_auth_enabled, handle_two_factor_auth
@@ -95,7 +98,6 @@ def login(request, template_name='registration/login.html',
           redirect_field_name=REDIRECT_FIELD_NAME,
           authentication_form=AuthenticationForm):
     """Displays the login form and handles the login action."""
-
     redirect_to = request.GET.get(redirect_field_name, '')
     if request.user.is_authenticated:
         if redirect_to and url_has_allowed_host_and_scheme(redirect_to, allowed_hosts=request.get_host()):
@@ -128,7 +130,8 @@ def login(request, template_name='registration/login.html',
                                             redirect_to, remember_me)
 
         # form is invalid
-        user_logged_in_failed.send(sender=None, request=request)
+        form.db_record and user_logged_in_failed.send(sender=None, request=request)
+        
         failed_attempt = incr_login_failed_attempts(username=login,
                                                     ip=ip)
 
@@ -139,11 +142,13 @@ def login(request, template_name='registration/login.html',
                             (login, ip, failed_attempt))
                 email = Profile.objects.get_username_by_login_id(login)
                 if email is None:
-                    email = login
+                    email = Profile.objects.get_username_by_contact_email(login)
+                    if email is None:
+                        email = login
                 try:
                     user = User.objects.get(email)
                     if user.is_active:
-                        user.freeze_user(notify_admins=True)
+                        user.freeze_user(notify_admins=True, notify_org_admins=True)
                         logger.warn('Login attempt limit reached, freeze the user email/username: %s, ip: %s, attemps: %d' %
                                     (login, ip, failed_attempt))
                 except User.DoesNotExist:
@@ -192,10 +197,9 @@ def login(request, template_name='registration/login.html',
                  getattr(settings, 'ENABLE_KRB5_LOGIN', False) or \
                  getattr(settings, 'ENABLE_ADFS_LOGIN', False) or \
                  getattr(settings, 'ENABLE_OAUTH', False) or \
-                 getattr(settings, 'ENABLE_DINGTALK', False) or \
+                 getattr(settings, 'ENABLE_CUSTOM_OAUTH', False) or \
                  getattr(settings, 'ENABLE_CAS', False) or \
-                 getattr(settings, 'ENABLE_REMOTE_USER_AUTHENTICATION', False) or \
-                 getattr(settings, 'ENABLE_WORK_WEIXIN', False)
+                 getattr(settings, 'ENABLE_REMOTE_USER_AUTHENTICATION', False)
 
     login_bg_image_path = get_login_bg_image_path()
 
@@ -213,59 +217,63 @@ def login(request, template_name='registration/login.html',
     })
 
 def login_simple_check(request):
-    """A simple check for login called by thirdpart systems(OA, etc).
 
-    Token generation: MD5(secret_key + foo@foo.com + 2014-1-1).hexdigest()
-    Token length: 32 hexadecimal digits.
-    """
-    username = request.GET.get('user', '')
-    random_key = request.GET.get('token', '')
+    if not SSO_SECRET_KEY:
+        return render_error(request, 'Permission denied.')
+    
+    login_token = request.GET.get('token', '')
+    if not login_token:
+        return render_error(request, 'token invalid.')
 
-    if not username or not random_key:
-        raise Http404
+    try:
+        payload = jwt.decode(login_token, SSO_SECRET_KEY, algorithms=['HS256'])
+    except jwt.ExpiredSignatureError:
+        return render_error(request, 'token expired.')
+    except jwt.PyJWTError:
+        return render_error(request, 'token invalid.')
 
-    today = datetime.now().strftime('%Y-%m-%d')
-    expect = hashlib.md5((settings.SECRET_KEY+username+today).encode('utf-8')).hexdigest()
-    if expect == random_key:
-        try:
-            user = User.objects.get(email=username)
-        except User.DoesNotExist:
-            raise Http404
-
-        for backend in get_backends():
-            user.backend = "%s.%s" % (backend.__module__, backend.__class__.__name__)
-
-        auth_login(request, user)
-
-        # Ensure the user-originating redirection url is safe.
-        if REDIRECT_FIELD_NAME in request.GET:
-            next_page = request.GET[REDIRECT_FIELD_NAME]
-            if not url_has_allowed_host_and_scheme(url=next_page, allowed_hosts=request.get_host()):
-                next_page = settings.LOGIN_REDIRECT_URL
-        else:
-            next_page = settings.SITE_ROOT
-
-        return HttpResponseRedirect(next_page)
+    if 'exp' not in payload:
+        return render_error(request, 'token invalid.')
+    
+    user_id = payload.get('user_id')
+    if not user_id:
+        return render_error(request, 'token invalid.')
+    
+    try:
+        user = User.objects.get(email=user_id)
+    except User.DoesNotExist:
+        return render_error(request, 'token invalid.')
+    
+    for backend in get_backends():
+        user.backend = "%s.%s" % (backend.__module__, backend.__class__.__name__)
+    auth_login(request, user)
+    if REDIRECT_FIELD_NAME in request.GET:
+        next_page = request.GET[REDIRECT_FIELD_NAME]
+        if not url_has_allowed_host_and_scheme(url=next_page, allowed_hosts=request.get_host()):
+            next_page = settings.LOGIN_REDIRECT_URL
     else:
-        raise Http404
-
+        next_page = settings.SITE_ROOT
+    return HttpResponseRedirect(next_page)
 
 def logout(request, next_page=None,
            template_name='registration/logged_out.html',
            redirect_field_name=REDIRECT_FIELD_NAME):
     "Logs out the user and displays 'You are logged out' message."
 
-    if getattr(settings, 'ENABLE_MULTI_ADFS', False):
-        from seahub.utils import is_org_context
+    if getattr(settings, 'ENABLE_ADFS_LOGIN', False) or getattr(settings, 'ENABLE_MULTI_ADFS', False):
         try:
             saml_subject_id = decode(request.saml_session["_saml2_subject_id"])
+            if saml_subject_id:
+                from seahub.utils import is_org_context
+                if is_org_context(request):
+                    org_id = request.user.org.org_id
+                    response = HttpResponseRedirect(get_service_url().rstrip('/') + '/org/custom/%s/saml2/logout/' % str(org_id))
+                else:
+                    response = HttpResponseRedirect(get_service_url().rstrip('/') + '/saml2/logout/')
+                response.delete_cookie('seahub_auth')
+                return response
         except Exception as e:
             logger.warning(e)
-            saml_subject_id = None
-        if saml_subject_id and is_org_context(request):
-            org_id = request.user.org.org_id
-            org = ccnet_api.get_org_by_id(org_id)
-            return HttpResponseRedirect('/org/custom/%s/saml2/logout/' % org.url_prefix)
 
     from seahub.auth import logout
     logout(request)
@@ -286,6 +294,15 @@ def logout(request, next_page=None,
         response.delete_cookie('seahub_auth')
         return response
 
+    # Local logout for ouath user.
+    via_oauth = request.COOKIES.get('via_oauth', '')
+    oauth_logout_url = getattr(settings, 'OAUTH_LOGOUT_URL', '')
+    if (getattr(settings, 'ENABLE_OAUTH', False) or getattr(settings, 'ENABLE_CUSTOM_OAUTH', False)) and via_oauth and oauth_logout_url:
+        response = HttpResponseRedirect(oauth_logout_url)
+        response.delete_cookie('via_oauth')
+        response.delete_cookie('seahub_auth')
+        return response
+
     from seahub.settings import LOGOUT_REDIRECT_URL
     if LOGOUT_REDIRECT_URL:
         response = HttpResponseRedirect(LOGOUT_REDIRECT_URL)
@@ -333,13 +350,31 @@ def redirect_to_login(next, login_url=None, redirect_field_name=REDIRECT_FIELD_N
 #   prompts for a new password
 # - password_reset_complete shows a success message for the above
 
+
 @csrf_protect
-def password_reset(request, is_admin_site=False, template_name='registration/password_reset_form.html',
-        email_template_name='registration/password_reset_email.html',
-        password_reset_form=PasswordResetForm, token_generator=default_token_generator,
-        post_reset_redirect=None):
+@rate_limit()
+def password_reset(request, is_admin_site=False,
+                   template_name='registration/password_reset_form.html',
+                   email_template_name='registration/password_reset_email.html',
+                   password_reset_form=PasswordResetForm,
+                   token_generator=default_token_generator,
+                   post_reset_redirect=None):
+
+    has_bind_social_auth = False
+    if SocialAuthUser.objects.filter(username=request.user.username).exists():
+        has_bind_social_auth = True
+
+    can_reset_password = True
+    if has_bind_social_auth and (not settings.ENABLE_SSO_USER_CHANGE_PASSWORD):
+        can_reset_password = False
+
+    if not can_reset_password:
+        return render_error(request, _('Unable to reset password.'))
+
     if post_reset_redirect is None:
         post_reset_redirect = reverse('auth_password_reset_done')
+
+    login_bg_image_path = get_login_bg_image_path()
     if request.method == "POST":
         form = password_reset_form(request.POST)
         if form.is_valid():
@@ -358,6 +393,7 @@ def password_reset(request, is_admin_site=False, template_name='registration/pas
                 messages.error(request, _('Failed to send email, please contact administrator.'))
                 return render(request, template_name, {
                         'form': form,
+                        'login_bg_image_path': login_bg_image_path,
                         })
             else:
                 return HttpResponseRedirect(post_reset_redirect)
@@ -365,10 +401,14 @@ def password_reset(request, is_admin_site=False, template_name='registration/pas
         form = password_reset_form()
     return render(request, template_name, {
         'form': form,
+        'login_bg_image_path': login_bg_image_path,
     })
 
 def password_reset_done(request, template_name='registration/password_reset_done.html'):
-    return render(request, template_name)
+    login_bg_image_path = get_login_bg_image_path()
+    return render(request, template_name, {
+        'login_bg_image_path': login_bg_image_path,
+    })
 
 # Doesn't need csrf_protect since no-one can guess the URL
 def password_reset_confirm(request, uidb36=None, token=None, template_name='registration/password_reset_confirm.html',
@@ -401,6 +441,8 @@ def password_reset_confirm(request, uidb36=None, token=None, template_name='regi
         context_instance['validlink'] = False
         form = None
     context_instance['form'] = form
+
+    context_instance['strong_pwd_required'] = config.USER_STRONG_PASSWORD_REQUIRED
     return render(request, template_name, context_instance)
 
 def password_reset_complete(request, template_name='registration/password_reset_complete.html'):
@@ -413,8 +455,16 @@ def password_change(request, template_name='registration/password_change_form.ht
     if post_change_redirect is None:
         post_change_redirect = reverse('auth_password_change_done')
 
-    if is_ldap_user(request.user):
-        messages.error(request, _("Can not update password, please contact LDAP admin."))
+    has_bind_social_auth = False
+    if SocialAuthUser.objects.filter(username=request.user.username).exists():
+        has_bind_social_auth = True
+
+    can_change_password = True
+    if has_bind_social_auth and (not settings.ENABLE_SSO_USER_CHANGE_PASSWORD):
+        can_change_password = False
+
+    if not can_change_password:
+        return render_error(request, _('Unable to change password.'))
 
     if settings.ENABLE_USER_SET_CONTACT_EMAIL:
         user_profile = Profile.objects.get_profile_by_user(request.user.username)
@@ -423,10 +473,10 @@ def password_change(request, template_name='registration/password_change_form.ht
             password_change_form = SetContactEmailPasswordForm
             template_name = 'registration/password_set_form.html'
 
-        elif request.user.enc_password == UNUSABLE_PASSWORD:
-            # set password only
-            password_change_form = SetPasswordForm
-            template_name = 'registration/password_set_form.html'
+    if request.user.enc_password == UNUSABLE_PASSWORD:
+        # set password only
+        password_change_form = SetPasswordForm
+        template_name = 'registration/password_set_form.html'
 
     if request.method == "POST":
         form = password_change_form(user=request.user, data=request.POST)
@@ -445,9 +495,7 @@ def password_change(request, template_name='registration/password_change_form.ht
 
     return render(request, template_name, {
         'form': form,
-        'min_len': config.USER_PASSWORD_MIN_LENGTH,
         'strong_pwd_required': config.USER_STRONG_PASSWORD_REQUIRED,
-        'level': config.USER_PASSWORD_STRENGTH_LEVEL,
         'force_passwd_change': request.session.get('force_passwd_change', False),
     })
 
@@ -477,23 +525,23 @@ def multi_adfs_sso(request):
         try:
             org_saml_config = OrgSAMLConfig.objects.get_config_by_domain(domain)
             if not org_saml_config:
-                render_data['error_msg'] = "Cannot find a SAML/ADFS config for the organization related to domain %s." % domain
+                render_data['error_msg'] = "Cannot find an ADFS/SAML config for the team related to domain %s." % domain
                 return render(request, template_name, render_data)
             if not org_saml_config.domain_verified:
-                render_data['error_msg'] = "The domain %s has not been verified ownership, please login after verification." % domain
+                render_data['error_msg'] = \
+                  "The ownership of domain %s has not been verified. Please ask your team admin to verify it." % domain
                 return render(request, template_name, render_data)
             org_id = org_saml_config.org_id
             org = ccnet_api.get_org_by_id(org_id)
             if not org:
-                render_data['error_msg'] = 'Cannot find an organization related to domain %s.' % domain
+                render_data['error_msg'] = "Cannot find an ADFS/SAML config for the team related to domain %s." % domain
                 return render(request, template_name, render_data)
-            url_prefix = org.url_prefix
         except Exception as e:
             logger.error(e)
             render_data['error_msg'] = 'Error, please contact administrator.'
             return render(request, template_name, render_data)
 
-        return HttpResponseRedirect('/org/custom/%s/saml2/login/' % url_prefix)
+        return HttpResponseRedirect(get_service_url().rstrip('/') + '/org/custom/%s/saml2/login/' % str(org_id))
 
     if request.method == "GET":
         return render(request, template_name, render_data)
