@@ -27,7 +27,7 @@ from seahub.profile.models import Profile, DetailedProfile
 from seahub.role_permissions.models import AdminRole
 from seahub.role_permissions.utils import get_enabled_role_permissions_by_role, \
         get_enabled_admin_role_permissions_by_role
-from seahub.utils import is_user_password_strong, get_site_name, \
+from seahub.utils import get_site_name, \
     clear_token, get_system_admins, is_pro_version, IS_EMAIL_CONFIGURED
 from seahub.utils.mail import send_html_email_with_dj_template
 from seahub.utils.licenseparse import user_number_over_limit
@@ -35,6 +35,7 @@ from seahub.share.models import ExtraSharePermission
 from seahub.utils.auth import gen_user_virtual_id
 from seahub.auth.models import SocialAuthUser
 from seahub.repo_auto_delete.models import RepoAutoDelete
+from seahub.utils.password import get_password_strength_requirements, is_password_strength_valid
 
 try:
     from seahub.settings import CLOUD_MODE
@@ -45,41 +46,16 @@ try:
 except ImportError:
     MULTI_TENANCY = False
 
-from seahub.settings import ENABLE_LDAP, LDAP_USER_FIRST_NAME_ATTR, LDAP_USER_LAST_NAME_ATTR, \
+from seahub.utils.ldap import ENABLE_LDAP, LDAP_USER_FIRST_NAME_ATTR, LDAP_USER_LAST_NAME_ATTR, \
     LDAP_USER_NAME_REVERSE, LDAP_FILTER, LDAP_CONTACT_EMAIL_ATTR, LDAP_USER_ROLE_ATTR, \
-    ENABLE_SASL, SASL_MECHANISM, SASL_AUTHC_ID_ATTR
-
-LDAP_PROVIDER = getattr(settings, 'LDAP_PROVIDER', 'ldap')
-try:
-    from seahub.settings import LDAP_SERVER_URL, LDAP_BASE_DN, LDAP_ADMIN_DN, LDAP_ADMIN_PASSWORD, LDAP_LOGIN_ATTR
-except ImportError:
-    LDAP_SERVER_URL = ''
-    LDAP_BASE_DN = ''
-    LDAP_ADMIN_DN = ''
-    LDAP_ADMIN_PASSWORD = ''
-    LDAP_LOGIN_ATTR = ''
-
-# multi ldap
-try:
-    from seahub.settings import ENABLE_MULTI_LDAP, MULTI_LDAP_1_SERVER_URL, MULTI_LDAP_1_BASE_DN, \
-         MULTI_LDAP_1_ADMIN_DN, MULTI_LDAP_1_ADMIN_PASSWORD, MULTI_LDAP_1_LOGIN_ATTR
-except ImportError:
-    ENABLE_MULTI_LDAP = False
-    MULTI_LDAP_1_SERVER_URL = ''
-    MULTI_LDAP_1_BASE_DN = ''
-    MULTI_LDAP_1_ADMIN_DN = ''
-    MULTI_LDAP_1_ADMIN_PASSWORD = ''
-    MULTI_LDAP_1_LOGIN_ATTR = ''
-
-MULTI_LDAP_1_PROVIDER = getattr(settings, 'MULTI_LDAP_1_PROVIDER', 'ldap1')
-MULTI_LDAP_1_FILTER = getattr(settings, 'MULTI_LDAP_1_FILTER', '')
-MULTI_LDAP_1_CONTACT_EMAIL_ATTR = getattr(settings, 'MULTI_LDAP_1_CONTACT_EMAIL_ATTR', '')
-MULTI_LDAP_1_USER_ROLE_ATTR = getattr(settings, 'MULTI_LDAP_1_USER_ROLE_ATTR', '')
-MULTI_LDAP_1_ENABLE_SASL = getattr(settings, 'MULTI_LDAP_1_ENABLE_SASL', False)
-MULTI_LDAP_1_SASL_MECHANISM = getattr(settings, 'MULTI_LDAP_1_SASL_MECHANISM', '')
-MULTI_LDAP_1_SASL_AUTHC_ID_ATTR = getattr(settings, 'MULTI_LDAP_1_SASL_AUTHC_ID_ATTR', '')
-
-LDAP_UPDATE_USER_WHEN_LOGIN = getattr(settings, 'LDAP_UPDATE_USER_WHEN_LOGIN', True)
+    ENABLE_SASL, SASL_MECHANISM, SASL_AUTHC_ID_ATTR, \
+    LDAP_PROVIDER, LDAP_SERVER_URL, LDAP_BASE_DN, LDAP_ADMIN_DN, LDAP_ADMIN_PASSWORD, LDAP_LOGIN_ATTR, \
+    ENABLE_MULTI_LDAP, MULTI_LDAP_1_SERVER_URL, MULTI_LDAP_1_BASE_DN, MULTI_LDAP_1_ADMIN_DN, \
+    MULTI_LDAP_1_ADMIN_PASSWORD, MULTI_LDAP_1_LOGIN_ATTR, \
+    MULTI_LDAP_1_PROVIDER, MULTI_LDAP_1_FILTER, MULTI_LDAP_1_CONTACT_EMAIL_ATTR, \
+    MULTI_LDAP_1_USER_ROLE_ATTR, MULTI_LDAP_1_ENABLE_SASL, MULTI_LDAP_1_SASL_MECHANISM, \
+    MULTI_LDAP_1_SASL_AUTHC_ID_ATTR, LDAP_UPDATE_USER_WHEN_LOGIN, \
+    LDAP_FOLLOW_REFERRALS, MULTI_LDAP_1_FOLLOW_REFERRALS
 
 logger = logging.getLogger(__name__)
 
@@ -91,18 +67,28 @@ UNUSABLE_PASSWORD = '!'  # This will never be a valid hash
 def default_ldap_role_mapping(role):
     return role
 
+def default_ldap_role_list_mapping(role_list):
+    return role_list[0] if role_list else ''
 
 ldap_role_mapping = default_ldap_role_mapping
+ldap_role_list_mapping = default_ldap_role_list_mapping
+USE_LDAP_ROLE_LIST_MAPPING = False
+
 if ENABLE_LDAP:
+    current_path = os.path.dirname(os.path.abspath(__file__))
+    conf_dir = os.path.join(current_path, '../../../../conf')
+    sys.path.append(conf_dir)
     try:
-        current_path = os.path.dirname(os.path.abspath(__file__))
-        conf_dir = os.path.join(current_path, '../../../../conf')
-        sys.path.append(conf_dir)
         from seahub_custom_functions import ldap_role_mapping
         ldap_role_mapping = ldap_role_mapping
     except:
         pass
-
+    try:
+        from seahub_custom_functions import ldap_role_list_mapping
+        ldap_role_list_mapping = ldap_role_list_mapping
+        USE_LDAP_ROLE_LIST_MAPPING = True
+    except:
+        pass
 
 class UserManager(object):
 
@@ -126,11 +112,11 @@ class UserManager(object):
 
         return self.get(email=virtual_id)
 
-    def update_role(self, email, role):
+    def update_role(self, email, role, is_manual_set=True):
         """
         If user has a role, update it; or create a role for user.
         """
-        ccnet_api.update_role_emailuser(email, role)
+        ccnet_api.update_role_emailuser(email, role, is_manual_set=is_manual_set)
         return self.get(email=email)
 
     def create_oauth_user(self, email=None, password=None, is_staff=False, is_active=False):
@@ -282,7 +268,6 @@ class UserManager(object):
         user.org = emailuser.org
         user.source = emailuser.source
         user.role = emailuser.role
-        user.reference_id = emailuser.reference_id
 
         if user.is_staff:
             try:
@@ -319,7 +304,6 @@ class UserManager(object):
         user.org = emailuser.org
         user.source = emailuser.source
         user.role = emailuser.role
-        user.reference_id = emailuser.reference_id
 
         if user.is_staff:
             try:
@@ -359,6 +343,9 @@ class UserPermissions(object):
     def can_add_repo(self):
         return self._get_perm_by_roles('can_add_repo')
 
+    def can_share_repo(self):
+        return self._get_perm_by_roles('can_share_repo')
+
     def can_add_group(self):
         return self._get_perm_by_roles('can_add_group')
 
@@ -428,11 +415,21 @@ class UserPermissions(object):
     def storage_ids(self):
         return self._get_perm_by_roles('storage_ids')
 
-    def can_publish_repo(self):
+    def can_create_wiki(self):
         if not settings.ENABLE_WIKI:
             return False
 
-        return self._get_perm_by_roles('can_publish_repo')
+        return self._get_perm_by_roles('can_create_wiki')
+
+    def can_publish_wiki(self):
+        if not settings.ENABLE_WIKI:
+            return False
+        return self._get_perm_by_roles('can_publish_wiki')
+    
+    def can_choose_office_suite(self):
+        if not settings.ENABLE_MULTIPLE_OFFICE_SUITE:
+            return False
+        return self._get_perm_by_roles('can_choose_office_suite')
 
 
 class AdminPermissions(object):
@@ -520,6 +517,8 @@ class User(object):
         self.permissions = UserPermissions(self)
         self.admin_permissions = AdminPermissions(self)
 
+        self.password_changed = False
+
     def __unicode__(self):
         return self.username
 
@@ -563,6 +562,11 @@ class User(object):
                                                               self.password,
                                                               int(self.is_staff),
                                                               int(self.is_active))
+
+            if self.password_changed:
+                emailuser = ccnet_threaded_rpc.get_emailuser(self.username)
+                self.enc_password = emailuser.password
+                self.password_changed = False
         else:
             result_code = ccnet_threaded_rpc.add_emailuser(self.username,
                                                            self.password,
@@ -653,6 +657,7 @@ class User(object):
         else:
             self.password = '%s' % raw_password
 
+        self.password_changed = True
         # clear web api and repo sync token
         # when user password change
         try:
@@ -682,7 +687,7 @@ class User(object):
         "Sends an e-mail to this User."
         send_mail(subject, message, from_email, [self.email])
 
-    def freeze_user(self, notify_admins=False):
+    def freeze_user(self, notify_admins=False, notify_org_admins=False):
         self.is_active = False
         self.save()
 
@@ -696,12 +701,43 @@ class User(object):
                 user_language = Profile.objects.get_user_language(u.email)
                 translation.activate(user_language)
 
-                send_html_email_with_dj_template(u.email,
+                send_html_email_with_dj_template(email2contact_email(u.email),
                                                  subject=_('Account %(account)s froze on %(site)s.') % {
-                                                     "account": self.email,
+                                                     "account": email2contact_email(self.email),
                                                      "site": get_site_name()},
                                                  dj_template='sysadmin/user_freeze_email.html',
-                                                 context={'user': self.email})
+                                                 context={'user': email2contact_email(self.email)})
+
+                # restore current language
+                translation.activate(cur_language)
+
+        if notify_org_admins:
+            org = None
+            if is_pro_version():
+                orgs = ccnet_api.get_orgs_by_user(self.username)
+                if orgs:
+                    org = orgs[0]
+
+            org_members = list()
+            if org:
+                org_members = ccnet_api.get_org_emailusers(org.url_prefix, -1, -1)
+            for u in org_members:
+                if not (ccnet_api.is_org_staff(org.org_id, u.email) == 1):
+                    continue
+
+                # save current language
+                cur_language = translation.get_language()
+
+                # get and active user language
+                user_language = Profile.objects.get_user_language(u.email)
+                translation.activate(user_language)
+
+                send_html_email_with_dj_template(email2contact_email(u.email),
+                                                 subject=_('Account %(account)s froze on %(site)s.') % {
+                                                     "account": email2contact_email(self.email),
+                                                     "site": get_site_name()},
+                                                 dj_template='sysadmin/user_freeze_email.html',
+                                                 context={'user': email2contact_email(self.email)})
 
                 # restore current language
                 translation.activate(cur_language)
@@ -826,8 +862,12 @@ def parse_ldap_res(ldap_search_result, enable_sasl, sasl_mechanism, sasl_authc_i
         contact_email = contact_email_list[0].decode()
 
     if user_role_list:
-        user_role = user_role_list[0].decode()
-        user_role = ldap_role_mapping(user_role)
+        if not USE_LDAP_ROLE_LIST_MAPPING:
+            role = user_role_list[0].decode()
+            user_role = ldap_role_mapping(role)
+        else:
+            role_list = [role.decode() for role in user_role_list]
+            user_role = ldap_role_list_mapping(role_list)
 
     if authc_id_list:
         authc_id = authc_id_list[0].decode()
@@ -845,11 +885,11 @@ class CustomLDAPBackend(object):
             user = None
         return user
 
-    def ldap_bind(self, server_url, dn, authc_id, password, enable_sasl, sasl_mechanism):
+    def ldap_bind(self, server_url, dn, authc_id, password, enable_sasl, sasl_mechanism, follow_referrals):
         bind_conn = ldap.initialize(server_url)
 
         try:
-            bind_conn.set_option(ldap.OPT_REFERRALS, 0)
+            bind_conn.set_option(ldap.OPT_REFERRALS, 1 if follow_referrals else 0)
         except Exception as e:
             raise Exception('Failed to set referrals option: %s' % e)
 
@@ -873,9 +913,9 @@ class CustomLDAPBackend(object):
 
     def search_user(self, server_url, admin_dn, admin_password, enable_sasl, sasl_mechanism,
                     sasl_authc_id_attr, base_dn, login_attr_conf, login_attr, password, serch_filter,
-                    contact_email_attr, role_attr):
+                    contact_email_attr, role_attr, follow_referrals):
         try:
-            admin_bind = self.ldap_bind(server_url, admin_dn, admin_dn, admin_password, enable_sasl, sasl_mechanism)
+            admin_bind = self.ldap_bind(server_url, admin_dn, admin_dn, admin_password, enable_sasl, sasl_mechanism, follow_referrals)
         except Exception as e:
             raise Exception(e)
 
@@ -890,7 +930,7 @@ class CustomLDAPBackend(object):
                 continue
             try:
                 result_data = admin_bind.search_s(base, ldap.SCOPE_SUBTREE, filterstr)
-                if result_data is not None:
+                if result_data:
                     break
             except Exception as e:
                 raise Exception('ldap user search failed: %s' % e)
@@ -910,7 +950,7 @@ class CustomLDAPBackend(object):
             raise Exception('parse ldap result failed: %s' % e)
 
         try:
-            user_bind = self.ldap_bind(server_url, dn, authc_id, password, enable_sasl, sasl_mechanism)
+            user_bind = self.ldap_bind(server_url, dn, authc_id, password, enable_sasl, sasl_mechanism, follow_referrals)
         except Exception as e:
             raise Exception(e)
 
@@ -932,7 +972,7 @@ class CustomLDAPBackend(object):
             nickname, contact_email, user_role = self.search_user(
                 LDAP_SERVER_URL, LDAP_ADMIN_DN, LDAP_ADMIN_PASSWORD, ENABLE_SASL, SASL_MECHANISM,
                 SASL_AUTHC_ID_ATTR, LDAP_BASE_DN, LDAP_LOGIN_ATTR, login_attr, password, LDAP_FILTER,
-                LDAP_CONTACT_EMAIL_ATTR, LDAP_USER_ROLE_ATTR)
+                LDAP_CONTACT_EMAIL_ATTR, LDAP_USER_ROLE_ATTR, LDAP_FOLLOW_REFERRALS)
             ldap_provider = LDAP_PROVIDER
         except Exception as e:
             if ENABLE_MULTI_LDAP:
@@ -947,7 +987,7 @@ class CustomLDAPBackend(object):
                         MULTI_LDAP_1_SERVER_URL, MULTI_LDAP_1_ADMIN_DN, MULTI_LDAP_1_ADMIN_PASSWORD,
                         MULTI_LDAP_1_ENABLE_SASL, MULTI_LDAP_1_SASL_MECHANISM, MULTI_LDAP_1_SASL_AUTHC_ID_ATTR,
                         MULTI_LDAP_1_BASE_DN, MULTI_LDAP_1_LOGIN_ATTR, login_attr, password, MULTI_LDAP_1_FILTER,
-                        MULTI_LDAP_1_CONTACT_EMAIL_ATTR, MULTI_LDAP_1_USER_ROLE_ATTR)
+                        MULTI_LDAP_1_CONTACT_EMAIL_ATTR, MULTI_LDAP_1_USER_ROLE_ATTR, MULTI_LDAP_1_FOLLOW_REFERRALS)
                     ldap_provider = MULTI_LDAP_1_PROVIDER
                 except Exception as e:
                     logger.error(e)
@@ -982,12 +1022,13 @@ class CustomLDAPBackend(object):
 
         username = user.username
         if LDAP_UPDATE_USER_WHEN_LOGIN:
-            profile_kwargs = {
-                'nickname': nickname,
-                'contact_email': contact_email,
-            }
             try:
-                Profile.objects.add_or_update(username, **profile_kwargs)
+                if nickname:
+                    Profile.objects.add_or_update(username, nickname=nickname)
+                if contact_email:
+                    p = Profile.objects.get_profile_by_user(username)
+                    if not (p and p.is_manually_set_contact_email):
+                        Profile.objects.add_or_update(username, contact_email=contact_email)
             except Exception as e:
                 logger.error(f'update ldap user failed {e}')
 
@@ -1216,18 +1257,16 @@ class RegistrationForm(forms.Form):
         if 'password1' in self.cleaned_data:
             pwd = self.cleaned_data['password1']
 
-            if bool(config.USER_STRONG_PASSWORD_REQUIRED) is True:
-                if bool(is_user_password_strong(pwd)) is True:
-                    return pwd
-                else:
-                    raise forms.ValidationError(
-                        _(("%(pwd_len)s characters or more, include "
-                           "%(num_types)s types or more of these: "
-                           "letters(case sensitive), numbers, and symbols")) %
-                        {'pwd_len': config.USER_PASSWORD_MIN_LENGTH,
-                         'num_types': config.USER_PASSWORD_STRENGTH_LEVEL})
-            else:
+            if is_password_strength_valid(pwd):
                 return pwd
+            else:
+                password_strength_requirements = get_password_strength_requirements()
+                raise forms.ValidationError(
+                    _(("%(pwd_len)s characters or more, include "
+                        "%(num_types)s types or more of these: "
+                        "letters(case sensitive), numbers, and symbols")) %
+                    {'pwd_len': password_strength_requirements.get('min_len'),
+                        'num_types': len(password_strength_requirements.get('char_types'))})
 
     def clean_password2(self):
         """
