@@ -18,18 +18,21 @@ from constance import config
 import seaserv
 
 from seahub.settings import SEAFILE_VERSION, SITE_DESCRIPTION, \
-    MAX_FILE_NAME, LOGO_PATH, BRANDING_CSS, LOGO_WIDTH, LOGO_HEIGHT,\
+    MAX_FILE_NAME, LOGO_PATH, BRANDING_CSS, LOGO_WIDTH, LOGO_HEIGHT, \
     SHOW_REPO_DOWNLOAD_BUTTON, SITE_ROOT, ENABLE_GUEST_INVITATION, \
     FAVICON_PATH, APPLE_TOUCH_ICON_PATH, THUMBNAIL_SIZE_FOR_ORIGINAL, \
     MEDIA_ROOT, SHOW_LOGOUT_ICON, CUSTOM_LOGO_PATH, CUSTOM_FAVICON_PATH, \
-    ENABLE_SEAFILE_DOCS, LOGIN_BG_IMAGE_PATH, \
+    LOGIN_BG_IMAGE_PATH, THUMBNAIL_DEFAULT_SIZE, \
     CUSTOM_LOGIN_BG_PATH, ENABLE_SHARE_LINK_REPORT_ABUSE, \
-    PRIVACY_POLICY_LINK, TERMS_OF_SERVICE_LINK, ENABLE_SEADOC, ENABLE_SEAFILE_AI, \
-    ENABLE_SEATABLE_INTEGRATION
+    PRIVACY_POLICY_LINK, TERMS_OF_SERVICE_LINK, ENABLE_SEADOC, THUMBNAIL_SIZE_FOR_GRID, \
+    FILE_SERVER_ROOT, ENABLE_WHITEBOARD, ENABLE_SEAFILE_AI
 
 from seahub.organizations.models import OrgAdminSettings
 from seahub.organizations.settings import ORG_ENABLE_ADMIN_CUSTOM_LOGO
-from seahub.onlyoffice.settings import ENABLE_ONLYOFFICE, ONLYOFFICE_CONVERTER_EXTENSIONS
+from seahub.onlyoffice.settings import ENABLE_ONLYOFFICE, \
+        ONLYOFFICE_CONVERTER_EXTENSIONS, ONLYOFFICE_EDIT_FILE_EXTENSION
+from seahub.wopi.settings import ENABLE_OFFICE_WEB_APP, \
+        OFFICE_WEB_APP_EDIT_FILE_EXTENSION
 from seahub.constants import DEFAULT_ADMIN
 from seahub.utils import get_site_name, get_service_url
 from seahub.avatar.templatetags.avatar_tags import api_avatar_url
@@ -48,6 +51,7 @@ except ImportError:
     ENABLE_FILE_SCAN = False
 from seahub.work_weixin.settings import ENABLE_WORK_WEIXIN
 from seahub.weixin.settings import ENABLE_WEIXIN
+from seahub.dingtalk.settings import ENABLE_DINGTALK
 
 try:
     from seahub.settings import SIDE_NAV_FOOTER_CUSTOM_HTML
@@ -74,7 +78,7 @@ def base(request):
     repo_id_patt = r".*/([a-f0-9]{8}-[a-f0-9]{4}-4[a-f0-9]{3}-[89ab][a-f0-9]{3}-[a-f0-9]{12})/.*"
     m = re.match(repo_id_patt, request.get_full_path())
     search_repo_id = m.group(1) if m is not None else None
-    file_server_root = config.FILE_SERVER_ROOT
+    file_server_root = FILE_SERVER_ROOT
     if not file_server_root.endswith('/'):
         file_server_root += '/'
 
@@ -112,7 +116,7 @@ def base(request):
         if os.path.exists(custom_login_bg_file):
             login_bg_path = CUSTOM_LOGIN_BG_PATH
 
-        avatar_url, is_default, date_uploaded = api_avatar_url(username, 72)
+        avatar_url, is_default, date_uploaded = api_avatar_url(username)
 
     result = {
         'seafile_version': SEAFILE_VERSION,
@@ -131,6 +135,8 @@ def base(request):
         'site_name': get_site_name(),
         'enable_signup': config.ENABLE_SIGNUP,
         'enable_weixin': ENABLE_WEIXIN,
+        'enable_work_weixin': ENABLE_WORK_WEIXIN,
+        'enable_dingtalk': ENABLE_DINGTALK,
         'max_file_name': MAX_FILE_NAME,
         'has_file_search': HAS_FILE_SEARCH,
         'show_repo_download_button': SHOW_REPO_DOWNLOAD_BUTTON,
@@ -149,20 +155,23 @@ def base(request):
         'FILE_SERVER_ROOT': file_server_root,
         'USE_GO_FILESERVER': seaserv.USE_GO_FILESERVER if hasattr(seaserv, 'USE_GO_FILESERVER') else False,
         'LOGIN_URL': dj_settings.LOGIN_URL,
-        'enableOnlyoffice': ENABLE_ONLYOFFICE,
-        'onlyofficeConverterExtensions': ONLYOFFICE_CONVERTER_EXTENSIONS,
+        'enable_onlyoffice': ENABLE_ONLYOFFICE,
+        'onlyoffice_edit_file_extension': list(ONLYOFFICE_EDIT_FILE_EXTENSION),
+        'enable_office_web_app': ENABLE_OFFICE_WEB_APP,
+        'office_web_app_edit_file_extension': list(OFFICE_WEB_APP_EDIT_FILE_EXTENSION),
+        'onlyoffice_converter_extensions': ONLYOFFICE_CONVERTER_EXTENSIONS,
         'thumbnail_size_for_original': THUMBNAIL_SIZE_FOR_ORIGINAL,
+        'thumbnail_size_for_grid': THUMBNAIL_SIZE_FOR_GRID,
+        'thumbnail_default_size': THUMBNAIL_DEFAULT_SIZE,
         'enable_guest_invitation': ENABLE_GUEST_INVITATION,
         'enable_terms_and_conditions': config.ENABLE_TERMS_AND_CONDITIONS,
         'show_logout_icon': SHOW_LOGOUT_ICON,
         'is_pro': True if is_pro_version() else False,
         'is_db_sqlite3': IS_DB_SQLITE3,
-        'is_docs': ENABLE_SEAFILE_DOCS,
         'enable_upload_folder': dj_settings.ENABLE_UPLOAD_FOLDER,
         'enable_resumable_fileupload': dj_settings.ENABLE_RESUMABLE_FILEUPLOAD,
         'service_url': get_service_url().rstrip('/'),
         'enable_file_scan': ENABLE_FILE_SCAN,
-        'enable_work_weixin': ENABLE_WORK_WEIXIN,
         'avatar_url': avatar_url if avatar_url else '',
         'privacy_policy_link': PRIVACY_POLICY_LINK,
         'terms_of_service_link': TERMS_OF_SERVICE_LINK,
@@ -171,7 +180,7 @@ def base(request):
         'enable_repo_auto_del': ENABLE_REPO_AUTO_DEL,
         'enable_seadoc': ENABLE_SEADOC,
         'enable_seafile_ai': ENABLE_SEAFILE_AI,
-        'enable_seatable_integration': ENABLE_SEATABLE_INTEGRATION
+        'enable_whiteboard': ENABLE_WHITEBOARD,
     }
 
     if request.user.is_staff:
