@@ -51,9 +51,11 @@ def tsstr_day(value):
 FILEEXT_ICON_MAP = {
 
     # text file
-    'md': 'txt.png',
     'txt': 'txt.png',
 
+    # markdown file
+    'md': 'md.png',
+
     # pdf file
     'pdf': 'pdf.png',
 
@@ -62,6 +64,7 @@ FILEEXT_ICON_MAP = {
     'docx': 'word.png',
     'odt': 'word.png',
     'fodt': 'word.png',
+    'tldr': 'word.png',
 
     'ppt': 'ppt.png',
     'pptx': 'ppt.png',
@@ -86,7 +89,9 @@ FILEEXT_ICON_MAP = {
     'mp3': 'music.png',
     'oga': 'music.png',
     'ogg': 'music.png',
+    'wav': 'music.png',
     'flac': 'music.png',
+    'opus': 'music.png',
     'aac': 'music.png',
     'ac3': 'music.png',
     'wma': 'music.png',
@@ -99,12 +104,26 @@ FILEEXT_ICON_MAP = {
     'gif': 'pic.png',
     'bmp': 'pic.png',
     'ico': 'pic.png',
+    'psd': 'psd.png',
+    'draw': 'draw.png',
+
+    # zip file
+    'zip': 'zip.png',
+    'rar': 'zip.png',
+    'tar': 'zip.png',
+
+    # style file
+    'css': 'css.png',
+
+    # sdoc file
+    'sdoc': 'sdoc.png',
+    'sdoc_notification': 'sdoc_notification.ico',
 
     # default
     'default': 'file.png',
 }
 @register.filter(name='file_icon_filter')
-def file_icon_filter(value, size=None):
+def file_icon_filter(value):
     """Get file icon according to the file postfix"""
     if value.rfind('.') > 0:
         file_ext = value.split('.')[-1].lower()
@@ -112,15 +131,9 @@ def file_icon_filter(value, size=None):
         file_ext = None
 
     if file_ext and file_ext in FILEEXT_ICON_MAP:
-        if size == 192:
-            return '192/' + FILEEXT_ICON_MAP.get(file_ext)
-        else:
-            return '24/' + FILEEXT_ICON_MAP.get(file_ext)
+        return '256/' + FILEEXT_ICON_MAP.get(file_ext)
     else:
-        if size == 192:
-            return '192/' + FILEEXT_ICON_MAP.get('default')
-        else:
-            return '24/' + FILEEXT_ICON_MAP.get('default')
+        return '256/' + FILEEXT_ICON_MAP.get('default')
 
 # This way of translation looks silly, but works well.
 COMMIT_MSG_TRANSLATION_MAP = {
@@ -130,10 +143,10 @@ COMMIT_MSG_TRANSLATION_MAP = {
     'Modified': _('Modified'),
     'Renamed': _('Renamed'),
     'Moved': _('Moved'),
-    'Added directory': _('Added directory'),
-    'Removed directory': _('Removed directory'),
-    'Renamed directory': _('Renamed directory'),
-    'Moved directory': _('Moved directory'),
+    'Added directory': _('Added folder'),
+    'Removed directory': _('Removed folder'),
+    'Renamed directory': _('Renamed folder'),
+    'Moved directory': _('Moved folder'),
     'Added or modified': _('Added or modified'),
 }
 @register.filter(name='translate_commit_desc')
@@ -156,7 +169,7 @@ def translate_commit_desc(value):
                 {'file':matchobj.group(1), 'time':matchobj.group(2)}
         return re.sub('Reverted file "(.*)" to status at (.*)', repl, value)
     elif value.startswith('Recovered deleted directory'):
-        return value.replace('Recovered deleted directory', _('Recovered deleted directory'))
+        return value.replace('Recovered deleted directory', _('Recovered deleted folder'))
     elif value.startswith('Changed library'):
         return value.replace('Changed library name or description', _('Changed library name or description'))
     elif value.startswith('Merged') or value.startswith('Auto merge'):
@@ -227,7 +240,7 @@ def translate_commit_desc_escape(value):
                 {'file':matchobj.group(1), 'time':matchobj.group(2)}
         return_value = escape(re.sub('Reverted file "(.*)" to status at (.*)', repl, value))
     elif value.startswith('Recovered deleted directory'):
-        return_value = escape(value.replace('Recovered deleted directory', _('Recovered deleted directory')))
+        return_value = escape(value.replace('Recovered deleted directory', _('Recovered deleted folder')))
     elif value.startswith('Changed library'):
         return_value = escape(value.replace('Changed library name or description', _('Changed library name or description')))
     elif value.startswith('Merged') or value.startswith('Auto merge'):
