@@ -1,11 +1,12 @@
 import seahub.settings as settings
+from seahub.utils import is_pro_version
 
 # constants
 DINGTALK_PROVIDER = 'dingtalk'
 
-ENABLE_DINGTALK = getattr(settings, 'ENABLE_DINGTALK', False)
+ENABLE_DINGTALK = getattr(settings, 'ENABLE_DINGTALK', False) and is_pro_version()
 DINGTALK_AGENT_ID = getattr(settings, 'DINGTALK_AGENT_ID', '')
-
+USER_ACTIVATE_AFTER_DINGTALK_IMPORT = getattr(settings, 'USER_ACTIVATE_AFTER_DINGTALK_IMPORT', True)
 # for 10.0 or later
 
 # base setting
