@@ -26,6 +26,7 @@ from seahub.dingtalk.utils import dingtalk_get_detailed_user_info, \
         dingtalk_get_userid_by_unionid_new, \
         dingtalk_get_detailed_user_info_new
 
+from seahub.settings import SITE_ROOT
 from seahub.dingtalk.settings import ENABLE_DINGTALK
 
 # for 10.0 or later
@@ -143,8 +144,12 @@ def dingtalk_callback(request):
         if not profile:
             profile = Profile(user=email)
         profile.nickname = name.strip()
-        profile.contact_email = contact_email
-        profile.save()
+        if contact_email:
+            profile.contact_email = contact_email
+        try:
+            profile.save()
+        except Exception as e:
+            logger.error(e)
 
     # generate auth token for Seafile client
     api_token = get_api_token(request)
@@ -244,7 +249,8 @@ def dingtalk_connect_callback(request):
         profile.contact_email = contact_email
         profile.save()
 
-    return HttpResponseRedirect(request.session['dingtalk_connect_redirect'])
+    return HttpResponseRedirect(request.session.get('dingtalk_connect_redirect',
+                                                    SITE_ROOT))
 
 
 @login_required
@@ -351,6 +357,8 @@ def dingtalk_callback_new(request):
 
     try:
         user = auth.authenticate(remote_user=email)
+        if is_new_user:
+            SocialAuthUser.objects.add(user.username, 'dingtalk', union_id)
         email = user.username
     except User.DoesNotExist:
         user = None
@@ -361,10 +369,6 @@ def dingtalk_callback_new(request):
     if not user or not user.is_active:
         return render_error(request, _('User %s not found or inactive.') % email)
 
-    # bind
-    if is_new_user:
-        SocialAuthUser.objects.add(user.username, 'dingtalk', union_id)
-
     # User is valid.  Set request.user and persist user in the session
     # by logging the user in.
     request.user = user
