@@ -54,6 +54,16 @@ def info(request):
         'inst': inst,
     })
 
+@inst_admin_required
+def useradmin_react_fake_view(request, **kwargs):
+    """List users in the institution.
+    """
+    # Make sure page request is an int. If not, deliver first page.
+    inst = request.user.institution
+
+    return render(request, 'institutions/admin.html', {
+        'institution': inst.name,
+    })
 
 @inst_admin_required
 def useradmin(request):
@@ -230,7 +240,7 @@ def user_set_quota(request, email):
     available_quota = get_institution_available_quota(request.user.institution)
     if available_quota < quota:
         result = {}
-        result['error'] = _('Failed to set quota: maximum quota is %d MB' % (available_quota / 10 ** 6))
+        result['error'] = 'Failed to set quota: maximum quota is %d MB' % (available_quota / 10 ** 6)
         return HttpResponse(json.dumps(result), status=400, content_type=content_type)
 
     seafile_api.set_user_quota(email, quota)
