@@ -19,9 +19,8 @@ from seaserv import seafile_api, ccnet_api
 from seahub.base.fields import LowerCaseCharField
 from seahub.base.templatetags.seahub_tags import email2nickname
 from seahub.invitations.models import Invitation
-from seahub.utils import normalize_cache_key
+from seahub.utils import normalize_cache_key, get_site_scheme_and_netloc
 from seahub.constants import HASH_URLS
-from seahub.drafts.models import DraftReviewer
 from seahub.file_participants.utils import list_file_participants
 
 # Get an instance of a logger
@@ -66,7 +65,10 @@ class NotificationForm(ModelForm):
 MSG_TYPE_GROUP_JOIN_REQUEST = 'group_join_request'
 MSG_TYPE_ADD_USER_TO_GROUP = 'add_user_to_group'
 MSG_TYPE_FILE_UPLOADED = 'file_uploaded'
+MSG_TYPE_FOLDER_UPLOADED = 'folder_uploaded'
 MSG_TYPE_REPO_SHARE = 'repo_share'
+MSG_TYPE_REPO_SHARE_PERM_CHANGE = 'repo_share_perm_change'
+MSG_TYPE_REPO_SHARE_PERM_DELETE = 'repo_share_perm_delete'
 MSG_TYPE_REPO_SHARE_TO_GROUP = 'repo_share_to_group'
 MSG_TYPE_USER_MESSAGE = 'user_message'
 MSG_TYPE_FILE_COMMENT = 'file_comment'
@@ -76,6 +78,8 @@ MSG_TYPE_GUEST_INVITATION_ACCEPTED = 'guest_invitation_accepted'
 MSG_TYPE_REPO_TRANSFER = 'repo_transfer'
 MSG_TYPE_REPO_MINOTOR = 'repo_monitor'
 MSG_TYPE_DELETED_FILES = 'deleted_files'
+MSG_TYPE_SAML_SSO_FAILED = 'saml_sso_failed'
+MSG_TYPE_FACE_CLUSTER = 'face_cluster'
 
 USER_NOTIFICATION_COUNT_CACHE_PREFIX = 'USER_NOTIFICATION_COUNT_'
 
@@ -85,10 +89,24 @@ def file_uploaded_msg_to_json(file_name, repo_id, uploaded_to):
     return json.dumps({'file_name': file_name, 'repo_id': repo_id,
                        'uploaded_to': uploaded_to})
 
+def folder_uploaded_msg_to_json(folder_name, repo_id, uploaded_to):
+    """Encode folder uploaded message to json string.
+    """
+    return json.dumps({'folder_name': folder_name, 'repo_id': repo_id,
+                       'uploaded_to': uploaded_to})
+
 def repo_share_msg_to_json(share_from, repo_id, path, org_id):
     return json.dumps({'share_from': share_from, 'repo_id': repo_id,
                        'path': path, 'org_id': org_id})
 
+def repo_share_perm_change_msg_to_json(share_from, repo_id, path, org_id, perm):
+    return json.dumps({'share_from': share_from, 'repo_id': repo_id,
+                       'path': path, 'org_id': org_id, 'permission': perm})
+
+def repo_share_perm_delete_msg_to_json(share_from, repo_id, path, org_id):
+    return json.dumps({'share_from': share_from, 'repo_id': repo_id,
+                       'path': path, 'org_id': org_id})
+
 def repo_share_to_group_msg_to_json(share_from, repo_id, group_id, path, org_id):
     return json.dumps({'share_from': share_from, 'repo_id': repo_id,
                        'group_id': group_id, 'path': path, 'org_id': org_id})
@@ -133,6 +151,11 @@ def repo_transfer_msg_to_json(org_id, repo_owner, repo_id, repo_name):
     return json.dumps({'org_id': org_id, 'repo_owner': repo_owner,
         'repo_id': repo_id, 'repo_name': repo_name})
 
+
+def saml_sso_error_msg_to_json(error_msg):
+    return json.dumps({'error_msg': error_msg})
+
+
 def get_cache_key_of_unseen_notifications(username):
     return normalize_cache_key(username,
             USER_NOTIFICATION_COUNT_CACHE_PREFIX)
@@ -249,6 +272,18 @@ class UserNotificationManager(models.Manager):
         return self._add_user_notification(to_user,
                                            MSG_TYPE_FILE_UPLOADED, detail)
 
+    def add_folder_uploaded_msg(self, to_user, detail):
+        """
+
+        Arguments:
+        - `self`:
+        - `to_user`:
+        - `folder_name`:
+        - `upload_to`:
+        """
+        return self._add_user_notification(to_user,
+                                           MSG_TYPE_FOLDER_UPLOADED, detail)
+
     def add_repo_share_msg(self, to_user, detail):
         """Notify ``to_user`` that others shared a repo to him/her.
 
@@ -260,6 +295,13 @@ class UserNotificationManager(models.Manager):
         return self._add_user_notification(to_user,
                                            MSG_TYPE_REPO_SHARE, detail)
 
+    def add_repo_share_perm_change_msg(self, to_user, detail):
+        return self._add_user_notification(to_user, MSG_TYPE_REPO_SHARE_PERM_CHANGE, detail)
+
+    def add_repo_share_perm_delete_msg(self, to_user, detail):
+        return self._add_user_notification(to_user, MSG_TYPE_REPO_SHARE_PERM_DELETE, detail)
+
+
     def add_repo_share_to_group_msg(self, to_user, detail):
         """Notify ``to_user`` that others shared a repo to group.
 
@@ -288,12 +330,12 @@ class UserNotificationManager(models.Manager):
         return self._add_user_notification(to_user, MSG_TYPE_FILE_COMMENT, detail)
 
     def add_draft_comment_msg(self, to_user, detail):
-        """Notify ``to_user`` that review creator 
+        """Notify ``to_user`` that review creator
         """
         return self._add_user_notification(to_user, MSG_TYPE_DRAFT_COMMENT, detail)
 
     def add_request_reviewer_msg(self, to_user, detail):
-        """Notify ``to_user`` that reviewer 
+        """Notify ``to_user`` that reviewer
         """
         return self._add_user_notification(to_user, MSG_TYPE_DRAFT_REVIEWER, detail)
 
@@ -309,6 +351,11 @@ class UserNotificationManager(models.Manager):
         return self._add_user_notification(
             to_user, MSG_TYPE_REPO_TRANSFER, detail)
 
+    def add_saml_sso_error_msg(self, to_user, detail):
+        """Notify ``to_user`` that saml sso occurred an error
+        """
+        return self._add_user_notification(to_user, MSG_TYPE_SAML_SSO_FAILED, detail)
+
 
 class UserNotification(models.Model):
     to_user = LowerCaseCharField(db_index=True, max_length=255)
@@ -350,6 +397,14 @@ class UserNotification(models.Model):
         """
         return self.msg_type == MSG_TYPE_FILE_UPLOADED
 
+    def is_folder_uploaded_msg(self):
+        """
+
+        Arguments:
+        - `self`:
+        """
+        return self.msg_type == MSG_TYPE_FOLDER_UPLOADED
+
     def is_repo_share_msg(self):
         """
 
@@ -358,6 +413,12 @@ class UserNotification(models.Model):
         """
         return self.msg_type == MSG_TYPE_REPO_SHARE
 
+    def is_repo_share_perm_change_msg(self):
+        return self.msg_type == MSG_TYPE_REPO_SHARE_PERM_CHANGE
+
+    def is_repo_share_perm_delete_msg(self):
+        return self.msg_type == MSG_TYPE_REPO_SHARE_PERM_DELETE
+
     def is_repo_share_to_group_msg(self):
         """
 
@@ -411,6 +472,12 @@ class UserNotification(models.Model):
     def is_deleted_files_msg(self):
         return self.msg_type == MSG_TYPE_DELETED_FILES
 
+    def is_saml_sso_error_msg(self):
+        return self.msg_type == MSG_TYPE_SAML_SSO_FAILED
+
+    def is_face_cluster_msg(self):
+        return self.msg_type == MSG_TYPE_FACE_CLUSTER
+
     def user_message_detail_to_dict(self):
         """Parse user message detail, returns dict contains ``message`` and
         ``msg_from``.
@@ -436,6 +503,8 @@ class UserNotification(models.Model):
     def format_msg(self):
         if self.is_file_uploaded_msg():
             return self.format_file_uploaded_msg()
+        if self.is_folder_uploaded_msg():
+            return self.format_folder_uploaded_msg()
         elif self.is_repo_share_msg():
             return self.format_repo_share_msg()
         elif self.is_repo_share_to_group_msg():
@@ -454,6 +523,8 @@ class UserNotification(models.Model):
             return self.format_add_user_to_group()
         elif self.is_repo_transfer_msg():
             return self.format_repo_transfer_msg()
+        elif self.is_repo_monitor_msg():
+            return self.format_repo_monitor_msg()
         else:
             return ''
 
@@ -492,12 +563,54 @@ class UserNotification(models.Model):
                 'name': escape(name),
                 }
         else:
-            msg = _("A file named <strong>%(file_name)s</strong> is uploaded to <strong>Deleted Library</strong>") % {
+            msg = _("A file named <strong>%(file_name)s</strong> is uploaded") % {
                 'file_name': escape(filename),
                 }
 
         return msg
 
+    def format_folder_uploaded_msg(self):
+        """
+
+        Arguments:
+        - `self`:
+        """
+        try:
+            d = json.loads(self.detail)
+        except Exception as e:
+            logger.error(e)
+            return _("Internal Server Error")
+
+        foldername = d['folder_name']
+        repo_id = d['repo_id']
+        repo = seafile_api.get_repo(repo_id)
+        if repo:
+            if d['uploaded_to'] == '/':
+                # current upload path is '/'
+                folder_path = '/' + foldername
+                link = reverse('lib_view', args=[repo_id, repo.name, ''])
+                name = repo.name
+            else:
+                uploaded_to = d['uploaded_to'].rstrip('/')
+                folder_path = uploaded_to + '/' + foldername
+                link = reverse('lib_view', args=[repo_id, repo.name, uploaded_to.lstrip('/')])
+                name = os.path.basename(uploaded_to)
+
+            folder_link = reverse('lib_view', args=[repo_id, repo.name, folder_path])
+
+            msg = _("A folder named <a href='%(folder_link)s'>%(folder_name)s</a> is uploaded to <a href='%(link)s'>%(name)s</a>") % {
+                'folder_link': folder_link,
+                'folder_name': escape(foldername),
+                'link': link,
+                'name': escape(name),
+                }
+        else:
+            msg = _("A folder named <strong>%(folder_name)s</strong> is uploaded") % {
+                'folder_name': escape(foldername),
+                }
+
+        return msg
+
     def format_repo_share_msg(self):
         """
 
@@ -769,17 +882,118 @@ class UserNotification(models.Model):
         }
         return msg
 
+    def format_repo_monitor_msg(self):
+        """
+
+        Arguments:
+        - `self`:
+        """
+        # {'commit_id': '5a52250eec53f32e771e7e032e5a40fd33143610',
+        #  'repo_id': 'b37d325a-5e72-416b-aa36-10643cee2f42',
+        #  'repo_name': 'lib of lian@seafile.com',
+        #  'op_user': 'lian@lian.com',
+        #  'op_type': 'create',
+        #  'obj_type': 'file',
+        #  'obj_path_list': ['/sdf.md'],
+        #  'old_obj_path_list': []}
+
+        try:
+            d = json.loads(self.detail)
+        except Exception as e:
+            logger.error(e)
+            return ""
+
+        repo_id = d['repo_id']
+        repo_name = escape(d['repo_name'])
+        name = escape(email2nickname(d['op_user']))
+
+        op_type = d['op_type']
+
+        obj_type = _('file') if d['obj_type'] == 'file' else _('folder')
+        obj_path_list = d['obj_path_list']
+        obj_path = obj_path_list[0]
+        obj_name = escape(os.path.basename(obj_path))
+
+        obj_path_count = len(obj_path_list)
+        obj_path_count_minus_one = len(obj_path_list) - 1
+
+        old_obj_path_list = d.get('old_obj_path_list', [])
+        if old_obj_path_list:
+            old_obj_name = os.path.basename(d['old_obj_path_list'][0])
+        else:
+            old_obj_name = ''
+
+        def get_repo_url(repo_id, repo_name):
+            p = reverse('lib_view', args=[repo_id, repo_name, ''])
+            return get_site_scheme_and_netloc() + p
+
+        def get_file_url(repo_id, file_path):
+            p = reverse('view_lib_file', args=[repo_id, file_path])
+            return get_site_scheme_and_netloc() + p
+
+        def get_dir_url(repo_id, repo_name, dir_path):
+            p = reverse('lib_view', args=[repo_id, repo_name, dir_path.strip('/')])
+            return get_site_scheme_and_netloc() + p
+
+        repo_url = get_repo_url(repo_id, repo_name)
+        repo_link = f'<a href="{repo_url}">{repo_name}</a>'
+
+        if obj_type == 'file':
+            file_url = get_file_url(repo_id, obj_path)
+            obj_link = f'<a href="{file_url}">{obj_name}</a>'
+        else:
+            folder_url = get_dir_url(repo_id, repo_name, obj_path)
+            obj_link = f'<a href="{folder_url}">{obj_name}</a>'
+
+        if op_type == 'create':
+
+            if obj_path_count == 1:
+                message = _(f'{name} created {obj_type} {obj_link} in library {repo_link}.')
+            else:
+                message = _(f'{name} created {obj_type} {obj_link} and {obj_path_count_minus_one} other {obj_type}(s) in library {repo_link}.')
+
+        elif op_type == 'delete':
+
+            if obj_path_count == 1:
+                message = _(f'{name} deleted {obj_type} {obj_name} in library {repo_link}.')
+            else:
+                message = _(f'{name} deleted {obj_type} {obj_name} and {obj_path_count_minus_one} other {obj_type}(s) in library {repo_link}.')
+
+        elif op_type == 'recover':
+
+            message = _(f'{name} restored {obj_type} {obj_link} in library {repo_link}.')
+
+        elif op_type == 'rename':
+
+            message = _(f'{name} renamed {obj_type} {old_obj_name} to {obj_link} in library {repo_link}.')
+
+        elif op_type == 'move':
+
+            if obj_path_count == 1:
+                message = _(f'{name} moved {obj_type} {obj_link} in library {repo_link}.')
+            else:
+                message = _(f'{name} moved {obj_type} {obj_link} and {obj_path_count_minus_one} other {obj_type}(s) in library {repo_link}.')
+
+        elif op_type == 'edit':
+
+            message = _(f'{name} updated {obj_type} {obj_link} in library {repo_link}.')
+
+        else:
+            message = _(f'{name} {op_type} {obj_type} {obj_link} in library {repo_link}.')
+
+        return message
+
 
 ########## handle signals
 from django.dispatch import receiver
 
-from seahub.signals import upload_file_successful, comment_file_successful, repo_transfer
+from seahub.signals import upload_file_successful, upload_folder_successful, repo_transfer
 from seahub.group.signals import group_join_request, add_user_to_group
 from seahub.share.signals import share_repo_to_user_successful, \
-    share_repo_to_group_successful
+    share_repo_to_group_successful, change_repo_perm_successful, delete_repo_perm_successful
 from seahub.invitations.signals import accept_guest_invitation_successful
-from seahub.drafts.signals import comment_draft_successful, \
-        request_reviewer_successful
+from seahub.adfs_auth.signals import saml_sso_failed
+
 
 @receiver(upload_file_successful)
 def add_upload_file_msg_cb(sender, **kwargs):
@@ -797,6 +1011,23 @@ def add_upload_file_msg_cb(sender, **kwargs):
     detail = file_uploaded_msg_to_json(filename, repo_id, folder_path)
     UserNotification.objects.add_file_uploaded_msg(owner, detail)
 
+
+@receiver(upload_folder_successful)
+def add_upload_folder_msg_cb(sender, **kwargs):
+    """Notify repo owner when others upload folder to his/her folder from shared link.
+    """
+    repo_id = kwargs.get('repo_id', None)
+    folder_path = kwargs.get('folder_path', None)
+    owner = kwargs.get('owner', None)
+
+    assert repo_id and folder_path and owner is not None, 'Arguments error'
+
+    folder_name = os.path.basename(folder_path.rstrip('/'))
+    parent_dir = os.path.dirname(folder_path.rstrip('/'))
+    detail = folder_uploaded_msg_to_json(folder_name, repo_id, parent_dir)
+    UserNotification.objects.add_folder_uploaded_msg(owner, detail)
+
+
 @receiver(share_repo_to_user_successful)
 def add_share_repo_msg_cb(sender, **kwargs):
     """Notify user when others share repos to him/her.
@@ -812,6 +1043,34 @@ def add_share_repo_msg_cb(sender, **kwargs):
     detail = repo_share_msg_to_json(from_user, repo.id, path, org_id)
     UserNotification.objects.add_repo_share_msg(to_user, detail)
 
+@receiver(change_repo_perm_successful)
+def add_modify_share_repo_msg_cb(sender, **kwargs):
+    from_user = kwargs.get('from_user', None)
+    to_user = kwargs.get('to_user', None)
+    repo = kwargs.get('repo', None)
+    path = kwargs.get('path', None)
+    org_id = kwargs.get('org_id', None)
+    permission = kwargs.get('permission', None)
+
+    assert from_user and to_user and repo and path and permission is not None, 'Arguments error'
+
+    detail = repo_share_perm_change_msg_to_json(from_user, repo.id, path, org_id, permission)
+    UserNotification.objects.add_repo_share_perm_change_msg(to_user, detail)
+
+@receiver(delete_repo_perm_successful)
+def add_delete_share_repo_msg_cb(sender, **kwargs):
+    from_user = kwargs.get('from_user', None)
+    to_user = kwargs.get('to_user', None)
+    repo = kwargs.get('repo', None)
+    path = kwargs.get('path', None)
+    org_id = kwargs.get('org_id', None)
+
+    assert from_user and to_user and repo and path is not None, 'Arguments error'
+
+    detail = repo_share_perm_delete_msg_to_json(from_user, repo.id, path, org_id)
+    UserNotification.objects.add_repo_share_perm_delete_msg(to_user, detail)
+
+
 @receiver(share_repo_to_group_successful)
 def add_share_repo_to_group_msg_cb(sender, **kwargs):
     """Notify group member when others share repos to group.
@@ -857,47 +1116,6 @@ def add_user_to_group_cb(sender, **kwargs):
     UserNotification.objects.set_add_user_to_group_notice(to_user=added_user,
                                                           detail=detail)
 
-@receiver(comment_file_successful)
-def comment_file_successful_cb(sender, **kwargs):
-    """ send notification to file participants
-    """
-    repo = kwargs['repo']
-    repo_owner = kwargs['repo_owner']
-    file_path = kwargs['file_path']
-    comment = kwargs['comment']
-    author = kwargs['author']
-
-    notify_users = list_file_participants(repo.id, file_path)
-    notify_users = [x for x in notify_users if x != author]
-    for u in notify_users:
-        detail = file_comment_msg_to_json(repo.id, file_path, author, comment)
-        UserNotification.objects.add_file_comment_msg(u, detail)
-
-@receiver(comment_draft_successful)
-def comment_draft_successful_cb(sender, **kwargs):
-    draft = kwargs['draft']
-    comment = kwargs['comment']
-    author = kwargs['author']
-
-    detail = draft_comment_msg_to_json(draft.id, author, comment)
-
-    if draft.username != author:
-        UserNotification.objects.add_draft_comment_msg(draft.username, detail)
-
-    reviewers = DraftReviewer.objects.filter(draft=draft)
-    for r in reviewers:
-        if r.reviewer != author:
-            UserNotification.objects.add_draft_comment_msg(r.reviewer, detail)
-
-@receiver(request_reviewer_successful)
-def requeset_reviewer_successful_cb(sender, **kwargs):
-    from_user = kwargs['from_user']
-    draft_id = kwargs['draft_id']
-    to_user = kwargs['to_user']
-
-    detail = request_reviewer_msg_to_json(draft_id, from_user, to_user)
-
-    UserNotification.objects.add_request_reviewer_msg(to_user, detail)
 
 @receiver(accept_guest_invitation_successful)
 def accept_guest_invitation_successful_cb(sender, **kwargs):
@@ -918,3 +1136,12 @@ def repo_transfer_cb(sender, **kwargs):
 
     detail = repo_transfer_msg_to_json(org_id, repo_owner, repo_id, repo_name)
     UserNotification.objects.add_repo_transfer_msg(to_user, detail)
+
+
+@receiver(saml_sso_failed)
+def saml_sso_failed_cb(sender, **kwargs):
+    to_user = kwargs['to_user']
+    error_msg = kwargs['error_msg']
+
+    detail = saml_sso_error_msg_to_json(error_msg)
+    UserNotification.objects.add_saml_sso_error_msg(to_user, detail)
