@@ -7,10 +7,13 @@ from django.utils.html import escape
 from django.utils.translation import gettext as _
 
 from seaserv import ccnet_api, seafile_api
+
+from seahub.constants import CUSTOM_PERMISSION_PREFIX
 from seahub.notifications.models import Notification
 from seahub.notifications.settings import NOTIFICATION_CACHE_TIMEOUT
 from seahub.avatar.templatetags.avatar_tags import api_avatar_url
 from seahub.base.templatetags.seahub_tags import email2nickname, email2contact_email
+from seahub.share.models import CustomSharePermissions
 from seahub.utils import get_service_url
 
 logger = logging.getLogger(__name__)
@@ -49,7 +52,87 @@ def update_notice_detail(request, notices):
                 else:
                     d.pop('org_id', None)
                     share_from_user_email = d.pop('share_from')
-                    url, is_default, date_uploaded = api_avatar_url(share_from_user_email, 32)
+                    url, is_default, date_uploaded = api_avatar_url(share_from_user_email)
+                    d['repo_name'] = repo.name
+                    d['repo_id'] = repo.id
+                    d['share_from_user_name'] = email2nickname(share_from_user_email)
+                    d['share_from_user_email'] = share_from_user_email
+                    d['share_from_user_contact_email'] = email2contact_email(share_from_user_email)
+                    d['share_from_user_avatar_url'] = url
+                    notice.detail = d
+
+            except Exception as e:
+                logger.error(e)
+
+        elif notice.is_repo_share_perm_change_msg():
+            try:
+                d = json.loads(notice.detail)
+                repo_id = d['repo_id']
+                path = d.get('path', '/')
+                org_id = d.get('org_id', None)
+                permission = d.get('permission', None)
+                if CUSTOM_PERMISSION_PREFIX in permission:
+                    custom_permission_id = permission.split('-')[1]
+                    try:
+                        csp = CustomSharePermissions.objects.get(id=int(custom_permission_id))
+                        permission = csp.name
+                    except Exception as e:
+                        logger.error(e)
+                        permission = ''
+                if path == '/':
+                    repo = seafile_api.get_repo(repo_id)
+                else:
+                    if org_id:
+                        owner = seafile_api.get_org_repo_owner(repo_id)
+                        repo = seafile_api.get_org_virtual_repo(
+                            org_id, repo_id, path, owner)
+                    else:
+                        owner = seafile_api.get_repo_owner(repo_id)
+                        repo = seafile_api.get_virtual_repo(repo_id, path, owner)
+
+                if repo is None:
+                    notice.detail = None
+                else:
+                    d.pop('org_id', None)
+                    share_from_user_email = d.pop('share_from')
+                    url, is_default, date_uploaded = api_avatar_url(share_from_user_email)
+
+                    d['repo_name'] = repo.name
+                    d['repo_id'] = repo.id
+                    d['share_from_user_name'] = email2nickname(share_from_user_email)
+                    d['share_from_user_email'] = share_from_user_email
+                    d['share_from_user_contact_email'] = email2contact_email(share_from_user_email)
+                    d['share_from_user_avatar_url'] = url
+                    d['permission'] = permission
+                    notice.detail = d
+
+            except Exception as e:
+                logger.error(e)
+
+        elif notice.is_repo_share_perm_delete_msg():
+            try:
+                d = json.loads(notice.detail)
+                repo_id = d['repo_id']
+                path = d.get('path', '/')
+                org_id = d.get('org_id', None)
+                if path == '/':
+                    repo = seafile_api.get_repo(repo_id)
+                else:
+                    if org_id:
+                        owner = seafile_api.get_org_repo_owner(repo_id)
+                        repo = seafile_api.get_org_virtual_repo(
+                            org_id, repo_id, path, owner)
+                    else:
+                        owner = seafile_api.get_repo_owner(repo_id)
+                        repo = seafile_api.get_virtual_repo(repo_id, path, owner)
+
+                if repo is None:
+                    notice.detail = None
+                else:
+                    d.pop('org_id', None)
+                    share_from_user_email = d.pop('share_from')
+                    url, is_default, date_uploaded = api_avatar_url(share_from_user_email)
+
                     d['repo_name'] = repo.name
                     d['repo_id'] = repo.id
                     d['share_from_user_name'] = email2nickname(share_from_user_email)
@@ -85,7 +168,7 @@ def update_notice_detail(request, notices):
                 else:
                     d.pop('org_id', None)
                     share_from_user_email = d.pop('share_from')
-                    url, is_default, date_uploaded = api_avatar_url(share_from_user_email, 32)
+                    url, is_default, date_uploaded = api_avatar_url(share_from_user_email)
                     d['share_from_user_name'] = email2nickname(share_from_user_email)
                     d['share_from_user_email'] = share_from_user_email
                     d['share_from_user_contact_email'] = email2contact_email(share_from_user_email)
@@ -107,7 +190,7 @@ def update_notice_detail(request, notices):
                     notice.detail = None
                 else:
                     group_staff_email = d.pop('group_staff')
-                    url, is_default, date_uploaded = api_avatar_url(group_staff_email, 32)
+                    url, is_default, date_uploaded = api_avatar_url(group_staff_email)
                     d['group_staff_name'] = email2nickname(group_staff_email)
                     d['group_staff_email'] = group_staff_email
                     d['group_staff_contact_email'] = email2contact_email(group_staff_email)
@@ -122,7 +205,7 @@ def update_notice_detail(request, notices):
             try:
                 d = json.loads(notice.detail)
                 author_email = d.pop('author')
-                url, is_default, date_uploaded = api_avatar_url(author_email, 32)
+                url, is_default, date_uploaded = api_avatar_url(author_email)
                 d['author_name'] = email2nickname(author_email)
                 d['author_email'] = author_email
                 d['author_context_email'] = email2contact_email(author_email)
@@ -145,7 +228,7 @@ def update_notice_detail(request, notices):
                     d['transfer_from_user_name'] = email2nickname(repo_owner_email)
                     d['transfer_from_user_email'] = repo_owner_email
                     d['transfer_from_user_contact_email'] = email2contact_email(repo_owner_email)
-                    url, is_default, date_uploaded = api_avatar_url(repo_owner_email, 32)
+                    url, is_default, date_uploaded = api_avatar_url(repo_owner_email)
                     d['transfer_from_user_avatar_url'] = url
                     notice.detail = d
 
@@ -157,7 +240,7 @@ def update_notice_detail(request, notices):
                 d = json.loads(notice.detail)
                 d.pop('to_user', None)
                 request_user_email = d.pop('from_user')
-                url, is_default, date_uploaded = api_avatar_url(request_user_email, 32)
+                url, is_default, date_uploaded = api_avatar_url(request_user_email)
                 d['request_user_name'] = email2nickname(request_user_email)
                 d['request_user_email'] = request_user_email
                 d['request_user_contact_email'] = email2contact_email(request_user_email)
@@ -192,7 +275,42 @@ def update_notice_detail(request, notices):
                     d['folder_path'] = d.pop('uploaded_to')
                     d['folder_name'] = name
                     d['file_path'] = file_path
-                    url, is_default, date_uploaded = api_avatar_url('', 32)
+                    url, is_default, date_uploaded = api_avatar_url('')
+                    d['uploaded_user_avatar_url'] = url
+                    notice.detail = d
+                else:
+                    notice.detail = None
+
+            except Exception as e:
+                logger.error(e)
+
+        elif notice.is_folder_uploaded_msg():
+            try:
+                d = json.loads(notice.detail)
+                foldername = d['folder_name']
+                repo_id = d['repo_id']
+
+                if repo_id in repo_dict:
+                    repo = repo_dict[repo_id]
+                else:
+                    repo = seafile_api.get_repo(repo_id)
+                    repo_dict[repo_id] = repo
+
+                if repo:
+                    if d['uploaded_to'] == '/':
+                        # current upload path is '/'
+                        folder_path = '/' + foldername
+                        name = repo.name
+                    else:
+                        uploaded_to = d['uploaded_to'].rstrip('/')
+                        folder_path = uploaded_to + '/' + foldername
+                        name = os.path.basename(uploaded_to)
+
+                    d['repo_name'] = repo.name
+                    d['parent_dir_path'] = d.pop('uploaded_to')
+                    d['parent_dir_name'] = name
+                    d['folder_path'] = folder_path
+                    url, is_default, date_uploaded = api_avatar_url('')
                     d['uploaded_user_avatar_url'] = url
                     notice.detail = d
                 else:
@@ -219,7 +337,7 @@ def update_notice_detail(request, notices):
                 else:
                     author_email = d.pop('author')
                     file_name = os.path.basename(file_path)
-                    url, is_default, date_uploaded = api_avatar_url(author_email, 32)
+                    url, is_default, date_uploaded = api_avatar_url(author_email)
                     d['author_avatar_url'] = url
                     d['author_name'] = email2nickname(author_email)
                     d['author_email'] = author_email
@@ -241,7 +359,7 @@ def update_notice_detail(request, notices):
                     repo_dict[repo_id] = repo
 
                 op_user_email = d.pop('op_user')
-                url, is_default, date_uploaded = api_avatar_url(op_user_email, 32)
+                url, is_default, date_uploaded = api_avatar_url(op_user_email)
                 d['op_user_avatar_url'] = url
                 d['op_user_email'] = op_user_email
                 d['op_user_name'] = email2nickname(op_user_email)
@@ -268,6 +386,19 @@ def update_notice_detail(request, notices):
             except Exception as e:
                 logger.error(e)
 
+        elif notice.is_saml_sso_error_msg():
+            try:
+                d = json.loads(notice.detail)
+                notice.detail = d
+            except Exception as e:
+                logger.error(e)
+        elif notice.is_face_cluster_msg():
+            try:
+                d = json.loads(notice.detail)
+                notice.detail = d
+            except Exception as e:
+                logger.error(e)
+
     return notices
 
 
@@ -297,7 +428,7 @@ def format_sdoc_notice(sdoc_queryset, sdoc_notice, include_detail_link=False):
     if msg_type == 'comment':
         message = _("%(author)s added a new comment in document %(sdoc_name)s") % {
             'author': escape(email2nickname(author)),
-            'sdoc_name': sdoc_name,
+            'sdoc_name': escape(sdoc_name),
         }
         message = '%s "%s"' % (message, detail.get('comment', ''))
         if include_detail_link:
@@ -305,11 +436,21 @@ def format_sdoc_notice(sdoc_queryset, sdoc_notice, include_detail_link=False):
             message = '%s %s' % (message, add_a_element(_('Details'), sdoc_file_url))
 
     if msg_type == 'reply':
+        resolve_comment = detail.get('resolve_comment', None)
+        is_resolved = detail.get('is_resolved', None)
+        
         message = _("%(author)s added a new reply in document %(sdoc_name)s") % {
             'author': escape(email2nickname(author)),
-            'sdoc_name': sdoc_name,
+            'sdoc_name': escape(sdoc_name),
         }
         message = '%s "%s"' % (message, detail.get('reply', ''))
+        if is_resolved:
+            message = _('%(author)s has marked the comment "%(resolve_comment)s" as resolved in document %(sdoc_name)s\n') % {
+                'author': escape(email2nickname(author)),
+                'resolve_comment': escape(resolve_comment),
+                'sdoc_name': escape(sdoc_name),
+            }
+            
         if include_detail_link:
             sdoc_file_url = gen_sdoc_smart_link(sdoc_notice.doc_uuid)
             message = '%s %s' % (message, add_a_element(_('Details'), sdoc_file_url))
