@@ -27,6 +27,7 @@ def merge_roles(default, custom):
 DEFAULT_ENABLED_ROLE_PERMISSIONS = {
     DEFAULT_USER: {
         'can_add_repo': True,
+        'can_share_repo': True,
         'can_add_group': True,
         'can_view_org': True,
         'can_add_public_repo': False,
@@ -42,12 +43,17 @@ DEFAULT_ENABLED_ROLE_PERMISSIONS = {
         'can_export_files_via_mobile_client': True,
         'storage_ids': [],
         'role_quota': '',
-        'can_publish_repo': True,
+        'can_create_wiki': True,
+        'can_publish_wiki': True,
         'upload_rate_limit': 0,
         'download_rate_limit': 0,
+        'monthly_rate_limit': '',
+        'monthly_rate_limit_per_user': '',
+        'can_choose_office_suite': True,
     },
     GUEST_USER: {
         'can_add_repo': False,
+        'can_share_repo': False,
         'can_add_group': False,
         'can_view_org': False,
         'can_add_public_repo': False,
@@ -63,9 +69,13 @@ DEFAULT_ENABLED_ROLE_PERMISSIONS = {
         'can_export_files_via_mobile_client': False,
         'storage_ids': [],
         'role_quota': '',
-        'can_publish_repo': False,
+        'can_create_wiki': False,
+        'can_publish_wiki': False,
         'upload_rate_limit': 0,
         'download_rate_limit': 0,
+        'monthly_rate_limit': '',
+        'monthly_rate_limit_per_user': '',
+        'can_choose_office_suite': False,
     },
 }
 
