@@ -14,10 +14,11 @@ from django.utils import timezone
 from django.utils.translation import gettext_lazy as _
 from django.contrib.auth.hashers import check_password
 
+
 from seahub.signals import repo_deleted
 from seahub.base.fields import LowerCaseCharField
 from seahub.utils.hasher import AESPasswordHasher
-from seahub.utils import normalize_file_path, normalize_dir_path, gen_token,\
+from seahub.utils import normalize_file_path, normalize_dir_path, gen_token, \
     get_service_url, is_valid_org_id
 from seahub.constants import PERMISSION_READ, PERMISSION_ADMIN
 
@@ -71,6 +72,40 @@ def check_share_link_access(request, token, is_upload_link=False):
         return False
 
 
+def check_share_link_access_by_scope(request, sharelink):
+    from seahub.share.utils import SCOPE_ALL_USERS, SCOPE_SPECIFIC_EMAILS, SCOPE_SPECIFIC_USERS
+    scope = sharelink.user_scope
+    username = request.user.username
+    if sharelink.username == username:
+        return True
+    
+    if scope == SCOPE_ALL_USERS:
+        return True
+    
+    if scope == SCOPE_SPECIFIC_USERS:
+        try:
+            authed_details = json.loads(sharelink.authed_details)
+        except:
+            authed_details = {}
+
+        authed_users = authed_details.get('authed_users', [])
+        if username in authed_users:
+            return True
+        
+    if scope == SCOPE_SPECIFIC_EMAILS:
+        try:
+            authed_details = json.loads(sharelink.authed_details)
+        except:
+            authed_details = {}
+        
+        authed_emails = authed_details.get('authed_emails', [])
+        session_key = "link_authed_email_%s" % sharelink.token
+        email = request.session.get(session_key)
+        if email in authed_emails:
+            return True
+        
+    return False
+    
 def check_share_link_common(request, sharelink, is_upload_link=False):
     """Check if user can view a share link
     """
@@ -345,6 +380,9 @@ class FileShare(models.Model):
                                   choices=PERMISSION_CHOICES,
                                   default=PERM_VIEW_DL)
 
+    user_scope = models.CharField(max_length=255, default='all_users')
+    authed_details = models.TextField(default='')
+
     objects = FileShareManager()
 
     def is_file_share_link(self):
@@ -371,6 +409,14 @@ class FileShare(models.Model):
             return '%s/f/%s/' % (service_url, self.token)
         else:
             return '%s/d/%s/' % (service_url, self.token)
+    
+    @property   
+    def show_download_link(self):
+        if self.is_encrypted():
+            return False
+        if self.user_scope != 'all_users':
+            return False
+        return True
 
     def get_permissions(self):
         perm_dict = {}
@@ -378,22 +424,27 @@ class FileShare(models.Model):
             perm_dict['can_edit'] = False
             perm_dict['can_download'] = True
             perm_dict['can_upload'] = False
+            perm_dict['can_copy_content'] = True
         elif self.permission == FileShare.PERM_VIEW_ONLY:
             perm_dict['can_edit'] = False
             perm_dict['can_download'] = False
             perm_dict['can_upload'] = False
+            perm_dict['can_copy_content'] = False
         elif self.permission == FileShare.PERM_EDIT_DL:
             perm_dict['can_edit'] = True
             perm_dict['can_download'] = True
             perm_dict['can_upload'] = False
+            perm_dict['can_copy_content'] = True
         elif self.permission == FileShare.PERM_EDIT_ONLY:
             perm_dict['can_edit'] = True
             perm_dict['can_download'] = False
             perm_dict['can_upload'] = False
+            perm_dict['can_copy_content'] = False
         elif self.permission == FileShare.PERM_VIEW_DL_UPLOAD:
             perm_dict['can_edit'] = False
             perm_dict['can_download'] = True
             perm_dict['can_upload'] = True
+            perm_dict['can_copy_content'] = True
         else:
             assert False
         return perm_dict
