@@ -13,12 +13,13 @@ import tempfile
 import configparser
 import mimetypes
 import contextlib
+import json
 from datetime import datetime
 from urllib.parse import urlparse, urljoin
 
 from constance import config
 import seaserv
-from seaserv import seafile_api
+from seaserv import seafile_api, ccnet_api
 
 from django.urls import reverse
 from django.core.mail import EmailMessage
@@ -36,6 +37,9 @@ from seahub.api2.models import Token, TokenV2
 import seahub.settings
 from seahub.settings import MEDIA_URL, LOGO_PATH, \
         MEDIA_ROOT, CUSTOM_LOGO_PATH
+from seahub.constants import PERMISSION_READ_WRITE
+from seahub.utils.db_api import SeafileDB
+
 try:
     from seahub.settings import EVENTS_CONFIG_FILE
 except ImportError:
@@ -128,8 +132,8 @@ EMPTY_SHA1 = '0000000000000000000000000000000000000000'
 MAX_INT = 2147483647
 
 PREVIEW_FILEEXT = {
-    IMAGE: ('gif', 'jpeg', 'jpg', 'png', 'ico', 'bmp', 'tif', 'tiff', 'psd', 'webp'),
-    DOCUMENT: ('doc', 'docx', 'docxf', 'oform', 'ppt', 'pptx', 'odt', 'fodt', 'odp', 'fodp'),
+    IMAGE: ('gif', 'jpeg', 'jpg', 'png', 'heic', 'ico', 'bmp', 'tif', 'tiff', 'psd', 'webp', 'jfif'),
+    DOCUMENT: ('doc', 'docx', 'docxf', 'oform', 'ppt', 'pptx', 'odt', 'fodt', 'odp', 'fodp', 'odg'),
     SPREADSHEET: ('xls', 'xlsx', 'ods', 'fods'),
     SVG: ('svg',),
     PDF: ('pdf', 'ai'),
@@ -139,8 +143,17 @@ PREVIEW_FILEEXT = {
     #'3D': ('stl', 'obj'),
     XMIND: ('xmind',),
     SEADOC: ('sdoc',),
+    TLDRAW: ('draw',),
 }
 
+def get_non_sdoc_file_exts():
+    exts = []
+    for filetype in PREVIEW_FILEEXT.keys():
+        if filetype in [IMAGE, SEADOC]:
+            continue
+        exts.extend(list(PREVIEW_FILEEXT.get(filetype, [])))
+    return exts
+
 def gen_fileext_type_map():
     """
     Generate previewed file extension and file type relation map.
@@ -160,6 +173,7 @@ def render_permission_error(request, msg=None, extra_ctx=None):
 
     """
     ctx = {}
+    ctx['unable_view_file'] = msg == _('Unable to view file')
     ctx['error_msg'] = msg or _('permission error')
 
     if extra_ctx:
@@ -174,6 +188,7 @@ def render_error(request, msg=None, extra_ctx=None):
 
     """
     ctx = {}
+    ctx['unable_view_file'] = msg == _('Unable to view file')
     ctx['error_msg'] = msg or _('Internal Server Error')
 
     if extra_ctx:
@@ -195,7 +210,7 @@ def get_fileserver_root():
     Returns:
     	Constructed fileserver root.
     """
-    return config.FILE_SERVER_ROOT
+    return seahub.settings.FILE_SERVER_ROOT
 
 def get_inner_fileserver_root():
     """Construct inner seafile fileserver address and port.
@@ -298,6 +313,14 @@ def is_valid_username2(username):
 def is_valid_dirent_name(name):
     """Check whether repo/dir/file name is valid.
     """
+    for character in name:
+        # Emojis fall within the range \U0001F300 to \U0001FAD6
+        if 0x1F300 <= ord(character) <= 0x1FAD6:
+            return False
+    if name == '..':
+        return False
+    if '/' in name:
+        return False
     # `repo_id` parameter is not used in seafile api
     return seafile_api.is_valid_filename('fake_repo_id', name)
 
@@ -406,7 +429,7 @@ def get_conf_text_ext():
 
 def get_file_type_and_ext(filename):
     """
-    Return file type and extension if the file can be previewd online,
+    Return file type and extension if the file can be previewed online,
     otherwise, return unknown type.
     """
     fileExt = os.path.splitext(filename)[1][1:].lower()
@@ -529,6 +552,27 @@ def gen_file_get_url(token, filename):
     """
     return '%s/files/%s/%s' % (get_fileserver_root(), token, quote(filename))
 
+
+def gen_file_get_url_by_sharelink(token):
+    """
+    Generate fileserver file url by sharelink.
+    Format: http://<domain:port>/f/<token>/
+    """
+    return '%s/f/%s/' % (get_fileserver_root(), token)
+
+def gen_file_get_url_new(repo_id, filepath, op='download'):
+    """
+    Generate fileserver file url.
+    Format: http://<domain:port>/repos/<repo_id>files/<filepath>/?op=download
+    """
+
+    return '%s/repos/%s/files/%s/?op=%s' % (
+        get_fileserver_root(),
+        repo_id,
+        quote(filepath.strip('/')),
+        op
+    )
+
 def gen_file_upload_url(token, op, replace=False):
     url = '%s/%s/%s' % (get_fileserver_root(), op, token)
     if replace is True:
@@ -588,12 +632,16 @@ if EVENTS_CONFIG_FILE:
            session.close()
 
 
-    def _get_activities(username, start, count):
+    def _get_activities(username, start, count, op_user=None):
         ev_session = SeafEventsSession()
 
         events = []
         try:
-            events = seafevents_api.get_user_activities(ev_session,
+            if op_user:
+                events = seafevents_api.get_user_activities_by_op_user(ev_session,
+                    username, op_user, start, count)
+            else:
+                events = seafevents_api.get_user_activities(ev_session,
                     username, start, count)
         finally:
             ev_session.close()
@@ -601,14 +649,14 @@ if EVENTS_CONFIG_FILE:
         return events
 
 
-    def get_user_activities(username, start, count):
+    def get_user_activities(username, start, count, op_user=None):
         """Return user events list and a new start.
         For example:
         ``get_user_activities('foo@example.com', 0, 10)`` returns the first 10
         ``get_user_activities('foo@example.com', 4, 10)`` returns the 6th through
                  15th events.
         """
-        return _get_activities(username, start, count)
+        return _get_activities(username, start, count, op_user)
 
     def get_user_activity_stats_by_day(start, end, offset):
         """
@@ -637,7 +685,7 @@ if EVENTS_CONFIG_FILE:
         with _get_seafevents_session() as session:
             res = seafevents_api.get_file_history_by_day(session, repo_id, path, start, count, to_tz, history_limit)
         return res
-    
+
     def get_file_daily_history_detail(repo_id, path, start_time, end_time, to_tz):
         """Return file histories detail
         """
@@ -682,7 +730,7 @@ if EVENTS_CONFIG_FILE:
             events = seafevents_api.get_file_audit_events_by_path(session,
                 email, org_id, repo_id, file_path, start, limit)
 
-        return events if events else None
+        return events if events else []
 
     def get_file_audit_events(email, org_id, repo_id, start, limit):
         """Return file audit events list. (If no file audit, return 'None')
@@ -805,9 +853,19 @@ if EVENTS_CONFIG_FILE:
             res = seafevents_api.get_user_traffic_by_month(session, username, month)
         return res
 
+    def get_org_traffic_by_month(org_id, month):
+        with _get_seafevents_session() as session:
+            res = seafevents_api.get_org_traffic_by_month(session, org_id, month)
+        return res
+
     def get_file_history_suffix():
         return seafevents_api.get_file_history_suffix(parsed_events_conf)
 
+    def get_trash_records(repo_id, show_time, start, limit):
+        with _get_seafevents_session() as session:
+            res, total_count = seafevents_api.get_delete_records(session, repo_id, show_time, start, limit)
+        return res, total_count
+
 else:
     parsed_events_conf = None
     EVENTS_ENABLED = False
@@ -819,6 +877,8 @@ else:
         pass
     def get_user_traffic_by_month():
         pass
+    def get_org_traffic_by_month():
+        pass
     def get_user_activity_stats_by_day():
         pass
     def get_org_user_activity_stats_by_day():
@@ -869,6 +929,8 @@ else:
         pass
     def get_user_activities_by_timestamp():
         pass
+    def get_trash_records():
+        pass
 
 
 def calc_file_path_hash(path, bits=12):
@@ -876,13 +938,12 @@ def calc_file_path_hash(path, bits=12):
         path = path.encode('UTF-8')
 
     path_hash = hashlib.md5(urllib.parse.quote(path)).hexdigest()[:bits]
-
     return path_hash
 
 def get_service_url():
     """Get service url from seaserv.
     """
-    return config.SERVICE_URL
+    return seahub.settings.SERVICE_URL
 
 def get_webdav_url():
     """Get webdav url.
@@ -939,6 +1000,7 @@ def send_html_email(subject, con_template, con_context, from_email, to_email,
     """
 
     # get logo path
+    from seahub.utils.mail import SmimeEmailMessage
     logo_path = LOGO_PATH
     custom_logo_file = os.path.join(MEDIA_ROOT, CUSTOM_LOGO_PATH)
     if os.path.exists(custom_logo_file):
@@ -958,9 +1020,10 @@ def send_html_email(subject, con_template, con_context, from_email, to_email,
         if reply_to is not None:
             headers['Reply-to'] = reply_to
 
-    msg = EmailMessage(subject, t.render(con_context), from_email,
+    msg = SmimeEmailMessage(subject, t.render(con_context), from_email,
                        to_email, headers=headers)
     msg.content_subtype = "html"
+
     msg.send()
 
 def gen_dir_share_link(token):
@@ -1160,13 +1223,13 @@ if HAS_OFFICE_CONVERTER:
         try:
             add_office_convert_task(obj_id, doctype, raw_path)
         except Exception as e:
-            print(e)
             logging.exception('failed to add_office_convert_task: %s' % e)
             return _('Internal Server Error')
         return None
 
 # search realted
 HAS_FILE_SEARCH = False
+HAS_FILE_SEASEARCH = False
 if EVENTS_CONFIG_FILE:
     def check_search_enabled():
         enabled = False
@@ -1179,7 +1242,16 @@ if EVENTS_CONFIG_FILE:
                 logging.debug('search: not enabled')
         return enabled
 
+    def check_seasearch_enabled():
+        enabled = False
+        if hasattr(seafevents_api, 'is_seasearch_enabled'):
+            enabled = seafevents_api.is_seasearch_enabled(parsed_events_conf)
+        return enabled
+
     HAS_FILE_SEARCH = check_search_enabled()
+    HAS_FILE_SEASEARCH = check_seasearch_enabled()
+    if HAS_FILE_SEARCH and HAS_FILE_SEASEARCH:
+        raise Exception('ES and seasearch cannot be configured simultaneously.')
 
 # repo auto delete related
 ENABLE_REPO_AUTO_DEL = False
@@ -1196,27 +1268,6 @@ if EVENTS_CONFIG_FILE:
 
     ENABLE_REPO_AUTO_DEL = check_repo_auto_del_enabled()
 
-
-def is_user_password_strong(password):
-    """Return ``True`` if user's password is STRONG, otherwise ``False``.
-       STRONG means password has at least USER_PASSWORD_STRENGTH_LEVEL(3) types of the bellow:
-       num, upper letter, lower letter, other symbols
-    """
-
-    if len(password) < config.USER_PASSWORD_MIN_LENGTH:
-        return False
-    else:
-        num = 0
-        for letter in password:
-            # get ascii dec
-            # bitwise OR
-            num |= get_char_mode(ord(letter))
-
-        if calculate_bitwise(num) < config.USER_PASSWORD_STRENGTH_LEVEL:
-            return False
-        else:
-            return True
-
 def get_password_strength_level(password):
 
     num = 0
@@ -1275,6 +1326,38 @@ def clear_token(username):
     TokenV2.objects.filter(user = username).delete()
     seafile_api.delete_repo_tokens_by_email(username)
 
+
+def inactive_user(username):
+    # del tokens and personal repo api tokens (not department)
+    from seahub.repo_api_tokens.models import RepoAPITokens
+    try:
+        clear_token(username)
+    except Exception as e:
+        logger.error("Failed to delete tokens for user %s: %s." % (username, e))
+    try:
+        from seahub.settings import MULTI_TENANCY
+    except ImportError:
+        MULTI_TENANCY = False
+    try:
+        org_id = -1
+        if MULTI_TENANCY:
+            orgs = ccnet_api.get_orgs_by_user(username)
+            if orgs:
+                org = orgs[0]
+                org_id = org.org_id
+        if org_id > 0:
+            owned_repos = seafile_api.get_org_owned_repo_list(
+                org_id, username, ret_corrupted=True)
+        else:
+            owned_repos = seafile_api.get_owned_repo_list(
+                username, ret_corrupted=True)
+        owned_repo_ids = [item.repo_id for item in owned_repos]
+        RepoAPITokens.objects.filter(
+            repo_id__in=owned_repo_ids).delete()
+    except Exception as e:
+        logger.error("Failed to delete repo api tokens for user %s: %s." % (username, e))
+
+
 def send_perm_audit_msg(etype, from_user, to, repo_id, path, perm):
     """Send repo permission audit msg.
 
@@ -1286,15 +1369,34 @@ def send_perm_audit_msg(etype, from_user, to, repo_id, path, perm):
     - `path`: dir path
     - `perm`: r or rw
     """
-    msg = 'perm-change\t%s\t%s\t%s\t%s\t%s\t%s' % \
-        (etype, from_user, to, repo_id, path, perm)
+
+    msg = {
+        'msg_type': 'perm-change',
+        'etype': etype,
+        'from_user': from_user,
+        'to': to,
+        'repo_id': repo_id,
+        'file_path': path,
+        'perm': perm,
+    }
 
     try:
-        seafile_api.publish_event('seahub.audit', msg)
+        seafile_api.publish_event('seahub.audit', json.dumps(msg))
     except Exception as e:
         logger.error("Error when sending perm-audit-%s message: %s" %
                      (etype, str(e)))
 
+
+def send_user_login_msg(username, timestamp, org_id):
+    msg = {
+        'msg_type': 'user-login',
+        'user_name': username,
+        'timestamp': timestamp,
+        'org_id': org_id,
+    }
+    seafile_api.publish_event('seahub.stats', json.dumps(msg))
+
+
 def get_origin_repo_info(repo_id):
     repo = seafile_api.get_repo(repo_id)
     if repo.origin_repo_id is not None:
@@ -1387,3 +1489,82 @@ ASCII_RE = re.compile(r'[^\x00-\x7f]')
 def is_valid_password(password):
 
     return False if ASCII_RE.search(password) else True
+
+
+def get_logo_path_by_user(username):
+
+    logo_path = LOGO_PATH
+
+    # custom logo
+    custom_logo_file = os.path.join(MEDIA_ROOT, CUSTOM_LOGO_PATH)
+    if os.path.exists(custom_logo_file):
+        logo_path = CUSTOM_LOGO_PATH
+
+    # org custom logo
+    orgs = ccnet_api.get_orgs_by_user(username)
+    if orgs:
+
+        from seahub.organizations.settings import ORG_ENABLE_ADMIN_CUSTOM_LOGO
+        if ORG_ENABLE_ADMIN_CUSTOM_LOGO:
+
+            org = orgs[0]
+            from seahub.organizations.models import OrgAdminSettings
+            org_logo_url = OrgAdminSettings.objects.get_org_logo_url(org.org_id)
+
+            if org_logo_url:
+                logo_path = org_logo_url
+
+                from seahub.avatar.settings import AVATAR_FILE_STORAGE
+                if AVATAR_FILE_STORAGE == 'seahub.base.database_storage.DatabaseStorage':
+                    logo_path = "/image-view/" + logo_path
+
+    return logo_path
+
+
+def transfer_repo(repo_id, new_owner, is_share, org_id=None):
+    group_id = None
+    if "seafile_group" in new_owner:
+        group_id = int(new_owner.split('@')[0])
+    if type(is_share) is not bool:
+        if is_share == 'false':
+            is_share = False
+        else:
+            is_share = True
+    repo_owner = seafile_api.get_org_repo_owner(repo_id) if org_id else seafile_api.get_repo_owner(repo_id)
+    current_group_id = None
+    if "seafile_group" in repo_owner:
+        current_group_id = int(repo_owner.split('@')[0])
+    # transfer repo
+    # retain share
+    if is_share:
+        seafile_db_api = SeafileDB()
+        # transfer to group
+        if group_id:
+            if org_id and org_id != ccnet_api.get_org_id_by_group(group_id):
+                error_msg = 'Permission denied.'
+                raise error_msg
+            seafile_db_api.set_repo_group_owner(repo_id, group_id, current_group_id, org_id)
+        # transfer to user
+        else:
+            seafile_db_api.set_repo_owner(repo_id, new_owner, org_id)
+
+        # Update shares and delete the old owner's token
+        seafile_db_api.update_repo_user_shares(repo_id, new_owner, org_id)
+        seafile_db_api.update_repo_group_shares(repo_id, new_owner, org_id)
+        seafile_db_api.delete_repo_user_token(repo_id, repo_owner)
+    else:
+        if org_id:
+            if group_id:
+                # org transfer check,only transfer current org repo
+                if org_id != ccnet_api.get_org_id_by_group(group_id):
+                    error_msg = 'Permission denied.'
+                    raise error_msg
+                seafile_api.org_transfer_repo_to_group(repo_id, org_id, group_id, PERMISSION_READ_WRITE)
+            else:
+                seafile_api.set_org_repo_owner(org_id, repo_id, new_owner)
+        else:
+            if group_id:
+                seafile_api.transfer_repo_to_group(repo_id, group_id, PERMISSION_READ_WRITE)
+            else:
+                seafile_api.set_repo_owner(repo_id, new_owner)
+
