@@ -10,7 +10,9 @@ AUDIO = 'Audio'
 SPREADSHEET = 'SpreadSheet'
 XMIND = 'XMind'
 SEADOC = 'SDoc'
+TLDRAW = 'Tldraw'
 
 
 MARKDOWN_SUPPORT_CONVERT_TYPES = ['sdoc']
-SDOC_SUPPORT_CONVERT_TYPES = ['markdown']
+DOCX_SUPPORT_CONVERT_TYPES = ['sdoc']
+SDOC_SUPPORT_CONVERT_TYPES = ['markdown', 'docx']
