@@ -1,28 +1,29 @@
 # Copyright (c) 2012-2016 Seafile Ltd.
 # encoding: utf-8
-import hashlib
 import os
 import stat
 import json
-import mimetypes
+import hashlib
 import logging
+import mimetypes
 import posixpath
+from constance import config
+from urllib.parse import quote
 
 from django.core.cache import cache
-from django.urls import reverse, resolve
 from django.contrib import messages
-from django.http import HttpResponse, Http404, \
-    HttpResponseRedirect
-from django.shortcuts import render, redirect
-from urllib.parse import quote
 from django.utils.html import escape
+from django.urls import reverse, resolve
+from django.shortcuts import render, redirect
 from django.utils.translation import gettext as _
 from django.views.decorators.http import condition
+from django.http import HttpResponse, Http404, \
+    HttpResponseRedirect
 
 import seaserv
 from seaserv import get_repo, get_commits, \
     seafserv_threaded_rpc, is_repo_owner, \
-    get_file_size, seafile_api
+    get_file_size, seafile_api, ccnet_api
 from pysearpc import SearpcError
 
 from seahub.avatar.util import get_avatar_file_storage
@@ -41,41 +42,42 @@ from seahub.utils import render_permission_error, render_error, \
     gen_shared_upload_link, is_org_context, \
     gen_dir_share_link, gen_file_share_link, get_file_type_and_ext, \
     get_user_repos, EMPTY_SHA1, gen_file_get_url, \
-    new_merge_with_no_conflict, get_max_upload_file_size, \
+    new_merge_with_no_conflict, \
     is_pro_version, FILE_AUDIT_ENABLED, is_valid_dirent_name, \
     is_windows_operating_system, get_file_history_suffix, IS_EMAIL_CONFIGURED, \
-    normalize_file_path
+    normalize_file_path, normalize_dir_path
 from seahub.utils.star import get_dir_starred_files
-from seahub.utils.repo import get_library_storages, parse_repo_perm
+from seahub.utils.repo import get_library_storages, parse_repo_perm, is_repo_admin
 from seahub.utils.file_op import check_file_lock
 from seahub.utils.timeutils import utc_to_local
 from seahub.utils.auth import get_login_bg_image_path
 import seahub.settings as settings
 from seahub.settings import AVATAR_FILE_STORAGE, ENABLE_REPO_SNAPSHOT_LABEL, \
-    UNREAD_NOTIFICATIONS_REQUEST_INTERVAL, SHARE_LINK_EXPIRE_DAYS_MIN, \
+    SHARE_LINK_EXPIRE_DAYS_MIN, ENABLE_METADATA_MANAGEMENT, \
     SHARE_LINK_EXPIRE_DAYS_MAX, SHARE_LINK_EXPIRE_DAYS_DEFAULT, \
     UPLOAD_LINK_EXPIRE_DAYS_MIN, UPLOAD_LINK_EXPIRE_DAYS_MAX, UPLOAD_LINK_EXPIRE_DAYS_DEFAULT, \
-    SEAFILE_COLLAB_SERVER, ENABLE_RESET_ENCRYPTED_REPO_PASSWORD, \
-    ADDITIONAL_SHARE_DIALOG_NOTE, ADDITIONAL_APP_BOTTOM_LINKS, ADDITIONAL_ABOUT_DIALOG_LINKS, \
-    DTABLE_WEB_SERVER, EX_PROPS_TABLE, SEATABLE_EX_PROPS_BASE_API_TOKEN, EX_EDITABLE_COLUMNS
+    ENABLE_RESET_ENCRYPTED_REPO_PASSWORD, \
+    ADDITIONAL_SHARE_DIALOG_NOTE, ADDITIONAL_ABOUT_DIALOG_LINKS, \
+    SEADOC_SERVER_URL, SHOW_WECHAT_SUPPORT_GROUP
 
-from seahub.wopi.settings import ENABLE_OFFICE_WEB_APP
 from seahub.ocm.settings import ENABLE_OCM, OCM_REMOTE_SERVERS
 from seahub.ocm_via_webdav.settings import ENABLE_OCM_VIA_WEBDAV
-from seahub.constants import HASH_URLS, PERMISSION_READ
+from seahub.constants import PERMISSION_READ
 from seahub.group.settings import GROUP_IMPORT_MEMBERS_EXTRA_MSG
 
 from seahub.weixin.settings import ENABLE_WEIXIN
 from seahub.onlyoffice.settings import ONLYOFFICE_DESKTOP_EDITOR_HTTP_USER_AGENT
 
+from seahub.organizations.models import OrgAdminSettings, DISABLE_ORG_USER_CLEAN_TRASH, DISABLE_ORG_ENCRYPTED_LIBRARY
+
 LIBRARY_TEMPLATES = getattr(settings, 'LIBRARY_TEMPLATES', {})
 CUSTOM_NAV_ITEMS = getattr(settings, 'CUSTOM_NAV_ITEMS', '')
 
-from constance import config
 
 # Get an instance of a logger
 logger = logging.getLogger(__name__)
 
+
 def validate_owner(request, repo_id):
     """
     Check whether user in the request owns the repo.
@@ -85,6 +87,7 @@ def validate_owner(request, repo_id):
 
     return True if ret else False
 
+
 def is_registered_user(email):
     """
     Check whether user is registerd.
@@ -97,6 +100,7 @@ def is_registered_user(email):
 
     return True if user else False
 
+
 _default_repo_id = None
 def get_system_default_repo_id():
     global _default_repo_id
@@ -107,6 +111,7 @@ def get_system_default_repo_id():
             logger.error(e)
     return _default_repo_id
 
+
 def check_folder_permission(request, repo_id, path):
     """Check repo/folder/file access permission of a user.
 
@@ -289,170 +294,29 @@ def get_unencry_rw_repos_by_user(request):
 
     return accessible_repos
 
-def render_recycle_root(request, repo_id, referer):
-    repo = get_repo(repo_id)
-    if not repo:
-        raise Http404
-
-    return render(request, 'repo_dir_recycle_view.html', {
-            'show_recycle_root': True,
-            'repo': repo,
-            'repo_dir_name': repo.name,
-            'enable_clean': config.ENABLE_USER_CLEAN_TRASH,
-            'referer': referer,
-            })
-
-def render_recycle_dir(request, repo_id, commit_id, referer):
-    basedir = request.GET.get('base', '')
-    path = request.GET.get('p', '')
-    if not basedir or not path:
-        return render_recycle_root(request, repo_id)
-
-    if basedir[0] != '/':
-        basedir = '/' + basedir
-    if path[-1] != '/':
-        path += '/'
-
-    repo = get_repo(repo_id)
-    if not repo:
-        raise Http404
-
-    try:
-        commit = seafserv_threaded_rpc.get_commit(repo.id, repo.version, commit_id)
-    except SearpcError as e:
-        logger.error(e)
-        referer = request.headers.get('referer', None)
-        next_page = settings.SITE_ROOT if referer is None else referer
-        return HttpResponseRedirect(next_page)
-
-    if not commit:
-        raise Http404
-
-    zipped = gen_path_link(path, '')
-
-    dir_entries = seafile_api.list_dir_by_commit_and_path(commit.repo_id,
-                                                   commit.id, basedir+path,
-                                                   -1, -1)
-    for dirent in dir_entries:
-        if stat.S_ISDIR(dirent.mode):
-            dirent.is_dir = True
-        else:
-            dirent.is_dir = False
-
-    return render(request, 'repo_dir_recycle_view.html', {
-            'show_recycle_root': False,
-            'repo': repo,
-            'repo_dir_name': repo.name,
-            'zipped': zipped,
-            'dir_entries': dir_entries,
-            'commit_id': commit_id,
-            'basedir': basedir,
-            'path': path,
-            'referer': referer,
-            })
-
-def render_dir_recycle_root(request, repo_id, dir_path, referer):
-    repo = get_repo(repo_id)
-    if not repo:
-        raise Http404
-
-    return render(request, 'repo_dir_recycle_view.html', {
-            'show_recycle_root': True,
-            'repo': repo,
-            'repo_dir_name': os.path.basename(dir_path.rstrip('/')),
-            'dir_path': dir_path,
-            'referer': referer,
-            })
-
-def render_dir_recycle_dir(request, repo_id, commit_id, dir_path, referer):
-    basedir = request.GET.get('base', '')
-    path = request.GET.get('p', '')
-    if not basedir or not path:
-        return render_dir_recycle_root(request, repo_id, dir_path)
-
-    if basedir[0] != '/':
-        basedir = '/' + basedir
-    if path[-1] != '/':
-        path += '/'
-
-    repo = get_repo(repo_id)
-    if not repo:
-        raise Http404
-
-    try :
-        commit = seafserv_threaded_rpc.get_commit(repo.id, repo.version, commit_id)
-    except SearpcError as e:
-        logger.error(e)
-        referer = request.headers.get('referer', None)
-        next_page = settings.SITE_ROOT if referer is None else referer
-        return HttpResponseRedirect(next_page)
-
-    if not commit:
-        raise Http404
-
-    zipped = gen_path_link(path, '')
-    dir_entries = seafile_api.list_dir_by_commit_and_path(commit.repo_id,
-                                                   commit.id, basedir+path,
-                                                   -1, -1)
-    for dirent in dir_entries:
-        if stat.S_ISDIR(dirent.mode):
-            dirent.is_dir = True
-        else:
-            dirent.is_dir = False
-
-    return render(request, 'repo_dir_recycle_view.html', {
-            'show_recycle_root': False,
-            'repo': repo,
-            'repo_dir_name': os.path.basename(dir_path.rstrip('/')),
-            'zipped': zipped,
-            'dir_entries': dir_entries,
-            'commit_id': commit_id,
-            'basedir': basedir,
-            'path': path,
-            'dir_path': dir_path,
-            'referer': referer,
-            })
-
-@login_required
-def repo_recycle_view(request, repo_id):
-    if not seafile_api.get_dir_id_by_path(repo_id, '/') or \
-        check_folder_permission(request, repo_id, '/') != 'rw':
-        return render_permission_error(request, _('Unable to view recycle page'))
-
-    commit_id = request.GET.get('commit_id', '')
-    referer = request.GET.get('referer', '') # for back to 'dir view' page
-    if not commit_id:
-        return render_recycle_root(request, repo_id, referer)
-    else:
-        return render_recycle_dir(request, repo_id, commit_id, referer)
-
-@login_required
-def dir_recycle_view(request, repo_id):
-    dir_path = request.GET.get('dir_path', '')
-
-    if not seafile_api.get_dir_id_by_path(repo_id, dir_path) or \
-        check_folder_permission(request, repo_id, dir_path) != 'rw':
-        return render_permission_error(request, _('Unable to view recycle page'))
-
-    commit_id = request.GET.get('commit_id', '')
-    referer = request.GET.get('referer', '') # for back to 'dir view' page
-    if not commit_id:
-        return render_dir_recycle_root(request, repo_id, dir_path, referer)
-    else:
-        return render_dir_recycle_dir(request, repo_id, commit_id, dir_path, referer)
 
 @login_required
 def repo_folder_trash(request, repo_id):
     path = request.GET.get('path', '/')
+    username = request.user.username
 
     if not seafile_api.get_dir_id_by_path(repo_id, path) or \
-        check_folder_permission(request, repo_id, path) != 'rw':
+            check_folder_permission(request, repo_id, path) != 'rw':
         return render_permission_error(request, _('Unable to view recycle page'))
 
     repo = get_repo(repo_id)
     if not repo:
         raise Http404
 
+    repo_admin = is_repo_admin(username, repo_id)
+    org_setting = None
+    if is_org_context(request):
+        org_id = request.user.org.org_id
+        org_setting = OrgAdminSettings.objects.filter(org_id=org_id, key=DISABLE_ORG_USER_CLEAN_TRASH).first()
+    enable_clean_trash = config.ENABLE_USER_CLEAN_TRASH
+    if enable_clean_trash:
+        enable_clean_trash = int(not org_setting.value) if org_setting else True
+
     if path == '/':
         name = repo.name
     else:
@@ -462,7 +326,8 @@ def repo_folder_trash(request, repo_id):
             'repo': repo,
             'repo_folder_name': name,
             'path': path,
-            'enable_clean': config.ENABLE_USER_CLEAN_TRASH,
+            'enable_user_clean_trash': enable_clean_trash,
+            'is_repo_admin': repo_admin
             })
 
 def can_access_repo_setting(request, repo_id, username):
@@ -525,7 +390,7 @@ def repo_history(request, repo_id):
         current_page = 1
 
     per_page = 100
-    commits_all = get_commits(repo_id, per_page * (current_page -1),
+    commits_all = get_commits(repo_id, per_page * (current_page - 1),
                               per_page + 1)
     commits = commits_all[:per_page]
     for c in commits:
@@ -550,7 +415,6 @@ def repo_history(request, repo_id):
     # for 'go back'
     referer = request.GET.get('referer', '')
 
-    #template = 'repo_history.html'
     template = 'repo_history_react.html'
 
     return render(request, template, {
@@ -707,6 +571,7 @@ def create_default_library(request):
     UserOptions.objects.set_default_repo(username, default_repo)
     return default_repo
 
+
 def get_owned_repo_list(request):
     """List owned repos.
     """
@@ -726,10 +591,11 @@ def repo_set_access_property(request, repo_id):
 
     return HttpResponseRedirect(reverse_url)
 
+
 @login_required
 def validate_filename(request):
-    repo_id     = request.GET.get('repo_id')
-    filename    = request.GET.get('filename')
+    repo_id = request.GET.get('repo_id')
+    filename = request.GET.get('filename')
 
     if not (repo_id and filename):
         return render_error(request)
@@ -798,6 +664,7 @@ def file_revisions(request, repo_id):
 
     if file_type == 'sdoc':
         file_uuid = get_seadoc_file_uuid(repo, path)
+        from seahub.seadoc.utils import gen_seadoc_access_token
         return render(request, 'sdoc_file_revisions.html', {
             'repo': repo,
             'path': path,
@@ -807,7 +674,9 @@ def file_revisions(request, repo_id):
             'is_owner': is_owner,
             'can_compare': can_compare,
             'can_revert_file': can_revert_file,
-            'assets_url': '/api/v2.1/seadoc/download-image/' + file_uuid
+            'assets_url': '/api/v2.1/seadoc/download-image/' + file_uuid,
+            'seadoc_access_token': gen_seadoc_access_token(file_uuid, u_filename, username, permission='rw'),
+            'seadoc_server_url' : SEADOC_SERVER_URL
         })
 
     # Whether use new file history API which read file history from db.
@@ -1058,6 +927,7 @@ def convert_cmmt_desc_link(request):
 
     raise Http404
 
+
 storage = get_avatar_file_storage()
 def latest_entry(request, filename):
     try:
@@ -1066,6 +936,7 @@ def latest_entry(request, filename):
         logger.error(e)
         return None
 
+
 @condition(last_modified_func=latest_entry)
 def image_view(request, filename):
     if AVATAR_FILE_STORAGE is None:
@@ -1156,12 +1027,21 @@ def react_fake_view(request, **kwargs):
 
         repo_id = kwargs.get('repo_id', '')
         repo_name = kwargs.get('repo_name', '')
-        path = kwargs.get('path', '')
-        if repo_id and repo_name and not path:
-            path = '/'
+        if not repo_id or not repo_name:
+            raise Http404
 
-        if repo_id and path and \
-                not check_folder_permission(request, repo_id, path):
+        repo = seafile_api.get_repo(repo_id)
+        if not repo:
+            error_msg = f'Library {repo_id} not found.'
+            return render_error(request, error_msg)
+
+        path = kwargs.get('path', '/')
+        path = normalize_dir_path(path)
+        if path != '/' and not seafile_api.get_dirent_by_path(repo_id, path):
+            error_msg = f'Dirent {path} not found.'
+            return render_error(request, error_msg)
+
+        if not check_folder_permission(request, repo_id, path):
 
             converted_repo_path = seafile_api.convert_repo_path(repo_id, path, username)
             if not converted_repo_path:
@@ -1177,8 +1057,8 @@ def react_fake_view(request, **kwargs):
                 return render_error(request, error_msg)
 
             converted_path = repo_path_dict['path']
-            if converted_path != '/' and not seafile_api.get_dirent_by_path(converted_repo_id, converted_path):
-
+            if converted_path != '/' and \
+                    not seafile_api.get_dirent_by_path(converted_repo_id, converted_path):
                 error_msg = 'Dirent %s not found.' % converted_path
                 return render_error(request, error_msg)
 
@@ -1196,23 +1076,42 @@ def react_fake_view(request, **kwargs):
         create_default_library(request)
 
     try:
-        expire_days = seafile_api.get_server_config_int('library_trash', 'expire_days')
+        expire_days = seafile_api.get_server_config_int('library_trash',
+                                                        'expire_days')
     except Exception as e:
         logger.error(e)
         expire_days = -1
 
     try:
-        max_upload_file_size = seafile_api.get_server_config_int('fileserver', 'max_upload_size')
+        max_upload_file_size = seafile_api.get_server_config_int('fileserver',
+                                                                 'max_upload_size')
     except Exception as e:
         logger.error(e)
         max_upload_file_size = -1
 
-    return render(request, "react_app.html", {
+    org_setting = {
+        DISABLE_ORG_ENCRYPTED_LIBRARY: False,
+        DISABLE_ORG_USER_CLEAN_TRASH: False
+    }
+    if is_org_context(request):
+        org_id = request.user.org.org_id
+        if org_id and org_id > 0:
+            org_configs = OrgAdminSettings.objects.filter(org_id=org_id)
+            org_configs = {item.key: item.value for item in org_configs}
+            for key, value in org_setting.items():
+                if key in org_configs:
+                    org_setting[key] = int(org_configs[key])
+
+    enable_encryped_lib, enable_clean_trash = config.ENABLE_ENCRYPTED_LIBRARY, config.ENABLE_USER_CLEAN_TRASH
+    if enable_encryped_lib:
+        enable_encryped_lib = int(not org_setting[DISABLE_ORG_ENCRYPTED_LIBRARY])
+    if enable_clean_trash:
+        enable_clean_trash = int(not org_setting[DISABLE_ORG_USER_CLEAN_TRASH])
+
+    return_dict = {
         "guide_enabled": guide_enabled,
         'trash_repos_expire_days': expire_days if expire_days > 0 else 30,
-        'dtable_web_server': DTABLE_WEB_SERVER,
         'max_upload_file_size': max_upload_file_size,
-        'seafile_collab_server': SEAFILE_COLLAB_SERVER,
         'storages': get_library_storages(request),
         'library_templates': list(LIBRARY_TEMPLATES.keys()),
         'enable_repo_snapshot_label': settings.ENABLE_REPO_SNAPSHOT_LABEL,
@@ -1224,26 +1123,37 @@ def react_fake_view(request, **kwargs):
         'upload_link_expire_days_default': UPLOAD_LINK_EXPIRE_DAYS_DEFAULT,
         'upload_link_expire_days_min': UPLOAD_LINK_EXPIRE_DAYS_MIN,
         'upload_link_expire_days_max': UPLOAD_LINK_EXPIRE_DAYS_MAX,
-        'enable_encrypted_library': config.ENABLE_ENCRYPTED_LIBRARY,
+        'enable_encrypted_library': enable_encryped_lib,
         'enable_repo_history_setting': config.ENABLE_REPO_HISTORY_SETTING,
+        'enable_user_clean_trash': enable_clean_trash,
         'enable_reset_encrypted_repo_password': ENABLE_RESET_ENCRYPTED_REPO_PASSWORD,
-        'enableFileComment': settings.ENABLE_FILE_COMMENT,
         'is_email_configured': IS_EMAIL_CONFIGURED,
         'can_add_public_repo': request.user.permissions.can_add_public_repo(),
         'folder_perm_enabled': is_pro_version(),
         'file_audit_enabled': FILE_AUDIT_ENABLED,
         'custom_nav_items': json.dumps(CUSTOM_NAV_ITEMS),
         'enable_show_contact_email_when_search_user': settings.ENABLE_SHOW_CONTACT_EMAIL_WHEN_SEARCH_USER,
+        'enable_show_login_id_when_search_user': settings.ENABLE_SHOW_LOGIN_ID_WHEN_SEARCH_USER,
         'additional_share_dialog_note': ADDITIONAL_SHARE_DIALOG_NOTE,
-        'additional_app_bottom_links': ADDITIONAL_APP_BOTTOM_LINKS,
         'additional_about_dialog_links': ADDITIONAL_ABOUT_DIALOG_LINKS,
         'enable_ocm_via_webdav': ENABLE_OCM_VIA_WEBDAV,
         'enable_ocm': ENABLE_OCM,
         'ocm_remote_servers': OCM_REMOTE_SERVERS,
+        'show_wechat_support_group': SHOW_WECHAT_SUPPORT_GROUP,
         'enable_share_to_department': settings.ENABLE_SHARE_TO_DEPARTMENT,
         'enable_video_thumbnail': settings.ENABLE_VIDEO_THUMBNAIL,
+        'enable_pdf_thumbnail': settings.ENABLE_PDF_THUMBNAIL,
         'group_import_members_extra_msg': GROUP_IMPORT_MEMBERS_EXTRA_MSG,
         'request_from_onlyoffice_desktop_editor': ONLYOFFICE_DESKTOP_EDITOR_HTTP_USER_AGENT in request.headers.get('user-agent', ''),
         'enable_sso_to_thirdpart_website': settings.ENABLE_SSO_TO_THIRDPART_WEBSITE,
-        'can_set_ex_props': DTABLE_WEB_SERVER and SEATABLE_EX_PROPS_BASE_API_TOKEN and EX_PROPS_TABLE and EX_EDITABLE_COLUMNS
-    })
+        'enable_metadata_management': ENABLE_METADATA_MANAGEMENT,
+        'enable_file_tags': settings.ENABLE_FILE_TAGS,
+        'enable_show_about': settings.ENABLE_SHOW_ABOUT
+    }
+
+    if ENABLE_METADATA_MANAGEMENT:
+        return_dict['baidu_map_key'] = settings.BAIDU_MAP_KEY
+        return_dict['google_map_key'] = settings.GOOGLE_MAP_KEY
+        return_dict['google_map_id'] = settings.GOOGLE_MAP_ID
+    
+    return render(request, "react_app.html", return_dict)
