@@ -19,19 +19,20 @@ from seahub.options.models import UserOptions, CryptoOptionNotSetError
 from seahub.share.decorators import share_link_audit, share_link_login_required
 from seahub.share.models import FileShare, UploadLinkShare, \
     check_share_link_common
+from seahub.share.utils import check_share_link_user_access
 from seahub.views import gen_path_link, get_repo_dirents, \
     check_folder_permission
 
 from seahub.utils import gen_dir_share_link, \
     gen_shared_upload_link, render_error, \
-    get_file_type_and_ext, get_service_url, normalize_dir_path
+    get_file_type_and_ext, get_service_url, normalize_dir_path, redirect_to_login
 from seahub.utils.repo import is_repo_owner, get_repo_owner
 from seahub.settings import ENABLE_UPLOAD_FOLDER, \
     ENABLE_RESUMABLE_FILEUPLOAD, ENABLE_VIDEO_THUMBNAIL, \
     THUMBNAIL_ROOT, THUMBNAIL_DEFAULT_SIZE, THUMBNAIL_SIZE_FOR_GRID, \
     MAX_NUMBER_OF_FILES_FOR_FILEUPLOAD, SHARE_LINK_EXPIRE_DAYS_MIN, \
-    SHARE_LINK_EXPIRE_DAYS_MAX, SEAFILE_COLLAB_SERVER, \
-    ENABLE_SHARE_LINK_REPORT_ABUSE
+    SHARE_LINK_EXPIRE_DAYS_MAX, \
+    ENABLE_SHARE_LINK_REPORT_ABUSE, ENABLE_PDF_THUMBNAIL
 from seahub.utils.file_types import IMAGE, VIDEO, XMIND
 from seahub.thumbnail.utils import get_share_link_thumbnail_src
 from seahub.group.utils import is_group_admin
@@ -69,15 +70,6 @@ def is_no_quota(repo_id):
     return True if seaserv.check_quota(repo_id) < 0 else False
 
 
-def get_fileshare(repo_id, username, path):
-    if path == '/':    # no shared link for root dir
-        return None
-
-    share_list = FileShare.objects.filter(repo_id=repo_id).filter(
-        username=username).filter(path=path)
-    return share_list[0] if len(share_list) > 0 else None
-
-
 def get_dir_share_link(fileshare):
     # dir shared link
     if fileshare:
@@ -243,7 +235,6 @@ def view_lib_as_wiki(request, repo_id, path):
         user_can_write = False
 
     return render(request, 'view_lib_as_wiki.html', {
-        'seafile_collab_server': SEAFILE_COLLAB_SERVER,
         'repo_id': repo_id,
         'service_url': get_service_url().rstrip('/'),
         'initial_path': path,
@@ -261,6 +252,11 @@ def view_lib_as_wiki(request, repo_id, path):
 def view_shared_dir(request, fileshare):
 
     token = fileshare.token
+    if not check_share_link_user_access(fileshare, request.user.username):
+        if not request.user.username:
+            return redirect_to_login(request)
+        error_msg = _('Permission denied')
+        return render_error(request, error_msg)
 
     password_check_passed, err_msg = check_share_link_common(request, fileshare)
     if not password_check_passed:
@@ -341,31 +337,45 @@ def view_shared_dir(request, fileshare):
     # for 'upload file'
     no_quota = True if seaserv.check_quota(repo_id) < 0 else False
 
+    try:
+        max_upload_file_size = seafile_api.get_server_config_int('fileserver', 'max_upload_size')
+    except Exception as e:
+        logger.error(e)
+        max_upload_file_size = -1
+
     template = 'view_shared_dir_react.html'
 
     dir_share_link = request.path
     desc_for_ogp = _('Share link for %s.') % dir_name
 
-    return render(request, template, {
-            'repo': repo,
-            'token': token,
-            'path': req_path,
-            'username': username,
-            'dir_name': dir_name,
-            'dir_path': real_path,
-            'file_list': file_list,
-            'dir_list': dir_list,
-            'zipped': zipped,
-            'traffic_over_limit': False,
-            'no_quota': no_quota,
-            'permissions': permissions,
-            'mode': mode,
-            'thumbnail_size': thumbnail_size,
-            'dir_share_link': dir_share_link,
-            'desc_for_ogp': desc_for_ogp,
-            'enable_share_link_report_abuse': ENABLE_SHARE_LINK_REPORT_ABUSE,
-            'enable_video_thumbnail': ENABLE_VIDEO_THUMBNAIL,
-            })
+    data = {
+        'repo': repo,
+        'token': token,
+        'path': req_path,
+        'username': username,
+        'dir_name': dir_name,
+        'dir_path': real_path,
+        'file_list': file_list,
+        'dir_list': dir_list,
+        'zipped': zipped,
+        'traffic_over_limit': False,
+        'max_upload_file_size': max_upload_file_size,
+        'no_quota': no_quota,
+        'permissions': permissions,
+        'mode': mode,
+        'thumbnail_size': thumbnail_size,
+        'dir_share_link': dir_share_link,
+        'desc_for_ogp': desc_for_ogp,
+        'enable_share_link_report_abuse': ENABLE_SHARE_LINK_REPORT_ABUSE,
+        'enable_video_thumbnail': ENABLE_VIDEO_THUMBNAIL,
+        'enable_pdf_thumbnail': ENABLE_PDF_THUMBNAIL,
+    }
+
+    if not request.user.is_authenticated:
+        from seahub.utils import get_logo_path_by_user
+        data['logo_path'] = get_logo_path_by_user(fileshare.username)
+
+    return render(request, template, data)
 
 
 @share_link_audit
@@ -397,7 +407,7 @@ def view_shared_upload_link(request, uploadlink):
         raise Http404
 
     if repo.encrypted or \
-            seafile_api.check_permission_by_path(repo_id, '/', username) != 'rw':
+            seafile_api.check_permission_by_path(repo_id, path, username) != 'rw':
         return render_error(request, _('Permission denied'))
 
     uploadlink.view_cnt = F('view_cnt') + 1
@@ -411,15 +421,21 @@ def view_shared_upload_link(request, uploadlink):
         logger.error(e)
         max_upload_file_size = -1
 
-    return render(request, 'view_shared_upload_link_react.html', {
-            'repo': repo,
-            'path': path,
-            'username': username,
-            'dir_name': dir_name,
-            'max_upload_file_size': max_upload_file_size,
-            'no_quota': no_quota,
-            'uploadlink': uploadlink,
-            'enable_upload_folder': ENABLE_UPLOAD_FOLDER,
-            'enable_resumable_fileupload': ENABLE_RESUMABLE_FILEUPLOAD,
-            'max_number_of_files_for_fileupload': MAX_NUMBER_OF_FILES_FOR_FILEUPLOAD,
-            })
+    data = {
+        'repo': repo,
+        'path': path,
+        'username': username,
+        'dir_name': dir_name,
+        'max_upload_file_size': max_upload_file_size,
+        'no_quota': no_quota,
+        'uploadlink': uploadlink,
+        'enable_upload_folder': ENABLE_UPLOAD_FOLDER,
+        'enable_resumable_fileupload': ENABLE_RESUMABLE_FILEUPLOAD,
+        'max_number_of_files_for_fileupload': MAX_NUMBER_OF_FILES_FOR_FILEUPLOAD,
+    }
+
+    if not request.user.is_authenticated:
+        from seahub.utils import get_logo_path_by_user
+        data['logo_path'] = get_logo_path_by_user(uploadlink.username)
+
+    return render(request, 'view_shared_upload_link_react.html', data)
