@@ -21,6 +21,8 @@ from seahub.utils import render_permission_error, render_error
 from seahub.api2.utils import get_token_v1, get_token_v2
 from seahub.settings import CLIENT_SSO_VIA_LOCAL_BROWSER, CLIENT_SSO_TOKEN_EXPIRATION, LOGIN_URL
 from seahub.base.models import ClientSSOToken
+from seahub.work_weixin.settings import ENABLE_WORK_WEIXIN
+from seahub.dingtalk.settings import ENABLE_DINGTALK
 
 # Get an instance of a logger
 logger = logging.getLogger(__name__)
@@ -48,25 +50,62 @@ def sso(request):
         return HttpResponseRedirect(next_page)
 
     # send next page back to other views
-    next_param = '?%s=' % REDIRECT_FIELD_NAME + quote(next_page)
+    next_param = f'?{REDIRECT_FIELD_NAME}={quote(next_page)}'
     if getattr(settings, 'ENABLE_ADFS_LOGIN', False):
         return HttpResponseRedirect(reverse('saml2_login') + next_param)
 
     if getattr(settings, 'ENABLE_OAUTH', False):
         return HttpResponseRedirect(reverse('oauth_login') + next_param)
 
-    if getattr(settings, 'ENABLE_DINGTALK', False):
-        return HttpResponseRedirect(reverse('dingtalk_login') + next_param)
+    if getattr(settings, 'ENABLE_CUSTOM_OAUTH', False):
+        return HttpResponseRedirect(reverse('oauth_login') + next_param)
 
     if getattr(settings, 'ENABLE_CAS', False):
         return HttpResponseRedirect(reverse('cas_ng_login') + next_param)
 
-    if getattr(settings, 'ENABLE_WORK_WEIXIN', False):
-        return HttpResponseRedirect(reverse('work_weixin_oauth_login') + next_param)
-
     return HttpResponseRedirect(next_page)
 
 
+def work_weixin_sso(request):
+
+    if not ENABLE_WORK_WEIXIN:
+        error_msg = '企业微信单点登录功能未开启'
+        return render_error(request, error_msg)
+
+    request.session['is_sso_user'] = True
+
+    # Ensure the user-originating redirection url is safe.
+    if REDIRECT_FIELD_NAME in request.GET:
+        next_page = request.GET[REDIRECT_FIELD_NAME]
+        if not url_has_allowed_host_and_scheme(url=next_page, allowed_hosts=request.get_host()):
+            next_page = settings.LOGIN_REDIRECT_URL
+    else:
+        next_page = reverse('libraries')
+
+    next_param = f'?{REDIRECT_FIELD_NAME}={quote(next_page)}'
+    return HttpResponseRedirect(reverse('work_weixin_oauth_login') + next_param)
+
+
+def dingtalk_sso(request):
+
+    if not ENABLE_DINGTALK:
+        error_msg = '钉钉单点登录功能未开启'
+        return render_error(request, error_msg)
+
+    request.session['is_sso_user'] = True
+
+    # Ensure the user-originating redirection url is safe.
+    if REDIRECT_FIELD_NAME in request.GET:
+        next_page = request.GET[REDIRECT_FIELD_NAME]
+        if not url_has_allowed_host_and_scheme(url=next_page, allowed_hosts=request.get_host()):
+            next_page = settings.LOGIN_REDIRECT_URL
+    else:
+        next_page = reverse('libraries')
+
+    next_param = f'?{REDIRECT_FIELD_NAME}={quote(next_page)}'
+    return HttpResponseRedirect(reverse('dingtalk_login') + next_param)
+
+
 def jwt_sso(request):
 
     ENABLE_JWT_SSO = getattr(settings, 'ENABLE_JWT_SSO', False)
@@ -196,6 +235,7 @@ def client_sso_complete(request, token):
         else:
             logger.warning('Client SSO token is not waiting, skip.')
 
-        return HttpResponseRedirect(reverse('libraries'))
+        template_name = 'client_login_complete.html'
+        return render(request, template_name, {})
     else:
         return render_permission_error(request, _('Permission denied.'))
