@@ -39,6 +39,7 @@ from seahub.utils.ldap import get_ldap_info
 from seahub.utils.licenseparse import parse_license
 from seahub.utils.ms_excel import write_xls
 from seahub.utils.repo import get_related_users_by_repo, get_repo_owner
+from seahub.utils.auth import get_login_bg_image_path
 from seahub.views import get_system_default_repo_id
 from seahub.forms import SetUserQuotaForm, AddUserForm
 from seahub.options.models import UserOptions
@@ -297,8 +298,7 @@ def user_set_quota(request, email):
                 org_id = org[0].org_id
                 org_quota_mb = seafserv_threaded_rpc.get_org_quota(org_id) / get_file_size_unit('MB')
                 if space_quota_mb > org_quota_mb:
-                    result['error'] = _('Failed to set quota: maximum quota is %d MB' % \
-                                            org_quota_mb)
+                    result['error'] = 'Failed to set quota: maximum quota is %d MB' % org_quota_mb
                     return HttpResponse(json.dumps(result), status=400, content_type=content_type)
                 else:
                     seafile_api.set_org_user_quota(org_id, email, space_quota)
@@ -816,7 +816,7 @@ def sys_sudo_mode(request):
         if password:
             user = authenticate(username=username, password=password)
             # After local user authentication process is completed, authenticate LDAP user
-            if user is None and settings.ENABLE_LDAP:
+            if user is None and settings.ENABLE_LDAP and not settings.USE_LDAP_SYNC_ONLY:
                 user = authenticate(ldap_user=username, password=password)
             if user:
                 update_sudo_mode_ts(request)
@@ -839,11 +839,13 @@ def sys_sudo_mode(request):
 
     enable_shib_login = getattr(settings, 'ENABLE_SHIB_LOGIN', False)
     enable_adfs_login = getattr(settings, 'ENABLE_ADFS_LOGIN', False)
+    login_bg_image_path = get_login_bg_image_path()
     return render(request,
         'sysadmin/sudo_mode.html', {
             'password_error': password_error,
             'enable_sso': enable_shib_login or enable_adfs_login,
             'next': next_page,
+            'login_bg_image_path': login_bg_image_path,
         })
 
 @login_required_ajax
