@@ -1,19 +1,18 @@
 from mock import patch
-from seaserv import ccnet_api
 
 from seahub.test_utils import BaseTestCase
 from seahub.api2.serializers import AuthTokenSerializer
 from seahub.profile.models import Profile
 
+
 class AuthTokenSerializerTest(BaseTestCase):
+
     def setUp(self):
         self.inactive_user = self.create_user('inactive@test.com', is_active=False)
         Profile.objects.add_or_update(self.user.username,
                                       login_id='user_login_id',
                                       contact_email='contact@test.com')
 
-        ccnet_api.set_reference_id(self.user.username, 'another_email@test.com')
-
     def assertSuccess(self, s):
         assert s.is_valid() is True
         assert s.errors == {}
@@ -91,7 +90,8 @@ class AuthTokenSerializerTest(BaseTestCase):
         }
 
         s = AuthTokenSerializer(data=d, context={'request': self.fake_request})
-        self.assertFailed(s)
+        assert s.is_valid() is False
+        assert 'User account is disabled.' in s.errors['non_field_errors']
 
     def test_login_failed(self):
         d = {
