@@ -12,7 +12,7 @@ TEST_CAN_ADD_PUBLICK_REPO_TRUE = copy.deepcopy(ENABLED_ROLE_PERMISSIONS)
 TEST_CAN_ADD_PUBLICK_REPO_TRUE['default']['can_add_public_repo'] = True
 
 TEST_PUBLISH_REPO_CAN_PUBLISH_REPO_FALSE = copy.deepcopy(ENABLED_ROLE_PERMISSIONS)
-TEST_PUBLISH_REPO_CAN_PUBLISH_REPO_FALSE['default']['can_publish_repo'] = False
+TEST_PUBLISH_REPO_CAN_PUBLISH_REPO_FALSE['default']['can_create_wiki'] = False
 
 CLOUD_MODE_TRUE = True
 MULTI_TENANCY_TRUE = True
@@ -85,20 +85,20 @@ class UserPermissionsTest(BaseTestCase):
 
     def test_can_publish_repo_permission(self):
         # enableWIKI = True, and can_publish_repo = True
-        assert self.user.permissions._get_perm_by_roles('can_publish_repo') is True
-        assert self.user.permissions.can_publish_repo() is True
+        assert self.user.permissions._get_perm_by_roles('can_create_wiki') is True
+        assert self.user.permissions.can_create_wiki() is True
 
     @override_settings(ENABLE_WIKI=False)
     def test_can_publish_repo_permission_with_enable_wiki_False(self):
         # enableWIKI = False, and can_publish_repo = True
-        assert self.user.permissions._get_perm_by_roles('can_publish_repo') is True
-        assert self.user.permissions.can_publish_repo() is False
+        assert self.user.permissions._get_perm_by_roles('can_create_wiki') is True
+        assert self.user.permissions.can_create_wiki() is False
 
     def test_can_publish_repo_permission_with_can_publish_repo_False(self):
         # enableWIKI = True, and can_publish_repo = False
         with patch('seahub.role_permissions.utils.ENABLED_ROLE_PERMISSIONS', TEST_PUBLISH_REPO_CAN_PUBLISH_REPO_FALSE):
-            assert self.user.permissions._get_perm_by_roles('can_publish_repo') is False
-            assert self.user.permissions.can_publish_repo() is False
+            assert self.user.permissions._get_perm_by_roles('can_create_wiki') is False
+            assert self.user.permissions.can_create_wiki() is False
 
 
 class RegistrationFormTest(BaseTestCase):
@@ -129,7 +129,7 @@ class RegistrationFormTest(BaseTestCase):
 
     def test_clean_email(self):
         form = self.form_class({'email': 'some_random_user@1.com',
-                                'password1': '123',
-                                'password2': '123'})
+                                'password1': 'Seafile123',
+                                'password2': 'Seafile123'})
         assert form.is_valid() is True
         assert form.clean_email() == 'some_random_user@1.com'
