@@ -8,6 +8,8 @@ from sqlalchemy import select
 
 from seafobj.exceptions import InvalidConfigError
 from seafobj.backends.filesystem import SeafObjStoreFS
+from seafobj.mc import get_mc_cache
+from seafobj.redis_cache import get_redis_cache
 
 def get_ceph_conf(cfg, section):
     config_file = cfg.get(section, 'ceph_config')
@@ -23,10 +25,10 @@ def get_ceph_conf(cfg, section):
 def get_ceph_conf_from_json(cfg):
     config_file = cfg['ceph_config']
     pool_name = cfg['pool']
-    ceph_client_id = None
+    ceph_client_id = ''
 
     if 'ceph_client_id' in cfg:
-        host = cfg['ceph_client_id']
+        ceph_client_id = cfg['ceph_client_id']
 
     from seafobj.backends.ceph import CephConf
     conf = CephConf(config_file, pool_name, ceph_client_id)
@@ -58,8 +60,6 @@ def get_s3_conf(cfg, section):
     aws_region = None
     if cfg.has_option(section, 'aws_region'):
         aws_region = cfg.get(section, 'aws_region')
-    if not host and not aws_region:
-        raise InvalidConfigError('aws_region and host are not configured')
 
     use_https = False
     if cfg.has_option(section, 'use_https'):
@@ -69,8 +69,13 @@ def get_s3_conf(cfg, section):
     if cfg.has_option(section, 'path_style_request'):
         path_style_request = cfg.getboolean(section, 'path_style_request')
 
-    from seafobj.backends.s3 import S3Conf
-    conf = S3Conf(key_id, key, bucket, host, port, use_v4_sig, aws_region, use_https, path_style_request)
+    sse_c_key = None
+    if cfg.has_option(section, 'sse_c_key'):
+        sse_c_key = cfg.get(section, 'sse_c_key')
+
+
+    from objwrapper.s3 import S3Conf
+    conf = S3Conf(key_id, key, bucket, host, port, use_v4_sig, aws_region, use_https, path_style_request, sse_c_key)
 
     return conf
 
@@ -99,8 +104,6 @@ def get_s3_conf_from_json(cfg):
     aws_region = None
     if 'aws_region' in cfg:
         aws_region = cfg['aws_region']
-    if not host and not aws_region:
-        raise InvalidConfigError('aws_region and host are not configured')
 
     use_https = False
     if 'use_https' in cfg:
@@ -111,8 +114,12 @@ def get_s3_conf_from_json(cfg):
     if 'path_style_request' in cfg:
         path_style_request = cfg['path_style_request']
 
-    from seafobj.backends.s3 import S3Conf
-    conf = S3Conf(key_id, key, bucket, host, port, use_v4_sig, aws_region, use_https, path_style_request)
+    sse_c_key = None
+    if 'sse_c_key' in cfg:
+        sse_c_key = cfg['sse_c_key']
+
+    from objwrapper.s3 import S3Conf
+    conf = S3Conf(key_id, key, bucket, host, port, use_v4_sig, aws_region, use_https, path_style_request, sse_c_key)
 
     return conf
 
@@ -123,14 +130,16 @@ def get_oss_conf(cfg, section):
     endpoint = ''
     if cfg.has_option(section, 'endpoint'):
         endpoint = cfg.get(section, 'endpoint')
-    if not endpoint:
+    region = ''
+    if cfg.has_option(section, 'region'):
         region = cfg.get(section, 'region')
-        endpoint = 'oss-cn-%s-internal.aliyuncs.com' % region
 
-    host = endpoint
+    use_https = False
+    if cfg.has_option(section, 'use_https'):
+        use_https = cfg.getboolean(section, 'use_https')
 
-    from seafobj.backends.alioss import OSSConf
-    conf = OSSConf(key_id, key, bucket, host)
+    from objwrapper.alioss import OSSConf
+    conf = OSSConf(key_id, key, bucket, endpoint, region, use_https)
 
     return conf
 
@@ -143,14 +152,17 @@ def get_oss_conf_from_json(cfg):
 
     if 'endpoint' in cfg:
         endpoint = cfg['endpoint']
-    if not endpoint:
+    region = ''
+    if 'region' in cfg:
         region = cfg['region']
-        endpoint = 'oss-cn-%s-internal.aliyuncs.com' % region
 
-    host = endpoint
+    use_https = False
+    if 'use_https' in cfg:
+        if str(cfg['use_https']).lower().strip() == 'true':
+            use_https = True
 
-    from seafobj.backends.alioss import OSSConf
-    conf = OSSConf(key_id, key, bucket, host)
+    from objwrapper.alioss import OSSConf
+    conf = OSSConf(key_id, key, bucket, endpoint, region, use_https)
 
     return conf
 
@@ -258,6 +270,31 @@ class SeafileConfig(object):
             return os.path.join(self.seafile_conf_dir, 'storage')
         raise RuntimeError('environment SEAFILE_CONF_DIR not set correctly.');
 
+    def get_seaf_cache(self):
+        if self.cfg.has_option('redis', 'redis_host'):
+            host = self.cfg.get('redis', 'redis_host')
+            if self.cfg.has_option('redis', 'redis_port'):
+                port = self.cfg.get('redis', 'redis_port')
+            else:
+                port = 6379
+            if self.cfg.has_option('redis', 'redis_expiry'):
+                expiry = self.cfg.get('redis', 'redis_expiry')
+            else:
+                expiry = 24 * 3600
+            if self.cfg.has_option('redis', 'max_connections'):
+                max_connections = self.cfg.get('redis', 'max_connections')
+            else:
+                max_connections = 20
+            return get_redis_cache(host, port, expiry, int(max_connections))
+
+        if self.cfg.has_option('memcached', 'memcached_options'):
+            mc_options = self.cfg.get('memcached', 'memcached_options')
+            return get_mc_cache(mc_options)
+        return None
+
+# You must ensure that the SeafObjStoreFactory is created in the main thread.
+# If you're using a high-level wrapper like SeafCommitManager or SeafFSManager, it will automatically be created in the main thread.
+
 class SeafObjStoreFactory(object):
     obj_section_map = {
         'blocks': 'block_backend',
@@ -297,6 +334,9 @@ class SeafObjStoreFactory(object):
 
             crypto = self.seafile_cfg.get_seaf_crypto()
             compressed = obj_type == 'fs'
+            cache = None
+            if obj_type != 'blocks':
+                cache = self.seafile_cfg.get_seaf_cache()
 
             if bend[obj_type]['backend'] == 'fs':
                 obj_dir = os.path.join(bend[obj_type]['dir'], 'storage', obj_type)
@@ -304,19 +344,19 @@ class SeafObjStoreFactory(object):
             elif bend[obj_type]['backend'] == 'swift':
                 from seafobj.backends.swift import SeafObjStoreSwift
                 swift_conf = get_swift_conf_from_json(bend[obj_type])
-                self.obj_stores[obj_type][storage_id] = SeafObjStoreSwift(compressed, swift_conf, crypto)
+                self.obj_stores[obj_type][storage_id] = SeafObjStoreSwift(compressed, swift_conf, crypto, cache)
             elif bend[obj_type]['backend'] == 's3':
                 from seafobj.backends.s3 import SeafObjStoreS3
                 s3_conf = get_s3_conf_from_json(bend[obj_type])
-                self.obj_stores[obj_type][storage_id] = SeafObjStoreS3(compressed, s3_conf, crypto)
+                self.obj_stores[obj_type][storage_id] = SeafObjStoreS3(compressed, s3_conf, crypto, cache)
             elif bend[obj_type]['backend'] == 'ceph':
                 from seafobj.backends.ceph import SeafObjStoreCeph
                 ceph_conf = get_ceph_conf_from_json(bend[obj_type])
-                self.obj_stores[obj_type][storage_id] = SeafObjStoreCeph(compressed, ceph_conf, crypto)
+                self.obj_stores[obj_type][storage_id] = SeafObjStoreCeph(compressed, ceph_conf, crypto, cache)
             elif bend[obj_type]['backend'] == 'oss':
                 from seafobj.backends.alioss import SeafObjStoreOSS
                 oss_conf = get_oss_conf_from_json(bend[obj_type])
-                self.obj_stores[obj_type][storage_id] = SeafObjStoreOSS(compressed, oss_conf, crypto)
+                self.obj_stores[obj_type][storage_id] = SeafObjStoreOSS(compressed, oss_conf, crypto, cache)
             else:
                 raise InvalidConfigError('Unknown backend type: %s.' % bend[obj_type]['backend'])
 
@@ -336,6 +376,9 @@ class SeafObjStoreFactory(object):
             raise RuntimeError('unknown obj_type ' + obj_type)
 
         crypto = self.seafile_cfg.get_seaf_crypto()
+        cache = None
+        if obj_type != 'blocks':
+            cache = self.seafile_cfg.get_seaf_cache()
 
         if cfg.has_option(section, 'name'):
             backend_name = cfg.get(section, 'name')
@@ -361,24 +404,24 @@ class SeafObjStoreFactory(object):
             # not using s3
             from seafobj.backends.s3 import SeafObjStoreS3
             s3_conf = get_s3_conf(cfg, section)
-            return SeafObjStoreS3(compressed, s3_conf, crypto)
+            return SeafObjStoreS3(compressed, s3_conf, crypto, cache)
 
         elif backend_name == 'ceph':
             # We import ceph backend here to avoid depenedency on rados for
             # users not using rados
             from seafobj.backends.ceph import SeafObjStoreCeph
             ceph_conf = get_ceph_conf(cfg, section)
-            return SeafObjStoreCeph(compressed, ceph_conf, crypto)
+            return SeafObjStoreCeph(compressed, ceph_conf, crypto, cache)
 
         elif backend_name == 'oss':
             from seafobj.backends.alioss import SeafObjStoreOSS
             oss_conf = get_oss_conf(cfg, section)
-            return SeafObjStoreOSS(compressed, oss_conf, crypto)
+            return SeafObjStoreOSS(compressed, oss_conf, crypto, cache)
 
         elif backend_name == 'swift':
             from seafobj.backends.swift import SeafObjStoreSwift
             swift_conf = get_swift_conf(cfg, section)
-            return SeafObjStoreSwift(compressed, swift_conf, crypto)
+            return SeafObjStoreSwift(compressed, swift_conf, crypto, cache)
 
         else:
             raise InvalidConfigError('unknown %s backend "%s"' % (obj_type, backend_name))
