@@ -1,6 +1,6 @@
 import hashlib
 import base64
-import seahub_settings
+import seahub.settings as seahub_settings
 from seaserv import ccnet_api as api
 from wsgidav.dc.seaf_utils import multi_tenancy_enabled
 from wsgidav.dc import seahub_db
@@ -66,7 +66,7 @@ class SeafileDomainController(BaseDomainController):
                 if session:
                     profile_profile = seahub_db.Base.classes.profile_profile
                     q = session.query(profile_profile.user) \
-                               .filter(profile_profile.contact_email == username)
+                               .filter((profile_profile.contact_email == username) | (profile_profile.login_id == username))
                     res = q.first()
                     if res:
                         ccnet_email = res[0]
@@ -83,19 +83,21 @@ class SeafileDomainController(BaseDomainController):
             if session and enableTwoFactorAuth(session, ccnet_email):
                 enable_two_factor_auth = True
 
-            if not enable_webdav_secret and enable_two_factor_auth:
-                _logger.warning("Two factor auth is enabled, no access to webdav.")
-                return False
-            elif enable_webdav_secret and enable_two_factor_auth:
-                if not validateSecret(session, password, ccnet_email):
-                    return False
-            elif not enable_webdav_secret and not enable_two_factor_auth:
-                if api.validate_emailuser(ccnet_email, password) != 0:
+            if enable_two_factor_auth:
+                if not enable_webdav_secret:
+                    _logger.warning("Two factor auth is enabled, no access to webdav.")
                     return False
+                else:
+                    if not validate_secret(session, ccnet_email, password):
+                        return False
             else:
-                if not validateSecret(session, password, ccnet_email) and \
-                        api.validate_emailuser(ccnet_email, password) != 0:
-                    return False
+                if not enable_webdav_secret:
+                    if api.validate_emailuser(ccnet_email, password) != 0:
+                        return False
+                else:
+                    if api.validate_emailuser(ccnet_email, password) != 0 and \
+                            not validate_secret(session, ccnet_email, password):
+                        return False
 
             username = ccnet_email
         except Exception as e:
@@ -128,7 +130,7 @@ class SeafileDomainController(BaseDomainController):
         return True
 
 
-def validateSecret(session, password, ccnet_email):
+def validate_secret(session, ccnet_email, password):
 
     if not session:
         return False
