@@ -346,7 +346,7 @@ def _read_config_file(config_file, _verbose):
     config_file = os.path.abspath(config_file)
 
     if not os.path.exists(config_file):
-        raise RuntimeError(f"Couldn't open configuration file '{config_file}'.")
+        raise RuntimeError(f"Couldn't open configuration file {config_file!r}.")
 
     if config_file.endswith(".json"):
         with open(config_file, mode="rt", encoding="utf-8-sig") as fp:
@@ -527,9 +527,10 @@ def _run_cheroot(app, config, _server):
         _logger.error("Try `pip install cheroot`.")
         return False
 
-    version = wsgi.Server.version
-    version = f"WsgiDAV/{__version__} {version} Python {util.PYTHON_VERSION}"
-    wsgi.Server.version = version
+    version = (
+        f"WsgiDAV/{__version__} {wsgi.Server.version} Python/{util.PYTHON_VERSION}"
+    )
+    # wsgi.Server.version = version
 
     info = _get_common_info(config)
 
@@ -598,38 +599,6 @@ def _run_ext_wsgiutils(app, config, _server):
     return
 
 
-# def _run_flup(app, config, server):
-#     """Run WsgiDAV using flup.server.fcgi (http://trac.saddi.com/flup/wiki/FlupServers)."""
-#     try:
-#         if server == "flup-fcgi":
-#             from flup.server.fcgi import WSGIServer
-#             from flup.server.fcgi import __version__ as flupver
-#         elif server == "flup-fcgi-fork":
-#             from flup.server.fcgi_fork import WSGIServer
-#             from flup.server.fcgi_fork import __version__ as flupver
-#         else:
-#             raise ValueError
-#     except ImportError:
-#         _logger.exception(f"Could not import {server} (https://gunicorn.org).")
-#         _logger.error("Try `pip install flup`.")
-#         return False
-
-#     version = f"{WSGIServer.__module__}/{flupver}"
-#     version = f"WsgiDAV/{__version__} {version} Python {util.PYTHON_VERSION}"
-#     _logger.info(f"Running {version} ...")
-
-#     server = WSGIServer(
-#         app,
-#         bindAddress=(config["host"], config["port"]),
-#         # debug=True,
-#     )
-#     try:
-#         server.run()
-#     except KeyboardInterrupt:
-#         _logger.warning("Caught Ctrl-C, shutting down...")
-#     return
-
-
 def _run_gevent(app, config, server):
     """Run WsgiDAV using gevent if gevent (https://www.gevent.org).
 
@@ -727,7 +696,7 @@ def _run_gunicorn(app, config, server):
     # See https://docs.gunicorn.org/en/latest/settings.html
     server_args = {
         "bind": "{}:{}".format(config["host"], config["port"]),
-        'workers': config.get('workers'),
+        'threads': config.get('workers'),
         "timeout": config.get('timeout'),
         "pidfile": config.get('pidfile'),
     }
@@ -873,10 +842,7 @@ def _run_wsgiref(app, config, _server):
 
 SUPPORTED_SERVERS = {
     "cheroot": _run_cheroot,
-    # "cherrypy": _run__cherrypy,
     "ext-wsgiutils": _run_ext_wsgiutils,
-    # "flup-fcgi_fork": _run_flup,
-    # "flup-fcgi": _run_flup,
     "gevent": _run_gevent,
     "gunicorn": _run_gunicorn,
     "paste": _run_paste,
@@ -888,7 +854,8 @@ SUPPORTED_SERVERS = {
 def run():
     cli_opts, config = _init_config()
 
-    util.init_logging(config)
+    # util.init_logging(config) # now handled in constructor:
+    config["logging"]["enable"] = True
 
     info = _get_common_info(config)
 
